#delimit ;
pause off ;
set more off ; 

local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;

log using /disk/agedisk3/oebb.work/cbehrer/oregon/log/cleaning/0_11trimvariables_`cdate'_`ctime'.log ;

/* Project:     Oregon Health Plan Choice Analysis                                	*/;
/* Program:     miscellaneus cleaning                                             	*/;
/* Author:      Chris Behrer (christopher_behrer@post.harvard.edu)        			*/;
/* Dates:               													*/;
/* 		Created:        4/29/2015                                 				*/;
/*		Modified:       09/23/2016                         						*/;

/* 0) Specify filepaths as locals                                                 	*/;

local dir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/3devoid/" ;

use "`dir'/facilityNEW_devoid_04_Mar_2016.dta", clear ; 
drop adjustcd proc_surg ; 
drop chargeamt customcode empcode conditioncd servicedetaildt discount diseasecd eligtag fullinsured hsa_amt hra_amt ;
drop lifestylecd netpayment netpayment_detail pcpresp relation security srvccount datasource thirdptyamt ; 
drop codingsys diagnosis6 - diagnosis9 ;
drop empstatus ;
cap drop srvccat; 
drop absamt abscopay abscharge voidamt void minvoid hasvoid voidsrvcdt sign ;
drop sex ; 

	*** keep medical claims  ;
	keep if covtypcd == 1;
	drop covtypcd ;
	
	rename paiddt paiddt_s;
	gen paiddt=date(paiddt_s, "MDY");
	format paiddt %d; drop paiddt_s;
	
	gen first_srvcdt = date(firstsrvcdt, "MDY") ;
	format first_srvcdt %td ; 
	
	gen last_srvcdt = date(lastsrvcdt, "MDY") ;
	format last_srvcdt %td ; 
	
	replace familyid = trim(familyid) ;
	
	gen 	lastplanyear = 2008 if last_srvcdt >= mdy(10,1,2008) & last_srvcdt <= mdy(9,30,2009) ;
	replace lastplanyear = 2009 if last_srvcdt >= mdy(10,1,2009) & last_srvcdt <= mdy(9,30,2010) ;
	replace lastplanyear = 2010 if last_srvcdt >= mdy(10,1,2010) & last_srvcdt <= mdy(9,30,2011) ;
	replace lastplanyear = 2011 if last_srvcdt >= mdy(10,1,2011) & last_srvcdt <= mdy(9,30,2012) ; 
	replace lastplanyear = 2012 if last_srvcdt >= mdy(10,1,2012) & last_srvcdt <= mdy(9,30,2013) ; 
	replace lastplanyear = 2013 if last_srvcdt >= mdy(10,1,2013) & last_srvcdt <= mdy(9,30,2014) ; 
	replace lastplanyear = 2014 if last_srvcdt >= mdy(10,1,2014) & last_srvcdt <= mdy(9,30,2015) ; 
                                   
	replace lastplanyear = 2007 if last_srvcdt < mdy(10,1,2008) ; 
	replace lastplanyear = 2015 if last_srvcdt > mdy(9,30,2015) ;
	
	gen 	firstplanyear = 2008 if first_srvcdt >= mdy(10,1,2008) & first_srvcdt <= mdy(9,30,2009) ;
	replace firstplanyear = 2009 if first_srvcdt >= mdy(10,1,2009) & first_srvcdt <= mdy(9,30,2010) ;
	replace firstplanyear = 2010 if first_srvcdt >= mdy(10,1,2010) & first_srvcdt <= mdy(9,30,2011) ;
	replace firstplanyear = 2011 if first_srvcdt >= mdy(10,1,2011) & first_srvcdt <= mdy(9,30,2012) ; 
	replace firstplanyear = 2012 if first_srvcdt >= mdy(10,1,2012) & first_srvcdt <= mdy(9,30,2013) ; 
	replace firstplanyear = 2013 if first_srvcdt >= mdy(10,1,2013) & first_srvcdt <= mdy(9,30,2014) ; 
	replace firstplanyear = 2014 if first_srvcdt >= mdy(10,1,2014) & first_srvcdt <= mdy(9,30,2015) ; 
                                    
	replace firstplanyear = 2007 if first_srvcdt < mdy(10,1,2008) ; 
	replace firstplanyear = 2015 if first_srvcdt > mdy(9,30,2015) ;
	
	tab lastplanyear ;
	tab firstplanyear ; 
	
	* if early is still 2014 or last is 2007, then we definitely do no include ; 
	drop if firstplanyear == 2014 ; 
	drop if lastplanyear == lastplanyear == 2007 ;
	
	tab firstplanyear lastplanyear ; 

	tab plan firstplanyear ; 
	tab plan lastplanyear ; 
	
	* based on this tabulation, using first_srvcdt to make plan years minimizes the number of claims in ; 
	* plan year * plan combinations that do not exist, e.g. it minimizes 2010 claims in KMED2 and PMED1 ; 
	drop last_srvcdt ; 
	drop lastplanyear ; 
	
	rename first_srvcdt srvcdt ; 
	rename firstplanyear planyear ; 
		
	rename copay origcopay;
	rename deductible origded;
	rename coinsurance origcoin;

	tab plan ; 
describe , fullnames ; 
save "`dir'/facility_trimmed_23_Sep_2016.dta", replace ;

use "`dir'/professional_devoid_04_Mar_2016.dta", clear ; 
drop adjustcd proc_surg ; 
drop chargeamt customcode empcode conditioncd discount diseasecd eligtag fullinsured hsa_amt hra_amt ;
drop lifestylecd netpayment pcpresp relation security srvccount datasource thirdptyamt ; 
drop codingsys diagnosis6 - diagnosis9 ;
drop empstatus ;
cap drop srvccat; 
drop absamt abscopay abscharge void minvoid hasvoid ;
drop sex ; 
	
	*** keep medical claims  ;
	keep if covtypcd == 1;
	drop covtypcd ;
	
	rename paiddt paiddt_s;
	gen paiddt=date(paiddt_s, "MDY");
	format paiddt %d; drop paiddt_s;
	
	gen first_srvcdt = date(firstsrvcdt, "MDY") ;
	format first_srvcdt %td ; 
	
	gen last_srvcdt = date(lastsrvcdt, "MDY") ;
	format last_srvcdt %td ; 
	
	replace familyid = trim(familyid) ;
	
	gen 	lastplanyear = 2008 if last_srvcdt >= mdy(10,1,2008) & last_srvcdt <= mdy(9,30,2009) ;
	replace lastplanyear = 2009 if last_srvcdt >= mdy(10,1,2009) & last_srvcdt <= mdy(9,30,2010) ;
	replace lastplanyear = 2010 if last_srvcdt >= mdy(10,1,2010) & last_srvcdt <= mdy(9,30,2011) ;
	replace lastplanyear = 2011 if last_srvcdt >= mdy(10,1,2011) & last_srvcdt <= mdy(9,30,2012) ; 
	replace lastplanyear = 2012 if last_srvcdt >= mdy(10,1,2012) & last_srvcdt <= mdy(9,30,2013) ; 
	replace lastplanyear = 2013 if last_srvcdt >= mdy(10,1,2013) & last_srvcdt <= mdy(9,30,2014) ; 
	replace lastplanyear = 2014 if last_srvcdt >= mdy(10,1,2014) & last_srvcdt <= mdy(9,30,2015) ; 
                                   
	replace lastplanyear = 2007 if last_srvcdt < mdy(10,1,2008) ; 
	replace lastplanyear = 2015 if last_srvcdt > mdy(9,30,2015) ;
	
	gen 	firstplanyear = 2008 if first_srvcdt >= mdy(10,1,2008) & first_srvcdt <= mdy(9,30,2009) ;
	replace firstplanyear = 2009 if first_srvcdt >= mdy(10,1,2009) & first_srvcdt <= mdy(9,30,2010) ;
	replace firstplanyear = 2010 if first_srvcdt >= mdy(10,1,2010) & first_srvcdt <= mdy(9,30,2011) ;
	replace firstplanyear = 2011 if first_srvcdt >= mdy(10,1,2011) & first_srvcdt <= mdy(9,30,2012) ; 
	replace firstplanyear = 2012 if first_srvcdt >= mdy(10,1,2012) & first_srvcdt <= mdy(9,30,2013) ; 
	replace firstplanyear = 2013 if first_srvcdt >= mdy(10,1,2013) & first_srvcdt <= mdy(9,30,2014) ; 
	replace firstplanyear = 2014 if first_srvcdt >= mdy(10,1,2014) & first_srvcdt <= mdy(9,30,2015) ; 
                                    
	replace firstplanyear = 2007 if first_srvcdt < mdy(10,1,2008) ; 
	replace firstplanyear = 2015 if first_srvcdt > mdy(9,30,2015) ;
	
	tab lastplanyear ;
	tab firstplanyear ; 
	
	* if early is still 2014 or last is 2007, then we definitely do no include ; 
	drop if firstplanyear == 2014 ; 
	drop if lastplanyear == 2007 ;
	
	tab firstplanyear lastplanyear ; 

	tab plan firstplanyear ; 
	tab plan lastplanyear ; 
	
	* based on this tabulation, using first_srvcdt to make plan years minimizes the number of claims in ; 
	* plan year * plan combinations that do not exist, e.g. it minimizes 2010 claims in KMED2 and PMED1 ; 
	drop last_srvcdt ; 
	drop lastplanyear ; 
	
	rename first_srvcdt srvcdt ; 
	rename firstplanyear planyear ; 
		
	rename copay origcopay;
	rename deductible origded;
	rename coinsurance origcoin;

	tab plan ; 
describe , fullnames ; 	
save "`dir'/professional_trimmed_23_Sep_2016.dta", replace ;

use "`dir'/drugs_devoid__4_Mar_2016.dta", clear ;
drop relation absamt minvoid srvcplace provtyp orderingprov ; 
	*** confirm no voids ; 
	drop if allowedamt < 0 ; 
	drop if dayssupply < 0 ; 
	replace plan = trim(plan);
/* cleaning up data */;
	replace plan = trim(plan);
	replace plan=substr(plan, 1, 5);
	replace plan = trim(plan) ;
	drop if plan== "NE" | plan=="OPT" | plan=="~";

				
	cap drop planyear;

	gen paiddt2=date(paiddt, "MDY");
	drop paiddt;
	rename paiddt2 paiddt; 
	format paiddt %d;
	
	gen srvcdt2=date(srvcdt, "MDY");
	drop srvcdt;
	rename srvcdt2 srvcdt;
	format srvcdt %d;	
	
	gen 	planyear = 2008 if srvcdt >= mdy(10,1,2008) & srvcdt <= mdy(9,30,2009);
	replace planyear = 2009 if srvcdt >= mdy(10,1,2009) & srvcdt <= mdy(9,30,2010);
	replace planyear = 2010 if srvcdt >= mdy(10,1,2010) & srvcdt <= mdy(9,30,2011);
	replace planyear = 2011 if srvcdt >= mdy(10,1,2011) & srvcdt <= mdy(9,30,2012); 
	replace planyear = 2012 if srvcdt >= mdy(10,1,2012) & srvcdt <= mdy(9,30,2013) ; 
	replace planyear = 2013 if srvcdt >= mdy(10,1,2013) & srvcdt <= mdy(9,30,2014) ; 
	replace planyear = 2014 if srvcdt >= mdy(10,1,2014) & srvcdt <= mdy(9,30,2015) ; 

	replace planyear = 2007 if srvcdt < mdy(10,1,2008) ; 
	assert planyear != .  ;
	drop if planyear == 2007 ; 
	drop if planyear == 2014 ; 
	
	duplicates drop;
	cap drop drugplan;
	keep if covtypcd == 2;
	drop covtypcd ; 
	rename copay origcopay;
	rename deductible origded;
	rename coinsurance origcoin;
	duplicates drop;
describe , fullnames ; 
save "`dir'/drugs_trimmed_23_Sep_2016.dta", replace ; 

log close ; 
	