#delimit ;
pause off ;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

log using /disk/agedisk3/oebb.work/cbehrer/oregon/log/cleaning/datacleaning_pkg4_`cdate'_`ctime'.log;

/* Project: 	Oregon Health Plan Choice Analysis													*/;
/* Program: 	datacleaning_PY2013																	*/;
/* Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 									*/;
/*				--> code based on existing code by Adrienne Sabety									*/;
/* Dates:		Created: 	3/09/2015																*/;
/*				Modified: 	3/11/2015																*/;

/* This do file cleans data received on 9 March 2015. Cleaning in this program is mostly renaming. 	*/;

/* 0) Specify filepaths as locals 																	*/;

	local facility "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/truventext/package4/advext_4018_Facility_MIT_2014IEResults.txt";
	local professional "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/truventext/package4/advext_4018_Professional_MIT_2014IEResults.txt";
	local eligibility "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/truventext/package4/advext_4018_Elig_MIT_2014IEResults.txt";
	local drug "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/truventext/package4/advext_4018_Drug_MIT_2014IEResults.txt";

	local datadir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package4" ;
	
	/* 1) Eligibility file */;
	insheet using `eligibility', clear ;
	label data "Eligibility data";

		di _N;
		/*the last 8 variables have no data*/;
		drop v44 - v51;

		/* variable v1 has the address as a string, but is indecipherable random characters - we don't need or use it, so let drop it now*/;
		drop v1;

		/* renaming variables based on data dictionary, prior data cleaning code, and review of the data*/;
		label var v2 "The age of the person in months for the month of eligibility or service for a person who is less than 37 months old" ;
		rename v2 age_month ;

		label var v3 "The age of the person in years for the month of eligibility or service" ;
		rename v3 age_yr ;

		label var v4 "The employer group code" ;
		label define empkey 4018 "OEBB" ;
		label values v4 empkey ;
		rename v4  empcode ;

		gen dentcov = 1 if v5 == "Y" ;
		replace dentcov = 0 if v5 == "N" ;
		drop v5 ;
		label var dentcov "An indicator of dental benefit coverage for the member or employee" ;
		label define indickey 1 "Yes" 0 "No" ;
		label values dentcov indickey ;

		gen drugcov = 1 if v6 == "Y" ;
		replace drugcov = 0 if v6 == "N" ;
		drop v6 ;
		label var drugcov "An indicator of drug benefit coverage for the member or employee" ;
		label values drugcov indickey ;

		gen hearcov = 1 if v7 == "Y" ;
		replace hearcov = 0 if v7 == "N" ;
		drop v7 ;
		label var hearcov "An indicator of hearing benefit coverage for the member or employee" ;
		label values hearcov indickey ;

		gen medcov = 1 if v8 == "Y" ;
		replace medcov = 0 if v8 == "N" ;
		drop v8 ;
		label var medcov "An indicator of medical benefit coverage for the member or employee" ;
		label values medcov indickey ;

		gen mhsacov = 1 if v9 == "Y" ;
		replace mhsacov = 0 if v9 == "N" ;
		drop v9 ;
		label var mhsacov "An indicator of mental health and substance abuse benefit coverage for the member or employee" ;
		label values mhsacov indickey ;

		gen visioncov = 1 if v10 == "Y" ;
		replace visioncov = 0 if v10 == "N" ;
		drop v10 ;
		label var visioncov "An indicator of vision benefit coverage for the member or employee" ;
		label values visioncov indickey ;

		label var v11 "Client-specific code for the coverage tier" ;
		rename v11 tiercd ;

		label var v12 "Entity number" ;
		rename v12 entitynum ;
		replace entitynum = trim(entitynum) ;

		label var v13 "Member ID" ;
		destring v13, replace ;
		rename v13 memid ;

		label var v14 "Employee id" ;
		rename v14 empid ;

		label var v15 "The last date of eligibility within the eligibility month" ;
		rename v15 eligend ;

		label var v16 "The date which reflects the month of eligibility" ;
		rename v16 eligmonth ;

		label var v17 "The first date of eligibility within the eligibility month" ;
		rename v17 eligstart ;

		label var v18 "The eligibility data source code" ;
		rename v18 eligsrce ;

		label var v19 "A flag of the employees in the eligibility record";
		label define flagkey 1 "Employee" 0 "Other";
		label values v19 flagkey;
		rename v19 eligflag;

		rename v20 empstatus;
		replace empstatus = "0" if empstatus == "~";
		destring empstatus, replace;
		label var empstatus "The Medstat standard code for the status of the employee";
		label define statuskey 0 "Missing" 1 "Active Full Time" 2 "Active Part-Time/Seasonal" 3	"Early Retiree" 4 "Medicare Eligible Retiree" 
		5 "Retiree (Status Unknown)" 6 "COBRA Continuee" 7 "Long Term Disability" 8	"Surviving Spouse/Dependent" 9 "Other/Unknown";
		label values empstatus statuskey;

		label var v21 "The Medstat standard code for the grouping of the employee status";
		rename v21 statusgrp;
		replace statusgrp = "0" if statusgrp=="~";
		destring statusgrp, replace;
		label define grpkey 1 "Active" 2 "Early Retiree" 3 "Medicare Retiree" 4	"Other";
		label values statusgrp grpkey;

		/* all 4018 - not useful data */;
		drop v22;

		label var v23 "Family ID";        
		rename v23 familyid;

		gen sex = 1 if v24 == "F";
		replace sex = 2 if v24 == "M";
		replace sex = 0 if v24 == "~";
		drop v24;
		label var sex "Medstat code for gender";        
		label define sexkey 1 "Female" 2 "Male" 0 "Missing";
		label values sex sexkey;

		gen vendorcd = real(v25);
		replace vendorcd = 0 if vendorcd ==.;
		drop v25;
		label var vendorcd "Medical Vendor Code - Watson Wyatt defined field";
		label define vendorkey 0 "Missing" 468 "Kaiser Permanente" 3017	"Providence Health Plan" 3581 "ODS";
		label values vendorcd vendorkey;

		label var v26 "The standard US Census Bureau code for the MSA of the person";
		rename v26 msa;

		label var v27 "Person ID for IE 2012--2014"; 
		rename v27 personidIE;

		label var v28 "Client-specific code for the plan or product line of the medical plan package";       
		rename v28 plan;

		gen plangrp = real(v29);
		drop v29;
		replace plangrp = 0 if plangrp == .;
		label var plangrp "Client-specific code for the analytical grouping of plans or product lines of the medical plan package";
		label define plankey 0 "No Coverage" 468 "Kaiser" 3017	"Providence Health Plan" 3581 "ODS";
		label values plangrp plankey;

		gen plantype = real(v30);
		drop v30;
		replace plantype = 0 if plantype == .;
		label var plantype "Plan Type Code Medstat";
		label define plantypekey 0 "Missing" 1 "HMO" 2 "PPO" 8 "ODS9";
		label values plantype plantypekey;

		label var v31 "The number of eligibles represented in the record";
		rename v31 popcount;

		gen relat = v32;
		drop v32;
		replace relat = 0 if relat == .;
		label var relat "Relationship of beneficiary to policy holder";
		label define relatkey 0 "Missing" 1 "Employee/self" 2 "Spouse/Partner" 3 "Child/Other Dependent";
		label values relat relatkey;

		/* all ~ */;
		drop v33;

		label var v34 "The state abbreviation for the residence of the person";
		rename v34 state;

		gen union = 1 if v35 == "Y";
		replace union = 0 if v35 == "N";
		drop v35;
		label var union "An indicator that the contract holder (subscriber) belongs to a union";
		label define unionkey 1 "Yes" 0 "No";
		label values union unionkey;

		label var v36 "The most recent update date for the eligibility data";
		rename v36 updatedt;

		label var v37 "The 5-digit zip code of the person, based on the time of service or the month of eligibility";
		rename v37 zipcd;

		label var v38 "Pharmacy plan code";
		rename v38 drugplan;

		label var v39 "person id";
		rename v39 personid;

		label var v40 "Dental Plan";
		rename v40 dentalplan;

		label var v41 "Vision Plan";
		rename v41 visionplan;

		label var v42 "Short term disability coverage indicator";
		rename v42 disability_short;

		label var v43 "Short term disability coverage indicator";
		rename v43 disability_long;

		gen file = 8 ; 
		
save `datadir'/eligibilitydata_`cdate'.dta, replace ;

/* 2) Facility claims */;
insheet using `facility', clear;
label data "Facility Claims";

	label var v1 "Adjustment Type Code Medstat";
	label define adjustkey 1 "Adjustment" 2	"Void" 3 "Original or Replacement" 4 "Bulk Adjustment";
	label values v1 adjustkey;
	rename v1 adjustcd;

	label var v2  "Allowed Amount";  
	rename v2  allowedamt;
	
	/*v3 and v4 are all missing; v5 is a capitated cost indicator, and all claims are not capitated by this indicator*/;
	drop v3 v4 v5;
	
	label var v6 "The submitted or billed charge amount";   
	rename v6 chargeamt; 
	
	/* all values are the same - valuable variable?*/;
	label var v7  "The controlling customer code";
	rename v7 customcode;
	
	/* all values are the same - valuable variable?*/;
	label var v8 "The employer group code";
	label values v8 empkey;
	rename v8 empcode; 
	
	gen claimid = trim(v9);
	label var claimid "The client-specific unique identifier of the claim";
	drop v9;

	label var v10  "Medstat standard code for coverage type under which claim was paid";
	label define covkey  1 "Medical/MHSA" 2 "Drug" 3 "Dental" 4 "Vision" 5 "Hearing" 7 "Life Insurance" 10 "Long term disability"
						 11 "Short term disability" 12 "Absenteeism" 13 "Worker Comp" 20 "Capitation Payment" 21 "Administrative Fee"
						 22 "Premium Payment" 23 "Employee Premium Contribution" 25 "Premium Income (Revenue)" 31 "Employee Assistance" 
						 32 "Health Risk Appraisal" 50 "Other";
						 
	label values v10 covkey;
	rename v10  covtypcd;
	
	label var v11 "Medstat code for clinical condition based on ICD-9 codes";
	rename v11 conditioncd;
	
	label var v12 "Coinsurance paid by the subscriber";
	rename v12 coinsurance; 
	
	label var v13 "Copay paid by the subscriber";
	rename v13 copay; 

	label var v14 "Date of first service reported on claim or authorization record";
	rename v14 firstsrvcdt;           

	label var v15 "Date of last service reported on claim or authorization record";
	rename v15 lastsrvcdt;     

	label var v16 "Date of service facility detail";
	rename v16 servicedetaildt;

	label var v17 "Date the claim or data record was paid";
	rename v17 paiddt; 

	label var v18 "Days";        
	rename v18 days; 
	
	label var v19 "The amount paid by the subscriber through the deductible arrangement of the plan";        
	rename v19 deductible; 

	label var v20 "First 3 digits of the principal diagnosis code (ICD-9)";
	rename v20 diag3code;

	label var v21 "Secondary UB diagnosis code for the facility claim";
	rename v21 diagnosis2;

	label var v22 "Secondary UB diagnosis code for the facility claim";
	rename v22 diagnosis3;     

	label var v23 "Secondary UB diagnosis code for the facility claim";
	rename v23 diagnosis4;  

	label var v24 "Secondary UB diagnosis code for the facility claim";
	rename v24 diagnosis5; 

	label var v25 "Secondary UB diagnosis code for the facility claim";
	rename v25 diagnosis6;      

	label var v26 "Secondary UB diagnosis code for the facility claim";
	rename v26 diagnosis7;    

	label var v27 "Secondary UB diagnosis code for the facility claim"; 
	rename v27 diagnosis8; 

	label var v28 "Secondary UB diagnosis code for the facility claim";
	rename v28 diagnosis9; 

	label var v29 "First/principal diagnosis code for service, claim, or lab result";    
	rename v29 diagnosis1; 
	
	/* all missing - discharge status code */;
	drop v30;
	
	label var v31 "Discount amount of the claim, applied to charges for any plan pricing reductions";
	rename v31 discount;

	label var v32 "The disease category code based on valid ICD-9 principal diagnosis codes";
	rename v32 diseasecd;

	label var v33 "The code identifying the type of eligibility tagging in the build";
	rename v33 eligtag;
	
	replace v34 = "0" if v34 == "~"; 
	gen empstatus = real(v34);
	drop v34;
	replace empstatus = 0 if empstatus == .;
	label var empstatus "The Medstat standard code for the status of the employee";
	label values empstatus statuskey;

	drop v35;

	label var v36 "Family ID";      
	rename v36 familyid;

	label var v37 "An indicator that the claim was for a fully insured plan";
	rename v37 fullinsured;
	
	gen sex = 1 if v38 == "F"; // right;
	replace sex = 2 if v38 == "M";
	replace sex = 0 if v38 == "~";
	drop v38;
	label var sex "Medstat code for gender";        
	label values sex sexkey;
	
	/*this is all 0*/;
	label var v39 "Financial amount of the HSA for consumer-driven health plans";        
	rename v39 hsa_amt;
	
	/*this is also all 0*/;
	label var v40 "Financial amount of healthcare reimbursement arrangement for consumer-driven health plans";      
	rename v40 hra_amt; 
	
	label var v41 "Medstat code for lifestyle condition based on ICD-9 codes for lifestyle risk factors";
	label define lifestylekey 0 "~Missing "
	10 "Lifestyle Dx: Cancer - Breast"
	20 "Lifestyle Dx: Coronary Artery Disease"
	30 "Lifestyle Dx: Cerebrovascular Disease"
	40 "Lifestyle Dx: Cancer - Skin"
	50 "Lifestyle Dx: Diabetes Mellitus, Non-Insulin Depen"
	51 "Lifestyle Dx: Lipid Metabolism Disorders"
	52 "Lifestyle Dx: Overweight/Obese"
	60 "Lifestyle Dx: Cancer - Larynx"
	61 "Lifestyle Dx: Cancer - Lip/Oral Cavity/Pharynx"
	62 "Lifestyle Dx: Oral Disease"
	70 "Lifestyle Dx: Cancer - Colorectal"
	71 "Lifestyle Dx: Cancer - Esophagus"
	72 "Lifestyle Dx: Constipation"
	73 "Lifestyle Dx: Diverticular Disease"
	80 "Lifestyle Dx: Cancer - Cervix"
	81 "Lifestyle Dx: Cancer - Ovary"
	82 "Lifestyle Dx: Cancer - Uterus"
	100 "Lifestyle Dx: Cancer - Gallbladder/Biliary Tract"
	101 "Lifestyle Dx: Cancer - Liver"
	102 "Lifestyle Dx: Cancer - Pancreas"
	103 "Lifestyle Dx: Cholecystitis/Cholelithiasis"
	104	"Lifestyle Dx: Pancreatitis"
	110	"Lifestyle Dx: HIV Infection"
	130	"Lifestyle Dx: Cancer - Prostate"
	140	"Lifestyle Dx: Sleep Apnea"
	150	"Lifestyle Dx: Hypertension"
	151	"Lifestyle Dx: Malnutrition"
	152	"Lifestyle Dx: Sexually Transmitted Diseases"
	160	"Lifestyle Dx: Osteoarthritis"
	161	"Lifestyle Dx: Osteoporosis"
	220	"Lifestyle Dx: Alcohol Abuse"
	221	"Lifestyle Dx: Alcohol Withdrawal Syndrome"
	222	"Lifestyle Dx: Alcoholic Cardiomyopathy"
	223	"Lifestyle Dx: Alcoholic Liver Damage"
	224	"Lifestyle Dx: Alcoholic Polyneuropathy"
	225	"Lifestyle Dx: Alcoholic Psychosis"
	226	"Lifestyle Dx: Stress/Anxiety/Depression"
	227	"Lifestyle Dx: Tobacco Use"
	230	"Lifestyle Dx: Cancer - Bladder/Kidney/Oth Urinary"
	240	"Lifestyle Dx: Asthma"
	241	"Lifestyle Dx: Bronchitis, Acute"
	242	"Lifestyle Dx: Cancer - Trachea/Bronchus/Lung"
	243	"Lifestyle Dx: COPD"
	244	"Lifestyle Dx: Pneumonia"
	250	"Lifestyle Dx: Peripheral Vascular Disease"
	251	"Lifestyle Dx: Venous Embolism/Thrombosis";
	label values v41 lifestylekey;
	rename v41 lifestylecd; 

	label var v42 "The detail line number for the service on the claim";
	rename v42 linenum; 

	label var v43 "An identifier of physical media for the claims";       
	rename v43 mediacd; 
	
	gen vendorcd = v44; 
	replace vendorcd ="0" if vendorcd =="~    ";
	destring vendorcd, replace;
	replace vendorcd = 0 if vendorcd ==.;
	drop v44;
	label var vendorcd "Medical Vendor Code - Watson Wyatt defined field";
	label values vendorcd vendorkey;
	
	label var v45 "A unique identifier of each facility, professional or drug claim record, as set by Medstat";       
	rename v45 recordid;

	label var v46 "The actual check amount for the record";      
	rename v46  netpayment; 
	
	/*I believe that this is identical to v46, at least for package 4*/;
	label var v47 "The net payment amount on the facility detail record";
	rename v47 netpayment_detail;
	
	label var v48 "An indicator of whether the claim was paid at the in-network or out-of-network level";
	rename v48 networkpaid;
	
	label var v49 "Indicates if the servicing provider participates in the network to which the patient belongs";      
	rename v49 provnetwork;
	
	label var v50 "ID of the provider who referred the patient, prescribed the drug, or ordered the test or procedure";  
	rename v50 orderingprov;
	
	label var v51 "Indicator signifying that the PCP is the physician considered responsible or accountable for this claim";    
	rename v51 pcpresp;      

	label var v52 "Person ID for IE 2012--2014";
	rename v52  personidIE;

	label var v53 "The Medstat standard code indicating the place of service, based on CMS standard values";   
	label define placekey 11 "Office" 12 "Patient Home" 20 "'Urgent Care Facility" 21 "Inpatient Hospital" 22 "Outpatient Hospital"
	23 "Emergency Room - Hospital" 24 "Ambulatory Surgical Center" 25 "Birthing Center" 31 "Skilled Nursing Facility"
	32 "Nursing Facility" 34 "Hospice" 41 "Ambulance(land)" 42 "'Ambulance (air or water)" 50 "Federally Qualified Health Ctr"
	51 "Inpatient Psychiatric Facility" 52 "Psych Facility Partial Hosp" 53	"Community Mental Health Center" 
	54 "Intermed Care/Mental Retarded" 55 "Residential Subst Abuse Facil" 65 "End-Stage Renal Disease Facil" 
	72 "Rural Health Clinic" 95 "Outpatient, NOS" 99 "Missing/Unknown";
	label values v53 "placekey";
	rename v53 srvcplace;

	label var v54 "Client-specific code for the plan or product line of the medical plan package";       
	rename v54 plan;

	label var v55 "The procedure code for the service record";      
	rename v55 procedure;
	
	/*We dropped v56 before. Unclear why. It is a surgery procedure code, probably HCPCS.*/;
	/*We may not use it, but lets keep it for now.*/;
	label var v56 "UB Surg 1 procedure code - probably HCPCS";      
	rename v56 proc_surg;
	
	label var v57 "The 2-character code of the first procedure code modifier on the claim";       
	rename v57 procmodcd;
	
	gen codingsys = real(v58);
	drop v58;
	label var codingsys "The Medstat standard code indicating the procedure coding system";     
	label define systemkey 0 "ICD-10-PCS" 1 "CPT" 3 "Client-specific" 7 "HCPCS" 8 "CDT (ADA)" 9 "ICD-9-CM"; 
	label values codingsys systemkey; 

	label var v59 "The current city of the provider of service";
	rename v59 provcity;
	
	label var v60 "The identifier for the provider of service (NPI)";   
	rename v60 providerid;

	label var v61 "The description or name corresponding to the Provider ID";    
	rename v61 provname;

	label var v62 "The state abbreviation for the provider of service";     
	rename v62 provstate;

	label var v63 "The Medstat standard provider type code as reported on the claim";      
	rename v63  provtyp;

	label var v64 "The 5-digit zip code corresponding to the Provider ID";       
	rename v64 provzipcd;      

	label var v65 "The Medstat code for the relationship of the member to the contract holder";
	label define relationkey 1 "Employee/Self" 2 "Spouse/Partner" 3	"Child/Other Dependent";
	label values v65 relationkey;
	rename v65 relation;

	label var v66 "The CMS standard revenue code from the facility claim"; 
	rename v66 revenuecd;

	/*all missing*/;
	drop v67;

	label var v68 "The security view field for secure id";      
	rename v68 security;

	label var v69 "A count of the number of services rendered by the provider";      
	rename v69 srvccount;  

	label var v70 "The Medstat standard code for the source of data (facility, professional, drug, financial)";
	rename v70 datasource;

	label var v71 "The amount saved due to integration of third party liability by all third party payers (including Medicare)";       
	rename v71 thirdptyamt;

	drop v72 ; 
	
	gen file = 8 ; 
	
save `datadir'/facility_claims_`cdate'.dta, replace ;

/* 3) Professional claims */;

insheet using `professional', clear;

label data "Professional Claims";

	label var v1 "Adjustment Type Code Medstat";

	label values v1 adjustkey;
	rename v1 adjustcd;
	
	label var v2  "Allowed Amount";  
	rename v2  allowedamt;
	
	/*v3 and v4 are all missing; v5 is a capitated cost indicator, and all claims are not capitated by this indicator*/;
	/* original code kept v5, but it is all missing and we drop it above for facility. Dropping here to match datasets*/;
	drop v3-v5;

	label var v6 "The submitted or billed charge amount";   
	rename v6 chargeamt; 

	/* all values are the same - valuable variable?*/;
	label var v7  "The controlling customer code";
	rename v7 customcode;
	
	/* all values are the same */;
	label var v8 "The employer group code";
	label values v8 empkey;
	rename v8 empcode;

	gen claimid = trim(v9);
	label var claimid "The client-specific unique identifier of the claim";
	drop v9;

	/* We have dental claims - how is this going to work across plans?*/;
	label values v10 covkey;
	rename v10 covtypcd;

	label var v11  "Medstat code for clinical condition based on ICD-9 codes";
	rename v11   conditioncd; 
	
	label var v12 "Coinsurance paid by the subscriber";
	rename v12 coinsurance;  

	label var v13 "Copay paid by the subscriber";
	rename v13 copay;  

	label var v14 "Date of first service reported on claim or authorization record";
	rename v14 firstsrvcdt;    

	label var v15 "Date of last service reported on claim or authorization record";
	rename v15 lastsrvcdt;  

	label var v16 "Date the claim or data record was paid";
	rename v16 paiddt; 

	label var v17 "The amount paid by the subscriber through the deductible arrangement of the plan";        
	rename v17 deductible;   

	label var v18 "First 3 digits of the principal diagnosis code (ICD-9)";
	rename v18 diag3code;

	label var v19 "Secondary UB diagnosis code for the facility claim";
	rename v19  diagnosis2;

	label var v20 "Secondary UB diagnosis code for the facility claim";
	rename v20  diagnosis3;     

	label var v21 "Secondary UB diagnosis code for the facility claim";
	rename v21  diagnosis4;  

	label var v22  "Secondary UB diagnosis code for the facility claim";
	rename v22 diagnosis5; 

	label var v23 "Secondary UB diagnosis code for the facility claim";
	rename v23 diagnosis6;      

	label var v24 "Secondary UB diagnosis code for the facility claim";
	rename v24 diagnosis7;    

	label var v25 "Secondary UB diagnosis code for the facility claim"; 
	rename v25 diagnosis8; 

	label var v26 "Secondary UB diagnosis code for the facility claim";
	rename v26 diagnosis9; 

	label var v27 "First/principal diagnosis code for service, claim, or lab result";    
	rename v27 diagnosis1;

	/* all missing - discharge status code */;
	drop v28;

	label var v29 "Discount amount of the claim, applied to charges for any plan pricing reductions";
	rename v29 discount;
	
	label var v30 "The disease category code based on valid ICD-9 principal diagnosis codes";
	rename v30 diseasecd;

	label var v31 "The code identifying the type of eligibility tagging in the build";
	rename v31 eligtag;

	replace v32 = "0" if v32 == "~"; 
	gen empstatus = real(v32);
	drop v32;
	label var empstatus "The Medstat standard code for the status of the employee";
	label values empstatus statuskey;

	/* all missing - ER or observation room flag code */;	
	drop v33;

	label var v34 "Family ID";        
	rename v34 familyid;
	
	label var v35 "An indicator that the claim was for a fully insured plan";
	rename v35 fullinsured;
	
	gen sex = 1 if v36 == "F";
	replace sex = 2 if v36 == "M";
	replace sex = 0 if v36 == "~";
	drop v36;
	label var sex "Medstat code for gender";        
	label values sex sexkey;

	/* all zero */;
	label var v37 "Financial amount of the HSA for consumer-driven health plans";        
	rename v37 hsa_amt;

	/* all zero */;
	label var v38 "Financial amount of healthcare reimbursement arrangement for consumer-driven health plans";      
	rename v38 hra_amt; 

	label var v39 "Medstat code for lifestyle condition based on ICD-9 codes for lifestyle risk factors";
	label values v39 lifestylekey;
	rename v39 lifestylecd; 

	label var v40 "The detail line number for the service on the claim";
	rename v40 linenum;

	label var v41 "An identifier of physical media for the claims";       
	rename v41 mediacd; 
	
	gen vendorcd = real(v42);
	replace vendorcd = 0 if vendorcd ==.;
	
	drop v42;
	label var vendorcd "Medical Vendor Code - Watson Wyatt defined field";
	label values vendorcd vendorkey;

	label var v43 "A unique identifier of each facility, professional or drug claim record, as set by Medstat";       
	rename v43 recordid;

	label var v44 "The actual check amount for the record";      
	rename v44  netpayment;    

	label var v45 "An indicator of whether the claim was paid at the in-network or out-of-network level";
	rename v45  networkpaid;

	label var v46 "Indicates if the servicing provider participates in the network to which the patient belongs";      
	rename v46  provnetwork;

	label var v47 "ID of the provider who referred the patient, prescribed the drug, or ordered the test or procedure";  
	rename v47 orderingprov;

	/*Can we use this?*/;
	label var v48 "Indicator signifying that the PCP is the physician considered responsible or accountable for this claim";    
	rename v48 pcpresp; 

	label var v49 "Person ID for IE 2012--2014";
	rename v49  personidIE;
	
	label var v50 "The Medstat standard code indicating the place of service, based on CMS standard values";   
	label values v50 placekey;
	rename v50 srvcplace; 

	label var v51 "Client-specific code for the plan or product line of the medical plan package";       
	rename v51  plan;

	label var v52 "The procedure code for the service record";      
	rename v52  procedure;
	
	/*We dropped v53 before. Unclear why. It is a surgery procedure code, probably HCPCS.*/;
	/*We may not use it, but lets keep it for now.*/;
	label var v53 "UB Surg 1 procedure code - probably HCPCS";      
	rename v53 proc_surg;

	label var v54 "The 2-character code of the first procedure code modifier on the claim";       
	rename v54 procmodcd;

	gen codingsys = real(v55);
	drop v55;
	label var codingsys "The Medstat standard code indicating the procedure coding system";     
	label values codingsys systemkey;    

	label var v56 "The current city of the provider of service";
	rename v56 provcity;

	label var v57 "The identifier for the provider of service (NPI)";   
	rename v57 providerid;

	label var v58 "The description or name corresponding to the Provider ID";    
	rename v58 provname;

	label var v59 "The state abbreviation for the provider of service";     
	rename v59 provstate;
	
	label var v60 "The Medstat standard provider type code as reported on the claim";      
	rename v60 provtyp;

	label var v61 "The 5-digit zip code corresponding to the Provider ID";       
	rename v61 provzipcd;

	label var v62 "The Medstat code for the relationship of the member to the contract holder";
	label values v62 relationkey;
	rename v62 relation;
	
	/* all missing*/;
	drop v63 v64;

	label var v65 "The security view field for secure id";      
	rename v65 security;

	label var v66 "A count of the number of services rendered by the provider";      
	rename v66 srvccount;    

	label var v67 "The Medstat standard code for the detailed service subcategory"; 
	rename v67 srvccat;

	label var v68 "The Medstat standard code for the source of data (facility, professional, drug, financial)";
	rename v68 datasource;
	 
	label var v69 "The amount saved due to integration of third party liability by all third party payers (including Medicare)";       
	rename v69 thirdptyamt; 
	
	drop v70 ; 
	
	gen file = 8 ; 

save `datadir'/professional_claims_`cdate'.dta, replace ;

/* 4) Drug */;
clear all;
/* unclear why this import command is used rather than insheet, I will leave as is for now*/;
import delim using `drug',  stringcols(28) clear;
label data "Drug Claims";

	label var v1 "Adjustment Type Code Medstat";
	label define adjustkey 1 "Adjustment" 2	"Void" 3 "Original or Replacement" 4 "Bulk Adjustment";
	label values v1 adjustkey;
	rename v1 adjustcd;
	
	label var v2  "Allowed Amount";  
	rename v2 allowedamt;
	
	/* universally N */;
	label var v3 "Capitated Service Indicator";
	rename v3  capitated_srv;
	
	label var v4 "The submitted or billed charge amount";   
	rename v4 chargeamt;
	
	/* universally 4018 */;
	label var v5  "The controlling customer code";
	rename v5  customcode;

	/* universally 4018 */;
	label var v6 "The employer group code";
	label define empkey 4018 "OEBB";
	label values v6 empkey;
	rename v6  empcode;
	
	gen claimid = trim(v7);
	label var claimid "The client-specific unique identifier of the claim";
	drop v7;
	
	label var v8  "Medstat standard code for coverage type under which claim was paid";
	label define covkey  1 "Medical/MHSA" 2 "Drug" 3 "Dental" 4 "Vision";
	label values v8 covkey;
	rename v8  covtypcd;
	
	label var v9  "Coinsurance paid by the subscriber";
	rename v9  coinsurance;  

	label var v10  "Copay paid by the subscriber";
	rename v10  copay;        

	label var v11  "The date of service for the financial record, drug claim, or lab result";
	rename v11 srvcdt;           

	label var v12  "Date the claim or data record was paid";
	rename v12 paiddt; 

	label var v13 "The number of days of drug therapy covered by this prescription";
	rename v13 dayssupply;

	label var v14 "The amount paid by the subscriber through the deductible arrangement of the plan";        
	rename v14 deductible;   

	label var v15  "Discount amount of the claim, applied to charges for any plan pricing reductions";
	rename v15  discount;

	label var v16 "Dispensing fee charged by the pharmacy for dispensing the prescription";
	rename v16 dispfee;
	
	/* label this */;
	label var v17 "The code identifying the type of eligibility tagging in the build";
	rename v17 eligtag;
	
	replace v18 = "0" if v18 == "~"; 
	gen empstatus = real(v18);
	drop v18;
	label var empstatus "The Medstat standard code for the status of the employee";
	label define statuskey 0 "Missing" 1 "Active Full Time" 2 "Active Part-Time/Seasonal" 3	"Early Retiree" 4 "Medicare Eligible Retiree" 
	5 "Retiree (Status Unknown)" 6 "COBRA Continuee" 7 "Long Term Disability" 8	"Surviving Spouse/Dependent" 9 "Other/Unknown";
	label values empstatus statuskey;
	
	label var v19 "Family ID";        
	rename v19 familyid;
	
	label var v20 "An indicator that the claim was for a fully insured plan";
	rename v20 fullinsured;

	gen sex = 1 if v21 == "F";
	replace sex = 2 if v21 == "M";
	replace sex = 0 if v21 == "~";
	drop v21;
	label var sex "Medstat code for gender";        
	label define sexkey 1 "Female" 2 "Male" 0 "Missing";
	label values sex sexkey;
	
	/* all 0*/;
	label var v22 "Financial amount of the HSA for consumer-driven health plans";        
	rename v22  hsa_amt;

	/* all 0*/;
	label var v23 "Financial amount of healthcare reimbursement arrangement for consumer-driven health plans";      
	rename v23 hra_amt;  
	
	label var v24 "Ingredient Cost: The charge or cost associated with the pharmaceutical product";
	rename v24 prodcost;

	gen vendorcd = real(v25);
	replace vendorcd = 0 if vendorcd ==.;
	drop v25;
	label var vendorcd "Medical Vendor Code - Watson Wyatt defined field";
	label define vendorkey 0 "Missing" 468 "Kaiser Permanente" 3017	"Providence Health Plan" 3581 "ODS";
	label values vendorcd vendorkey;

	label var v26 "A unique identifier of each facility, professional or drug claim record, as set by Medstat";       
	rename v26 recordid;
	
	/*The range of this variable is seemingly too large. How should it be cleaned? Do we use it?*/;
	label var v27 "The number of units dispensed for the prescription drug claim, defined by the NCPDP";
	rename v27 units;
	
	label var v28 "The FDA registered number (without the dashes) for the drug";
	rename v28 ndc;

	label var v29 "The actual check amount for the record";      
	rename v29  netpayment;       

	gen networkpaid = 1 if v30 == "Y";
	replace networkpaid = 0 if v30 == "N";
	replace networkpaid =. if v30 == "~";
	drop v30;
	label var networkpaid "An indicator of whether the claim was paid at the in-network or out-of-network level";
	label define networkpaidkey 1 "In-Network" 0 "Out-of-Network";
	label values  networkpaid networkpaidkey;

	gen provnetwork = 1 if v31 == "Y";
	replace provnetwork = 0 if v31 == "N";
	drop v31;
	label var provnetwork "Indicates if the servicing provider participates in the network to which the patient belongs";      
	label define networkkey 1 "In-Network" 0 "Out-of-Network";
	label values  provnetwork networkkey;

	label var v32 "ID of the provider who referred the patient, prescribed the drug, or ordered the test or procedure";  
	rename v32 orderingprov;

	label var v33 "Indicator signifying that the PCP is the physician considered responsible or accountable for this claim";    
	rename v33 pcpresp;      

	label var v34 "Person ID for IE 2012--2014";
	rename v34  personidIE;
	
	label var v35 "The Medstat standard code indicating the place of service, based on CMS standard values";   
	label values v35 placekey;
	rename v35 srvcplace;
	
	label var v36 "Client-specific code for the plan or product line of the medical plan package";       
	rename v36  plan;  

	label var v37 "The current city of the provider of service";
	rename v37  provcity;

	label var v38 "The identifier for the provider of service (NPI)";   
	rename v38 providerid;

	label var v39 "The description or name corresponding to the Provider ID";    
	rename v39  provname;

	label var v40 "The state abbreviation for the provider of service";     
	rename v40  provstate;

	label var v41 "The Medstat standard provider type code as reported on the claim";      
	rename v41  provtyp;

	label var v42 "The 5-digit zip code corresponding to the Provider ID";       
	rename v42 provzipcd;    
	
	label var v43 "The Medstat code for the relationship of the member to the contract holder";
	label values v43 relationkey;
	rename v43 relation;
	
	/* label?*/;
	label var v44 "The NCPDP code that indicates how the product was dispensed";
	rename v44 dispensecd;
	
	gen formulary = 1 if v45 == "Y";
	replace formulary = 0 if v45 == "N";
	replace formulary =. if v45 == "~";
	drop v45;
	label var formulary "An indicator that the prescription drug is included in the formulary";
	label define formkey 1 "Included in formulary" 0 "Not included in formulary";
	label values formulary formkey;

	gen retail = 1 if v46 == "R";
	replace retail = 0 if v46 == "M";
	replace retail =. if v46 == "~";
	drop v46;
	label var retail "The Medstat standard code indicating the purchase place of the prescription";
	label define retailkey 1 "Retail" 0 "Mail";
	label values retail retailkey;

	gen drugtier = real(v47);
	drop v47;
	label var drugtier "Client-specific code for the payment tier of the drug claim";
	label define tierkey 1 "Generic" 2	"Brand  Name Formulary (Preferred)" 3 "Brand Non-Formulary (Non-Preferred)" 4 "Other";
	label values drugtier tierkey;

	label var v48 "Number indicating original prescription or refill number (not number of refills remaining)";
	rename v48 refillnum;

	label var v49 "The amount of sales tax applied to the cost of the prescription";
	rename v49 salestax;

	label var v50 "The security view field for secure id";      
	rename v50  security;

	label var v51 "The Medstat standard code for the source of data (facility(F), professional(P), drug(D), financial(N))";
	rename v51 datasource;

	label var v52 "The amount saved due to integration of third party liability by all third party payers (including Medicare)";       
	rename v52 thirdptyamt;  
	
	gen file = 7 ; 
	
save `datadir'/drug_claims_`cdate'.dta, replace ;

log close;
/* end */;