#delimit ;
pause off ;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

log using /disk/agedisk3/oebb.work/cbehrer/oregon/log/cleaning/0_6misccleaning_`cdate'_`ctime'.log;

/* Project: 	Oregon Health Plan Choice Analysis													*/;
/* Program: 	miscellaneous cleaning																*/;
/* Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 									*/;
/*				--> code based on existing code by Adrienne Sabety									*/;
/* Dates:		Created: 	4/29/2015																*/;
/*				Modified: 	6/11/2015																*/;

/* 0) Specify filepaths as locals 																	*/;
local labeldate 11_May_2015 ;

local outdir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/" ;

local elig_production "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/eligibilitydata_productionrun_`labeldate'.dta" ;
local eligibility1 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/eligibilitydata_`labeldate'.dta" ;
local eligibility2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/eligibilitydata_2012_`labeldate'.dta" ;
local eligibility3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/eligibilitydata_`labeldate'.dta" ;
local eligibility4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/eligibilitydata_2-7_`labeldate'.dta" ;
local eligibility5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/eligibilitydata_`labeldate'.dta" ;
local eligibility6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/eligibilitydata_SECONDHALF_`labeldate'.dta" ;
local eligibility7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package4/eligibilitydata_`labeldate'.dta" ;
local eligibility8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package5/eligibilitydata_`labeldate'.dta" ;

local facility1 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/facility_claims_`labeldate'.dta" ;
local facility2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/facility_claims_2012_`labeldate'.dta" ;
local facility3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/facility_claims_`labeldate'.dta" ;
local facility4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/facility_claims_2-7_`labeldate'.dta" ;
local facility5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/facility_claims_newKcut_`labeldate'.dta" ;
local facility6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/facility_claims_`labeldate'.dta" ;
local facility7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package4/facility_claims_`labeldate'.dta" ;
local facility8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package5/facility_claims_`labeldate'.dta" ;

local professional1	"/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/professional_claims_`labeldate'.dta" ;
local professional2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/professional_claims_2012_`labeldate'.dta" ;
local professional3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/professional_claims_`labeldate'.dta" ;
local professional4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/professional_claims_2-7_`labeldate'.dta" ;
local professional5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/professional_claims_newKcut_`labeldate'.dta" ;
local professional6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/professional_claims_`labeldate'.dta" ;
local professional7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package4/professional_claims_`labeldate'.dta" ;
local professional8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package5/professional_claims_`labeldate'.dta" ;

local drug1 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/drug_claims_`labeldate'.dta" ;
local drug2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package1/drug_claims_2012_`labeldate'.dta" ;
local drug3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/drug_claims_`labeldate'.dta" ;
local drug4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/drug_claims_newKcut_`labeldate'.dta" ;
local drug5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/drug_claims_`labeldate'.dta" ;
local drug6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/drug_claims_SECONDHALF_`labeldate'.dta" ;
local drug7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package4/drug_claims_`labeldate'.dta" ;
local drug8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package5/drug_claims_`labeldate'.dta" ;

/* 1) Confirm eligibility file "production run" covers prior 4 eligibility file periods */;
use `elig_production', clear ; 
	unique(personid eligmonth) ; 
	merge 1:1 personid eligmonth using `eligibility1' ; 
	assert _merge != 2 ; 
	drop _merge ; 
	merge 1:1 personid eligmonth using `eligibility2' ; 
	assert _merge != 2 ; 
	drop _merge ; 
	merge 1:1 personidIE eligmonth using `eligibility3' ; 
	assert _merge != 2 ; 
	drop _merge ; 
	merge 1:1 personidIE eligmonth using `eligibility4' ; 
	assert _merge != 2 ; 
	drop _merge ; 
clear ; 
/* coverage confirmed. We do not need to use the first 4 eligibility files. */;
	
/* 2) Add personidIE variables to old claims files */ ;

use `elig_production', clear ; 
	append using `eligibility5' ; 
	append using `eligibility6' ; 
	append using `eligibility7' ; 
	append using `eligibility8' ; 

	replace plan = trim(plan) ; 
	drop if plan == "~" | plan == "NE" | plan == "OPT" ; 
	
	keep personid personidIE familyid ; 
	duplicates drop ; 
	unique(personid personidIE) ; 
	assert _result(18) == _N ; 
	
	preserve ; 
	gen counter = 1 ; 
	egen dups = sum(counter), by(personidIE) ; 
	tab dups ; 
	gsort -dups personidIE familyid personid ;
	drop if dups == 1 ; 	
	drop counter dups ; 	
	outfile familyid personidIE personid using "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/x_tovendor_withquestions/personidxwalkduplicates_`cdate'.txt", comma replace ;
	restore ; 
	
	tempfile personidxwalk0 ; 
	save `personidxwalk0' ; 
	
	/* Okay, lets take all of the datasets that have the old personid variable */ ; 
	/* Take all of the old personid's present in those datasets, and make a unique list of those IDs */; 
	/* These are the IDs that we need to match to a new personid variable*/; 
	/* Then lets merge that list with our cross walk and see if we actually have to match any people who are matched to the same new personid*/;
	
	use `facility1', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile f1;
	save `f1';
	
	use `facility2', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile f2 ;
	save `f2' ;
	
	use `facility4', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile f4;
	save `f4';
	
	use `professional1', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile p1;
	save `p1';
	
	use `professional2', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile p2;
	save `p2';
	
	use `professional4', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile p4;
	save `p4';
	
	use `drug1', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile d1;
	save `d1';
	
	use `drug2', clear ; 
	keep personid ; 
	duplicates drop ;
	tempfile d2;
	save `d2';
	
	use `f1', clear ; 
	append using `f2' ; 
	append using `f4' ;
	append using `p1' ; 
	append using `p2' ; 
	append using `p4' ;
	append using `d1' ; 
	append using `d2' ; 
	
	duplicates drop ; 
	tempfile oldpid ; 
	save `oldpid' ; 
	
	use `personidxwalk0', clear ; 
	merge 1:1 personid using `oldpid' ; 
	
	keep if _merge == 3 ; 
	
	duplicates drop personidIE, force ;
	/* Multiple assignment issue effects 186 personidIE's */;
	/* this is multiple coverage - we will end up dropping all of these people */ ; 
	
	unique(personidIE) ; 
	assert _result(18) == _N ; 
	
	replace personid = trim(personid) ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	
	tempfile personidxwalk ; 
	save `personidxwalk' ; 	

use `facility1' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package1/facility_claims_`cdate'.dta", replace ; 

use `facility2' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 
	
	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
		
	drop _merge ; 
	save "`outdir'/package1/facility_claims_2012_`cdate'.dta", replace ;

use `facility3' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/facility_claims_`cdate'.dta", replace ; 

use `facility4' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/facility_claims_2-7_`cdate'.dta", replace ;

use `facility5' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 

	drop _merge ; 
	save "`outdir'/package2/facility_claims_newKcut_`cdate'.dta", replace ;

use `facility6' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 

	drop _merge ; 
	save "`outdir'/package3/facility_claims_`cdate'.dta", replace ; 
	
use `facility7' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package4/facility_claims_`cdate'.dta", replace ; 
	
use `facility8' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	 
	drop _merge ; 
	save "`outdir'/package5/facility_claims_`cdate'.dta", replace ; 

/* Professional */ ; 

use `professional1' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package1/professional_claims_`cdate'.dta", replace ; 

use `professional2' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
		
	drop _merge ; 
	save "`outdir'/package1/professional_claims_2012_`cdate'.dta", replace ;

use `professional3' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/professional_claims_`cdate'.dta", replace ; 

use `professional4' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/professional_claims_2-7_`cdate'.dta", replace ;

use `professional5' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/professional_claims_newKcut_`cdate'.dta", replace ;

use `professional6' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package3/professional_claims_`cdate'.dta", replace ; 
	
use `professional7' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package4/professional_claims_`cdate'.dta", replace ; 
	
use `professional8' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package5/professional_claims_`cdate'.dta", replace ; 

/* Drugs */ ; 	
	
use `drug1' , clear ; 
	replace personid = trim(personid) ;  
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 

	drop _merge ; 
	save "`outdir'/package1/drug_claims_`cdate'.dta", replace ; 

use `drug2' , clear ; 
	replace personid = trim(personid) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personid familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
		
	drop _merge ; 
	save "`outdir'/package1/drug_claims_2012_`cdate'.dta", replace ;

use `drug3' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/drug_claims_`cdate'.dta", replace ; 

use `drug4' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package2/drug_claims_newKcut_`cdate'.dta", replace ;

use `drug5' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package3/drug_claims_`cdate'.dta", replace ;

use `drug6' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package3/drug_claims_SECONDHALF_`cdate'.dta", replace ; 
	
use `drug7' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package4/drug_claim_`cdate'.dta", replace ; 
	
use `drug8' , clear ; 
	replace personidIE = trim(personidIE) ; 
	replace familyid = trim(familyid) ; 
	merge m:1 personidIE familyid using `personidxwalk', keepusing(personid personidIE familyid) ; 

	* drops people in the crosswalk without claims ; 
	drop if _merge == 2 ; 
	tab _merge ; 
	
	* drops claims of people not in the eligibility file and some claims of people with multiple coverage - the remaining claims of these people will be dropped later ; 
	drop if _merge == 1 ; 
	
	drop _merge ; 
	save "`outdir'/package5/drug_claims_`cdate'.dta", replace ; 	
	
log close;
/* end */;