#delimit ;
pause off ;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

log using /disk/agedisk3/oebb.work/cbehrer/oregon/log/cleaning/0_7deduplicate_`cdate'_`ctime'.log;

/* Project:     Oregon Health Plan Choice Analysis                                	*/;
/* Program:     miscellaneus cleaning                                             	*/;
/* Author:      Chris Behrer (christopher_behrer@post.harvard.edu)        			*/;
/* Dates:               															*/;
/* 		Created:        4/29/2015                                 					*/;
/*		Modified:       6/11/2015                         							*/;

/* 0) Specify filepaths as locals                                                 	*/;
local labeldate 11_Jun_2015 ;
loca eligdate 11_May_2015 ; 

local in_data $directory/data/given/clean;
local indir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/" ;
local outdir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/2deduplicated/" ;

local elig_production "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package2/eligibilitydata_productionrun_`eligdate'.dta" ;
local eligibility5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/eligibilitydata_`eligdate'.dta" ;
local eligibility6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package3/eligibilitydata_SECONDHALF_`eligdate'.dta" ;
local eligibility7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package4/eligibilitydata_`eligdate'.dta" ;
local eligibility8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/raw/labeleddta/package5/eligibilitydata_`eligdate'.dta" ;

local facility1 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package1/facility_claims_`labeldate'.dta" ;
local facility2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package1/facility_claims_2012_`labeldate'.dta" ;
local facility3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/facility_claims_`labeldate'.dta" ;
local facility4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/facility_claims_2-7_`labeldate'.dta" ;
local facility5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/facility_claims_newKcut_`labeldate'.dta" ;
local facility6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package3/facility_claims_`labeldate'.dta" ;
local facility7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package4/facility_claims_`labeldate'.dta" ;
local facility8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package5/facility_claims_`labeldate'.dta" ;

local professional1 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package1/professional_claims_`labeldate'.dta" ;
local professional2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package1/professional_claims_2012_`labeldate'.dta" ;
local professional3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/professional_claims_`labeldate'.dta" ;
local professional4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/professional_claims_2-7_`labeldate'.dta" ;
local professional5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/professional_claims_newKcut_`labeldate'.dta" ;
local professional6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package3/professional_claims_`labeldate'.dta" ;
local professional7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package4/professional_claims_`labeldate'.dta" ;
local professional8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package5/professional_claims_`labeldate'.dta" ;

local drug1 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package1/drug_claims_`labeldate'.dta" ;
local drug2 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package1/drug_claims_2012_`labeldate'.dta" ;
local drug3 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/drug_claims_`labeldate'.dta" ;
local drug4 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package2/drug_claims_newKcut_`labeldate'.dta" ;
local drug5 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package3/drug_claims_`labeldate'.dta" ;
local drug6 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package3/drug_claims_SECONDHALF_`labeldate'.dta" ;
local drug7 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package4/drug_claim_`labeldate'.dta" ;
local drug8 "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/1both_ids/package5/drug_claims_`labeldate'.dta" ;

* De-duplicate eligibility file - straight forward select record from most recent data package ;
 use `elig_production', clear ;
    append using `eligibility5' ;
    append using `eligibility6' ;
    append using `eligibility7' ;
    append using `eligibility8' ;

    unique(personid personidIE eligmonth) ;
    duplicates drop ;
    gen eligmo_date = date(eligmonth,"MDY") ;
    format eligmo_date %td ;

    *** keep most recent record of duplicate records ;
    egen max_file = max(file), by(personid personidIE eligmo_date) ;
    keep if file == max_file ;
	drop file ;
    unique(personid personidIE eligmo_date) ;

    save "`outdir'/deduplicated_eligibility_`cdate'.dta", replace ;

    *get chosen plan to de-duplicate by dropping some claims from non-chosen plans ;
	gen month = month(eligmo_date) ;
    keep if month == 10 ;
    gen planyear = year(eligmo_date) ;
    keep personid personidIE planyear plan ;

    rename plan chosenplan ;
    duplicates drop ;
    unique(personid personidIE planyear) ;
    assert _result(18) == _N ;
    replace chosenplan = substr(chosenplan,1,5) ;
    replace chosenplan = substr(chosenplan,1,2) if (substr(chosenplan,1,2) == "K1" | substr(chosenplan,1,2) == "M1") ;
	tempfile chosenplan ;
	save `chosenplan' ;

* Clean and deduplicate facility claims ;
 use `facility8', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	tempfile fac8 ;
	save `fac8' ;

 use `facility7', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	
	gen end = "04/01/2012" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile fac7 ;
	save `fac7' ;
	
 use `facility6', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "07/01/2011" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile fac6 ;
	save `fac6' ;
	
 use `facility5', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	
	gen end = "07/01/2010" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile fac5 ;
	save `fac5' ;
	
* facility 3 and 4 are identical and facility 5 covered the same time period , only use one ; 
	
use `facility2', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "01/01/2010" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile fac2 ;
	save `fac2' ;
	
use `facility1', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "10/01/2009" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile fac1 ;
	save `fac1' ;

 use `fac1', clear ;
    append using `fac2' ;
    append using `fac5' ;
    append using `fac6' ;
    append using `fac7' ;
	append using `fac8' ;
   
   tab month year ; 
   
save "`outdir'/facilityNEW_to_devoid_`cdate'.dta", replace ;
	
* Clean and deduplicate professional claims ;
 use `professional8', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	tempfile prof8 ;
	save `prof8' ;

 use `professional7', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	
	gen end = "04/01/2012" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile prof7 ;
	save `prof7' ;
	
 use `professional6', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "07/01/2011" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile prof6 ;
	save `prof6' ;
	
 use `professional5', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	
	gen end = "07/01/2010" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile prof5 ;
	save `prof5' ;
	
* professional 3 and 4 are identical and professional 5 covered the same time period , only use one ; 
	
use `professional2', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "01/01/2010" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile prof2 ;
	save `prof2' ;
	
use `professional1', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "10/01/2009" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile prof1 ;
	save `prof1' ;

 use `prof1', clear ;
    append using `prof2' ;
    append using `prof5' ;
    append using `prof6' ;
    append using `prof7' ;
	append using `prof8' ;
   
   tab month year ; 
	
save "`outdir'/professionalNEW_to_devoid_`cdate'.dta", replace ;
	
* Clean and deduplicate drugs claims ;
 use `drug8', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	tempfile rx8 ;
	save `rx8' ;

 use `drug7', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	
	gen end = "04/01/2012" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile rx7 ;
	save `rx7' ;
	
 use `drug6', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "07/01/2011" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile rx6 ;
	save `rx6' ;

* drug 6 & 5 are identical, use one ; 
	
 use `drug4', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
	
	gen end = "07/01/2010" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile rx4 ;
	save `rx4' ;
	
* drug 3 and 4 are identical for the 6 month period that we use them for, use only 1 ; 
	
use `drug2', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "01/01/2010" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	tempfile rx2 ;
	save `rx2' ;
	
use `drug1', clear ;
	gen paid_date = date(paiddt, "MDY") ; 
	gen month = month(paid_date) ; 
	gen year = year(paid_date) ; 
	tab month year ; 
		
	gen end = "10/01/2009" ; 
	gen end_date = date(end,"MDY") ; 
	
	drop if paid_date >= end_date ; 
	
	tab month year ; 
	
	destring units, replace ; 
	
	tempfile rx1 ;
	save `rx1' ;

 use `rx1', clear ;
    append using `rx2' ;
    append using `rx4' ;
    append using `rx6' ;
    append using `rx7' ;
	append using `rx8' ;
   
   tab month year ; 
	
save "`outdir'/drugNEW_to_devoid_`cdate'.dta", replace ;	
	
log close ; 