#delimit ;
pause off ;
set more off ; 

local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;

log using /disk/agedisk3/oebb.work/cbehrer/oregon/log/cleaning/0_8devoidfacility_`cdate'_`ctime'.log ;

/* Project:     Oregon Health Plan Choice Analysis                                	*/;
/* Program:     miscellaneus cleaning                                             	*/;
/* Author:      Chris Behrer (christopher_behrer@post.harvard.edu)        			*/;
/* Dates:               													*/;
/* 		Created:        4/29/2015                                 				*/;
/*		Modified:       2/10/2016                         						*/;

/* 0) Specify filepaths as locals                                                 	*/;
local in_data $directory/data/given/clean;
local indir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/2deduplicated/" ;
local outdir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/3devoid/" ;

local ods_tos1 "`in_data'/treatmentcodematch/ods_tos.dta" ;
local ods_tos2 "`in_data'/treatmentcodematch/ods_tos_11-13.dta" ;
local ods_tos3 "`in_data'/treatmentcodematch/oebb_mit_svc_descs_201303_201402.dta" ;
local kaiser_orig "`in_data'/treatmentcodematch/KAISER_modified.txt" ;

*Cleaning task: Drop void claims - pair a claim labelled as void with the standard claim that it voids * ;
use "`indir'/facilityNEW_to_devoid_11_Jun_2015.dta", clear ;
	drop month year end end_date file provcity provname provstate provzipcd mediacd vendorcd vendorcd2 mediacd ; 
	
	* Cleaning task : fix some variable values ;
	*numeric over string ;
	rename networkpaid network;
	replace network="1" if network=="~";
	replace network="1" if network=="Y";
	replace network="0" if network=="N";
	destring network, replace;
	
	* we have some leading/trailing blanks;
	foreach string in plan firstsrvcdt lastsrvcdt servicedetaildt paiddt diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9 diseasecd eligtag familyid fullinsured orderingprov personid personidIE plan procedure proc_surg procmodcd provnetwork providerid revenuecd security datasource claimid recordid { ;
		replace `string' = trim(`string') ;
    } ;

	* some diagnosis codes with 0 as the final digit have dropped the 0 leading to duplicatesAdd zeros so that all diagnosis codes are 5 digit string;
	gen zero = "00000" ;
	foreach diagvar in diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9 {;
		egen fix_`diagvar' = concat(`diagvar' zero);
		replace fix_`diagvar' = substr(fix_`diagvar',1,5);
		replace `diagvar' = fix_`diagvar' ;
		drop fix_`diagvar';
		replace `diagvar' = "" if (substr(`diagvar',1,1)=="~"|substr(`diagvar',1,1)==".") ;
	};
	drop zero ;
	
	gen absamt = abs(allowedamt) ;
	tab adjustcd ;
	preserve ;
		bys personid: gen voidclaim = claimid if adjustcd == 2 ;
		bys personid: gen voidamt = absamt if adjustcd == 2 ;
		keep personid claimid voidclaim absamt voidamt ;
		display _N ;
		drop if voidclaim == "" ;
		duplicates drop ;
		sort personid claimid ;
		di _N ;
	tempfile claimid ;
	save `claimid',replace ;
	restore ;
	cap drop _merge ;
	merge m:1 personid claimid absamt using `claimid' ;
	assert _merge!=2 ;
	drop _merge ;
	gen void = 1 if claimid == voidclaim & absamt == voidamt ;
	display _N ;
	
	* Drop all positive/negative pairs of void claims, which have negative allowedamts ;
	* Start with most precise possible requirements for reversal to avoid triplets, sets of 4 etc ;
	* as necessary progressively relax grouping variables  ;
	* what's going on with 2013080100182970104 - huge allowed amount, many claims back and forth, voided & not;
	* we have to be careful with void claims with allowedamt == 0;
	gen abscopay = abs(copay) ;
	gen abscharge = abs(chargeamt) ;
	gen sign = 1 if allowedamt > 0 & void == 1 ;
		
	replace sign = -1 if allowedamt < 0 & void == 1 ;
	replace sign = 1 if allowedamt == 0 & void == 1 & adjustcd == 3 ;
	replace sign = -1 if allowedamt == 0 & void == 1 & adjustcd == 2 ;
	
	* most precise pairs ;
	bys absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	bys absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: gen order = _n ;
	sum order ;
	
	gen pair = . ;
    forvalues i = 1(2)559 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)600 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)559 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)600 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop order ; 
	
	* remove paiddt - allow voiding to occur on different day;
	bys absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	bys absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: gen order = _n ;
	sum order ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)559 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)600 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)559 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)600 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid linenum providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop order ; 
	
	* remove linenum, but add back in paiddt - allow biller to correct mistake in realtime ;
	bys absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt paiddt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	bys absamt abscopay abscharge personid claimid paiddt providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: gen order = _n ;
	sum order ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)1117 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid paiddt providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)1118 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid paiddt providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)1117 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid paiddt providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)1118 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid paiddt providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop order ; 
	
	* remove linenum and paiddt ;
	bys absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0;
	drop signsum ; 
	
	bys absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: gen order = _n ;
	sum order ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 
	
	*** remove diag codes ; 
	bys absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0;
	drop signsum ; 
	
	bys absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : gen order = _n ;
	sum order ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid claimid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop sign ; 
	drop order ; 
	drop pair ; 
	
	tab adjustcd ;
	drop void voidamt voidclaim ; 
	preserve ;
		bys personid: gen voidsrvcdt = firstsrvcdt if adjustcd == 2 ;
		bys personid: gen voidamt = absamt if adjustcd == 2 ;
		keep personid firstsrvcdt voidsrvcdt absamt voidamt ;
		display _N ;
		drop if voidsrvcdt == "" ;
		duplicates drop ;
		sort personid firstsrvcdt ;
		di _N ;
	tempfile firstsrvcdt ;
	save `firstsrvcdt',replace ;
	restore ;
	cap drop _merge ;
	merge m:1 personid firstsrvcdt absamt using `firstsrvcdt' ;
	assert _merge!=2 ;
	drop _merge ;
	gen void = 1 if firstsrvcdt == voidsrvcdt & absamt == voidamt ;
	display _N ;
	
	gen sign = 1 if allowedamt > 0 & void == 1 ;
		
	replace sign = -1 if allowedamt < 0 & void == 1 ;
	replace sign = 1 if allowedamt == 0 & void == 1 & adjustcd == 3 ;
	replace sign = -1 if allowedamt == 0 & void == 1 & adjustcd == 2 ;
	
	bys absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
		gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
		gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code diagnosis1 diagnosis2 diagnosis3 diagnosis4 diagnosis5 diagnosis6 diagnosis7 diagnosis8 diagnosis9: egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 
	
	*** drop diag codes ; 
	bys absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
		gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscopay abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 
	
	tab adjustcd ; 
	
	*** drop abscopay ; 
	bys absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;

	pause ; 
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid providerid procedure firstsrvcdt lastsrvcdt revenuecd orderingprov diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 

	* drop provider info ; 
	bys absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;

	pause ; 
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt revenuecd diag3code : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 
	
	*** drop revenuecd & diag3code ; 
	bys absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscharge personid procedure firstsrvcdt lastsrvcdt : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;

	pause ; 
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt lastsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 
	
	*** drop lastsrvcdt ; 
	bys absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscharge personid procedure firstsrvcdt : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;

	pause ; 
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid procedure firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 

	*** drop procedure ; 
	bys absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt abscharge personid firstsrvcdt : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;

	pause ; 
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt abscharge personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 	

	*** drop abscharge ; 
	bys absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	bys absamt personid firstsrvcdt : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;

	pause ; 
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 2(2)2502 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	gen pair = . ;
    forvalues i = 1(2)2501 { ;
        replace pair = `i' if order == `i' ;
        replace pair = `i' if order == `i'+1 ;
    } ;
	bys pair absamt personid firstsrvcdt : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop pair ; 
	drop order ; 	
	
	pause on ; 
	pause ; 
	
	gen void = 1 if adjustcd == 2 ; 
	replace void = 0 if adjustcd == 3 ; 
	egen minvoid = min(void), by(personid firstsrvcdt absamt) ; 
	drop if minvoid == 1 ; 
	drop if void = 1 & allowedamt == 0 ; 
	
	
	drop absamt - numvoid ; 

	drop proc_surg adjustcd paid_date pcpresp netpayment netpayment_detail fullinsured thirdptyamt chargeamt datasource discount customcode security empcode codingsys hsa_amt hra_amt conditioncd lifestylecd eligtag srvccount ;
	
	drop if copay < 0 ; 
	drop if coinsurance < 0 ; 
	drop if deductible < 0 ; 	
	
	save "`outdir'/facilityNEW_devoid_`cdate'.dta", replace ;
    pause ;

log close ; 
	