#delimit ;
pause off ;
set more off ; 

local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;

log using /disk/agedisk3/oebb.work/cbehrer/oregon/log/cleaning/0_10devoiddrug_`cdate'_`ctime'.log ;

/* Project:     Oregon Health Plan Choice Analysis                                	*/;
/* Program:     miscellaneus cleaning                                             	*/;
/* Author:      Chris Behrer (christopher_behrer@post.harvard.edu)        			*/;
/* Dates:               															*/;
/* 		Created:        4/29/2015                                 					*/;
/*		Modified:       5/4/2015                         							*/;

/* 0) Specify filepaths as locals                                                 	*/;
local in_data $directory/data/given/clean;
local indir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/2deduplicated/" ;
local outdir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/3devoid/" ;

use "`indir'/drugNEW_to_devoid_11_Jun_2015.dta", clear ;
	drop month year end end_date file provcity provname provstate provzipcd ; 
	
	foreach string in capitated_srv srvcdt paiddt eligtag familyid fullinsured recordid ndc orderingprov pcpresp personid plan providerid dispensecd security datasource claimid personidIE { ; 
		replace `string' = trim(`string') ; 
	} ; 	
	
	gen absamt = abs(allowedamt) ;
	replace absamt = round(absamt, 0.001) ;
	tab adjustcd ;
	preserve ;
		bys personid: gen voidclaim = claimid if adjustcd == 2 ;
		bys personid: gen voidamt = absamt if adjustcd == 2 ;
		keep personid claimid voidclaim absamt voidamt ;
		display _N ;
		drop if voidclaim == "" ;
		duplicates drop ;
		sort personid claimid ;
		di _N ;
	tempfile claimid ;
	save `claimid',replace ;
	restore ;
	cap drop _merge ;
	merge m:1 personid claimid absamt using `claimid' ;
	assert _merge!=2 ;
	drop _merge ;
	gen void = 1 if claimid == voidclaim & round(absamt,0.001) == round(voidamt,0.001) ;
	display _N ;

	* Drop all positive/negative pairs of void claims, which have negative allowedamts ;
	* Start with most precise possible requirements for reversal to avoid triplets, sets of 4 etc ;
	* as necessary progressively relax grouping variables  ;
	* what's going on with 2013080100182970104 - huge allowed amount, many claims back and forth, voided & not;
	* we have to be careful with void claims with allowedamt == 0;
	gen abscopay = abs(copay) ;
	gen abscharge = abs(chargeamt) ;
	gen sign = 1 if allowedamt > 0 & void == 1 ;
		
	replace sign = -1 if allowedamt < 0 & void == 1 ;
	replace sign = 1 if allowedamt == 0 & void == 1 & adjustcd == 3 ;
	replace sign = -1 if allowedamt == 0 & void == 1 & adjustcd == 2 ;
		
	* most precise pairs ;
	bys absamt abscopay abscharge personid claimid providerid srvcdt paiddt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	
	* remove paiddt - allow voiding to occur on different day;
	bys absamt abscopay abscharge personid claimid providerid srvcdt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	drop signsum ;
	drop sign ;
    drop void ;
	drop voidclaim ;
    drop voidamt ;
	
	tab adjustcd ;
	preserve ;
		bys personid: gen voidsrvcdt = srvcdt if adjustcd == 2 ;
		bys personid: gen voidamt = absamt if adjustcd == 2 ;
		keep personid srvcdt ndc voidsrvcdt absamt voidamt ;
		display _N ;
		drop if voidsrvcdt == "" ;
		duplicates drop ;
		sort personid srvcdt ;
		di _N ;
	tempfile srvcdt ;
	save `srvcdt',replace ;
	restore ;
	cap drop _merge ;
	merge m:1 personid srvcdt ndc absamt using `srvcdt' ;
	assert _merge!=2 ;
	drop _merge ;
	gen void = 1 if srvcdt == voidsrvcdt & round(absamt,0.001) == round(voidamt,0.001) ;
	display _N ;
	
	gen sign = 1 if allowedamt > 0 & void == 1 ;
	replace sign = -1 if allowedamt < 0 & void == 1 ;
	replace sign = 1 if allowedamt == 0 & void == 1 & adjustcd == 3 ;
	replace sign = -1 if allowedamt == 0 & void == 1 & adjustcd == 2 ;
	
	bys absamt abscopay abscharge personid providerid srvcdt paiddt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	
	drop if void == 1 & signsum == 0 ; 
	drop signsum ; 
	* remove paiddt - allow voiding to occur on different day;
	bys absamt abscopay abscharge personid providerid srvcdt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ;
	
	* Deal with triplets etc . ; 
	drop sign ; 
	drop signsum ; 
	drop voidsrvcdt ; 
	drop voidamt ; 
	drop void ; 
	tab adjustcd ;
	preserve ;
		bys personid: gen voidsrvcdt = srvcdt if adjustcd == 2 ;
		bys personid: gen voidamt = absamt if adjustcd == 2 ;
		keep personid srvcdt ndc voidsrvcdt absamt voidamt ;
		display _N ;
		drop if voidsrvcdt == "" ;
		duplicates drop ;
		sort personid srvcdt ;
		di _N ;
	tempfile srvcdt ;
	save `srvcdt',replace ;
	restore ;
	cap drop _merge ;
	merge m:1 personid srvcdt ndc absamt using `srvcdt' ;
	assert _merge!=2 ;
	drop _merge ;
	gen void = 1 if srvcdt == voidsrvcdt & round(absamt,0.001) == round(voidamt,0.001) ;
	display _N ;
	
	gen sign = 1 if allowedamt > 0 & void == 1 ;
	replace sign = -1 if allowedamt < 0 & void == 1 ;
	replace sign = 1 if allowedamt == 0 & void == 1 & adjustcd == 3 ;
	replace sign = -1 if allowedamt == 0 & void == 1 & adjustcd == 2 ;	
	
	bys absamt personid providerid srvcdt ndc orderingprov dispensecd refillnum : gen order = _n ;
	sum order ; 
	
	gen pair = . ;
    forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
	
	bys pair absamt personid providerid srvcdt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 

	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov dispensecd refillnum : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
		
	drop order pair signsum ; 
	bys absamt personid providerid srvcdt ndc orderingprov : gen order = _n ;
	sum order ; 

	gen pair = . ;
    forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
	
	bys pair absamt personid providerid srvcdt ndc orderingprov : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	drop pair signsum ;
	gen pair = . ;
	forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	drop pair signsum ;
	gen pair = . ;
	forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid providerid srvcdt ndc orderingprov : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
	
	drop order pair ; 
	bys absamt personid srvcdt ndc  : gen order = _n ;
	sum order ;

	gen pair = . ;
    forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
	
	bys pair absamt personid srvcdt ndc : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid srvcdt ndc : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	drop pair signsum ;
	gen pair = . ;
	forvalues i = 1(2)11 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid srvcdt ndc : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	drop pair signsum ; 
	gen pair = . ;
    forvalues i = 2(2)10 {;
		replace pair = `i' if order == `i' ;
		replace pair = `i' if order == `i'+1 ;
	};
		
	bys pair absamt personid srvcdt ndc : egen signsum = sum(sign) ;
	replace signsum = . if sign == . ;
	tab signsum ;
	drop if void == 1 & signsum == 0 ; 
	
	* some claims have negative copays, but are not marked as void ; 
	* these mess up sign sum, so drop them, and then if there was an actual void claim with a negative amount for the same absolute value ; 
	* this void will be dropped below as the only claim for a drug on that day ; 
	drop if allowedamt < 0 & adjustcd == 3 ; 
	
	cap drop void ; 
	gen void = 1 if adjustcd == 2 ; 
	gen counter = 1 ; 
	egen sum = sum(counter), by(personid ndc) ; 
	egen sumvoid = sum(void), by(personid ndc) ;
	tab sum sumvoid ; 

	* if the only claims this person ever got for this drug is a void, then we can drop it ; 
	drop if sumvoid == sum ; 
	drop sum sumvoid ; 
	egen sum = sum(counter), by(personid ndc srvcdt ) ; 
	egen sumvoid = sum(void), by(personid ndc srvcdt) ;
	tab sum sumvoid ; 
	* if the only claims this person ever got for this drug on a specific day is a void, then we can drop it ; 
	drop if sumvoid == sum ; 
	drop absamt - sumvoid ; 
	gen void = 1 if adjustcd == 2 ; 
	replace void = 0 if adjustcd == 3 ; 
	gen absamt = abs(allowedamt) ;
	egen hasvoid = max(void), by(personid ndc srvcdt) ;
	egen minvoid = min(void), by(personid ndc srvcdt absamt) ;
	drop if minvoid == 1 ; 
	assert adjustcd == 3 ; 
	
	drop adjustcd capitated_srv customcode empcode security datasource paid_date eligtag fullinsured vendorcd vendorcd2 void hasvoid chargeamt discount dispfee hsa_amt hra_amt prodcost units netpayment pcpresp dispensecd refillnum salestax thirdp empstatus sex ; 

	save "`outdir'/drugs_devoid_`cdate'.dta", replace ;

log close ; 
	