#delimit;
clear;
cap log close;
set more off;

pause off ; 

/********************************************************
$directory is: directory /disk/agedisk3/oebb.work/cbehrer/oregon/

-- data set drops all retirees and COBRA based plans.
- input files are from dropbox.  These files were provided by OEBB.
	(1) $directory/data/given/PlanEligibilityallYears20131202_`x'
	(2) $directory/data/given/PlanRateStructureandPremium.csv

- OUTPUT FILE: $directory/data/clean/oregonpremium_`cdate'.dta
	- used in computeempprem_`latestdate'.do;
- secondary output file: $directory/data/clean/choiceset_`cdate'.dta //  this file is an input into the calcinput file
**********************************************************/;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);

log using $directory/log/premium/0_Aoregonpremium_`cdate'.log, replace;

************************************ load in the MEDICAL AND RX data (all 3 spreadsheets) ********************************* ; 
insheet using $directory/data/given/PlanEligibilityallYears20131202_1.csv;
rename empcode empid;
rename employmenttype emptype;
rename memcode memid;
rename membertype memtype; 

preserve;
insheet using $directory/data/given/PlanEligibilityallYears20131202_2.csv, clear;
rename v1 carrier;
rename v2 entitynum;
rename v3 entityname;
rename v4 emptype;
rename v5 empid;
rename v6 memtype;
rename v7 memid;
rename v8 planname; 
rename v9 plancode; 
rename v10 plantype; 
rename v11 eff_date; 
rename v12 exp_date; 
tempfile two;
save `two';
restore;

preserve;
insheet using $directory/data/given/PlanEligibilityallYears20131202_3.csv, clear;
rename v1 carrier;
rename v2 entitynum;
rename v3 entityname;
rename v4 emptype;
rename v5 empid;
rename v6 memtype;
rename v7 memid;
rename v8 planname; 
rename v9 plancode; 
rename v10 plantype; 
rename v11 eff_date; 
rename v12 exp_date; 
tempfile three;
save `three';
restore;

preserve;
insheet using $directory/data/given/PlanEligibilityallYears20131202_4.csv, clear;
rename v1 carrier;
rename v2 entitynum;
rename v3 entityname;
rename v4 emptype;
rename v5 empid;
rename v6 memtype;
rename v7 memid;
rename v8 planname; 
rename v9 plancode; 
rename v10 plantype; 
rename v11 eff_date; 
rename v12 exp_date; 
tempfile four;
save `four';
restore;

preserve;
insheet using $directory/data/given/PlanEligibilityallYears20131202_5.csv, clear;
rename v1 carrier;
rename v2 entitynum;
rename v3 entityname;
rename v4 emptype;
rename v5 empid;
rename v6 memtype;
rename v7 memid;
rename v8 planname; 
rename v9 plancode; 
rename v10 plantype; 
rename v11 eff_date; 
rename v12 exp_date; 
tempfile five;
save `five';
restore;

append using `two';
append using `three'; 
append using `four'; 
append using `five'; 
compress;

	keep entitynum entityname plancode planname empid memid memtype *_date;
	duplicates drop;
	
	unique(entitynum) ;

	
	gen length=length(eff_date);
	gen planyear1=substr(eff_date, 7,2) if length==8;
	replace planyear1=substr(eff_date, 8,2) if length==9 & planyear1==""; 
	gen eff_mo_s=substr(eff_date,3,3) if length==8 ;
	replace eff_mo_s=substr(eff_date,4,3) if length==9 & eff_mo_s=="";
	gen eff_day_s=substr(eff_date,1,1) if length==8 ;
	replace eff_day_s=substr(eff_date,1,2) if length==9 & eff_day_s=="";
	drop length;
	
	gen length=length(exp_date); 
	gen planyear2=substr(exp_date, 7,2) if length==8;
	replace planyear2=substr(exp_date, 8,2) if length==9 & planyear2==""; 
	gen exp_mo_s=substr(exp_date,3,3) if length==8 ;
	replace exp_mo_s=substr(exp_date,4,3) if length==9 & exp_mo_s=="";
	gen exp_day_s=substr(exp_date,1,1) if length==8 ;
	replace exp_day_s=substr(exp_date,1,2) if length==9 & exp_day_s=="";
	
	replace planyear1="20" + planyear1; destring planyear1, replace;
	replace planyear2="20" + planyear2; destring planyear2, replace;
	
	gen planyear=0;
	replace planyear=2008 if planyear1==2008 & planyear2==2009;
	replace planyear=2009 if planyear1==2009 & planyear2==2010;
	replace planyear=2010 if planyear1==2010 & planyear2==2011;
	replace planyear=2011 if planyear1==2011 & planyear2==2012;
	replace planyear=2012 if planyear1==2012 & planyear2==2013;
	replace planyear=2013 if planyear1==2013 & planyear2==2014;
	
	list entitynum empid memid plancode eff_date exp_date planyear* if planyear==0;
	
	* these are all incomplete plans ; 
	tab planyear1 planyear2 if planyear == 0 ; 
	drop if planyear==0;
	
	drop length ; 
	gen length_eff_day = length(eff_day_s) ; 
	gen length_exp_day = length(exp_day_s) ; 
	replace eff_day_s = "0" + eff_day_s if length_eff_day == 1 ; 
	replace exp_day_s = "0" + exp_day_s if length_exp_day == 1 ; 
	
	gen exp_mo_num = "" ; 
	gen eff_mo_num = "" ; 
	replace eff_mo_num ="01" if eff_mo_s == "Jan" ; 
	replace eff_mo_num ="02" if eff_mo_s == "Feb" ; 
	replace eff_mo_num ="03" if eff_mo_s == "Mar" ; 
	replace eff_mo_num ="04" if eff_mo_s == "Apr" ; 
	replace eff_mo_num ="05" if eff_mo_s == "May" ; 
	replace eff_mo_num ="06" if eff_mo_s == "Jun" ; 
	replace eff_mo_num ="07" if eff_mo_s == "Jul" ; 
	replace eff_mo_num ="08" if eff_mo_s == "Aug" ; 
	replace eff_mo_num ="09" if eff_mo_s == "Sep" ; 
	replace eff_mo_num ="10" if eff_mo_s == "Oct" ; 
	replace eff_mo_num ="11" if eff_mo_s == "Nov" ; 
	replace eff_mo_num ="12" if eff_mo_s == "Dec" ; 
	                       
	replace exp_mo_num ="01" if exp_mo_s == "Jan" ; 
	replace exp_mo_num ="02" if exp_mo_s == "Feb" ; 
	replace exp_mo_num ="03" if exp_mo_s == "Mar" ; 
	replace exp_mo_num ="04" if exp_mo_s == "Apr" ; 
	replace exp_mo_num ="05" if exp_mo_s == "May" ; 
	replace exp_mo_num ="06" if exp_mo_s == "Jun" ; 
	replace exp_mo_num ="07" if exp_mo_s == "Jul" ; 
	replace exp_mo_num ="08" if exp_mo_s == "Aug" ; 
	replace exp_mo_num ="09" if exp_mo_s == "Sep" ; 
	replace exp_mo_num ="10" if exp_mo_s == "Oct" ; 
	replace exp_mo_num ="11" if exp_mo_s == "Nov" ; 
	replace exp_mo_num ="12" if exp_mo_s == "Dec" ; 
	
	gen effyear = string(planyear1) ; 
	gen expyear = string(planyear2) ; 
	
	gen effdate = eff_day_s + "/" + eff_mo_num + "/" + effyear ; 
	gen expdate = exp_day_s + "/" + exp_mo_num + "/" + expyear ; 
	
	gen startdate = date(effdate,"DMY") ; 
	format startdate %td ; 
	gen enddate = date(expdate,"DMY") ; 
	format enddate %td ; 
	gen cov_length = enddate - startdate ; 
	tab cov_length ; 
	
	gen plantype = substr(plancode,2,3) ;
	replace plantype = "MED" if plantype == "MP1" ;
	replace plantype = "MED" if plantype == "MP2" ;
	
	gen med_length = cov_length if plantype == "MED" ; 
	
	egen md_med_length = mode(med_length), by(entitynum empid memid planyear) maxmode ;
	replace cov_length = md_med_length if md_med_length != . ; 
	
	* full year plans , allow for leap year ; 
	keep if cov_length == 364 | cov_length == 365 ;
	
	gen cobra = 1 if strpos(memtype,"cobra") | strpos(memtype,"Cobra") | strpos(memtype,"COBRA") ; 
	replace cobra = 0 if cobra == . ; 
	
	gen retired = 1 if strpos(memtype,"Retiree") ; 
	replace retired = 0 if retired == . ; 
	
	gen selfpay = 1 if strpos(memtype,"SelfPay") ; 
	replace selfpay = 0 if selfpay == . ; 
	
	gen todrop = cobra + selfpay + retired ; 
	
	assert todrop == 1 if memid > 7 ; 
	assert todrop == 0 if memid < 8 ; 
	
	* memid > 7 corresponds to self pay, retirees, and COBRA - we do not want to analyze these plans ; 
	drop if memid > 7;
	
	keep entitynum entityname plancode empid memid planyear planname;
	
	duplicates drop;
	
******************************* drop COBRA (B`x') and RETIREEs and clean **********************************; 
	gen empkey=substr(empid, 1, 1);
	drop if empkey=="B" | empkey =="R"; // cobra and retirees;   
	
	tab entitynum ; 
	
	gen type=substr(plancode,2,1);
	drop if type=="I" | type=="O"; // these are KOOHI, KIDOH, KIMHI and KOMHI;
	gen planfirst=substr(plancode, 1, 1);

	gen plan=substr(plancode, 1, 5);
		gen tab=substr(plancode , 6,1);
	replace plan=substr(plancode, 1,6) if type=="D" & (tab=="1" | tab=="2");
		assert plancode!="" & empid!="" & memid!=.;

	duplicates drop; compress;

	gen ratestructure=substr(plancode,6,1); // compositve v. terred specification; 
	
	tempfile medworking;
	save `medworking';
******************************* separating out rx, dental and vision **********************************; 
preserve;
keep if type=="V";
rename plan visplan;

tab visplan ; 

keep if visplan !="";
isid (entitynum empid memid planyear visplan) ;
keep entitynum empid memid planyear visplan ; 
duplicates drop;

tempfile vision;
save `vision';
restore;

preserve;
keep if type=="D";
rename plan dentalplan;

tab dentalplan ; 

keep if dentalplan !="";
isid (entitynum empid memid planyear dentalplan) ;
keep entitynum empid memid planyear dentalplan ;
duplicates drop ;

tempfile dental;
save `dental';
restore;

************************************ combining dental/vison with med/rx ********************************* ; 
use `medworking', clear ;
	gen Kfirst=(planfirst=="K") ;

	tab type ; 
	
	keep if type=="M" ;

joinby  entitynum empid memid planyear using `vision', unmatched (both) ;

gen tag=(visplan=="KVIS5" & Kfirst==0) ;
bys entitynum empid memid planyear plan: egen mintag=min(tag) ;
	tab mintag;
	
	replace visplan="" if mintag==1 ;
		drop *tag ;
		gen tag=(visplan=="KVIS5" & Kfirst==0) ;
		bys entitynum empid memid planyear plan: egen mintag=min(tag) ;
		
		assert mintag==0; drop *tag;

		*only kaiser medical plan policy holders can be in kaiser vision plans ;
		tab visplan Kfirst ;  

		drop if visplan=="KVIS5" & Kfirst==0 ;
		tab _merge ;  
		tab visplan plan ; 

		drop if _merge==2 ; 
		drop _merge Kfirst ;

		joinby  entitynum empid memid planyear using `dental', unmatched (both) ;
		tab _merge ; 
		
		gen dentfirst = substr(dentalplan,1,1) ; 
		
		gen Kfirst=(planfirst=="K") ;
		gen tag=(dentfirst=="K" & Kfirst==0) ;
		bys entitynum empid memid planyear plan: egen mintag=min(tag) ;
		
		assert mintag==0 ; 
		drop *tag ;

		*only kaiser medical plan policy holders can be in kaiser dental plans ;

		tab dentfirst Kfirst ; 
		drop if dentfirst=="K" & Kfirst==0 ;
		tab _merge ;  
		tab dentalplan plan ; 
		
		drop if _merge==2 ; 
		drop _merge Kfirst dentfirst ; 

************************************  creating tiers  ********************************* ; 
gen one=1;

preserve;
keep entitynum one;
gen tier=_n;

keep if tier <5;
keep one tier;

tempfile tier;
save `tier';
restore;

joinby one using `tier', unmatched (both);
assert _merge==3; drop _merge one;

************* our plan rate structure (below) has separate rx premiums, so we need to divide out our rx **************; 

gen rxplan="OMED9" if type=="M" & plan=="OMED9";
	replace rxplan="KRX1" if type=="M" & planfirst=="K";
	replace rxplan="PRX1" if type=="M" & planfirst=="P" & rxplan=="";

	gen tag=substr(planname , 23, 1) if  rxplan==""  & type=="M";
	replace rxplan="ORXA" if tag=="A"  & rxplan=="" & type=="M";
	replace rxplan="ORXB" if tag=="B"  & rxplan=="" & type=="M";
	replace rxplan="ORXC" if tag=="C"  & rxplan=="" & type=="M";
	drop tag;

	replace rxplan="MMED" if planyear==2013 & planfirst=="M";
	* CB added - MMEDH has different drug plan payment structure ; 
	* get rid of this  - no one has MMEDH H available? I think ? Double check ; 
	replace rxplan="MMEDH" if planyear == 2013 & plan == "MMEDH" ; 
	assert rxplan !="" if type=="M";

tempfile working;
save `working';
********************************************oregon plan rate structure******************************************; 
insheet using $directory/data/given/PlanRateStructureandPremium.csv, names comma clear;
	notes: these premiums are separate for rx and med;
	
	gen plan=substr(plancode, 1, 5);
	gen type=substr(plan,2,1);
	
	replace planyear=substr(planyear, 7, 4);
	destring planyear, replace;
	duplicates drop;

gen tier=0;
replace tier=1 if plantier=="Employee Only";
replace tier=2 if plantier=="Employee & Partner" | plantier=="Employee & Spouse";
replace tier=3 if plantier=="Employee & Children" | plantier=="Employee, Employees Children & Partners Children"
	| plantier=="Employee & Partners Children";
replace tier=4 if plantier=="Employee, Partner, Employees Children & Partners Children" 
	| plantier=="Employee, Partner & Partners Children" 
	| plantier=="Employee, Partner & Employees Children"
	| plantier=="Employee, Spouse & Children";
drop plantier;

replace ratestructure=substr(ratestructure, 1, 1);

replace premium = subinstr(premium,",", "", 1);
destring premium, replace;

gen structure=substr(plancode, 6,1);
replace plan=substr(plancode, 1, 6) if type=="D" & (structure=="1" | structure=="2");   
	drop structure plannamelong;
replace plan=substr(plancode, 1, 4) if type=="R";

duplicates drop;

preserve; // med premiums; 
keep if type=="M";
keep plan planyear tier premium ratestructure; // merge by plan planyear ratestructure;
duplicates drop;
rename premium medpremium;

tempfile med;
save `med';
restore;

preserve; // rx premiums;
keep if type=="R";
gen rxplan=plan;
keep rxplan planyear tier premium ratestructure; // merge by plan planyear ratestructure tier;
duplicates drop;
rename premium rxpremium; 

tempfile rx;
save `rx';
restore;

preserve; // vision premiums;
keep if type=="V";
rename plan visplan;
keep visplan planyear tier premium ratestructure; // merge by plan planyear ratestructure tier;
duplicates drop;
rename premium vispremium;

tempfile vis;
save `vis';
restore;

// dental premiums;
keep if type=="D";
rename plan dentalplan;
gen dfirst=substr(dentalplan,1,1);

preserve; // 2010 WDEN premiums are just 2009;
keep if planyear==2009 | planyear==2010;
keep if dfirst=="W";
assert planyear !=2010;
replace planyear=2010;

tempfile wden;
save `wden';
restore;

append using `wden';
keep dentalplan planyear tier premium ratestructure; // merge by plan planyear ratestructure tier;
duplicates drop;
rename premium dentalpremium;

tempfile dental;
save `dental';

****************** combining choice set with premiums ******************;
use `working', clear;
drop plancode planname;
duplicates drop;

* this entity has one composite medical plan, and everything else is tiered. We are assuming this is some kind of data mistake ; 
replace ratestructure = "T" if entitynum == 2051 & memid == 4 & empid == "LF" & planyear == 2010 & ratestructure == "C" ; 

merge m:1 plan planyear ratestructure tier using `med';
assert type !="M" if _merge==1; rename _merge mergemed;

merge m:1 rxplan planyear ratestructure tier using `rx';
assert _merge !=2; 
assert planyear > 2010 | rxplan=="OMED9" if _merge==1; rename _merge mergerx;
replace rxpremium=0 if rxplan=="OMED9";
replace rxpremium=0 if planyear > 2010 ; 
assert medpremium !=.;
assert rxpremium !=.;

/*  dental vision */;
merge m:1 visplan planyear ratestructure tier using `vis';
assert _merge !=2;
assert visplan=="" if _merge==1;
tab _merge; rename _merge mergevis;

merge m:1 dentalplan planyear ratestructure tier using `dental';
assert _merge !=2;
assert dentalplan=="" if _merge==1;
tab _merge; rename _merge mergedental;

drop *merge*;

duplicates drop;

bys entitynum empid memid planyear plan rxplan dentalplan visplan tier ratestructure: gen count=_N;
assert count==1;

/* ***************** creating correct premium ******************;
RX and Med are separate for years <2011, but after they are represented by one premium.
As a result, we want to  create one premium for earlier years as well. 

How do we want to handle dental and vision premiums? I think we want a vision and dental 
premium on each claim.  This is hard though because they can have any vision plan 
and any dental plan;
 if entitynum ==1894 & empid=="AF" & memid==4 & planyear==2008

******************************************************************/;
gen premium_rxmed=rxpremium+medpremium;
assert premium_rxmed !=.; 
drop *planfirst entityname count  ;
duplicates drop;
****************** reshaping ******************;

preserve;
keep if ratestructure=="T";
rename tier level;
reshape wide premium_rxmed rxpremium medpremium vispremium dentalpremium, i(entitynum empid memid planyear plan rxplan dentalplan visplan ) j(level);

tempfile tier;
save `tier';
restore;

drop if ratestructure=="T";
drop tier;

append using `tier';

compress;
save $directory/data/built/premium/oregonpremium_`cdate'.dta, replace; 

keep entitynum memid empid planyear plan rxplan;
duplicates drop;

tostring entitynum, replace ; 

save $directory/data/built/premium/choiceset_`cdate'.dta, replace ;

keep planyear plan rxplan ; 
duplicates drop ; 

save $directory/data/built/premium/choiceset_acg_`cdate'.dta, replace ;

