#delimit;
/* created 8/14 to match the existing contribution info survey to the eligibility file, filling in the gaps.
Also, at the end, I compute the weighted avergae of observations that we're missing - AHS*/;
set more off;
cap log close;
local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

log using $directory/log/premium/0_Bcontributionfile_`cdate'_`ctime'.log, replace;

local eligibilitydata "$directory/data/cleaning/2deduplicated/deduplicated_eligibility_11_Jun_2015.dta"; 

local contributiondate $contributiondate;

/* Assigning all possible plans in the choice set (district) to each bene */;
use `eligibilitydata'; 

	// Looks like basically all we care about from the eligibility files (for now) is the eligibility date - what year is the plan for?
	
	drop  v*  empcode eligsrce statusgrp msa popcount state mhsacov union eligflag zipcd updatedt;
	gen eligdt = date(eligmonth,"MDY");
	format eligdt %d;

	gen eligst = date(eligstart,"MDY");
	gen year=year(eligst);
		drop eligst;
	gen month=month(eligdt);

	// Assign year based off the October enrollment period. 
	
	gen planyear = 2008 if eligdt>=mdy(10,1,2008) & eligdt <=mdy(9,30,2009);
	replace planyear = 2009 if eligdt > =mdy(10,1,2009) & eligdt <=mdy(9,30,2010) ;
	replace planyear = 2010 if eligdt >= mdy(10,1,2010) & eligdt <=mdy(9,30,2011) ;
	replace planyear = 2011 if eligdt >= mdy(10,1,2011) & eligdt <=mdy(9,30,2012) ;  
	replace planyear = 2012 if eligdt >= mdy(10,1,2012) & eligdt <=mdy(9,30,2013) ;  
	replace planyear = 2013 if eligdt >= mdy(10,1,2013) & eligdt <=mdy(9,30,2014) ;
	replace planyear = 2014 if eligdt >= mdy(10,1,2014) & eligdt <=mdy(9,30,2015) ; 
	tab planyear ;
	drop if planyear == 2014 ; 
	pause ;
	
	* there are non-numeric entities in these years - why? For now we need premiums for 08-12, so drop them and investigate later ; 
	drop if substr(entity,1,1) == "S" | substr(entity,1,1) == "U" ;
	
	replace entitynum = trim(entitynum) ; 
	tab entitynum ; 

	destring entitynum, replace ; 
	
	pause ; 
	
keep if month==10;

drop if memid > 7 ;

gen empkey=substr(empid, 1, 1) ;
drop if empkey=="R" | empkey=="B" ; // dropping retiree observations;

pause ; 

gen count=1;
collapse (sum) count, by (entitynum memid empid planyear);
duplicates drop;
tab planyear; 

/* masked entity xwalk */;
preserve;
insheet using "$directory/data/given/clean/package2/EntityNumberCrossWalk.csv", names clear;
rename crosswalkentity entitynum;
keep entitynumber entitynum;
duplicates drop;
tempfile entity;
save `entity';
restore ;

joinby entitynum using `entity', unmatched(both);

drop if _merge==2;

 // Basically here we are just keeping track of the entitymasked number for those entities that are masked (but we are removing
 // that mask here with the replace statement. 
 
gen entitymasked=entitynum if _merge==3;
replace entitynum=entitynumber if _merge==3; 
drop entitynumber _merge;

do $directory/do/macros/unmask.do; 

preserve ;

import excel using $directory/data/built/premium/ContributionInfoSurveys_`contributiondate'.xlsx, sheet("ContributionInfoSurveys_030116") first clear;
 
pause ;
drop Checked entityname count survey verified differencehsa differencehra notes ; 

bys empid memid entitynum planyear: gen test =_N;
 
 // Test just to see if data is read in correctly?
assert test==1; drop test;
 
 // This removes the comma out from the tier values. 
forvalues x=1/4 { ;
cap replace tier`x'=subinstr(tier`x', ",", "", .);
destring tier`x', replace;
} ;

pause ;
tempfile con;
save `con';
 // I believe the restores just go back to the original merged 3 eligibility files. 
restore ;

* we do not have 2014 contribution information ; 
drop if planyear == 2014 ; 

merge m:1 empid memid entitynum planyear using `con', keep (1 3); 
duplicates drop;
bys entitynum: egen maxmerge2=max(_merge);

assert maxmerge2==3;

pause ;

gen form =substr(empid,1,1);
gen class=substr(empid,2,2);
replace fixeddesc=. if medical==5;
replace dental=. if medical==5;
replace vision=. if medical==5;
 
 // A little bit of cleaning so that we don't necessarily have missing/non-sensical values where we don't want them. 
replace fixeddesc=3 if class=="P" & (fixeddesc==.);
replace fixeddesc=8 if percentage==1 & percentageamt !=.;
replace fixedamt=. if fixeddesc==3 & fixedamt==0;
pause ;

*****part time;
/* fixed */;
bys planyear memid entitynum form: egen prem = max(fixedamt);

replace fixedamt=prem/2 if fixeddesc==3 & prem !=. & class=="P" & fixedamt ==. & medical != 5 ;
* CB: sometime part timers get full benefits. Changing this replace to only be if fixed amt is missing ; 

/* tierred */;
bys planyear memid entitynum form: egen t_tier4=max(tier4);
bys planyear memid entitynum form: egen mindesc=min(fixeddesc);
replace fixedamt=t_tier4/2 if mindesc==2 & fixedamt ==. & tier4==. & t_tier4 !=. & class=="P";
pause ; 

/* percentage */;
bys planyear memid entitynum form: egen perc =max(percentageamt) if (fixeddesc==8 );
replace percentageamt=perc/2 if (fixeddesc==3 | fixeddesc==. ) & perc !=.  & class=="P" & percentageamt == . & medical != 5 ;
* similar to above ; 
pause ; 
drop form class medical prem t_* perc  mindesc t_tier4;

gen medical=1;
replace medical=5 if fixedamt==. & dental==. & vision==. & percentageamt==. & tier1==.;
replace fixeddesc=. if fixedamt==. & dental==. & vision==. & percentageamt==. & tier1==.;
di "THIS ONE";
pause ;


replace medical =1 if (fixedamt!=. | dental!=. | vision!=. | percentageamt!=. | tier1!=.);
* I don't think we should do this. The survey says that the employer contribution does not apply to dental and vision for the 2 entities affected by this ; 
* Why are we over-riding the survey? Is this incorporated later ? ; 
* Entities 4821 and 2054 ; 
*replace dental = 1 if  (fixedamt!=. | dental!=. | vision!=. | percentageamt!=. /*| tier1!=.*/);
*replace vision = 1 if  (fixedamt!=. | dental!=. | vision!=. | percentageamt!=. /*| tier1!=.*/);
pause ; 
drop _merge ; 
pause ;

 //Reordering probably for easiness sake or something like that. 
order empid, before(planyear);
order medical, before(dental);

 // Here we are just creating weights to see what percentage of obs/people are OEA, OSEA, etc. This is also where the percentage of missing is calculated.  
gen weight_ip=(medical==5);
bys entitynum planyear: egen total=total(count);
bys entitynum memid empid planyear: gen weight=count/total;

gen OO=1 if (memid==2 | memid==1);
replace OO=0 if OO==.;

bys planyear: egen total_yr=total(count);
bys planyear: egen total_yr_missing=total(count) if medical==5;
gen missingyr=total_yr_missing/total_yr*100;

bys planyear: egen OSEA_tot=total(count) if memid==2;
bys planyear: egen OSEA_total_yr_missing=total(count)if memid==2 & medical==5;
gen OSEA=OSEA_total_yr_missing/OSEA_tot*100;

bys planyear: egen OEA_tot=total(count) if memid==1;
bys planyear: egen OEA_total_yr_missing=total(count) if memid==1 & medical==5;
gen OEA= OEA_total_yr_missing / OEA_tot*100;

bys planyear: egen OO_tot=total(count) if OO==1;
bys planyear: egen OO_total_yr_missing=total(count) if OO==1 & medical==5;
gen OO_perc=OO_total_yr_missing/OO_tot*100;


gen perc=total_yr_missing/total_yr;
* list entitynum memid empid planyear count medical fixed*  total weight*;

drop weight* total* O* missingyr perc;
bys entitynum memid empid : egen minmed=min(medical);

 // Replacing some missing variables. 
local list_s  hsacontribution_fixed_indiv hracontribution maxhra;
local list_n hsaoffered difference hsapercentageofexcess hsacontributionfamily minhsa maxhsa hraoffered hrapercentageofexcess;
foreach var of local list_s { ;
cap replace `var'="0" if `var'=="";
} ;
foreach var of local list_n { ;
cap replace `var'=0 if `var'==.;
} ;

/* replacing missing strings */;
bys empid: egen modeemptype=mode(emptype);
replace emptype=modeemptype; 

pause ; 

outsheet using $directory/data/built/premium/ContributionInfoSurveys_`cdate'.csv, names comma replace;
keep if medical==5;
outsheet using $directory/data/built/premium/ContributionInfoSurveys_MISSING.csv, names comma replace;
