/* This do file creates a single file with the premium info by choice set 8/16/2013  -- AHS*/
#delimit ;
set more off;

capture log close;
log using $directory/log/premium/0_Ccomputeempprem_`cdate'.log, replace;

/* this file takes the latest district contribution information and merges it with the plan premium information to derive an employee in each entity-memid-empid-year's premium contribution. The input files and their description follows:
(1) "ContributionInfoSurveys_DATE.csv" 
	- this file primarily resides in the dropbox.  
	- this do file combines the contribution info surveys from the dropbox with the eligibility file, remidying irregularities.  Out put file from the do file is the best contribution version to use: .../premium/contribution/contributionfile.do
(2) "oregonpremium_`latestdate'.dta" 
	- insheets plan selection csvs and combines it with the medical and rx premium information 
	
OUTPUT FILE: $directory/data/clean/finalpremium_`cdate'.dta
	- this file contains the premium the employee sees by entity-memid-empid-year-plan.
	- used in oop analysis files;

*/;

di "$oregonpremiumdate";

* Insheet premium info;
insheet using $directory/data/built/premium/ContributionInfoSurveys_`cdate'.csv, names comma clear;
drop if entitynum==. & memid==. & planyear==. & medical==. & fixeddesc==.;

pause ;

merge 1:m entitynum empid memid planyear using $directory/data/built/premium/oregonpremium_$oregonpremiumdate.dta, keep (1 3);
tab _merge;

pause ;
replace medical=5 if medical == 1 & (fixedamt==. & dental==. & vision==. & percentageamt==.);

replace medical=5 if _merge==2;
drop if _merge==1;
* assert _merge !=1; 
rename _merge merge1;
label var merge1 "this merge is from merging the contribution survey 411 with oregon premium";
notes merge1: the _merge==2 observations should drop completely when we merge with the eligibility file; 

preserve ;
keep if medical==5;
tempfile missing;
save `missing';

pause ; 
restore ;

drop if medical==5 ;
replace dental = 1 if dental == . ; 
replace vision = 1 if vision == . ; 
pause ;

*Now calculate employee contribution;
replace percentage=0 if percentage==.;

replace fixeddesc = 1 if fixeddesc == . & fixedamt != . ; 

gen fixed=0 if (fixeddesc==2 | fixeddesc==5 | fixeddesc==6 | fixeddesc==7 );
* CB: I'm not certain that 8 is fixed! But this fixed variable may be about tiers not % vs lump sum; 
replace fixed=1 if (fixeddesc==1 | fixeddesc==3  | fixeddesc==8 |  fixeddesc==4 |  fixeddesc==9 );

assert tier1 != . if fixed == 0 ;
assert tier2 != . if fixed == 0 ;
assert tier3 != . if fixed == 0 ;
assert tier4 != . if fixed == 0 ;
assert tier1 == . if fixed == 1 ;
assert tier2 == . if fixed == 1 ;
assert tier3 == . if fixed == 1 ;
assert tier4 == . if fixed == 1 ;


assert percentage != . ;
assert medical == 1	;
assert vision != . ;
assert dental != . ;
assert fixed !=. ;

gen empamt = . ; 

* code some special cases ; 
replace percentageamt = 1 if entitynum == 2087 & plan == "OMED9" & fixeddesc == 8 ; 
replace percentageamt = 0.86 if entitynum == 2087 & plan == "OMED7" & fixeddesc == 8 ; 
replace percentageamt = 0.74 if entitynum == 2087 & plan == "OMED6" & fixeddesc == 8 ; 

replace fixedamt = 160 if entitynum == 2087 & plan == "OMED4" & planyear == 2008 ; 
replace fixedamt = 180 if entitynum == 2087 & plan == "OMED4" & planyear == 2008 ;



tab ratestructure fixeddesc ; 
pause ; 

***(1) COMPOSITE;
pause ; 
replace empamt = premium_rxmed - fixedamt if (ratestructure=="C") & percentage !=1 & fixedamt !=. & (fixeddesc == 1 | fixeddesc == 3);
pause ; 

replace empamt = fixedamt if fixeddesc==4 & fixedamt!=. & (ratestructure=="C") ;
pause ; 
replace empamt = (1-percentageamt)*premium_rxmed if (ratestructure=="C") & percentage ==1 & empamt==. & fixeddesc == 8 ;
pause ; 
* This is subtle. The premium is charged compositely, but the district subsidy for the premium varies by tier  - though we do not observe any when written ; 
gen empamt1 = . ;
gen empamt2 = . ;
gen empamt3 = . ;
gen empamt4 = . ;

forvalues x = 1/4 { ;
replace empamt`x' = premium_rxmed - tier`x' if (ratestructure=="C") & tier1!=. & tier2!=. & fixeddesc == 2 ;
} ;

*** CB: we need to weight the dent / vision premiums by the % paid by the district here too ; 
*** or at least keep the % subsidies so that we can weight the dent premiums later ; 

*** (2) TIERED;
forvalues x = 1/4 {;
replace empamt`x' = premium_rxmed`x' - tier`x' if  ratestructure=="T" & percentage !=1 & tier`x' !=. & fixed!=1 & (fixeddesc == 2 | fixeddesc == 6 );
pause ; 
*composite premium, tiered contribution ; 
replace empamt = premium_rxmed - tier`x' if  ratestructure=="C" & percentage !=1 & tier`x' !=. & fixed!=1 & fixeddesc == 2 ;
pause ;
replace empamt`x' = premium_rxmed`x' - fixedamt if  ratestructure=="T" & percentage !=1 & fixed==1 & (fixeddesc == 1| fixeddesc == 3);
pause ; 
replace empamt`x' = premium_rxmed`x'*(1 - percentageamt) if ratestructure=="T" & empamt`x'==. & percentage==1 & fixed==1 & percentageamt!=. & (fixeddesc == 8); 
pause ; 
replace empamt`x' = premium_rxmed`x'*(1 - tier`x') if ratestructure=="T" & empamt`x'==. & percentage==1 & percentageamt==. & (fixeddesc == 7); 
pause ; 
replace empamt`x' = tier`x' if percentage !=1 & tier`x' !=. & fixeddesc ==5 & ratestructure=="T" ;
replace empamt`x' = fixedamt if percentage !=1 & fixeddesc ==4 & ratestructure=="T" ;
* make sure correct frequency of changes are being made ; 
tab ratestructure fixeddesc ; 
pause ; 
};


pause ; 

* the special case that was here was wrong. ; 

pause ; 
gen tag=0;
replace tag=1 if empamt==. & 
				 empamt1==. &
				 empamt2==. &
				 empamt3==. &
				 empamt4==.;
assert tag==0;	drop tag;			 

pause ; 
append using `missing';
pause ; 
/******* turning the numbers into yearly figures, opposed to just monthly ******/;
replace premium_rxmed=premium_rxmed*12;
replace medpremium=medpremium*12;
replace rxpremium=rxpremium*12;
replace empamt=empamt*12;

forvalues x=1/4 { ;
replace premium_rxmed`x'=premium_rxmed`x'*12;
replace empamt`x'=empamt`x'*12;
replace medpremium`x' = medpremium`x'*12 ; 
replace rxpremium`x' = rxpremium`x'*12 ; 
} ;
pause ; 
gen tag=1 if  premium_rxmed ==. & premium_rxmed1 ==. & premium_rxmed2 ==. & premium_rxmed3 ==. & premium_rxmed4 ==.;
assert tag !=1;

pause ; 

rename rxplan drugplan ;
preserve ;
gen subsidy_pct_comp = percentageamt if fixeddesc == 8 ; 
gen subsidy_pct_t1 = tier1 if fixeddesc == 7 ; 
gen subsidy_pct_t2 = tier2 if fixeddesc == 7 ; 
gen subsidy_pct_t3 = tier3 if fixeddesc == 7 ; 
gen subsidy_pct_t4 = tier4 if fixeddesc == 7 ; 

*** make sure we keep dent / vision indicators, and percentage subsidies to apply to dent/vision premiums later ; 
keep entitynum empid memid planyear plan drugplan dental vision fixeddesc visplan dentalplan ratestructure empamt*  *prem* medical subsidy_pct_*;
duplicates drop;
sort entitynum empid memid planyear plan drugplan visplan dentalplan ratestructure empamt empamt1 empamt2 empamt3 empamt4 ; 
compress;
pause ; 
save $directory/data/built/premium/finalpremium_`cdate'.dta, replace;
restore ;