cap log close;
#delimit ;
/* Project: 	Oregon Health Plan Choice Analysis												*/;

/* Program: 	oregon_calculator																*/;
/* Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 								*/;
/*				--> code from Sean Sean and Adrienne Sabety										*/;
/* Dates:		Transition: 	9/30/2014														*/;
/*				Modified: 		10/15/2014														*/;

/* This takes the input files created by 1calc_input_`do_date'.do and calculates costs for 
   each beneficiary for the hypothetical choice of each plan in their choice set				*/;

/* The global $directory is /disk/agedisk3/oebb.work/cbehrer/oregon/ 							*/;
/* All globals are set in the shell file 0SHELL_fullrun_base_`do_date'							*/;

/* 0. Pass globals, set log 																	*/;
set more off; 
local cdate $cdate;
local ctime $ctime;
local claimyear $claimyear;
local year `claimyear';
local runtype $runtype;
local y $yplan;
local runfull $runfull;
local justdrug $justdrug;
local acg $acg;

if `acg' == 0 {;
	local acgbase base;
};

if `acg' == 1 {;
	local acgbase acg;
};
cap log close;
log using $directory/log/calculator/june2015/`acgbase'/`cdate'/`claimyear'/2calculator`claimyear'_`runtype'_`acgbase'${unit}${cells}_`cdate'_`ctime'.log, replace;

/* Oregon Calculator */;
di "Claim year: `claimyear'";
di "ACG vs Base: `acgbase'";
di "Runtype: `runtype'";
di "Just drug: `justdrug'";
di "Shell file run date: `c_date'";
di "Shell file run time: `ctime'";

local clean $directory/data/given/clean;
local pieces_do $directory/do/2calculator/pieces_calc;
local macros $directory/do/macros/;
local in_data $directory/data/calculator/june2015/`acgbase'/`cdate'/calc_input;
local out_data $directory/data/calculator/june2015/`acgbase'/`cdate'/calc_output;

if "`runtype'" == "PB" {;
local planyear = `claimyear' + 1;
};

if "`runtype'" == "PF" {;
local planyear = `claimyear'; 
};
local yplan = `planyear' - 2000;
local yclaim = `claimyear' - 2000;
local pyear=`planyear'-1;
assert `yplan'==`y';  di `planyear'; di `y';

/* specifying locals for input files																*/; 
if `acg'==0 { ;
	local bene_claim "`in_data'/`claimyear'/bene_allclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
	/* This file came from the calcinput.do file */;
	local bene_alldrugclaim_plan "`in_data'/`claimyear'/bene_alldrugclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
	/* This file came from the calcinput.do file */;
} ;
if `acg'==1 { ; di `acg';
	local bene_claim "`in_data'/`claimyear'/bene${unit}${cells}_allclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
	/* This file came from the calcinput.do file */;
	local bene_alldrugclaim_plan "`in_data'/`claimyear'/bene${unit}${cells}_alldrugclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
/* This file came from the calcinput.do file */; 
} ;
local limits "`clean'/limits.csv";

local prevyear_out `out_data'/`pyear'/calcrun_acg`acg'_`cdate'_`runtype'.dta;

if `planyear'< 2010{;
	local kaiserdo `pieces_do'/Calculate_Kaiser2.do;
	local provdo `pieces_do'/Calculate_Prov2.do;
};
if `planyear'> 2009{;
	local kaiserdo `pieces_do'/Calculate_Kaiser_10_7252.do;
	local provdo `pieces_do'/Calculate_Prov_10_7302.do;
};
di "`kaiser`yplan'";

/******Creating a tempfile for all facility and professional claims***********************/;

use `bene_claim', clear;
drop if personid == "" ; 

tab chosenplan if chosen==1;

cap drop chosenplanfirst;

gen chosenplanfirst=substr(chosenplan, 1, 1);
cap drop planfirst;
gen planfirst=substr(plan,1,1);

sort plan network;

cap drop max_deductible;
cap drop max_oopcost;

/* Merging in family vs individual plan info (individual and family oop and deductible 411 by plan and network) */;
preserve ;
clear;
insheet using `limits', clear;
keep if planyear == `planyear';
cap drop v*;
sort plan network;
desc;
tempfile limit`yplan';
save `limit`yplan'', replace;
restore;

merge m:1 plan network tier using `limit`yplan'', keep (1 3);

assert _merge==3;
drop _merge;

do `pieces_do'/ods_dedmax_fix.do; 
/* getting rid of claims where servicedate is < eligible startdate */;
drop if srvcdt < eligstrt & "`runtype'"=="PF";
destring entitynum, replace; 

* we used to mergein deductible information from the previous year, not anymore ;

/* creating individual specification */;
gen ded1=maxded if tier==1;
bys plan network: egen maxdedind=max(ded1);

gen oop1=maxoop if tier==1;
bys plan network: egen maxoopind=max(oop1);
	drop oop1 ded1;

gen individual_ded=0;
replace individual_ded=1 if tier==1;
replace individual_ded=1 if maxded==maxdedind;	

gen individual_oop=0;
replace individual_oop=1 if tier==1;	
replace individual_oop=1 if maxoop==maxoopind;

/* separating out OMED9 in order to run separately */;
preserve ;
keep if inlist(plan , "OMED9", "MMEDH"); // Need to do separately;
tempfile ods9claims`yplan';
save `ods9claims`yplan'', replace;
restore ;

/* separating out non-OMED9 plans in order to run separately */;
preserve ;
keep if  inlist(plan, "OMED3", "OMED4", "OMED5", "OMED6", "OMED7", "OMED8") | 
		 inlist(plan, "MMEDA", "MMEDB", "MMEDC", "MMEDD", "MMEDE", "MMEDF", "MMEDG")	;
desc ;
tempfile odsclaims`yplan';
save `odsclaims`yplan'', replace;
restore ;

/* separating out Kaiser plans in order to run separately */;
preserve ;
keep if planfirst=="K";
tempfile kaiser`yplan';
save `kaiser`yplan'', replace;
global kaiser`yplan' `kaiser`yplan'';
restore ;

/* separating out Prov plans in order to run separately */;
preserve ;
keep if planfirst=="P"; 
tempfile prov`yplan';
save `prov`yplan'';
global prov`yplan' `prov`yplan'';
restore ;

/* bringing in drug claims (will do separately as well) */;
*Creating a tempfile for all drug claims;
use `bene_alldrugclaim_plan', clear; /* this comes from calculator*/;
cap drop networkpaid;
cap drop provnetwork;
destring entitynum, replace;
gen drug=1;

/* getting rid of claims where servicedate is < eligible startdate;*/;
drop if srvcdt < eligstrt & "`runtype'"=="PF";

preserve ;
keep if (drugplan == "OMED9" | drugplan=="MMEDH"); /* Need to do separately */;

tempfile ods9drugs`yplan';
save `ods9drugs`yplan'', replace;
restore ;

drop if (drugplan == "OMED9" | drugplan=="MMEDH");
tempfile drugclaims`yplan';
save `drugclaims`yplan'', replace;

local fullrun 1;

/***************** IMPORTANT NOTE **************************
Copay only applies once per day for a particular service type.
Coinsurances apply for every single line of the claim.
**************************************************************/;
*Plans kept: "KMED1" "KMED2" "PMED1" "PMED2" "KMP1A" "PMP1A" "PMP2A"; 
* Kaiser and prov are modeled in ~/rebuild/ calculator files ; 
if `fullrun'==1 { ;
	preserve;
***	include `kaiserdo';
	restore;
} ;

if `fullrun'==1  { ;
	if `planyear' < 2012 { ;
		preserve;
***		include `provdo';
		restore;
	} ;
} ; 

if `fullrun'==1  { ;
	*** FACILITY AND PROFESSIONAL CLAIMS FOR ODS PPO PLANS 3-8(DOES NOT INCLUDE OMED9)***;
	*** Merging in copay and coinsurance info from plan design sheets to claims data */;

	use `odsclaims`yplan'', clear;
	if _N !=0 { ;
		assert coinsuranceperc!=. if NA !=1;
		assert copay!=. if NA !=1;

		/************ Dual copays and coinsurances ***********/;
		gen dualcc=0;
		replace dualcc=1 if (serviceid==`y'90| // imaging
							 serviceid==`y'92| // endoscopies
							 serviceid==`y'61| // additional cost tier
							 serviceid==`y'04); // ER

		/************ PREV SERVICES ************/;
		
		replace prev = 1 if (network == 1) & 
							(serviceid == `y'54 | 
							 serviceid == `y'52 | 
							 serviceid == 855   |
							 serviceid == 955   |
							 serviceid == 1051  |
							 serviceid == 1151  );
							 
		replace prev = 1 if (network == 1) & 					 
							(serviceid == 1020  | 
							 serviceid == 1120  |
							 serviceid == 1220  ) ;
							 
		/************ DEDUCTIBLE ************/;
		gen noded=0;
		replace noded=1 if network==1 & copay !=0 & dualcc ==0; // these do not have a deductible;
		replace noded=1 if serviceid==`y'81; // urgent care ;
		replace noded=1 if NA==1 | prev==1; 
		replace noded = 0 if serviceid == `y'04; 

		/************ OOP MAX ***********/;
		* neither deductibles or copayments are included towards the oop max; 
		gen nooop=0; 
		replace nooop=1 if NA==1;

		*Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met;

		*Charge Submitted=Discount+Allowed Amount;
		*Allowed Amount=NetPayment+Third Party (COB or Medicare) +Out of Pocket;
		*Out of Pocket=Copayment+Coinsurance+Deductible;
		*totcost = Out of Pocket - Copay;

		/* for some charges, such as additional cost tier, the allowedamt is <500, but there were multiple serviced done under this tier on a given servicedate.  As a result, the full $500 was charged, but distributed among the different services.  We need a fix for this.  Here we create an indicator that we'll pull at the bottom of the piece.	For instance, see 2010: personid = "ATo21EbhToUo1QATosGt2ot" & chosen==1 */;

		gen CopayGTaa=(copay) if allowedamt < copay;
		replace CopayGTaa=0 if CopayGTaa==.;

		/* for the services below the coinsurance applies to the deductible, but the copay doesnt.  Since we calculate the deductible based on coinsurances, not copays, this is fine as stands.  The only thing to be careful of is when we replace the deductible=0 if copay ~=0.  These services have a copay and coinsurance, so they are an exception to the rule */;

		gen deductible = allowedamt;
		replace deductible = 0 if noded==1 | (copay !=0 & dualcc !=1); 
		gen totcost = deductible; 

		* 2013 System of Care ; 
		if `planyear' == 2013 { ; 
			preserve ; 
				tab plan ; 
				tab chosenplan ; 
				
			* okay that there is no plan == "MMEDH" those claims are in different tempfile at this point ; 
			
			* build dataset identifying system of care cells defined by providerid provider type and plan ; 
			* from claims in chosen plans ; 
				keep if chosen==1 ; 
				keep if network == 1 ; 
				gen system = . ; 
				replace system = 1 if origcopay == 20 & inlist(plan, "MMEDA", "MMEDB", "MMEDC")  ;
				replace system = 1 if origcopay == 30 & inlist(plan, "MMEDD", "MMEDE", "MMEDF", "MMEDG")  ;
				replace system = 1 if origcopay == 10 & inlist(plan, "MMEDA", "MMEDB", "MMEDC")  ;
				replace system = 1 if origcopay == 15 & inlist(plan, "MMEDD", "MMEDE", "MMEDF", "MMEDG")  ;
				drop if chosenplan == "MMEDH" ; 
				
				replace system = 0 if system == . ; 
				drop if origcopay == 0 & origcoin == 0 ; 
				
				gen sys_elig = 0 ; 
				replace sys_elig = 1 if inlist(tos, "HMCO", "HMAO", "PMAO", "PMCO") ; * outpatient mental health ; 
				replace sys_elig = 1 if inlist(tos,"OV", "CUO", "FVO", "OM") ;		  * office visits ; 
				replace sys_elig = 1 if inlist(tos,"MAT", "MATO") ;					  * maternity ; 
				replace sys_elig = 1 if substr(tos,1,2) == "IC" ; 					  * incentive ; 
				replace system = 0 if sys_elig == 0 ; 
				keep if sys_elig == 1 ; 
				
				gen test1 = 1 if origcoin != 0 ; 
				gen test2 = 1 if origcopay ! = 0 ; 
				
				replace test1 = 0 if test1 == . ; 
				replace test2 = 0 if test2 == . ;
				
				drop if test1 ==1 & test2 == 1 ; 
				* one weird claim ; 
				drop test1 test2 ; 
				cap drop counter ; 
				gen counter = 1 ; 
				tempfile system ; 
				save `system' ; 
				
				egen prov_ptyp_tos_count = sum(counter), by(providerid provtyp tos) ; 
				egen prov_ptyp_tos_sys = sum(system), by(providerid provtyp tos) ; 
				gen prov_ptyp_tos_pct = prov_ptyp_tos_sys / prov_ptyp_tos_count ; 
							
				keep providerid prov_ptyp_tos_count prov_ptyp_tos_sys prov_ptyp_tos_pct provtyp tos ; 
				duplicates drop ; 
				sum prov_ptyp_tos_pct, detail ; 
				gsort -prov_ptyp_tos_count ;  
				
				gen in_system = . ; 
				replace in_system = 1 if prov_ptyp_tos_pct >= 0.5 ; 
				replace in_system = 0 if prov_ptyp_tos_pct <= 0.5 ; 

				tempfile system_id1 ; 
				save `system_id1' ; 
			
				use `system', clear ; 
				egen prov_ptyp_count = sum(counter), by(providerid provtyp) ; 
				egen prov_ptyp_sys = sum(system), by(providerid provtyp) ; 
				gen prov_ptyp_pct = prov_ptyp_sys / prov_ptyp_count ; 
				
				keep providerid prov_ptyp_count prov_ptyp_sys prov_ptyp_pct provtyp ; 
				duplicates drop ; 
				sum prov_ptyp_pct, detail ; 
				gsort -prov_ptyp_count ;  
				
				gen in_system = . ; 
				replace in_system = 1 if prov_ptyp_pct >= 0.5 ; 
				replace in_system = 0 if prov_ptyp_pct <= 0.5 ; 

				tempfile system_id2 ; 
				save `system_id2' ; 
				
				use `system', clear ; 
				egen prov_count = sum(counter), by(providerid) ; 
				egen prov_sys = sum(system), by(providerid) ; 
				gen prov_pct = prov_sys / prov_count ; 
				
				keep providerid prov_count prov_sys prov_pct  ; 
				duplicates drop ; 
				sum prov_pct, detail ; 
				gsort -prov_count ;  
				
				gen in_system = . ; 
				replace in_system = 1 if prov_pct >= 0.5 ; 
				replace in_system = 0 if prov_pct <= 0.5 ; 
			
				tempfile system_id3 ; 
				save `system_id3' ; 
				
				use `system', clear ; 
					keep chosenplan system ; 
					collapse (mean) system, by(chosenplan) ; 
					rename chosenplan plan ; 
					list ; 
				tempfile system_id4 ; 
				save `system_id4' ; 
			restore ; 
			
			* merge system of care status back on to all hypothetical claims ; 
			* do we have a status for all necessary combinations of identifying variables?
			* almost certainly not ; 
			merge m:1 providerid provtyp tos using `system_id1' ; 

			gen sys_elig = 0 ; 
			replace sys_elig = 1 if inlist(tos, "HMCO", "HMAO", "PMAO", "PMCO") ; * outpatient mental health - note: substance abuse/chemical dependency is not included - no observed copay claims indicate that these claims are eligible for system of care rates ; 
			replace sys_elig = 1 if inlist(tos,"OV", "CUO", "FVO", "OM") ;		  * office visits ; 
			replace sys_elig = 1 if inlist(tos,"MAT", "MATO") ;					  * maternity ;
			replace sys_elig = 1 if substr(tos,1,2) == "IC" ; 					  * incentive ; 
			replace sys_elig = 0 if plan == "MMEDH" ;
			replace sys_elig = 0 if network == 0 ; 
			
			replace in_system = 0 if sys_elig == 0 ; 
		
			rename _merge merge1 ; 

			preserve ; 
			keep if sys_elig == 1 & merge1 == 1 ; 
			drop in_system prov_ptyp* ; 
			di _N ; 
			merge m:1 providerid provtyp using `system_id2' ;
			rename _merge merge2 ; 
			drop if merge2 == 2 ; 
			tempfile round2 ; 
			save `round2';
			
			restore ; 
			drop if sys_elig == 1 & merge1 == 1 ; 
			append using `round2' ; 
			replace in_system = 0 if sys_elig == 0 ; 
			mdesc in_system ; 
			
			preserve ; 
			keep if sys_elig == 1 & merge2 == 1 ;
			drop in_system prov_ptyp* ; 
			merge m:1 providerid using `system_id3' ;
			rename _merge merge3 ; 
			drop if merge3 == 2 ; 
			tempfile round3 ; 
			save `round3';
			restore ; 
			drop if sys_elig == 1 & merge2 == 1 ;
			append using `round3' ; 
			mdesc in_system ; 
			* identifying sys_elig claims that occured in Kaiser - office visits, consultations, outpatient mental health (not subs. abuse/ ;
			* chem. depend) & outpatient maternity ; 
			replace sys_elig = 1 if inlist(kaisercode, "PPOVM OHV", "PPOVM CO", "PPOVM MM" "PPOVM MH", "PHOP MH", "PHOPM ND") ; 
			replace in_system = . if sys_elig == 1 & substr(chosenplan,1,1) == "K" ;

			merge m:1 plan using `system_id4' ; 
			rename _merge merge4 ; 

			tempfile pre4 ; 
			save `pre4'; 
			
			keep if in_system == . ; 
						foreach plan in MMEDA MMEDB MMEDC MMEDD MMEDE MMEDF MMEDG { ; 
				preserve ; 
				keep if plan == "`plan'" ; 
				cap drop rand0_1 ; 
				gen rand0_1 = runiform() ; 
				replace in_system = 1 if rand0_1 < system ;
				replace in_system = 0 if rand0_1 >= system ;	
				tempfile round4_`plan' ; 
				save `round4_`plan'' ; 
				restore ; 
			} ; 
			
			use `pre4', clear ; 
			drop if in_system == . ; 
			append using `round4_MMEDA' ; 
			append using `round4_MMEDB' ; 
			append using `round4_MMEDC' ; 
			append using `round4_MMEDD' ; 
			append using `round4_MMEDE' ; 
			append using `round4_MMEDF' ; 
			append using `round4_MMEDG' ; 
			di _N ; 
			
			replace copay = 20 if in_system == 1 & inlist(plan, "MMEDA", "MMEDB", "MMEDC") & substr(tos,1,2) != "IC" ; 
			replace copay = 30 if in_system == 1 & inlist(plan, "MMEDD", "MMEDE", "MMEDF", "MMEDG") & substr(tos,1,2) != "IC" ;
			replace copay = 10 if in_system == 1 & inlist(plan, "MMEDA", "MMEDB", "MMEDC") & substr(tos,1,2) == "IC" ; 
			replace copay = 15 if in_system == 1 & inlist(plan, "MMEDD", "MMEDE", "MMEDF", "MMEDG") & substr(tos,1,2) == "IC" ;
			
			* incentive office eligible claims from kaiser into MODA diabetes, asthma, CHF, high cholesterol, and high blood pressure ; 
			replace copay = 10 if in_system == 1 & inlist(plan, "MMEDA", "MMEDB", "MMEDC") & substr(chosenplan,1,1) == "K" & inlist(diag3code, "250", "493", "272", "401", "428") ; 
			replace copay = 15 if in_system == 1 & inlist(plan, "MMEDD", "MMEDE", "MMEDF", "MMEDG") & substr(chosenplan,1,1) == "K" & inlist(diag3code, "250", "493", "272", "401", "428") ; 	
			replace coinsuranceperc = 0 if in_system == 1 ; 
			
		} ; 
		/* Calculating OOP cost for each claim */;
		/* Special case for ER visits, copay is waived if admitted, coinsurance must still be paid, ER copay paid only once per visit, deductible applies */;

		/* CB updated 2/22/15 to incorporate new info from MODA about TOS codes billed
		as ER claims when they occur on the same day as  ER - the numER2 and ERvisit2 and 	
		as_ER code models this info*/;
		
		gsort -allowedamt;
		bys personid plan claimid serviceid srvcdt:  gen dayssum = sum(days);
		replace dayssum=0 if dayssum>days;

		gen ERvisit = 1 if (serviceid == `y'04);
		gen ERvisit2 = ERvisit;
		replace ERvisit2 = 0 if ERvisit == . ;

		/* see above*/;
		gsort -origcopay -allowedamt;
		bys personid plan srvcdt:  gen numER = sum(ERvisit);
		replace numER=0 if ERvisit== .;
		
			egen numER2 = sum(ERvisit2), by(personid plan srvcdt);
			/* for now restricting to the three codes we were explicitly told are billed by this rule*/;
			gen as_ER = 1 if (/*tos == "ALS" | tos == "AM"  | tos == "BLS" | tos == "CAER" | tos == "CAT" | tos == "HMO" |*/ tos == "HV" | /*tos == "IV" | tos == "IVX" | tos == "LBER" |*/ tos == "LB" | /*tos == "MX" | tos == "OP" | tos == "OPER" | tos == "RXI" |tos == "SG1U" |*/ tos == "XR" | tos == "XRER");

			replace as_ER = 0 if as_ER == . ;
			replace coinsuranceperc = 0.1 if plan == "OMED3" & numER2 > 0 & as_ER == 1;
			replace copay = 0 if plan == "OMED3" & numER2 > 0 & as_ER == 1;

			replace coinsuranceperc = 0.2 if numER2 > 0 & (as_ER == 1) & (plan == "OMED4" | plan == "OMED5" | plan == "OMED6" | plan == "OMED7" | plan == "OMED8");

			replace copay = 0 if numER2 > 0 & (as_ER == 1) & (plan == "OMED4" | plan == "OMED5" | plan == "OMED6" | plan == "OMED7" | plan == "OMED8");

		/* CB: we need to move the allowed * coinsurance after creation of ER visit flags and reset coinsurance percent*/;
		/* I think we also need to change ERvisit == 1 condition to ER visit > 0 */;

		gen coinsurance = coinsuranceperc* allowedamt ;
		bys personid plan srvcdt: egen sum_origded = sum(origded) if ERvisit > 0 & ERvisit !=. ;
		bys personid plan srvcdt: egen sum_origcoin = sum(origcoin) if ERvisit > 0 & ERvisit !=. ;
		bys personid plan srvcdt: egen sum_origcopay = sum(origcopay) if ERvisit > 0 & ERvisit !=. ;
		bys personid plan srvcdt: egen sum_allowedamt = sum(allowedamt) if ERvisit > 0 & ERvisit !=. ;
				
		replace allowedamt = sum_allowedamt if ERvisit == 1 & numER==1;
		replace origded = sum_origded if ERvisit == 1 & numER==1;
		replace origcoin = sum_origcoin if ERvisit == 1 & numER==1;
		replace origcopay = sum_origcopay if ERvisit == 1 & numER==1;
		
		replace allowedamt = 0 if ERvisit == 1 & numER>1;
		replace origded = 0 if ERvisit == 1 & numER>1;
		replace origcopay = 0 if ERvisit == 1 & numER>1;
		replace origcoin = 0 if ERvisit == 1 & numER>1;
		 
		replace deductible = allowedamt;
		replace deductible = 0 if noded==1 | (copay !=0 & dualcc !=1);
		replace totcost = deductible;
		 
		/* Calculating OOP cost for each claim - does this need to be ==0?*/;
		replace coinsurance = coinsuranceperc* allowedamt /*if numER2 == 0*/;

		gsort personid srvcdt -origcopay -allowedamt;
		gen admit = 0 if (serviceid == `y'04) & origcopay == 0;
		replace admit = 1 if (serviceid == `y'04) & admit != 0;
		by personid srvcdt: egen admitted=max(admit);
		
		/* Special ER cases*/  
		replace copay = 0 if (numER > 1 & (serviceid == `y'04));

		/*ER copay paid only once per visit*/;
		replace copay= 0 if admitted == 0 & (serviceid == `y'04);

		/* if admitted ==0, it means the individual was admitted and the copay is waived*/;
		replace copay = 100 if numER == 1 & admitted==1 & (serviceid == `y'04) & allowedamt >=100;
		
		/* if not admitted, copay of 100 applies */;
		replace copay = allowedamt if numER == 1 & admitted == 1 & (serviceid == `y'04) & allowedamt < 100;
		replace deductible = 0 if numER == 1 & admitted == 1 & (serviceid == `y'04) & allowedamt < 100;
		replace deductible = deductible - 100 if (serviceid == `y'04) & deductible > 100 & copay == 100;
		 
		/* come in and pause this here to see how ER accuracy is*/;		
		/* adjustments */;
		replace deductible = 0 if (NA == 1 | prev==1);
		replace coinsurance = allowedamt if allowedamt < coinsurance & coinsurance!=0 & allowedamt>=0;
		replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>=0;
		replace coinsurance = 0 if ( NA== 1 | prev == 1);
		
		replace totcost = allowedamt ;

		replace totcost = allowedamt - copay if serviceid == `y'04; 
		* This is because the amount on the deductible is the allowedamt minus the copay, and we want the amount equal to the totcost now. ;
		replace totcost = allowedamt - copay if serviceid == `y'04;
		* above comment was not always true - make sure deductible is allowed - copay ; 

		replace totcost = 0 if prev == 1;
		replace coinsurance = 0 if allowedamt==copay; 
		

		/* sorting the order of the claims based on original claims data: rank = ded, rank1 = coins */;
		local ftype personid familyid;

		gen flag =0;
		gen ded =.;
		gen coin =.;

		foreach a of local ftype {;
			sort `a' plan paiddt; 
			replace flag = 1 if origded!=0 & origcoin != 0;
			replace ded = 0 if origded!= 0;
			replace ded = 1 if origded == 0;
			sort `a' plan paiddt ded flag;
			by `a' plan paiddt: gen rank`a' = _n;  

			sort `a' plan network paiddt; 
			replace coin = 0 if origcoin!= 0;
			replace coin = 1 if origcoin == 0;
			sort `a' plan network paiddt coin;
			by `a' plan network paiddt: gen rank1`a' = _n;  
		};
		drop coin ded;

		cap drop atmargin_max;
		 /* Calculating final cumulative totalcost and the OOP cost (totalcost + copay)*/;
		* Make sure copay only applies once per claim id;
		gsort personid plan claimid serviceid srvcdt -copay linenum -allowedamt;
		by personid plan claimid serviceid srvcdt :  gen numcopay = _n;
		/* additional cost tier services 
		 - for some charges, such as additional cost tier, the allowedamt is <500, but there were multiple serviced done under
		this tier on a given servicedate.  As a result, the full $500 was charged, but distributed among the different services.  
		We need a fix for this.  We're utilizing a variable from the beginning of the piece (CopayGTaa).
		 For instance, see 2010: personid = "ATo21EbhToUo1QATosGt2ot" & chosen==1 */;
		gsort personid plan claimid serviceid srvcdt linenum -allowedamt;
		by personid plan claimid serviceid srvcdt : gen cum_copaycost = sum(copay);
		by personid plan claimid serviceid srvcdt: gen atmargin_max = 1 if (cum_copaycost[_n] >= CopayGTaa) & (cum_copaycost[_n-1] < CopayGTaa)& (_n>1);
		replace copay = CopayGTaa - cum_copaycost[_n-1] if (atmargin_max == 1 ) & serviceid==`y'61 & allowedamt < CopayGTaa ;
		gen exempt=1 if serviceid==`y'61 & ((CopayGTaa > cum_copaycost) | atmargin_max==1);
		replace exempt=0 if exempt==.;
		gen diff=CopayGTaa-copay if CopayGTaa!=0 & numcopay==1;  replace diff=0 if diff==.;

			bys personid plan claimid serviceid srvcdt : egen maxcopay = max(copay);
			bys personid plan claimid serviceid srvcdt : egen maxdiff = max(diff);

		replace copay=maxdiff if allowedamt > maxdiff & numcopay ==2 & exempt !=1; 

			by personid plan claimid serviceid srvcdt : replace cum_copaycost = sum(copay);

			gen diff2=CopayGTaa-cum_copaycost if CopayGTaa!=0 & numcopay==2;
			replace diff2=0 if diff2==. | maxdiff==0;
			bys personid plan claimid serviceid srvcdt : egen maxdiff2 = max(diff2);
		replace copay=maxdiff2 if allowedamt > maxdiff2 & numcopay ==3 & exempt !=1; 
		replace copay = 0 if (numcopay > 3) & exempt !=1;

		gen runningallowedamt = allowedamt-copay if serviceid==`y'61;
		replace coinsurance = coinsuranceperc* runningallowedamt if (cum_copaycost[_n] >= CopayGTaa) & (_n>1) & serviceid==`y'61; cap drop runningallowedamt;

		/* Calculating totcost at the margin where it just reaches the deductible */;
		
		*In N/A cases, the cost doesn't count towards the deductible or the maximum;
		gsort personid plan paiddt rankpersonid -allowedamt;
 
		by personid plan: gen cum_totcost = sum(totcost*(noded != 1)); 
		by personid plan: gen atmargin=1 if (cum_totcost[_n] >= maxdedind & cum_totcost[_n-1] < maxdedind) & (_n>1) & noded !=1;
		by personid plan: replace atmargin=2 if (cum_totcost[_n] > maxdedind) & (_n==1) & noded !=1;
		replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxdedind) if ( noded != 1 & (atmargin == 1 | atmargin == 2)) ;
		replace deductible = (maxdedind - cum_totcost[_n-1]) if (noded != 1 & atmargin == 1);
		replace deductible = maxdedind if (noded != 1 & atmargin == 2);
		replace deductible = 0 if (prev == 1 | noded == 1 );

		/* Calculating  totcost if cumulative is greater than deductible */;
		sort personid plan paiddt rankpersonid;
		by personid plan: replace cum_totcost = sum(totcost*(noded != 1)); 
		by personid plan: gen greater_ded = 1 if (cum_totcost > maxdedind) & (atmargin != 1) & (atmargin != 2);
		replace deductible = 0 if (greater_ded == 1); /* Setting deductible to zero after it crosses limit */;
		replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2); ; /* Setting coinsurance to zero before deductible is met */;
		replace coinsurance = 0 if prev == 1;
		replace totcost = coinsurance if (noded != 1); /* Setting totcost to equal coinsurance after deductible is met */;
		replace totcost = allowedamt if noded == 1; 
		replace totcost = 0 if prev == 1; 

		/* check family deductible limit */;
		sort familyid plan paiddt rankfamilyid;
		by familyid plan: gen cumdedfam = sum(deductible);
		by familyid plan: replace atmargin = 3 if (cumdedfam[_n] >= maxded & cumdedfam[_n-1] < maxded) & (_n>1) & individual_ded == 0;
		by familyid plan: replace atmargin= 4 if (cumdedfam[_n] > maxded) & (_n==1) & individual_ded == 0;
		replace coinsurance = coinsuranceperc*(cumdedfam[_n] - maxded) if (prev! = 1 & noded != 1 & (atmargin == 3 | atmargin == 4) & individual_ded ==0) ;
		replace deductible = (maxded - cumdedfam[_n-1]) if (noded != 1 & atmargin == 3 & individual_ded == 0);
		replace deductible = maxded if (noded != 1 & atmargin == 4 & individual_ded == 0);
		replace deductible = 0 if prev == 1 & individual_ded == 0;
		replace totcost = deductible if individual_ded == 0;

		sort familyid plan paiddt rankfamilyid;
		by familyid plan: replace cumdedfam = sum(totcost*(noded != 1)); 
		by familyid plan: gen greater_dedfam = 1 if (cumdedfam > maxded) & (atmargin != 3) & (atmargin != 4) & individual_ded == 0;
		replace deductible = 0 if (greater_dedfam == 1 & individual_ded == 0); /* Setting deductible to zero after it crosses limit */;
		replace coinsurance = coinsuranceperc*allowedamt if (greater_dedfam == 1 & noded != 1 & prev != 1 & individual_ded == 0);
		replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & atmargin!=3 & atmargin!=4 & individual_ded == 0);  /* Setting coinsurance to zero before deductible is met */;
		replace coinsurance = 0 if (NA==1 | prev == 1) & individual_ded == 0;
		replace totcost = coinsurance if (noded != 1 & individual_ded == 0); /* Setting totcost to equal coinsurance after deductible is met */;
		replace totcost = allowedamt if NA == 1 & individual_ded == 0; 
		replace totcost = 0 if prev == 1 & individual_ded == 0;
 
		
		/* deal with dual copay and coinsurance charges:
		1) deal with charges with non-zero deductible--take copay out first, then coinsurance; 
		2) deal with charges with zero deductible--take coins out first, then copay */;
		* 1) ;
		gen cost =allowedamt-deductible if deductible !=0 & dualcc==1;

		replace copay = cost if (noded !=1 & copay > cost & dualcc==1 & deductible !=0 & cost > 0 & serviceid!=`y'04);

		replace cost =allowedamt-deductible-copay if dualcc==1 & deductible !=0;
		replace coinsurance = coinsuranceperc*(cost) if deductible !=0 & dualcc==1 & cost > 0;
		* 2);
		replace cost =allowedamt-copay if deductible==0 & dualcc==1;
		replace coinsurance = coinsuranceperc*(cost) if deductible==0 & dualcc==1 & coinsurance !=0 & cost > 0;
		replace coinsurance=0 if cost < 0;

		replace copay=0 if allowedamt==0;
		replace coinsurance=0 if allowedamt==0;

		if `year' == 2009 {;
			/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
			gen acs = 1 if inlist(serviceid, 922, 923, 924) & NA!= 1;
			gen acsinsurer = allowedamt - totcost if acs == 1;
			sort personid plan paiddt; 
			by personid plan: gen cum_acsinsurer = sum(acsinsurer);
			by personid plan: gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2500 & cum_acs) & (cum_acsinsurer[_n-1] < 2500) & (_n>1);
			by personid plan: replace acsmargin = 2 if (cum_acsinsurer[_n] > 2500) & (_n==1);
			replace acsinsurer = 2500 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
			replace acsinsurer = 2500 if (acsmargin == 2 & acs == 1);
			sort personid plan paiddt; 
			by personid plan: replace cum_acsinsurer = sum(acsinsurer);
			replace coinsurance = allowedamt - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
			replace totcost = coinsurance if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
			replace NA = 1 if acs == 1 & cum_acsinsurer > 2500;
			replace totcost = allowedamt if NA == 1;
		};
		 
		if `year' > 2009 {;
			/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
			gen acs = 1 if serviceid == `y'22 & NA! = 1;
			gen acsinsurer = allowedamt - totcost if acs == 1;
			sort personid plan paiddt; 
			by personid plan: gen cum_acsinsurer = sum(acsinsurer);
			by personid plan: gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2000 & cum_acs) & (cum_acsinsurer[_n-1] < 2000) & (_n>1);
			by personid plan: replace acsmargin = 2 if (cum_acsinsurer[_n] > 2000) & (_n==1);
			replace acsinsurer = 2000 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
			replace acsinsurer = 2000 if (acsmargin == 2 & acs == 1);
			sort personid plan paiddt; 
			by personid plan: replace cum_acsinsurer = sum(acsinsurer);
			replace coinsurance = allowedamt - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
			replace totcost = coinsurance if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
			replace NA = 1 if acs == 1 & cum_acsinsurer > 2500;
			replace totcost = allowedamt if NA == 1;
		};
	
		/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
		* totcost = coinsurance at this point. ; 
		gen nocount=0; 
		cap drop atmargin_max;
		replace nocount=1 if (NA==1 | nooop==1);
		replace totcost=coinsurance;
		replace totcost=allowedamt if NA==1;
		replace totcost=0 if nooop==1;
		replace totcost=0 if network==0; // in-network.  in network applies to out of network, but out of network doesn't apply to in network;
		
		gen totcost_out=coinsurance;
		replace totcost_out=0 if nooop==1;

		*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum;
		sort personid plan paiddt rank1personid;
		by personid plan : replace cum_totcost = sum(totcost*(nocount != 1));
		* in network;

		by personid plan : gen atmargin_max = 1 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1) & network==1;
		by personid plan : replace atmargin_max = 2 if (cum_totcost[_n] > maxoopind) & (_n==1) & network==1; 
		* out of network;
		by personid plan : gen cum_totcost_out = sum(totcost_out*(nocount != 1));
		by personid plan : gen atmargin_max_out = 1 if (cum_totcost_out[_n] >= maxoopind) & (cum_totcost_out[_n-1] < maxoopind)& (_n>1) & network==0;
		by personid plan : replace atmargin_max_out = 2 if (cum_totcost_out[_n] > maxoopind) & (_n==1) & network==0; 

		replace coinsurance = maxoopind - cum_totcost[_n-1] if (atmargin_max == 1 & nocount != 1) & network==1; // in network
		replace coinsurance = maxoopind - cum_totcost_out[_n-1] if (atmargin_max_out == 1 & nocount != 1) & network==0; // out of network
		replace coinsurance = maxoopind if (atmargin_max == 2 & nocount != 1);
		replace coinsurance = maxoopind if (atmargin_max_out == 2 & nocount != 1);
		
		/* Setting totcost to 0 past the coinsurance maximum limit */;
		sort personid plan  paiddt rank1personid;
		replace coinsurance = 0 if (cum_totcost > maxoopind) & atmargin_max==. & nocount==0;
		replace coinsurance = 0 if (cum_totcost_out > maxoopind) & atmargin_max_out==. & nocount==0 & network==0;
		/* deal with NA cases - patient pays full cost as a "copay" */;
		replace copay = allowedamt if NA == 1;
		replace coinsurance =0 if NA==1;
		replace coinsurance = 0 if prev == 1;
		replace copay = 0 if prev == 1;
		replace deductible=0 if (NA==1 | prev==1);
		replace totcost = coinsurance; 
		replace coinsurance = 0 if allowedamt==deductible; 
		replace copay = 0 if allowedamt==deductible;
		gen group = 2;
		
	} ; 
	tempfile ods_out`yplan';
	save `ods_out`yplan'', replace;
} ;

if `fullrun'==1  { ;

	*** PHARMACY CLAIMS ***;

	* there should be no determination based on network;
	use `drugclaims`yplan'', clear;
	if _N !=0 { ;
	
		* just for the versions where insurers are split into two files, keep only OMED/MODA drug claims ; 
		keep if substr(drugplan,1,1) == "O" | substr(drugplan,1,1) == "M" ;
	
		assert coinsuranceperc!=.;
		assert copay!=.;

		/* sorting the order of the claims based on original claims data: rank = ded, rank1 = coins */;
		sort personid drugplan paiddt; 
		sort personid drugplan paiddt ;
		by personid drugplan paiddt: gen rank1 = _n;  

		/* Calculating coinsurance amount */;
		gen coinsurance = coinsuranceperc * (allowedamt); 

		* Replacing copay to equal allowed amount if allowed amount is < copay;
		replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>0 ;
		replace coinsurance = 0 if allowedamt==copay & copay !=0;

		/********************taking care of the RX oop payment claims algorithm ****************************
		rules:
			1- Kaiser: all amounts are copays
			2- Providence: 
				a-> all generic payment tiers are copays
				b-> all brand formulary payment tiers are copays 
				c-> all brand non-formulary payment tiers are coinsurance
			3- OMED9
				a-> all RX amounts are coinsurances
			4- ORXA:
				a-> all generic payment tiers are copays
				b-> all brand formulary payment tiers are coinsurance
				c-> all brand non-formulary payment tiers are coinsurances
			5- ORXB:
				a-> all generic payment tiers are copays
				b-> all brand formulary payment tiers are copays
				c-> all brand non-formulary payment tiers are coinsurances
					- unless the copay is $100 and the allowed amt >$200, then it is a copayment 
					- PY 08 and 09: copay is $50 and the allowed amt >100, then it is a copayment 
									copay is $100 and the allowed amt > than $200, then it is a copayment 
			6- ORXC:
				-> all payment tiers are coinsurances
				
		******************************************************************************************/;
		/* Kaiser */;
		replace copay=coinsurance if drugplan=="KRX1" & copay==0;
		replace coinsurance=0 if drugplan=="KRX1";

		/* 2 - Providence */;
		replace copay=coinsurance if generic !=3 & copay==0 & drugplan=="PRX1"; // (a) and (b);
		replace coinsurance=0 if generic !=3 & drugplan=="PRX1"; // (a) and (b);
		replace coinsurance=copay if drugplan=="PRX1" & generic==3 & coinsurance==0;  
		replace copay=0 if drugplan=="PRX1" & generic==3; // may have to modified for year !=2008, ie, ... | drugplan=="PRX2";

		/* 4- ORXA */;
		replace copay=coinsurance if drugplan=="ORXA" & generic==1 & copay==0; // (a);
		replace coinsurance=0 if drugplan=="ORXA" & generic==1; // (a);
		replace coinsurance=copay if drugplan=="ORXA" & generic !=1 & coinsurance==0; // (b) and (c);  
		replace copay=0 if generic !=1 & drugplan=="ORXA"; // (b) and (c); 

		/* 5- ORXB */;
		replace copay=coinsurance if drugplan=="ORXB" & generic !=3 & copay==0; // (a);
		replace coinsurance=0 if drugplan=="ORXB" & generic !=3; // (a);

		gen exception=.;
		replace exception=1 if copay==100 & allowedamt >200 & drugplan=="ORXB";

		if `year'==2008 | `year'==2009{;
		replace exception=1 if copay==50 & allowedamt >100 & drugplan=="ORXB";
		replace exception=1 if copay==100 & allowedamt >200 & drugplan=="ORXB";
		};
		replace exception=0 if exception==.;

		replace copay=coinsurance if drugplan=="ORXB" & generic==3 & exception==1 & copay==0;
		replace coinsurance=0 if drugplan=="ORXB" & generic==3 & exception==1;

		replace coinsurance=copay if drugplan=="ORXB" & generic==3 & exception !=1 & coinsurance==0;
		replace copay=0 if drugplan=="ORXB" & generic==3 & exception !=1;

		/* 6- ORXC */;
		replace coinsurance=copay if drugplan=="ORXC" & coinsurance==0;
		replace copay=0 if drugplan=="ORXC";

		drop exception;
		
		******************************************************************************************;
		/* N/A cases. Assumption: Patient pays the full amount and it does not count towards deductible or max_oopcost*/;
		cap drop NA;
		cap drop na;

		gen NA=.;

		gen prev = 1 if (generic==0) & (drugplan == "KRX1");
		cap replace prev = 1 if free==1;
		* does this show up in the data? ; 
		replace prev = 1 if generic==0 & `claimyear' > 2012;

		/* Calculating OOP cost for each claim and cumulative OOP cost */;
		gen totcost = copay + coinsurance; /*No deductible for pharmacy plans and both copay and coinsurance counts towards max*/;
		replace totcost = allowedamt if NA == 1;

		/* Check to see if for Rx Option B the non-preffered drug cost is past the max limit */ ;
		/* CB 25 Jan 2016 hmm. this doesn't seem to be working, but the code looks correct...?*/ ; 
		/* we need to check how this maximum is imposed in years after 2008/2009*/ ;
		/* particularly 2011 and 2012. Is there any maximum?*/;
		gen planBgeneric3 = 1 if (drugplan == "ORXB") & (generic == 3) ; 
		replace planBgeneric3 = 1 if (drugplan == "MMED") & (generic == 2 | generic == 3) ;
		gen max_drug = . ; 
		replace max_drug = 50 if (planBgeneric3 == 1) & (retail == 1) & `planyear' < 2013 ;
		replace max_drug = 50 if (planBgeneric3 == 1) & (retail == 1) & (generic == 2) & `planyear' > 2012 ;
		replace max_drug = 150 if (planBgeneric3 == 1) & (retail == 1) & (generic == 3) & `planyear' > 2012 ;
		
		replace max_drug = 100 if (planBgeneric3 == 1) & (retail == 0) & `planyear' < 2013 ;
		replace max_drug = 100 if (planBgeneric3 == 1) & (retail == 0) & (generic == 2) & `planyear' > 2012 ;
		replace max_drug = 300 if (planBgeneric3 == 1) & (retail == 0) & (generic == 3) & `planyear' > 2012 ;

		replace totcost = max_drug if (planBgeneric3 == 1) & (totcost > max_drug) & NA!=1 ;
		replace coinsurance = max_drug if (planBgeneric3 == 1) & (coinsurance > max_drug) ;
				
		sort personid drugplan paiddt rank1;
		by personid drugplan : gen cum_totcost = sum(totcost) ; 

		replace coinsurance = 0 if (prev == 1 | dayssupply==1);
		replace copay=0 if (prev==1 | dayssupply==1);
		
		* Calculating  totcost at the margin where it just reaches the coinsurance maximum;
		*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum;
		sort personid drugplan  paiddt rank1;
		by personid drugplan : gen atmargin_max = 1 if (cum_totcost[_n] >= max_oopcost) & (cum_totcost[_n-1] < max_oopcost)& (_n>1);
		by personid drugplan : replace atmargin_max = 2 if (cum_totcost[_n] > max_oopcost) & (_n==1); 
		replace totcost = max_oopcost - cum_totcost[_n-1] if (atmargin_max == 1);
		replace totcost = max_oopcost if (atmargin_max == 2);
		replace coinsurance = totcost - copay if ((atmargin_max == 1 | atmargin_max == 2) & coinsuranceperc !=0 ); 
		replace coinsurance = 0 if prev == 1;
		replace copay = 0 if prev == 1; 
		replace totcost = copay + coinsurance; 

		/* Setting totcost to 0 past the coinsurance maximum limit */;
		sort personid drugplan  paiddt rank1;
		by personid drugplan : replace cum_totcost = sum(totcost);
		replace coinsurance = 0 if (cum_totcost > max_oopcost) & (atmargin_max != 1) & (atmargin_max != 2) ;
		replace copay = 0 if (cum_totcost > max_oopcost) & (atmargin_max != 1) & (atmargin_max != 2) ;

		
		replace totcost = copay + coinsurance;

		replace coinsurance = 0 if (prev == 1 | dayssupply==1);
		replace copay=0 if (prev==1 | dayssupply==1);
		* CB added - there are a dozen-ish non-zero, that shouldn't exist ; 
		* DEDUCTIBLE only applies to drug claims in OMED9 / MMED ; 
		cap drop deductible ; 
		gen deductible = 0 ;  
	} ;
	tempfile drug_out`yplan';
	save `drug_out`yplan'', replace;
} ;

if `fullrun'==1  { ;
*****OMED 9 CLAIMS****************************************;
	use `ods9claims`yplan'',clear;
	if _N !=0 { ;
		append using `ods9drugs`yplan'';
		
		* System of care is not available in this plan ; 
		
		* CB 9/9/2015 - I am not certain that we want to do this - why only in this plan? Commenting out for now; 
		* replace drug=1 if serviceid==`y'11 ; 
		
		replace drugplan="OMED9" if drugplan=="" & drug==1 & `planyear' < 2013 ;
		replace drugplan="MMEDH" if drugplan=="" & drug==1 & `planyear' > 2012 ;
		
		assert coinsuranceperc!=. if NA !=1;
		assert copay!=. if NA !=1;

		*Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met;

		*Charge Submitted=Discount+Allowed Amount;
		*Allowed Amount=NetPayment+Third Party (COB or Medicare) +Out of Pocket;
		*Out of Pocket=Copayment+Coinsurance+Deductible;
		*totcost = Out of Pocket - Copay;

		assert coinsuranceperc!=. if NA !=1;
		assert copay!=. if NA !=1;
		
		* This is true ~95% of the time, and we get almost all generic = 0 wrong because, ; 
		* without this change, we make the pay a deductible on them ;
		replace NA = 1 if drug == 1 & generic == 0 & drugplan == "MMEDH" ; 
		
		replace network=1 if network==.;
		replace network=1 if drug==1;
		replace network=1 if drug==1;

		/************ OOP MAX ***********/;
		* neither deductibles or copayments are included towards the oop max; 
		gen nooop=0; 
		replace nooop=1 if NA==1;

		/************ PREV SERVICES ************/;
		
		cap replace prev=1 if free==1;
		replace prev = 1 if (network == 1) & 
							(serviceid == `y'54 | 
							 serviceid == `y'52 | 
							 serviceid == 855   |
							 serviceid == 955   |
							 serviceid == 1050  |						 
							 serviceid == 1051  |
							 serviceid == 1150  |	
							 serviceid == 1151  |
							 serviceid == 1120  |
							 serviceid == 1020  |
							 serviceid == 1250  |
							 serviceid == 1230  | 
							 serviceid == 1220  );
							 
		/************ DEDUCTIBLE ************/;
		gen noded=0;
		
		* unclear whether there is documentation, but we never observe a non-zero deductible on drug claims from 2008 - 2010 ; 
		* even in OMED9  - so making all of those claims noded ; 
		replace noded = 1 if planyear < 2011 & drug == 1 ; 
		
		replace noded=1 if NA==1 | prev==1;
		replace noded=1 if copay !=0 & drug==.; // AHS addition;
		replace noded=1 if inlist(serviceid, `y'50, `y'30); // AHS addition;
							 
		/************ applying deductible to drug claims too ************/;
		if `planyear' < 2013 {; 
			replace plan="OMED9" if plan=="";
		} ;
		if `planyear' > 2012 {; 
			replace plan="MMEDH" if plan=="";
		} ;
		
		replace maxded = max_deductible if maxded == . ; 
		replace maxdedind = max_deductible if maxdedind == . ; 
		replace maxoop = max_oopcost if maxoop == . ; 
		replace maxoopind = max_oopcost if maxoopind == . ; 		
		bys plan personid: egen maxingdedind=max(maxdedind);
		bys plan personid: egen maxingded=max(maxded);
		replace maxdedind=maxingdedind if maxdedind==.;			 
		replace maxded=maxingded if maxded==.; drop maxingded;	

		bys plan personid: egen maxingoopind=max(maxoopind);
		bys plan personid: egen maxingoop=max(maxoop);
		replace maxoopind=maxingoopind if maxoopind==.;			 
		replace maxoop=maxingoop if maxoop==.; drop maxingoop;	
		
		assert maxded != . ; 
		assert maxoop != . ; 

		*Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met;

		*Charge Submitted=Discount+Allowed Amount;
		*Allowed Amount=NetPayment+Third Party (COB or Medicare) +Out of Pocket;
		*Out of Pocket=Copayment+Coinsurance+Deductible;
		*totcost = Out of Pocket - Copay;

		/* cleaning up drug claims */;
		gen deductible = allowedamt;
		replace deductible = 0 if noded==1; 
		gen totcost = deductible; 

		/* Calculating OOP cost for each claim */;
		gen coinsurance = coinsuranceperc* allowedamt;

		/* adjustments */;
		replace deductible = 0 if (NA == 1 | prev==1) ;
		replace coinsurance = allowedamt if allowedamt < coinsurance & coinsurance!=0 & allowedamt>=0;
		replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>=0;
		replace coinsurance = 0 if ( NA== 1 | prev==1);
		replace totcost = deductible ;
		replace totcost = 0 if (prev==1);
		replace coinsurance = 0 if allowedamt==copay; 

		/* sorting the order of the claims based on original claims data: rank = ded, rank1 = coins */;
		local ftype personid familyid;

		gen flag =0;
		gen ded =.;
		gen coin =.;

		foreach a of local ftype {;
			sort `a' plan paiddt; 

			replace flag = 1 if origded!=0 & origcoin != 0;
			gsort `a' plan paiddt -origded flag linenum;
			by `a' plan paiddt: gen rank`a' = _n;  

			sort `a' plan  paiddt; 
			replace coin = 0 if origcoin!= 0;
			replace coin = 1 if origcoin == 0;
			gsort `a' plan  paiddt -origded coin linenum;
			by `a' plan paiddt: gen rank1`a' = _n;  
		};
		drop ded coin;

		preserve; 
		keep if tier==1;
		if _N !=0 {;
		assert maxoopind != . ; 
		assert maxdedind != . ; 
		/* Calculating totcost at the margin where it just reaches the deductible */;

		*In N/A cases, the cost doesn't count towards the deductible or the maximum;
		sort personid plan paiddt rankpersonid;
		* Are we dealing with OMED9 drug costs relative to the deductible correctly? ; 

		by personid plan: gen cum_totcost = sum(totcost*(noded != 1)); 
		by personid plan : gen atmargin=1 if (cum_totcost[_n] >= maxdedind & cum_totcost[_n-1] < maxdedind) & (_n>1) & noded !=1;
		by personid plan : replace atmargin=2 if (cum_totcost[_n] > maxdedind) & (_n==1) & noded !=1;
		replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxdedind) if ( NA != 1 & (atmargin == 1 | atmargin == 2) & noded !=1) ;
		replace deductible = (maxdedind - cum_totcost[_n-1]) if (NA != 1 & atmargin == 1 & noded !=1);
		replace deductible = maxdedind if (NA != 1 & atmargin == 2 & noded !=1);
		replace deductible = 0 if noded==1;
		replace totcost = deductible;
		replace coinsurance = 0 if prev == 1;
		
		/* Calculating  totcost if cumulative is greater than deductible */;  
		sort personid plan  paiddt rankpersonid;
		by personid plan : replace cum_totcost = sum(deductible); 
		by personid plan : gen greater_ded = 1 if (cum_totcost > maxdedind) & (atmargin != 1) & (atmargin != 2);
		replace deductible = 0 if (greater_ded == 1); /* Setting deductible to zero after it crosses limit */;
		replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2);  /* Setting coinsurance to zero before deductible is met */;
		replace copay = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2); ; /* Setting coinsurance to zero before deductible is met */;
		replace coinsurance = 0 if (NA == 1 | prev == 1);
		replace totcost = coinsurance + copay + deductible if (NA != 1); /* Setting totcost to equal coinsurance after deductible is met */;
		replace totcost = allowedamt if NA == 1; 
		replace totcost = 0 if prev == 1;
		
		/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
		* totcost at this point = coinsurance; 
		gen nocount=0; 
		replace nocount=1 if (NA==1 | nooop==1);
		*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum;
		sort personid plan network paiddt rank1personid;
		by personid plan network: replace cum_totcost = sum(totcost*(NA != 1));
		by personid plan network: gen atmargin_max = 1 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1);
		by personid plan network: replace atmargin_max = 2 if (cum_totcost[_n] > maxoopind) & (_n==1); 
		replace coinsurance = maxoopind - cum_totcost[_n-1] if (atmargin_max == 1 & NA != 1);
		replace coinsurance = maxoopind if (atmargin_max == 2 & NA != 1);
		replace coinsurance = allowedamt if NA == 1;
		replace coinsurance = 0 if prev == 1;
		replace totcost = coinsurance + deductible + copay; 

		/* Setting totcost to 0 past the coinsurance maximum limit */;
		sort personid plan  paiddt rank1personid;
		by personid plan : replace cum_totcost = sum(totcost);
		replace coinsurance = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & NA ! = 1;
		replace copay = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & NA ! = 1;
		replace coinsurance = allowedamt if NA == 1;
		replace coinsurance = 0 if prev == 1;
		replace totcost = coinsurance + deductible + copay; 
		};
		tempfile indiv;
		save `indiv';
		
		restore;
		* 74.97502 v 70.42097;
		/* check family deductible limit */;
		drop if tier==1;
		if _N !=0 {;
		sort familyid plan  paiddt rankfamilyid; 
		by familyid plan: gen cum_totcost = sum(totcost*(noded != 1));
		by familyid plan : gen atmargin=1 if (cum_totcost[_n] >= maxded & cum_totcost[_n-1] < maxded) & (_n>1) & noded !=1;
		by familyid plan : replace atmargin=2 if (cum_totcost[_n] > maxded) & (_n==1) & noded !=1;
		replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxded) if ( NA != 1 & prev !=1 & (atmargin == 1 | atmargin == 2) & noded !=1);

		replace deductible = (maxded - cum_totcost[_n-1]) if (NA != 1 & atmargin == 1 & noded !=1);
		replace deductible = maxded if (NA != 1 & atmargin == 2 & individual_ded == 0);
		replace deductible = 0 if noded==1;
		replace totcost = deductible;
		replace coinsurance = 0 if prev == 1 ;

		sort familyid plan  paiddt rankfamilyid;
		by familyid plan : replace cum_totcost = sum(totcost);  
		by familyid plan : gen greater_ded = 1 if (cum_totcost > maxded) & (atmargin != 1) & (atmargin != 2);
		replace deductible = 0 if (greater_ded == 1); /* Setting deductible to zero after it crosses limit */;
		replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2); /* Setting coinsurance to zero before deductible is met */;
		replace copay = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2); /* Setting coinsurance to zero before deductible is met */;
		replace coinsurance = 0 if NA == 1 | prev == 1;
		replace totcost = coinsurance + deductible + copay if (NA != 1); /* Setting totcost to equal coinsurance after deductible is met */;
		replace totcost = allowedamt if NA == 1; 
		replace totcost = 0 if prev == 1 ;

		/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
		gen nocount=0; 
		replace nocount=1 if (NA==1 | nooop==1);
		*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum; // the oop max applies separately to each individual;
		sort personid plan network paiddt rank1personid;
		by personid plan network: replace cum_totcost = sum(totcost*(NA != 1));
		by personid plan network: gen atmargin_max = 1 if (cum_totcost[_n] >= maxoop) & (cum_totcost[_n-1] < maxoop)& (_n>1);
		by personid plan network: replace atmargin_max = 2 if (cum_totcost[_n] > maxoop) & (_n==1); 

		replace coinsurance = maxoop - cum_totcost[_n-1] if (atmargin_max == 1 & NA != 1);
		replace coinsurance = maxoop if (atmargin_max == 2 & NA != 1);
		replace coinsurance = allowedamt if NA == 1;
		replace coinsurance = 0 if prev == 1;
		replace copay = 0 if prev == 1;
		replace deductible=0 if NA==1;
		replace totcost = coinsurance + deductible + copay; 

		/* Setting totcost to 0 past the INDIVIDUAL coinsurance maximum limit */;
		sort personid plan  paiddt rankpersonid;
		by personid plan : replace cum_totcost = sum(totcost*(NA != 1));
		by personid plan:  replace atmargin_max = 4 if (cum_totcost[_n] >= maxoop) & (cum_totcost[_n-1] < maxoop)& (_n>1)  & NA !=1;
		by personid plan:  replace atmargin_max = 5 if (cum_totcost[_n] > maxoop) & (_n==1) & NA !=1;
		replace coinsurance = 0 if (cum_totcost > maxoop) & (atmargin_max != 4) & (atmargin_max != 5) & NA ! = 1;
		replace copay = 0 if (cum_totcost > maxoop) & (atmargin_max != 4) & (atmargin_max != 5) & NA ! = 1;
		replace coinsurance = allowedamt if NA == 1;
		replace coinsurance = 0 if prev == 1;
		replace totcost = coinsurance + deductible +copay;

		/* Setting totcost to 0 past the FAMILY coinsurance maximum limit */;
		sort familyid plan  paiddt rankfamilyid;
		by familyid plan : replace cum_totcost = sum(totcost*(NA != 1));
		by familyid plan:  replace atmargin_max = 5 if (cum_totcost[_n] >= maxoop) & (cum_totcost[_n-1] < maxoop)& (_n>1)  & NA !=1;
		by familyid plan:  replace atmargin_max = 6 if (cum_totcost[_n] > maxoop) & (_n==1) & NA !=1;
		replace coinsurance = 0 if (cum_totcost > maxoop) & (atmargin_max != 5) & (atmargin_max != 6) & NA ! = 1;
		replace copay = 0 if (cum_totcost > maxoop) & (atmargin_max != 5) & (atmargin_max != 6) & NA ! = 1;
		replace coinsurance = allowedamt if NA == 1;
		replace coinsurance = 0 if prev == 1;
		replace totcost = coinsurance + deductible + copay;
		} ;
		append using `indiv';  

		* /* deal with dual copay and coinsurance charges: ;
		* 1) deal with charges with non-zero deductible--take copay out first, then coinsurance; 
		* 2) deal with charges with zero deductible--take coins out first, then copay */;
		* * 1) ;
		* gen cost =allowedamt-deductible if deductible !=0 & dualcc==1 & drug==.;

		* replace copay = cost if (noded !=1 & copay > cost & dualcc==1 & deductible !=0 & cost > 0) & drug==.;
		* replace cost =allowedamt-deductible-copay if dualcc==1 & deductible !=0 & drug==.;
		* replace coinsurance = coinsuranceperc*(cost) if deductible !=0 & dualcc==1 & cost > 0 & drug==.;
		* * 2);
		* replace cost =allowedamt-copay if deductible==0 & dualcc==1 & drug==.;
		* replace coinsurance = coinsuranceperc*(cost) if deductible==0 & dualcc==1 & coinsurance !=0 & cost > 0 & drug==.;
		* replace coinsurance=0 if cost < 0;

		* /* for duallcc charges, the copay only applies to the first instance */;
		* gsort personid plan serviceid  srvcdt  -allowedamt;
		* by personid plan serviceid srvcdt: gen copaycount=_n;


		replace copay=0 if allowedamt==0;
		replace coinsurance=0 if allowedamt==0;
		replace deductible=0 if allowedamt==0;

		* below probably needs to be updated to include family id instead of personid. Note that this was tried and didn't lower the errors. -Jones 10/07/2014; 
		if `year' == 2009 {;
		/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
		gen acs = 1 if inlist(serviceid, 922, 923, 924) & NA!= 1;
		gen acsinsurer = allowedamt - totcost if acs == 1;
		sort personid plan  paiddt; 
		by personid plan : gen cum_acsinsurer = sum(acsinsurer);
		by personid plan : gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2500 & cum_acs) & (cum_acsinsurer[_n-1] < 2500) & (_n>1);
		by personid plan : replace acsmargin = 2 if (cum_acsinsurer[_n] > 2500) & (_n==1);
		replace acsinsurer = 2500 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
		replace acsinsurer = 2500 if (acsmargin == 2 & acs == 1);
		sort personid plan paiddt; 
		by personid plan: replace cum_acsinsurer = sum(acsinsurer);
		replace coinsurance = allowedamt - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
		replace totcost = coinsurance if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
		replace NA = 1 if acs == 1 & cum_acsinsurer > 2500;
		replace totcost = allowedamt if NA == 1;
		};

		if `year' > 2009 {;
			/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
			gen acs = 1 if serviceid == `y'22 & NA! = 1;
			gen acsinsurer = allowedamt - totcost if acs == 1;
			sort personid plan  paiddt; 
			by personid plan : gen cum_acsinsurer = sum(acsinsurer);
			by personid plan : gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2000 & cum_acs) & (cum_acsinsurer[_n-1] < 2000) & (_n>1);
			by personid plan : replace acsmargin = 2 if (cum_acsinsurer[_n] > 2000) & (_n==1);
			replace acsinsurer = 2000 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
			replace acsinsurer = 2000 if (acsmargin == 2 & acs == 1);
			sort personid plan paiddt; 
			by personid plan: replace cum_acsinsurer = sum(acsinsurer);
			replace coinsurance = allowedamt - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
			replace totcost = coinsurance if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
			replace NA = 1 if acs == 1 & cum_acsinsurer > 2500;
			replace totcost = allowedamt if NA == 1;
		};
	 		/* Calculating final cumulative totalcost and the OOP cost (totalcost + copay)*/;

		replace deductible=0 if (NA==1 | prev==1);
			* there are some drug claims that do have a deductible and are modeled here as 0;
			* by generic / retail / days these errors are <5% of the cell ; 
			* but probably worth returning and trying to get a list of ndc's that are ; 
			* subject to a deductible ; 
		replace copay=0 if deductible==allowedamt;
		replace copay=0 if (prev == 1 & network==1);
		replace coinsurance=0 if (prev == 1 & network==1) | NA==1;
		replace deductible=0 if (prev == 1 & network==1);

		gen group = 3;
	};

		*** CB: I think that having plan = OMED9 when drug ==1 is messing things up, I'm going to try resetting it to missing here and see what happens 12/03/2014;

		di _N;

		tab plan;

		tab plan drug;

		replace plan = "" if drug == 1;

		tab plan; 

		tab plan drug;

		tempfile ods9_out`yplan';
		save `ods9_out`yplan'', replace;
};
********* APPENDING ALL FINAL OUTPUT FILES							*********************;
/*
di "`kaiser_out`yplan''";
 
use `kaiser_out`yplan'', clear;

if `planyear' < 2012 {;
	append using `prov_out`yplan'';
};
*/
clear;
use using `ods_out`yplan'';
append using `drug_out`yplan'';
append using `ods9_out`yplan'';

* fail safe ; 
* Somehow on like 1-2 drug claims claims, the deductible is not capped by the deductible max ; 
if deductible > maxded replace deductible = maxded ; 

label variable group "This variable indicates if claim is from a HMO, ODS, ODS9 or DRUG claim";
label define group 1 "HMO" 2 "OMED" 3 "OMED9" 4 "DRUG";
label values group group;
notes group: created in oregoncalculator do file `cdate'; 

/* cleaning */;
destring memid, replace;
destring entitynum, replace;
compress;

cap drop v5* v1* empcode customcode covtypcd condi* entfirst empfirst entstring dedprev* _merge count first flag* diagnosis* eligtag lifestyle* procmodcd group;
cap drop planyear;

gen planyear=`planyear';

*** CB test;
replace plan = "" if drug ==1 ;

*** CB added;
local list drug deductible coinsurance copay origcoin origcopay origded;
	foreach var of local list { ;
	replace `var'=0 if `var'==.;
} ;

gen orig_sum = round(origcopay+origcoin+origded,0.01);
gen calc_sum = round(copay+coinsurance+deductible,0.01);

gen wrong = 1 if orig_sum != calc_sum;
replace wrong = 0 if wrong == .;
replace wrong = . if chosen != 1;

keep personid*  familyid plan drugplan drug copay coinsurance deductible origcopay origcoin origded allowedamt network nooop noded chosen;

if `acg'==0 { ;
save  "`out_data'/`claimyear'/calcrun_acg`acg'_`cdate'_`runtype'.dta", replace;
} ;

if `acg'==1 { ; di `acg';
save  "`out_data'/`claimyear'/calcrun_${unit}${cells}acg`acg'_`cdate'_`runtype'_${piece}.dta", replace;
} ;

display `year';
display `y';
clear;
capture log close;

/* modifications: 4-1: For providence, deductible the same no matter out of network or in.  OOP max DIFFERS for in network v. out of network--modification made */;