#delimit;
set more off;
clear;
local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

use `kaiser`yplan'', clear;

describe ;

/* Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met*/;
gen overallcost = allowedamt;
gen deductible = overallcost;

gen copayGTallowedamt=(copay) if allowedamt < copay;
replace copayGTallowedamt=0 if copayGTallowedamt==.;

gen coinsurance = coinsuranceperc*(overallcost);

gsort   -allowedamt -origded;

replace procedure = trim(procedure) ; 
*** Procedure code based exceptions with documentation in plan handbook ; 
*** 1) Colonoscopy and sigmoidoscopy ; 
	gen colonoscopy = 0 ; 
	replace colonoscopy = 1 if inlist(procedure, "G0105", "G0121", "G0122", "44388", "44389", "44391", "44392", "44393", "44394") ; 
	*** Note: inlist has a limit of 10 arguments ; 
	replace colonoscopy = 1 if inlist(procedure, "45378", "45379", "44397", "45380", "45381", "45382", "45383", "45384", "45385") ;
	replace colonoscopy = 1 if inlist(procedure, "45386", "45391", "45392", "43235", "43239", "43248", "43264", "43265") ;
	*** possibly also ICD-9 (45.23) ;
	replace colonoscopy = 0 if inlist(serviceid, "S600", "S610", "S615") ; *** If colonoscopy occurs in ER setting, bill it like ER ; 
	replace copay = 0 if colonoscopy == 1 ;
	replace coinsuranceperc = 0 if colonoscopy == 1 ; 
	*** based on table 1 of  Ko et al 2014 "Determination of colonoscopy indication from administrative claims data" & study below ; 
	*** http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3387505/table/T1/ ;
	
	gen sigmoidoscopy = 0 ; 
	replace sigmoidoscopy = 1 if inlist(procedure, "G0104", "45300", "45301", "45302", "45303", "45304", "45305", "45306", "45307") ;
	replace sigmoidoscopy = 1 if inlist(procedure, "45308", "45309", "45310", "45311", "45312", "45313", "45314", "45315", "45316") ;
	replace sigmoidoscopy = 1 if inlist(procedure, "45317", "45318", "45319", "45320", "45321", "45322", "45323", "45324", "45325") ;
	replace sigmoidoscopy = 1 if inlist(procedure, "45326", "45327", "45328", "45329", "45330", "45331", "45332", "45333", "45334") ;
	replace sigmoidoscopy = 1 if inlist(procedure, "45335", "45336", "45337", "45338", "45339",	"45340", "45341", "45342", "45343") ;
	replace sigmoidoscopy = 1 if inlist(procedure, "45344", "45345") ;									
	*** note: we may also need ICD-9 codes here (45.24, 48.21, 48.22, 48.23, 48.24, 48.36) ;
	replace sigmoidoscopy = 0 if inlist(serviceid, "S600", "S610", "S615") ; *** If sigmoidoscopy occurs in ER setting, bill it like ER ; 
	replace copay = 0 if sigmoidoscopy == 1 ;
	replace coinsuranceperc = 0 if sigmoidoscopy == 1 ; 
	*** based on Wernil et al 2014  "Patterns of Colorectal Cancer Screening Uptake in Newly Eligible Men and Women" ;
	*** http://cebp.aacrjournals.org/content/23/7/1230.full.pdf+html ;	


	*** 3) Labs ; 
	*** 88304 =  0  ?;
	*** why are we incorrectly 0 so often? ;
	*** we need to do this in the inputs file to make sure that this is reflected in cross plan modelling ; 
	replace prev = 1 if serviceid == "S671" & inlist(procedure, "80061","82306","82274","87491","87591","87389","86592","83540","80102") ;
	replace prev = 1 if serviceid == "S671" & inlist(procedure, "86803","84153","82248","88142","86901","86900","88141") ;
	
	*** 4) Imaging ; 
	*** again, do this in the input file ; 
	replace prev = 1 if serviceid == "S661" & inlist(procedure, "G0202","77052","77057","71010","77051","Q9967") ;

	*** 5) DME ; 
	replace coinsuranceperc = 0 if serviceid == "S700" & inlist(procedure, "A6549","A7034","A7037","A7038","A7039","A9900","E0760","E2402","L1800") ;
	replace coinsuranceperc = 0 if serviceid == "S700" & inlist(procedure, "L1815","L3030","L4360","L4396","A4466","A4450","A4351","A6402","A7030") ;
	replace coinsuranceperc = 0 if serviceid == "S700" & inlist(procedure, "A7034","A7035","A7037","A7038","A7039","A9901","E0143","E0955","E0956") ;
	replace coinsuranceperc = 0 if serviceid == "S700" & inlist(procedure, "E0957","E0960","L2999","L3030","L3760","L3908","L3923","L3962","L4350") ;
	replace coinsuranceperc = 0 if serviceid == "S700" & inlist(procedure, "L4386","L4396","T4529") ;
	replace coinsuranceperc = 0 if serviceid == "S700" & substr(procedure,1,1) == "B" & procedure != "B4088" ;
	replace coinsuranceperc = 0 if serviceid == "S700" & substr(procedure,1,1) == "Q" ;
	
	replace coinsuranceperc = 0 if serviceid == "S700" & inlist(procedure, "L8690") ; 
	replace coinsuranceperc = 0 if serviceid == "S719" & inlist(procedure, "L8690") ; 
	
*** Other procedure code based exceptions based on observed data ; 
	*** These exceptions minimize errors, however, they likely do not accurately reflect expectations because they are based on information that a subscriber would not have when making plan selection decision ; 

/***** MENTAL HEALTH SERVICES ******/ ; 

	if `year' == 2008 { ;
		replace copay = 10 if serviceid == "S208" & procedure == "90760" ;
		replace copay = 100 if serviceid == "S208" & procedure == "99218" ;
		replace copay = 0 if serviceid == "S430" & procedure == "H0048"; 
		replace copay = 5 if serviceid == "S430" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 0 if serviceid == "S430" & substr(procedure,1,1) == "8" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 0 if serviceid == "S430" & inlist(procedure, "99078", "99211", "99213", "99231", "99232", "99233", "~") & plan == "KMED1" & network == 1 & copay !=0 ; 

		replace copay = 2 if serviceid == "S430" & procedure == "90853" & plan == "KMED2" & network == 1 & copay !=0 ; 
		replace copay = 0 if serviceid == "S430" & substr(procedure,1,1) == "8" & plan == "KMED2" & network == 1 & copay !=0 ; 
		replace copay = 0 if serviceid == "S430" & inlist(procedure, "99078", "99211", "99213", "99231", "99232", "99233","~") & plan == "KMED2" & network == 1 & copay !=0  ; 
	} ;
	if `year' == 2009 { ;
		replace copay = 0 if serviceid == "S430" & procedure == "H0048" ; 
		replace copay = 5 if serviceid == "S430" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0; 
		replace copay = 0 if serviceid == "S430" & substr(procedure,1,1) == "8" & network == 1 & copay !=0; 
		replace copay = 0 if serviceid == "S430" & inlist(procedure, "99211", "99213", "99231", "99232", "99233","~") & network == 1 & copay !=0 ; 

		replace copay = 2 if serviceid == "S430" & procedure == "90853" & plan == "KMED2" & network == 1 & copay !=0 ; 
		replace copay = 2 if serviceid == "S430" & procedure == "90849" & plan == "KMED2" & network == 1 & copay !=0 ;
		replace copay = 0 if serviceid == "S430" & substr(procedure,1,1) == "8" & plan == "KMED2" & network == 1 & copay !=0 ; 
		replace copay = 0 if serviceid == "S430" & inlist(procedure, "99211", "99213", "99231", "99232", "99233","~") & plan == "KMED2" & network == 1 & copay !=0 ; 
	} ;

	if `year' == 2008 { ;
		replace copay = 0  if serviceid == "S431" & procedure == "H0048" ; 

		replace copay = 10 if serviceid == "S431" & procedure == "H0002" & plan == "KMED1" & network == 1 & copay != 0 ; 
		replace copay = 10 if serviceid == "S431" & procedure == "H0004" & plan == "KMED1" & network == 1 & copay != 0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0005" & plan == "KMED1" & network == 1 & copay != 0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0020" & plan == "KMED1" & network == 1 & copay != 0 ; 

		replace copay = 2 if serviceid == "S431" & procedure == "90853" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 2 if serviceid == "S431" & procedure == "H0005" & plan == "KMED2" & network == 1 & copay != 0 ;
		replace copay = 5 if serviceid == "S431" & procedure == "H0002" & plan == "KMED2" & network == 1 & copay != 0 ; 					
		replace copay = 5 if serviceid == "S431" & procedure == "H0004" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 5 if serviceid == "S431" & procedure == "H0016" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 5 if serviceid == "S431" & procedure == "H0020" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 5 if serviceid == "S431" & procedure == "H0037" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 5 if serviceid == "S431" & procedure == "H0012" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 5 if serviceid == "S431" & procedure == "90806" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 5 if serviceid == "S431" & procedure == "90887" & plan == "KMED2" & network == 1 & copay != 0 ; 
	} ;
	if `year' == 2009 { ;
		replace copay = 0  if serviceid == "S431" & procedure == "H0048" ; 
		replace copay = 10 if serviceid == "S431" & procedure == "H0002" & plan == "KMED1" & network == 1 & copay != 0 ; 
		replace copay = 10 if serviceid == "S431" & procedure == "H0004" & plan == "KMED1" & network == 1 & copay != 0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0005" & plan == "KMED1" & network == 1 & copay != 0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0020" & plan == "KMED1" & network == 1 & copay != 0 ; 

		replace copay = 2  if serviceid == "S431" & procedure == "90853" & plan == "KMED2" & network == 1 & copay != 0 ; 
		replace copay = 2  if serviceid == "S431" & procedure == "H0005" & plan == "KMED2" & network == 1 & copay != 0 ;
	} ; 

	*** Drugs - there are some drug claims in the medical files. They are assessed a 20% coinsurance, except a few very expensive claims. 
	replace coinsuranceperc = 0 if serviceid == "S721" & allowedamt > 175 ; 
	replace coinsuranceperc = 0 if serviceid == "S721" & inlist(procedure,"99211","99213","L1832");	
	
/***********************************2008 */;
/* services where you don't have to meet the deductible first */;
if `year'==2008{;

tab by_day;
tab prev; 

replace NA= 1 if network==0 & (plan== "KMED1" | plan=="KMED2");  
/* N/A cases: The patient pays the full amount and it doesn't count towards the deductible or oop max */;
/** CB CONFIRM*/;

/************* DEDUCTIBLE *************/;
gen noded=0;
replace noded=1 if planfirst=="K";

/************* PREV SERVICES *************/;
/* Preventive care services are always fully covered for PMED plans and for some services for KMED plans*/;
/* 854: routine womens/mens exam, 852: immunizations,  855: well baby*/;
replace prev = 0 if network == 0;

/*** This doesn't seem to be born out in the data*/

/****** accounting for charges by day ******/;
replace days = 0 if days == .;
bys personid plan claimid serviceid srvcdt: gen dayssum = sum(days);
replace dayssum=0 if dayssum>days; 
/* I just want one line to have the number of days - the raw claims data has the days at each inpatient stay line, which in the case would make us double count*/; 
/* for inpatient stay, mental health, inpatient and residential stay */;
/*CB: this process isn't working very well at all*/;

tab by_day;
replace copay = 100*dayssum if (by_day == 1) & (plan=="KMED1" ) & dayssum>0;
replace copay = 500 if copay >500 & (by_day == 1)  & (plan=="KMED1" );
replace deductible = (overallcost - copay) if (overallcost > copay & (by_day == 1) );

/* Okay - we overshoot here a bit, but that's fine. More concerning is the copay = 0, but origcopay !=0 claims

Problem: the observed copays do not follow the rule
*/;
gen dualcc=0;	
gen nooop=0;
gen chargedmaxoop=0;
};

/********************************************************************************************2009*/;
if `year'==2009{;
/************* DEDUCTIBLE *************/;
gen noded=0;
replace noded=1 if planfirst=="K";
  
/************* PREV SERVICES *************/;
/* Preventive care services are always fully covered for PMED plans and for some services for KMED plans*/;
/* 952=immunizations, 953=office visits, 954=routine women's/men's exam, 955=well-baby*/;
replace prev = 0 if network == 0;
  
*** Resetting to 0 b/c of prev used to appear first quit far below. I'm not completely sure why. Adding it here and leaving it below in several places ; 
replace coinsurance = 0 if prev == 1;
replace copay=0 if prev==1;
  
/****** accounding for charges by day ******/;
bys personid plan claimid serviceid srvcdt:  gen dayssum = sum(days);
replace dayssum=0 if dayssum>days; 
/** I just want one line to have the number of days - the raw claims data has the days at each inpatient stay line, which in the case would make us double count*/; 

replace copay = 100*dayssum if ((by_day == 1) ) & (plan=="KMED1" );
replace copay = 200*dayssum if ((by_day == 1) ) & (plan=="KMP1A" );
replace copay = 500 if copay >500 & (by_day == 1) & (plan=="KMED1");
replace copay = 1000 if copay >1000 & (by_day == 1) & (plan=="KMP1A" );
replace deductible = (overallcost - copay) if (overallcost > copay & (by_day == 1));

gen dualcc=0;	
gen nooop=0;
gen chargedmaxoop=0;
};

replace nooop = 1 if serviceid == "S719" ;

replace noded=0 if noded==.;
replace deductible = 0 if noded==1 | (copay !=0 & dualcc !=1);  // testing AHS;
gen totcost = deductible;

/* Special case for ER visits, copay is waived if admitted, coinsurance must still be paid, ER copay paid only once per visit, deductible applies */;
gen ERvisit = 1 if (serviceid == "S600"); 

gsort personid plan srvcdt  -origcopay -allowedamt;
by personid plan srvcdt:  gen numER = sum(ERvisit);
	replace numER=0 if ERvisit==.;

bys personid plan srvcdt: egen sum_origded = sum(origded) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcoin = sum(origcoin) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcopay = sum(origcopay) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_allowedamt = sum(allowedamt) if ERvisit == 1;
replace allowedamt = sum_allowedamt if ERvisit == 1 & numER==1;  
replace origded = sum_origded if ERvisit == 1 & numER==1;  
replace origcoin = sum_origcoin if ERvisit == 1 & numER==1;  
replace origcopay = sum_origcopay if ERvisit == 1 & numER==1;  

replace allowedamt = 0 if ERvisit == 1 & numER>1; 
replace origded = 0 if ERvisit == 1 & numER>1; 
replace origcopay = 0 if ERvisit == 1 & numER>1; 
replace origcoin = 0 if ERvisit == 1 & numER>1; 

gsort personid srvcdt -origcopay -allowedamt;
gen admit = 0 if serviceid == "S600" & origcopay == 0; 
replace admit = 1 if serviceid == "S600" & admit != 0; 
by personid srvcdt: egen admitted=max(admit);

 /* Special ER cases. */;
replace copay = 0 if (numER > 1 & (serviceid == "S600"));
 /* ER copay paid only once per visit*/;
replace copay= 0 if admitted == 0 & (serviceid == "S600"); 
/* if admitted ==0, it means the individual was admitted and the copay is waived*/;
replace copay = 100 if numER == 1 & admitted==1 & (serviceid == "S600") & allowedamt >= 100; 
/* if not admitted, copay of 100 applies.*/; 
replace copay = allowedamt if numER == 1 & admitted == 1 & (serviceid == "S600") & allowedamt < 100; 

replace coinsurance = 0 if NA == 1;
replace totcost = overallcost if NA == 1; 
replace deductible = 0 if NA == 1;

replace deductible = 0 if prev == 1;
replace totcost = 0 if prev == 1;

replace copay = 0 if copay == .;
replace coinsurance = 0 if coinsurance == .;

/* Replacing coinsurance to equal allowed amount if allowed amount is < coinsurance */;
replace coinsurance = allowedamt if allowedamt < coinsurance & coinsurance!=0 & allowedamt>=0;

/* Replacing copay to equal allowed amount if allowed amount is < copay */;
replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>=0;
replace coinsurance = 0 if allowedamt==copay & copay !=0;
replace copay = 0 if allowedamt==coinsurance & coinsurance !=0;

/* Calculating totcost at the margin where it just reaches the deductible */;

replace coinsurance = (allowedamt - copay) * coinsuranceperc if (serviceid == "S600"); 

/* copay applies once per serviceid per family (?) per day*/;
gsort familyid plan srvcdt serviceid -copay -allowedamt;
		by familyid plan srvcdt serviceid :  gen numcopay_cb = _n;
		
replace copay = 0 if (numcopay_cb > 1);

/***************************************************************************************************************************************************************************/;
/********************************************************************************CALCULATOR*******************************************************************************/;
/***************************************************************************************************************************************************************************/;
local ftype personid familyid;  
/* this just stores the two variables into ftype */;

gen flag=0;
gen ded=.;
gen coin=.;
gen cop=.;

/* this is the equivalent of running 2 loops, one for personid and one for family id */;
/* rank puts individuals with a non-zero deductible AND  individuals with a non-zero deductible and non-zero coins first*/; 
/* based on claims data: want to rank so procedures on same date, the procedures that are below the duductible*/ ;
/* come first and the claims that are paid for in full by the insurance come last*/;

foreach a of local ftype {;
	sort `a' plan paiddt linenum; 

	replace flag = 1 if origded!=0 & origcoin != 0 & origcopay !=0;
	replace ded = 0 if origded!= 0;
	replace ded = 1 if origded == 0;
	assert ded !=.;

	sort `a' plan network paiddt linenum; 
	replace coin = 0 if origcoin!= 0;
	replace coin = 1 if origcoin == 0;
	assert coin !=.;

	replace cop = 0 if origcopay!= 0;
	replace cop = 1 if origcopay == 0;
	assert cop !=.;

	gsort `a' plan network paiddt linenum coin cop;
	by `a' plan network paiddt: gen rank1`a' = _n;  

	sort `a' plan network paiddt linenum ded origded flag; 
	/* this puts ded=0 and flag=0 before ded=1 and flag=1*/;
	by `a' plan network paiddt: gen rank`a' = _n;  
};

drop ded coin cop;

/* Make sure copay only applies once per claim id*/;

/* CB 3/5/15 this was: gsort personid plan claimid serviceid srvcdt linenum */;
*** I think we need to have it as: gsort personid plan claimid serviceid srvcdt -allowedamt;
*** because we set have copay = 0 if allowedamt = 0, so if the first linenum is allowedamt 0,;
*** and we set all copays after the first line in a claimid = 0 (as below), then we get too ;
*** many zeros, -copay may work too.;

gsort personid plan claimid serviceid srvcdt -allowedamt;
by personid plan claimid serviceid srvcdt :  gen numcopay = _n;

/* additional cost tier services 
 - for some charges, such as additional cost tier, the allowedamt is <500, but there were multiple serviced done under
this tier on a given servicedate.  As a result, the full $500 was charged, but distributed among the different services.  
We need a fix for this.  We're utilizing a variable from the beginning of the piece (copayGTallowedamt).
 For instance, see 2010: personid = "ATo21EbhToUo1QATosGt2ot" & chosen==1 */;
gsort personid plan claimid serviceid srvcdt linenum ;
by personid plan claimid serviceid srvcdt : gen cum_copaycost = sum(copay);
by personid plan claimid serviceid srvcdt: gen atmarginc_max = 1 if (cum_copaycost[_n] >= copayGTallowedamt) & (cum_copaycost[_n-1] < copayGTallowedamt)& (_n>1);
replace copay = copayGTallowedamt - cum_copaycost[_n-1] if (atmarginc_max == 1 ) & (serviceid=="S440" | serviceid=="S660" | serviceid=="S661" ) & allowedamt < copayGTallowedamt;
gen exempt=1 if (serviceid=="S440" | serviceid=="S660" | serviceid=="S661") & ((copayGTallowedamt > cum_copaycost) | atmarginc_max==1);
replace exempt=0 if exempt==.;

/* for duallcc charges, the copay only applies to the first instance */;
gsort personid plan serviceid provid srvc_id  srvcdt linenum -copay;
by personid plan serviceid provid srvc_id srvcdt: gen copaycount=_n if dualcc==1;
replace copay=0 if copaycount >1 & dualcc==1 & (allowedamt > copayGTallowedamt);
/* Make sure copay only applies once per claim id*/;
/*exception: DME in 2011 providence; // CHECK THIS IN THE CLAIMS*/;
gen exception=0;
replace exception=1 if (plan=="PMED2" | plan=="PMP2A") & (`planyear'==2010 | `planyear'==2011) & serviceid=="`y'36";
gsort personid plan claimid serviceid paiddt -copay;
replace numcopay=1 if exception==1;
replace copay = 0 if (numcopay > 1) & exempt !=1 & planfirst=="K"; 

/* CB: 3/5/15 this may be messing up ER claims - addressed as noted in comment above.*/;

/* In N/A cases, the cost doesn't count towards the deductible or the maximum*/;
sort personid plan network paiddt linenum rankpersonid;

by personid plan network: gen cum_totcost = sum(totcost*(noded !=1)); 
/* if NA==1 what is inside the parenthesis=0, if the statement is true it =1*/; 
by personid plan network: gen atmargin=1 if (cum_totcost[_n] >= maxdedind & cum_totcost[_n-1] < maxdedind) & (_n>1); 
/* This simply notes if you're second to last claim is below the deductible max, and you're last claim puts you over it. 
by personid plan network: replace atmargin=2 if (cum_totcost[_n] > maxdedind) & (_n==1); // This does the same thing just specifying the case where there is only 1 claim. */;

replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxdedind) if (noded != 1  & (atmargin == 1 | atmargin == 2)) ;
/* If the claim is above the deductible, then you pay the coinsurance rate (since you have hit your deductible max). */;
replace deductible = (maxdedind - cum_totcost[_n-1]) if (noded !=1 & atmargin == 1);
/* You pay as much of the claim as you can up to the deductible max on this one. */;
replace deductible = maxdedind if (NA !=1 & atmargin == 2); 
/* You pay the deductible max if there is only one claim and the total amount owed is greater than the deductible. */;
replace deductible = 0 if (prev == 1 | noded==1 ); 
/* Deductible is not paid on preventative services and for some plans there is no deductible (noded == 1). */;

* why did we sum totcost above and not deductible?
* why is replace deductible = 0 line not prior to sum line?
replace totcost = deductible;
* why is this here? and not prior to summing?
replace coinsurance = 0 if prev == 1;
replace copay = 0 if prev == 1;

/* Calculating  totcost if cumulative is greater than deductible */;

/* What date to sort by here? it was paiddt. I don't see why it should be different than above, which is srvcdt. I think this is wrong. Let's try both ways*/;
sort personid plan network paiddt linenum rankpersonid;
by personid plan network: replace cum_totcost = sum(totcost*(noded !=1) ); 
/* If NA (which means noded !=1), then that cost doesn't count towards the deductible. */
by personid plan network: gen greater_ded = 1 if (cum_totcost > maxdedind) & (atmargin != 1) & (atmargin != 2);
replace deductible = 0 if (greater_ded == 1); 
/* Setting deductible to zero after it crosses limit */;
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2); 
/* Setting coinsurance to zero before deductible is met */;
replace coinsurance = 0 if ( NA == 1 | prev == 1);
replace totcost = coinsurance if NA !=1 ; 
/* Setting totcost to equal coinsurance after deductible is met */; 
replace totcost = overallcost if NA == 1; 
replace totcost = 0 if prev == 1;

/* check family deductible limit */;
sort familyid plan network paiddt rankfamilyid;
by familyid plan network: gen cumdedfam = sum(deductible);
by familyid plan network: replace atmargin = 3 if (cumdedfam[_n] >= maxded & cumdedfam[_n-1] < maxded) & (_n>1) & individual_ded == 0;
by familyid plan network: replace atmargin= 4 if (cumdedfam[_n] > maxded) & (_n==1) & individual_ded == 0;
replace coinsurance = coinsuranceperc*(cumdedfam[_n] - maxded) if (prev! = 1 & noded != 1 & (atmargin == 3 | atmargin == 4) & individual_ded ==0) ;
replace deductible = (maxded - cumdedfam[_n-1]) if ((noded != 1)  & atmargin == 3 & individual_ded == 0);
replace deductible = maxded if (noded !=1  & atmargin == 4 & individual_ded == 0);
replace deductible = 0 if prev == 1 & individual_ded == 0;
replace deductible=0 if noded==1;

replace totcost = deductible if individual_ded == 0;

sort familyid plan network paiddt rankfamilyid;
by familyid plan network: replace cumdedfam = sum(totcost*(noded !=1)); 
by familyid plan network: gen greater_dedfam = 1 if (cumdedfam > maxded) & (atmargin != 3) & (atmargin != 4) & individual_ded == 0;
replace deductible = 0 if (greater_dedfam == 1 & individual_ded == 0); 

/* Setting deductible to zero after it crosses limit */;
replace coinsurance = coinsuranceperc* overallcost if (greater_dedfam == 1 & noded != 1 & prev != 1 & individual_ded == 0);
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & atmargin!=3 & atmargin!=4 & individual_ded == 0);  
/* Setting coinsurance to zero before deductible is met */;
replace coinsurance = 0 if ( NA== 1 | prev == 1);
replace totcost = coinsurance + copay; 
/* setting this for the oop max; */
/* It could be because there is no deductible for Kaiser - so all costs should come from copay/coinsurance. But then why have all this code above?*/
/* This code is in all the files (that could be why). It could also be that this variable now will just measure the maximum cost for the person - so it's changing purpose. */
replace totcost = overallcost if NA == 1; 
replace totcost = 0 if prev == 1;

/*coinsurance all 0, correct*/;
/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
/* now just doing it for coins--sums up all the coins, and checks where it hits the maximum after which point*/;

/* it sets everything==0*/; 
/*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum*/;

/* deal with NA cases - patient pays full cost as a "copay" */;
replace copay = overallcost if NA==1;
replace coinsurance = 0 if NA == 1;
replace coinsurance = 0 if prev == 1;
replace copay=0 if prev==1;
replace deductible=0 if noded==1;

/* Setting totcost to 0 past the coinsurance maximum limit */;
/*cb: I think we need to redefine totcost as copay + coinsurance again, we've changed copay/coinsurance above after defining totcost*/;
sort personid plan network paiddt rank1personid; 
by personid plan : replace cum_totcost = sum(totcost*(nooop !=1));

by personid plan : gen atmargin_max = 1 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1) & nooop !=1;
by personid plan  : replace atmargin_max = 2 if (cum_totcost[_n] > maxoopind) & (_n==1) & nooop !=1; 
replace coinsurance = maxoopind - cum_totcost[_n-1] if (atmargin_max == 1 & (nooop !=1)) & coinsuranceperc !=0 ;
replace coinsurance = maxoopind if (atmargin_max == 2 & (nooop !=1)) & coinsuranceperc !=0;
replace coinsurance = 0 if prev == 1; 
replace copay = 0 if prev == 1;
replace totcost = coinsurance + copay  if (nooop !=1); /* for Kaiser copay and coins count to oop */;

sort personid plan network paiddt rank1personid;
by personid plan network: replace cum_totcost = sum(totcost*(nooop !=1));
replace coinsurance = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1 ;
replace copay = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1 ;
replace coinsurance = overallcost if NA == 1;
replace coinsurance = 0 if prev == 1;
replace totcost = coinsurance; 

/* check family oop limit */;
/* cb: Again, if we make things 0, I think we need to redefine totcost as copay + coinsurance again, we've changed copay/coinsurance above after defining totcost*/;
/* this isn't really working, at margin is never 3*/;
/* I'm not sure that we are doing this individual versus family oopmax thing right*/;
replace totcost = coinsurance + copay; 

sort familyid plan  paiddt rankfamilyid;
by familyid plan : gen cumoopfam = sum(totcost*(nooop !=1)) if individual_oop == 0;
by familyid plan : replace atmargin_max = 3 if (cumoopfam[_n] >= maxoop & cumoopfam[_n-1] < maxoop) & (_n>1) & individual_oop == 0 & nooop !=1;
by familyid plan : replace atmargin_max= 4 if (cumoopfam[_n] > maxoop) & (_n==1) & individual_oop == 0 & nooop !=1;
replace coinsurance = coinsuranceperc*(cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 3 | atmargin_max == 4) & individual_oop ==0 & coinsuranceperc !=0 );
replace copay = (cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 3 | atmargin_max == 4) & individual_oop ==0& coinsuranceperc ==0 & copay > (cumoopfam[_n] - maxoop) );

replace copay = (maxoop - cumoopfam[_n-1]) if ((nooop !=1) & atmargin_max == 3 & individual_oop == 0);
replace totcost = copay+coinsurance if individual_oop == 0;   

sort familyid plan  paiddt rankfamilyid;
by familyid plan : replace cumoopfam = sum(totcost*(nooop !=1)); 
by familyid plan : gen greater_oopfam = 1 if (cumoopfam > maxoop) & (atmargin_max != 3) & (atmargin_max != 4) & individual_oop == 0 & nooop!=1;
replace coinsurance = 0 if (greater_oopfam == 1 & individual_oop == 0  & nooop!=1); 
/* Setting coins to zero past limit */;
replace copay = 0 if (greater_oopfam == 1 & individual_oop == 0  & nooop!=1) ; 
/* Setting copay to zero past limit */;

gen oopcost = deductible + coinsurance + copay;
/* not for 2008--didn't have something something special for ACS, so don't need to include*/; 
/* check this though, because it may have changed*/; 

/** CB confirm*/;

if `year' == 2009 {;
/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
replace acs = 0 if NA == 1;
replace acs = 1 if (inlist(serviceid,"S688","S689","S443")) & NA! = 1 ;
gen acsinsurer = overallcost - oopcost if acs == 1;
sort personid plan paiddt; 
by personid plan: gen cum_acsinsurer = sum(acsinsurer);
by personid plan: gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2500 & cum_acs) & (cum_acsinsurer[_n-1] < 2500) & (_n>1);
by personid plan: replace acsmargin = 2 if (cum_acsinsurer[_n] > 2500) & (_n==1);
replace acsinsurer = 2500 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
replace acsinsurer = 2500 if (acsmargin == 2 & acs == 1);
sort personid plan paiddt; 
by personid plan: replace cum_acsinsurer = sum(acsinsurer);
gen bene_cost = overallcost - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
replace bene_cost = overallcost if (acs == 1 & cum_acsinsurer > 2500);
replace oopcost = bene_cost if acs == 1;
};

/* part of ACT addition*/;
replace copay = 0 if allowedamt==deductible & deductible !=0; 
replace coinsurance = 0 if allowedamt==copay; 

/* Shouldn't this be at the beginning, before deductible and oop stuff?*/;
/* I also think this is by familyid*/;
gsort personid plan serviceid srvcdt -copay;
by personid plan serviceid srvcdt:  gen numcopay2 = _n;
replace numcopay2=1 if exception==1;
replace copay = 0 if (numcopay2 > 1) & planfirst=="K";

/* make sure dualcc charges are calculating the coins correctly */;
cap drop cost;
gen cost =allowedamt-copay if deductible==0 & dualcc==1;
replace coinsurance = coinsuranceperc*(cost) if deductible==0 & dualcc==1;

/***********************ADJUSTMENTS***********************/;

/*coinsurance*/;
replace coinsurance = 0 if allowedamt==copay; 

/*copay*/;
replace copay = 0 if allowedamt==coinsurance;

gen group = 1;
tempfile kaiser_out`yplan';
save `kaiser_out`yplan'', replace;
