pause off;
#delimit;
/* Kaiser all years */;

set more off;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

local kaiser $kaiser;

/***************** IMPORTANT NOTE **************************
Copay only applies once per day for a particular service type.
Coinsurances apply for every single line of the claim.
**************************************************************/;
*Plans kept: "KMED1" "KMP1A";
/* ***********************************************************************************
|DERIVATION:
| - where are we storing NA values? COPAY 
| - family is 2 or more
|
|Plan structure
| - KMED1:
|		- no deductible
|		- oop max $1200/$2400
|			- services that apply to the max: Ambulance, chemical dep. services, emergency services, infertility, inpatient, lab, 
|				xray, imaging, special diagnostic, maternity, office visits, dialysis, therapy, mental health, outpatient surgery, SNF 
|			- maxiumum COPAY and COINS paid (2011) (2012)
| - KMP1A:
|		- deductible: $100/$300  *don't count towards oop max
|			- services that apply: TMJ therapy, ER, outpatient surgery, inpatient, xray, imaging, lab, 
|				drugs, chem. dep inpatient and residential, home health, SNF, transplant		
|  		- oop max $1200/$2400
|			- DOESN'T INCLUDE: deductible, copayments/coinsurances that are not subject to the deductible
|			- maxiumum COPAY and COINS paid (2011) (2012)
|
|
|SPECIAL CASES
| - ER:
| 		KMED1: $100 (waived if admitted) 
|		KMP1A: 20% coins AFTER ded - NOT WAIVED IF ADMITTED
| - inpatient:
|		KMED1: $100 per day/ up to $500 max
|		KMP1A: 20% coins AFTER ded
|
|

* ***********************************************************************************/;

*****************FACILITY AND PROFESSIONAL CLAIMS FOR HMO AND POS PLANS (DOES NOT INCLUDE ODS PPO AND PHARMACY CLAIMS)***************;

use `kaiser`yplan'', clear;
if _N !=0 { ;
assert coinsuranceperc!=. if NA !=1;
assert copay!=. if NA !=1;

*Charge Submitted=Discount+Allowed Amount;
*Allowed Amount=NetPayment+Third Party (COB or Medicare) +Out of Pocket;
*Out of Pocket=Copayment+Coinsurance+Deductible;
*totcost = Out of Pocket - Copay;

replace procedure = trim(procedure) ; 

*** Procedure code based exceptions with documentation in plan handbook ; 

	*** 1) Colonoscopy and sigmoidoscopy ; 
		gen colonoscopy = 0 ; 
		replace colonoscopy = 1 if inlist(procedure, "G0105", "G0121", "G0122", "44388", "44389", "44391", "44392", "44393", "44394") ; 
		*** Note: inlist has a limit of 10 arguments ; 
		replace colonoscopy = 1 if inlist(procedure, "45378", "45379", "44397", "45380", "45381", "45382", "45383", "45384", "45385") ;
		replace colonoscopy = 1 if inlist(procedure, "45386", "45391", "45392" ) ;
		*** possibly also ICD-9 (45.23) ;
		replace colonoscopy = 0 if inlist(serviceid, "S600", "S610", "S615") ; *** If colonoscopy occurs in ER setting, bill it like ER ; 
		replace copay = 0 if colonoscopy == 1 ;
		replace coinsuranceperc = 0 if colonoscopy == 1 ; 
		*** based on table 1 of  Ko et al 2014 "Determination of colonoscopy indication from administrative claims data" & study below ; 
		*** http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3387505/table/T1/ ;
		
		gen sigmoidoscopy = 0 ; 
		replace sigmoidoscopy = 1 if inlist(procedure, "G0104", "45300", "45301", "45302", "45303", "45304", "45305", "45306", "45307") ;
		replace sigmoidoscopy = 1 if inlist(procedure, "45308", "45309", "45310", "45311", "45312", "45313", "45314", "45315", "45316") ;
		replace sigmoidoscopy = 1 if inlist(procedure, "45317", "45318", "45319", "45320", "45321", "45322", "45323", "45324", "45325") ;
		replace sigmoidoscopy = 1 if inlist(procedure, "45326", "45327", "45328", "45329", "45330", "45331", "45332", "45333", "45334") ;
		replace sigmoidoscopy = 1 if inlist(procedure, "45335", "45336", "45337", "45338", "45339",	"45340", "45341", "45342", "45343") ;
		replace sigmoidoscopy = 1 if inlist(procedure, "45344", "45345") ;									
		*** note: we may also need ICD-9 codes here (45.24, 48.21, 48.22, 48.23, 48.24, 48.36) ;
		replace sigmoidoscopy = 0 if inlist(serviceid, "S600", "S610", "S615") ; *** If sigmoidoscopy occurs in ER setting, bill it like ER ; 
		replace copay = 0 if sigmoidoscopy == 1 ;
		replace coinsuranceperc = 0 if sigmoidoscopy == 1 ; 
		*** based on Wernil et al 2014  "Patterns of Colorectal Cancer Screening Uptake in Newly Eligible Men and Women" ;
		*** http://cebp.aacrjournals.org/content/23/7/1230.full.pdf+html ;		
	
	*** 2) Labs ; 
		*** Some of these may be overfitting by specifying non-standard (20/25 etc) dollar values ; 
		replace copay = 5 if serviceid == "S671" & plan == "KMED1" & procedure == "84132" ;
		replace copay = 10 if serviceid == "S671" & plan == "KMP1A" & procedure == "84132" ;
		
		*** consider also ;
		***  ;
	
	*** 3) Specialists outpatient surgery S312 ;
	
	*** 4) Podiatrist - unclear how predictable these would be by beneficiary ; 
	
	
*** Other procedure code based exceptions based on observed data ; 
	*** These exceptions minimize errors, however, they likely do not accurately reflect expectations because they are based on information that a subscriber would not have when making plan selection decision ; 

*** 2013 mental health ; 
	replace copay = 0 if `planyear' == 2013 & serviceid == "S430" & inlist(procedure,"90833","90867","90868");
	replace copay = 0 if `planyear' == 2013 & serviceid == "S430" & inlist(procedure,"90869","90870","99218","99222","99223","99231","99232","99233");
	
	replace copay = 10 if `planyear' == 2013 & serviceid == "S430" & inlist(procedure,"90849","90853","G0176");
	
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "7" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "8" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "9" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "C" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "G" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "J" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "Q" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "V" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & substr(procedure,1,1) == "~" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "52332" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "64568" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "67036" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "52005" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "52310" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "29824" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "23929" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "15822" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "14060" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "27380" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "27570" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "29824" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "29822" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "30420" ;
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" & procedure == "30520" ;

replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S661" & substr(procedure,1,1) == "4" ; 
replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S661" & substr(procedure,1,1) == "5" ; 
replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S661" & procedure == "77057" ; 
replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S661" & procedure == "77080" ; 

replace coinsuranceperc = 0 if `planyear' == 2011 & serviceid == "S713" & procedure == "V5011" ; 
replace coinsuranceperc = 1 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S713" & procedure == "V5298" ; 

*** MISC *;
replace coinsuranceperc = 1 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S900" & procedure == "V5257" ; 
replace coinsuranceperc = 1 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S900" & procedure == "A9270" ; 
replace copay = 30 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S900" & procedure == "96040" ; 
replace copay = 15 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S900" & procedure == "98962" ; 
replace copay = 20 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S900" & procedure == "G0399" ; 

replace copay = 0  if `planyear' == 2013 & plan == "KMP1A" & serviceid == "S631" & procedure == "93010" ; 
replace copay = 0  if `planyear' == 2013 & plan == "KMED1" & serviceid == "S631" & procedure == "93010" ; 

replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S719" & specialist == 1 ; 
replace copay = 30 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S641" & procedure == "96413" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S631" & procedure == "93015" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S631" & procedure == "93225" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S631" & procedure == "93270" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S631" & procedure == "93295" ; 

replace copay = 40  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "78452" ; 
replace copay = 30  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "93798" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "92960" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "93303" ; 
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "93305" ;
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "93306" ;  
replace copay = 20  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S630" & procedure == "93880" ; 

replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S500" & procedure == "0500F" ; 
replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S500" & procedure == "0502F" ; 

replace copay = 30  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S440" & procedure == "11721" ; 
replace copay = 30  if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S440" & procedure == "11750" ; 

replace copay = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S431" & procedure == "90821" ; 
replace coinsuranceperc = 0.2 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S431" & procedure == "90821" ; 

replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S719" & procedure == "V2623" ; 

/* DME */ ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S700" & procedure == "A6402" ; 
replace coinsuranceperc = 0.5 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S700" & procedure == "A7030" ; 
replace coinsuranceperc = 0.4 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S700" & procedure == "A7035" ; 
replace coinsuranceperc = 0 if serviceid == "S700" & substr(procedure,1,1) == "B" ; 
replace coinsuranceperc = 0 if serviceid == "S700" & substr(procedure,1,1) == "Q" ; 
replace coinsuranceperc = 0 if serviceid == "S700" & substr(procedure,1,1) == "S" ; 

replace coinsuranceperc = 0.35 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S700" & procedure == " E0562" ; 
replace coinsuranceperc = 0.25 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S700" & procedure == " E0601" ; 
replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S700" & procedure == " E0730" ; 

replace coinsuranceperc = 0 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S700" & procedure == "A6402" ; 
replace coinsuranceperc = 0 if plan == "KMED1" & serviceid == "S700" & substr(procedure,1,1) == "B" ; 
replace coinsuranceperc = 0 if plan == "KMED1" & serviceid == "S700" & substr(procedure,1,1) == "J" ; 
replace coinsuranceperc = 0 if plan == "KMED1" & serviceid == "S700" & substr(procedure,1,1) == "Q" ; 

replace coinsuranceperc = 0.4 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S700" & procedure == "A7034" ; 
replace coinsuranceperc = 0.4 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S700" & procedure == "A7035" ; 
replace coinsuranceperc = 0.3 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S700" & procedure == "A7036" ; 
replace coinsuranceperc = 0.4 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S700" & procedure == "E0562" ; 
replace coinsuranceperc = 0.3 if `planyear' == 2011 & plan == "KMED1" & serviceid == "S700" & procedure == "E0601" ; 

replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "92506" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "92507" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "92526" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "92610" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "97001" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "97003" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "97110" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "97124" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "97530" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S680" & procedure == "97535" ; 

replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S505" & procedure == "95012" ;  
replace copay = 10  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S555" & procedure == "J0585" ;  

replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S120" & procedure == "59000" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S120" & procedure == "59840" ;  
replace copay = 75  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S208" & procedure == "~" ;  

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & procedure == "59320" ;  
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & procedure == "59320" ;  
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & procedure == "96376" ;  
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & procedure == "97001" ;  
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & substr(procedure,1,1) == "G" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & procedure == "74455" ;  
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S210" & procedure == "88305" ;  

replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11400" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11401" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11402" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11403" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11421" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11422" ;  
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11423" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11440" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11441" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11442" ;  
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11443" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11601" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11602" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11603" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11606" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11621" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11623" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11641" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11900" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11981" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "11982" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "12001" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "12002" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "15823" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "17106" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "17108" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "17110" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "20610" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "29580" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "31575" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "46600" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "51702" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "51798" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "55250" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "55700" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "57454" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "58100" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "58300" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "62310" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "62311" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "64483" ; 
replace copay = 15  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "64612" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "64721" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S312" & procedure == "67840" ; 

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S441" & procedure == "92552" ;  
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S441" & procedure == "92587" ;  

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "92020" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "92082" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "92072" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "92071" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "92504" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "95810" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "95811" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "96366" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "96367" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "96375" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "~" ; 
replace copay = 7  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "96153" ; 
replace copay = 5  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S599" & procedure == "96910" ;

replace copay = 15  if `planyear' == 2013 & serviceid == "S615" & procedure == "99051" ;
replace copay = 20  if `planyear' == 2012 & plan == "KMED1" & serviceid == "S615" & procedure == "99051" & copay !=0 ;

/**** Mental Health ****/ ; 
replace copay = 12  if `planyear' == 2013 & plan == "KMP1A" & serviceid == "S431" & procedure == "90853" & copay != 0 ; 

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S431" & procedure == "90471" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S431" & procedure == "90472" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S431" & procedure == "90817" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S431" & procedure == "99239" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S431" & procedure == "99411" ; 

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93010" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93016" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93017" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93018" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93227" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93272" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S631" & procedure == "93651" ; 

replace copay = 0  if `planyear' == 2012 & plan == "KMED1" & serviceid == "S631" & procedure == "93010" ; 

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & substr(procedure,1,1) == "C" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & substr(procedure,1,1) == "A" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & substr(procedure,1,1) == "J" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & substr(procedure,1,1) == "~" ; 

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & procedure == "93797" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & procedure == "93320" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & procedure == "93325" ; 

replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S630" & procedure == "93798" ; 

replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S641" & substr(procedure,1,1) == "J" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S641" & substr(procedure,1,1) == "~" ; 
replace copay = 0  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S641" & procedure == "96417" ; 

replace copay = 5  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S640" & procedure == "J8610" ; 
replace copay = 5  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S640" & procedure == "J8610" ; 
replace copay = 25  if `planyear' == 2011 & plan == "KMED1" & serviceid == "S640" & procedure == "96409" ; 

	if `year' == 2010 { ;
		replace copay = 5  if serviceid == "S430" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 5  if serviceid == "S430" & procedure == "90849" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 5  if serviceid == "S430" & procedure == "90857" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 0  if serviceid == "S430" & inlist(procedure, "99231", "99232", "99233","99239", "99411") & plan == "KMED1" & network == 1 & copay !=0 ; 

		replace copay = 10 if serviceid == "S430" & procedure == "90853" & plan == "KMP1A" & network == 1 & copay !=0 ; 
		replace copay = 10 if serviceid == "S430" & procedure == "90849" & plan == "KMP1A"& network == 1 & copay !=0 ; 
		replace copay = 0  if serviceid == "S430" & inlist(procedure, "92012", "99211", "90817") & plan == "KMED1" & network == 1 & copay !=0 ; 
	};
	if `year' == 2011 { ;
		replace copay = 7  if serviceid == "S430" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0; 
		replace copay = 7  if serviceid == "S430" & procedure == "90857" & plan == "KMED1" & network == 1 & copay !=0; 
		replace copay = 7  if serviceid == "S430" & procedure == "90849" & plan == "KMED1" & network == 1 & copay !=0; 
		replace copay = 0  if serviceid == "S430" & inlist(procedure, "99231", "99232", "99233","~") & plan == "KMED1" & network == 1 & copay !=0; 

		replace copay = 10 if serviceid == "S430" & procedure == "90853" & plan == "KMP1A"& network == 1 & copay !=0 ; 
		replace copay = 10 if serviceid == "S430" & procedure == "90849" & plan == "KMP1A"& network == 1 & copay !=0 ;
		replace copay = 0  if serviceid == "S430" & inlist(procedure, "92012", "99231", "99232") & plan == "KMP1A"& network == 1 & copay !=0 ; 
	};
	if `year' == 2012 { ;
		replace copay = 7  if serviceid == "S430" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 7  if serviceid == "S430" & procedure == "90857" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 7  if serviceid == "S430" & procedure == "90849" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 0  if serviceid == "S430" & inlist(procedure, "99231", "99232", "99233","99238","99282","99284","~") & plan == "KMED1" & network == 1 & copay !=0 ; 

		replace copay = 10 if serviceid == "S430" & procedure == "90853" & plan == "KMP1A"& network == 1 & copay !=0 ; 
		replace copay = 10 if serviceid == "S430" & procedure == "90849" & plan == "KMP1A"& network == 1 & copay !=0 ;
	} ;

	if `year' == 2010 { ;
		replace copay = 10 if serviceid == "S431" & procedure == "H0004" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "H2018" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0005" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0020" & plan == "KMED1" & network == 1 & copay !=0 ; 
	};
	if `year' == 2011 { ;
		replace copay = 15 if serviceid == "S431" & procedure == "90806" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "90887" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "H0004" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "H0048" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 0 if serviceid == "S431" & procedure == "H2001" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 25 if serviceid == "S431" & procedure == "H2018" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 7  if serviceid == "S431" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 7  if serviceid == "S431" & procedure == "H0005" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 0  if serviceid == "S431" & procedure == "H0020" & plan == "KMED1" & network == 1 & copay !=0 ; 

		replace copay = 20 if serviceid == "S431" & procedure == "H0004" & plan == "KMP1A"& network == 1 & copay !=0 ; 
		replace copay = 10 if serviceid == "S431" & procedure == "H0005" & plan == "KMP1A"& network == 1 & copay !=0 ;
	};
	if `year' == 2012 { ;
		replace copay = 15 if serviceid == "S431" & procedure == "90806" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "90887" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "H0004" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 15 if serviceid == "S431" & procedure == "H0048" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 25 if serviceid == "S431" & procedure == "H2001" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 25 if serviceid == "S431" & procedure == "H2018" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 7  if serviceid == "S431" & procedure == "90853" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 7  if serviceid == "S431" & procedure == "H0005" & plan == "KMED1" & network == 1 & copay !=0 ; 
		replace copay = 5  if serviceid == "S431" & procedure == "H0020" & plan == "KMED1" & network == 1 & copay !=0 ; 

		replace copay = 20 if serviceid == "S431" & procedure == "H0004" & plan == "KMP1A"& network == 1 & copay !=0 ; 
		replace copay = 10 if serviceid == "S431" & procedure == "H0005" & plan == "KMP1A"& network == 1 & copay !=0 ;
		replace copay = 5  if serviceid == "S431" & procedure == "H0020" & plan == "KMP1A"& network == 1 & copay !=0 ;
	} ; 

	*** Drugs - there are some drug claims in the medical files. They are assessed a 20% coinsurance, except a few very expensive claims. 
	replace coinsuranceperc = 0 if serviceid == "S721" & allowedamt > 175 ; 
		
/************ DEDUCTIBLE ************/;
gen noded=0;

replace noded=1 if plan=="KMED1";

replace noded=1 if network==1 & plan=="KMP1A"; 
/*
replace noded=0 if network==1 & plan=="KMP1A" &  // these ARE SUPPOSED TO have a deductible, BUT IT'S NOT SHOWING UP IN THE DATA ;
	( 	* Lab *
		serviceid== "S670" | serviceid== "S671"	| serviceid== "S672" | serviceid== "S660"
		* xray & imaging *
		| serviceid== "S661" | serviceid== "S662" | serviceid== "S663" | serviceid== "S664" | serviceid== "S667" 
		* outpatient surgery services *
		| serviceid == "S310" | serviceid == "S311" | serviceid== "S312" | serviceid== "S313" | serviceid== "S314" | serviceid== "S210"	| serviceid== "S211" | serviceid== "S213" | serviceid== "S214" | serviceid== "S215"
		* Emergency room *
		| serviceid== "S600" | serviceid== "S605" | serviceid== "S610" | serviceid== "S615"	| serviceid== "S616" 
		* alternative care *
		| serviceid== "S688" | serviceid== "S689" | substr(serviceid,1,2) == "S0" | serviceid== "S443"
		* inpatient hospital services *
		| substr(serviceid,1,2) == "S0" | substr(serviceid,1,2) == "S1"	
		* maternity *
		| serviceid== "S226" | serviceid== "S227" | serviceid == "S505" 
		* home health *
		| serviceid== "S751"
		* Hospice *
		| serviceid=="S750"
		* allergy supplies, testing injections, tmj *
		| serviceid=="S505" | serviceid=="S551" | serviceid=="S555"
		* drugs *
		| serviceid=="S720" | serviceid=="S721"
		* SNF *
		| serviceid== "S080"
	);*/;
replace noded=1 if NA==1;

 

/************ OOP MAX ***********/;
* neither deductibles or copayments are included towards the oop max; 
/* !!! We need to check how other plans interact with this list*/;
gen nooop = 1;
replace nooop =0 if plan=="KMP1A" & noded==0; 
/* Services that DO count towards the OOP maximum:
ambulance							xray & imaging					physical & occupational therapy
chemical dependency					maternity 						outpatient surgery services
emergency room						office visits					SNF
inpatient hospital services 		mental health office visits		respiratory services - I do not see kaiser codes for this
lab									dialysis						infertility services - I do not see kaiser codes for this */;

replace nooop=0 if plan=="KMED1" &  
	( 
		/* ambulance */
		serviceid == "S890" | serviceid == "S891"  | serviceid == "S892" 
		/* chemical dependency */
		| serviceid == "S039" | serviceid == "S139" | serviceid == "S239" | serviceid == "S439"
		/* emergency room */
		| serviceid == "S600" | serviceid == "S605" | serviceid == "S610" | serviceid == "S615"	| serviceid == "S616" 
		/* inpatient hospital services */
		| substr(serviceid,1,2) == "S0" | substr(serviceid,1,2) == "S1" | serviceid == "S226"
		/* lab */
		| serviceid == "S670" | serviceid == "S671"	| serviceid == "S672" | serviceid == "S660"
		/* x-ray & imaging */
		| serviceid == "S661" | serviceid == "S662" | serviceid == "S663" | serviceid == "S664" | serviceid == "S667" | serviceid == "S311"
		/* maternity */
		| serviceid == "S226" | serviceid == "S227" | serviceid == "S531"
		/* office visits */
		| substr(serviceid,1,2) == "S5"	
		/* mental health office visits (not 100% sure about the 200 level codes) */
		| serviceid == "S430" | serviceid == "S431" | serviceid == "S230" | serviceid == "S230"
		/* dialysis & other treatment & diagnosis */
		| serviceid == "S620" | serviceid == "S621" | serviceid == "S630" | serviceid == "S631" | serviceid == "S640" | serviceid == "S641" | serviceid == "S650" | serviceid == "S651" 
		| serviceid == "S220" | serviceid == "S224" | serviceid == "S225" | serviceid == "S250"
		/* physical & occupational therapy & respiratory services*/
		| serviceid == "S680" | serviceid == "S681" | serviceid == "S682" | serviceid == "S683" | serviceid == "S684" 
		/* outpatient surgery services */
		| serviceid == "S310" | serviceid == "S311" | serviceid == "S312" | serviceid == "S313" | serviceid == "S314" | serviceid == "S210"	| serviceid == "S211" | serviceid == "S213" | serviceid == "S214" | serviceid == "S215"
		/* SNF */
		| serviceid == "S080"
		/* infertility services */
		| serviceid == "S308"
	); 			

replace nooop=1 if NA==1 ;
replace nooop = 1 if serviceid == "S719" ;

/* CB: this is how OOP max stuff was initially coded, I don't know where this list came from. 
I have changed to the above based on the document: 2011 OEBB member handbook-Kaiser Traditional Copayment Plan
located here: C:\Users\cbehrer\Dropbox\Oregon Health\plan design\Serivce-Procedure codes\Kaiser\medical benefit summaries
page 13 (pdf page22).
gen nooop=0; 
replace nooop=1 if plan=="KMED1" &  // these DONT count towards the max;
		( serviceid==`y'10 // non covered 
		| serviceid==`y'22 // alternative care
		| serviceid==`y'51 // ACA/weight watchers
		| serviceid==`y'52 // immunizations
		| serviceid==`y'54 // well-person exam
		| serviceid==`y'57 // home health
		| serviceid==`y'58 // hospice
		| serviceid==`y'61 // additional cost tier
		| serviceid==`y'92 // upper endoscopies
		| serviceid==`y'93 ); // hearing aids;
replace nooop=1 if plan=="KMP1A" & noded==1; // noded=1 means they DONT count towards the ded;
replace nooop=1 if NA==1;
*/;

/************ PREV SERVICES ************/;
replace prev = 0 if network == 0;

*** Resetting to 0 b/c of prev used to appear first quit far below. I'm not completely sure why. Adding it here and leaving it below in several places ; 

replace coinsurance = 0 if prev == 1;
replace copay=0 if prev==1;

/************ accounding for charges by day ************/; 
/****** accounding for charges by day ******/;
bys personid plan claimid serviceid srvcdt:  gen dayssum = sum(days);
replace dayssum=0 if dayssum>days; 
/** I just want one line to have the number of days - the raw claims data has the days at each inpatient stay line, which in the case would make us double count*/; 

replace copay = 100*dayssum if ((by_day == 1) ) & (plan=="KMED1" );
replace copay = 200*dayssum if ((by_day == 1) ) & (plan=="KMP1A" );
replace copay = 500 if copay >500 & (by_day == 1) & (plan=="KMED1");
replace copay = 1000 if copay >1000 & (by_day == 1) & (plan=="KMP1A" );


 
/************  Special case for ER visits, copay is waived if admitted, coinsurance must still be paid, ER copay paid only once per visit, deductible applies ************/;
gen ERvisit = 1 if (serviceid == "S600"); 

gsort personid plan srvcdt -allowedamt;
by personid plan srvcdt:  gen numER = sum(ERvisit);
	replace numER=0 if ERvisit==.; // added 4/29 ahs;

 
	
bys personid plan srvcdt: egen sum_origded = sum(origded) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcoin = sum(origcoin) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcopay = sum(origcopay) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_allowedamt = sum(allowedamt) if ERvisit == 1;
replace allowedamt = sum_allowedamt if ERvisit == 1 & numER==1;  
replace origded = sum_origded if ERvisit == 1 & numER==1;  
replace origcoin = sum_origcoin if ERvisit == 1 & numER==1;  
replace origcopay = sum_origcopay if ERvisit == 1 & numER==1;  

  

replace allowedamt = 0 if ERvisit == 1 & numER>1; 
replace origded = 0 if ERvisit == 1 & numER>1; 
replace origcopay = 0 if ERvisit == 1 & numER>1; 
replace origcoin = 0 if ERvisit == 1 & numER>1; 

  

gsort personid srvcdt -origcopay -allowedamt;
gen admit = 0 if serviceid == "S600" & origcopay == 0; 
replace admit = 1 if serviceid == "S600" & admit != 0; 
by personid srvcdt: egen admitted=max(admit);


/* Special ER cases. */;
replace copay = 0 if (numER > 1 & (serviceid == "S600"));
 /* ER copay paid only once per visit*/;
replace copay = 0 if admitted == 0 & (serviceid == "S600"); 
/* if admitted ==0, it means the individual was admitted and the copay is waived*/;
replace copay = 100 if numER == 1 & admitted==1 & (serviceid == "S600") & allowedamt >= 100; 
/* if not admitted, copay of 100 applies.*/; 
replace copay = allowedamt if numER == 1 & admitted == 1 & (serviceid == "S600") & allowedamt < 100; 
 
/************  defining and modifying oop variables  ************/;
*deductible;
gen deductible = allowedamt;
replace deductible = 0 if NA == 1;
replace deductible = 0 if prev == 1;
replace deductible = 0 if noded==1 | (copay !=0);

*coinsurance;
gen coinsurance = coinsuranceperc*(allowedamt); /* Calculating OOP cost for each claim */;
replace coinsurance = 0 if NA == 1;
replace coinsurance = allowedamt if allowedamt < coinsurance & coinsurance!=0 & allowedamt>=0;
replace coinsurance = 0 if allowedamt==copay & copay !=0;
replace coinsurance = (allowedamt - copay) * coinsuranceperc if serviceid == "S600"; 

 

*copay;
replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>=0;

* this serviceid seems to only allow one oop payment per serviceid per day, so we get many 0's wrong by still applying coinsurance copay is only allowed to apply once per family per day below ; 
replace copay = coinsurance if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" ;
replace coinsurance = 0 if `planyear' == 2011 & plan == "KMP1A" & serviceid == "S210" ; 

 
*totcost;
gen totcost = deductible;
replace totcost = allowedamt if NA == 1; 
replace totcost = 0 if prev == 1;

/************ Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met************/;
gen copayGTallowedamt=0;
replace copayGTallowedamt=copay if allowedamt < copay;

/* CB: FIX additional cost tier for providence*/;

/* additional cost tier services 
 - for some charges, such as additional cost tier, the allowedamt is <500, but there were multiple serviced done under
this tier on a given servicedate.  As a result, the full $500 was charged, but distributed among the different services.  
We need a fix for this.  We're utilizing a variable from the beginning of the piece (copayGTallowedamt).
 For instance, see 2010: personid = "ATo21EbhToUo1QATosGt2ot" & chosen==1 */;
gsort personid plan claimid serviceid srvcdt linenum ;
by personid plan claimid serviceid srvcdt : gen cum_copaycost = sum(copay);
by personid plan claimid serviceid srvcdt: gen atmarginc_max = 1 if (cum_copaycost[_n] >= copayGTallowedamt) & (cum_copaycost[_n-1] < copayGTallowedamt)& (_n>1);
replace copay = copayGTallowedamt - cum_copaycost[_n-1] if (atmarginc_max == 1 ) & (serviceid=="S660" | serviceid=="S661") & allowedamt < copayGTallowedamt;

/* charges that we only charge the first instance */;
/* CB: should this be by familyid?*/;

/* we have a lot of 0's where we should not in 2012. is this the reason?*/;
/* This doesn't make a ton of sense, it should be impacting more years if this is the reason.*/;

 

/* copay applies once per serviceid per family (?) per day*/;

/* CB 3/5/2014 - this was: 
gsort familyid plan claimid serviceid srvcdt -copay linenum -allowedamt;
		by familyid plan claimid serviceid srvcdt :  gen numcopay_cb = _n;*/;
		
/* changed to: */;
gsort familyid plan srvcdt serviceid -copay -allowedamt;
	by familyid plan srvcdt serviceid :  gen numcopay_cb = _n;

replace copay = 0 if (numcopay_cb > 1);

gen exempt=1 if (serviceid=="S660" | serviceid=="S661") & ((copayGTallowedamt > cum_copaycost) | atmarginc_max==1);
replace exempt=0 if exempt==.;

replace numcopay_cb=1 if exempt==1;

replace copay = 0 if (numcopay_cb > 1);

 

  
/*************************************************************************************************************************************************************************/;
/********************************************************************************CALCULATOR*******************************************************************************/;
/*************************************************************************************************************************************************************************/;

local ftype personid familyid;  /* this just stores the two variables into ftype */;

gen flag=0;
gen ded=.;
gen coin=.;
gen cop=.;

foreach a of local ftype {;
sort `a' plan paiddt linenum; 

replace flag = 1 if origded!=0 & origcoin != 0 & origcopay !=0;
replace ded = 0 if origded!= 0;
replace ded = 1 if origded == 0;
assert ded !=.;

sort `a' plan paiddt linenum; 
replace coin = 0 if origcoin!= 0;
replace coin = 1 if origcoin == 0;
assert coin !=.;

replace cop = 0 if origcopay!= 0;
replace cop = 1 if origcopay == 0;
assert cop !=.;
 

gsort `a' plan paiddt linenum coin cop;
by `a' plan paiddt: gen rank1`a' = _n;  

sort `a' plan paiddt linenum ded origded flag; // this puts ded=0 and flag=0 before ded=1 and flag=1;
by `a' plan paiddt: gen rank`a' = _n;  

};

drop ded coin cop;
 // 1;
 
/* Make sure copay only applies once per claim id*/;
gsort personid plan claimid serviceid paiddt -allowedamt;
by personid plan claimid serviceid paiddt :  gen numcopay = _n;
 replace copay = 0 if (numcopay > 1) & planfirst=="K"; 
 
 
 
 *In N/A cases, the cost doesn't count towards the deductible or the maximum;
sort personid plan paiddt linenum rankpersonid; 
by personid plan : gen cum_totcost = sum(totcost*(noded !=1) ); 
by personid plan : gen atmargin=1 if (cum_totcost[_n] >= maxdedind & cum_totcost[_n-1] < maxdedind) & (_n>1);
by personid plan : replace atmargin=2 if (cum_totcost[_n] > maxdedind) & (_n==1);
replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxdedind) if ( noded !=1 & (atmargin == 1 | atmargin == 2)) ;
replace deductible = (maxdedind - cum_totcost[_n-1]) if ((noded !=1) & atmargin == 1);
replace deductible = maxdedind if ((noded !=1) & atmargin == 2);
replace deductible = 0 if (prev == 1 | noded==1 | NA==1);
replace totcost = deductible;
replace coinsurance = 0 if prev == 1;
 
/* Calculating  totcost if cumulative is greater than deductible */;
sort personid plan  paiddt rankpersonid;
by personid plan : replace cum_totcost = sum(totcost*(noded !=1)); 
by personid plan : gen greater_ded = 1 if (cum_totcost > maxdedind) & (atmargin != 1) & (atmargin != 2);
replace deductible = 0 if (greater_ded == 1); /* Setting deductible to zero after it crosses limit */;
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & noded !=1); /* Setting coinsurance to zero before deductible is met */;
 
replace totcost=allowedamt-deductible if deductible !=0;
replace copay = allowedamt-deductible if (deductible!=0 & noded !=1 & copay > totcost & copay !=0); /* Setting coinsurance to zero before deductible is met */;
 
/* check family deductible limit */;
sort familyid plan  paiddt rankfamilyid;
by familyid plan : gen cumdedfam = sum(deductible) if tier>1;
by familyid plan : replace atmargin = 3 if (cumdedfam[_n] >= maxded & cumdedfam[_n-1] < maxded) & (_n>1) & individual_ded == 0;
by familyid plan : replace atmargin= 4 if (cumdedfam[_n] > maxded) & (_n==1) & individual_ded == 0;
replace coinsurance = coinsuranceperc*(cumdedfam[_n] - maxded) if (prev! = 1 & noded != 1 & (atmargin == 3 | atmargin == 4) & individual_ded ==0) ;

replace deductible = (maxded - cumdedfam[_n-1]) if ((noded !=1) & atmargin == 3 & individual_ded == 0);
replace deductible = maxded if ((noded !=1) & atmargin == 4 & individual_ded == 0);
replace deductible = 0 if prev == 1 & individual_ded == 0;
replace deductible=0 if noded==1;
replace totcost = deductible if individual_ded == 0;   
replace totcost=0 if noded==1;
 
sort familyid plan  paiddt rankfamilyid;
by familyid plan : replace cumdedfam = sum(totcost*(noded !=1))  if individual_ded == 0; 
by familyid plan : gen greater_dedfam = 1 if (cumdedfam > maxded) & (atmargin != 3) & (atmargin != 4) & individual_ded == 0;
replace deductible = 0 if (greater_dedfam == 1 & individual_ded == 0); /* Setting deductible to zero after it crosses limit */;
replace coinsurance = coinsuranceperc*allowedamt if (greater_dedfam == 1 & noded != 1 & prev != 1 & individual_ded == 0);
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & atmargin!=3 & atmargin!=4 & individual_ded == 0);  /* Setting coinsurance to zero before deductible is met */;

  

replace coinsurance = 0 if ( NA== 1 | prev == 1);
replace totcost = coinsurance + copay if (NA !=1); // setting this for the oop max; 
replace totcost = allowedamt if NA == 1; 
replace totcost = 0 if prev == 1;
replace totcost=0 if nooop==1;

 


*******************OOP MAX;
/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
* now just doing it for coins--sums up all the coins, and checks where it hits the maximum after which point
* it sets everythin g==0;  
*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum;
sort personid plan network paiddt rank1personid; 
by personid plan : replace cum_totcost = sum(totcost*(nooop !=1));

by personid plan : gen atmargin_max = 1 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1) & nooop !=1;
by personid plan  : replace atmargin_max = 2 if (cum_totcost[_n] > maxoopind) & (_n==1) & nooop !=1; 
replace coinsurance = maxoopind - cum_totcost[_n-1] if (atmargin_max == 1 & (nooop !=1)) & coinsuranceperc !=0 ;
replace coinsurance = maxoopind if (atmargin_max == 2 & (nooop !=1)) & coinsuranceperc !=0;
replace coinsurance = 0 if prev == 1; 
replace copay = 0 if prev == 1;
replace totcost = coinsurance + copay  if (nooop !=1); /* for Kaiser copay and coins count to oop */;


/* Setting totcost to 0 past the coinsurance maximum limit */;
sort personid plan network paiddt rank1personid;
by personid plan: replace cum_totcost = sum(totcost*(nooop !=1));
replace coinsurance = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1;
replace copay = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1  ;


 


/* deal with NA cases - patient pays full cost as a "copay" */;
replace copay = allowedamt if NA==1;
replace coinsurance = 0 if NA == 1;
replace coinsurance = 0 if prev == 1;
replace copay=0 if prev==1;
replace deductible=0 if NA==1;
replace deductible=0 if noded==1;
 

/* Setting totcost to 0 past the coinsurance maximum limit */;
/* CB:why are we referring to maxoop individual here?*/;

sort personid plan paiddt rank1personid;
by personid plan : replace cum_totcost = sum(totcost*(nooop !=1));
replace coinsurance = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1 ;
replace copay = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1;
replace totcost = coinsurance+copay; 

 

/* check family oop limit */;
sort familyid plan  paiddt rankfamilyid;
by familyid plan : gen cumoopfam = sum(totcost*(nooop !=1)) if individual_oop == 0;
by familyid plan : replace atmargin_max = 3 if (cumoopfam[_n] >= maxoop & cumoopfam[_n-1] < maxoop) & (_n>1) & individual_oop == 0 & nooop !=1;
by familyid plan : replace atmargin_max= 4 if (cumoopfam[_n] > maxoop) & (_n==1) & individual_oop == 0 & nooop !=1;
replace coinsurance = coinsuranceperc*(cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 3 | atmargin_max == 4) & individual_oop ==0 & coinsuranceperc !=0 );
replace copay = (cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 3 | atmargin_max == 4) & individual_oop ==0& coinsuranceperc ==0 & copay > (cumoopfam[_n] - maxoop) );

replace copay = (maxoop - cumoopfam[_n-1]) if ((nooop !=1) & atmargin_max == 3 & individual_oop == 0);
replace totcost = copay+coinsurance if individual_oop == 0;   


sort familyid plan  paiddt rankfamilyid;
by familyid plan : replace cumoopfam = sum(totcost*(nooop !=1)) if individual_oop==0; 
by familyid plan : gen greater_oopfam = 1 if (cumoopfam > maxoop) & (atmargin_max != 3) & (atmargin_max != 4) & individual_oop == 0 & nooop!=1;
replace coinsurance = 0 if (greater_oopfam == 1 & individual_oop == 0  & nooop!=1); /* Setting coins to zero past limit */;
replace copay = 0 if (greater_oopfam == 1 & individual_oop == 0  & nooop!=1) ; /* Setting copay to zero past limit */;

 
gen oopcost = deductible + coinsurance + copay;


* not for 2008--didn't have something something special for ACS, so don't need to include; 
* check this though, because it may have changed; 
/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
replace acs = 0;
replace acs = 1 if (inlist(serviceid,"S688","S689","S443")) & NA! = 1 ;
gen acsinsurer = allowedamt - oopcost if acs == 1;
sort personid plan srvcdt; 
by personid plan: gen cum_acsinsurer = sum(acsinsurer);
by personid plan: gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2000 & cum_acs) & (cum_acsinsurer[_n-1] < 2000) & (_n>1);
by personid plan: replace acsmargin = 2 if (cum_acsinsurer[_n] > 2000) & (_n==1);
replace acsinsurer = 2000 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
replace acsinsurer = 2000 if (acsmargin == 2 & acs == 1);
* sort personid plan paiddt; 
sort personid plan srvcdt; 
by personid plan: replace cum_acsinsurer = sum(acsinsurer);
gen bene_cost = allowedamt - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
replace bene_cost = allowedamt if (acs == 1 & cum_acsinsurer > 2000);
replace oopcost = bene_cost if acs == 1;

 


***************************************************************************************************************************************************************************;
/***********************ADJUSTMENTS***********************/;

 
*coinsurance;
replace coinsurance = 0 if allowedamt==copay; 
replace coinsurance = 0 if prev==1;

 

*copay;
replace copay = 0 if allowedamt==coinsurance;
replace copay = 0 if allowedamt==deductible; 
replace copay = 0 if prev==1;

 

gen group = 1;
} ;
tempfile kaiser_out`yplan';
save `kaiser_out`yplan'', replace;
* global kaiser_out`yplan' `kaiser_out`yplan'';
 
* display "`kaiser_out'";
