#delimit;
/* Providence all years */;

set more off;
clear;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

local prov $prov;

/***************** IMPORTANT NOTE **************************
Copay only applies once per day for a particular service type.
Coinsurances apply for every single line of the claim.
**************************************************************/;
*Plans kept: "PMED1" "PMED2"  "PMP1A" "PMP2A"; 
/* ***********************************************************************************
* ***********************************************************************************/;

use `prov`yplan'', clear;
if _N !=0 { ;

/*CB - the NA feature is resulting in high errors*/;
replace NA = 0;

assert coinsuranceperc!=. if NA !=1;
assert copay!=. if NA !=1;

tab by_day;
tab prev;

/* Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met*/;
gen overallcost = allowedamt;
gen deductible = overallcost;
 
gen copayGTallowedamt=(copay) if allowedamt < copay;
replace copayGTallowedamt=0 if copayGTallowedamt==.;

gen coinsurance = coinsuranceperc*(overallcost);
/* Calculating OOP cost for each claim */;
/* special case for inpatient stay in KMED 1: 100 per day, 500 admission max */;
gsort   -allowedamt -origded;


/***********************************2008*/;
/* services where you don't have to meet the deductible first */;
if `year'==2008{;
/************* DEDUCTIBLE *************/;
gen noded=0;
replace noded=1 if ((plan=="PMED1" | plan=="PMED2") & (serviceid=="S600" | serviceid=="S891" | serviceid=="S892" | serviceid=="S689"| serviceid=="S688"));
replace noded = 1 if network == 1 ; 
/************* PREV SERVICES *************/;
/* Preventive care services are always fully covered for PMED plans and for some services for KMED plans*/;
/* 854: routine womens/mens exam, 852: immunizations,  855: well baby*/;
replace prev = 0 if network == 0;

/****** accounding for charges by day ******/;
gen p_days = lastsrvcdt - srvcdt ; 
replace p_days = 0 if by_day == 0 ; 
bys personid plan claimid serviceid srvcdt:  gen dayssum = sum(p_days);

replace dayssum=0 if dayssum>p_days; // I just want one line to have the number of days - the raw claims data has the days at each inpatient stay line, which in the case would make us double count; 

  
/* for inpatient stay, mental health, inpatient and residential stay */;
replace copay = 100*dayssum if (by_day == 1) & (plan=="PMED1" & network==1) ;
*replace copay = 500 if copay >500 & (by_day == 1) & (plan=="PMED1" & network==1) ;
replace deductible = (overallcost - copay) if (overallcost > copay & by_day == 1);
  
gen dualcc=0;	
gen nooop=0;
gen chargedmaxoop=0;
};

/****2009*/;
if `year'==2009{;
/************* DEDUCTIBLE *************/;
gen noded=0;
replace noded=1 if ((plan=="PMED1" | plan=="PMED2") & (serviceid=="S600" | serviceid=="S891" | serviceid=="S892" | serviceid=="S689"| serviceid=="S688"));
replace noded = 1 if network == 1 ; 
/************* PREV SERVICES *************/;
/* Preventive care services are always fully covered for PMED plans and for some services for KMED plans*/;
/* 952=immunizations, 953=office visits, 954=routine women's/men's exam, 955=well-baby*/;
replace prev = 0 if network == 0;

/****** accounding for charges by day ******/;
gen p_days = lastsrvcdt - srvcdt ; 
replace p_days = 0 if by_day == 0 ; 
bys personid plan claimid serviceid srvcdt:  gen dayssum = sum(p_days);
replace dayssum=0 if dayssum>p_days; // I just want one line to have the number of days - the raw claims data has the days at each inpatient stay line, which in the case would make us double count; 
/* for inpatient stay, mental health, inpatient and residential stay */;
replace copay = 100*dayssum if (by_day == 1) & (plan=="PMED1" & network==1) ;
replace copay = 200*dayssum if (by_day == 1) & (plan=="PMP1A" & network==1) ;
*replace copay = 500 if copay >500 & (by_day == 1) & (plan=="PMED1" & network==1) ;
replace deductible = (overallcost - copay) if (overallcost > copay & by_day == 1);

gen dualcc=0;	
gen nooop=0;
gen chargedmaxoop=0;

* Procedure code modifications - likely not in keeping with expectations ; 
replace copay = 50 if serviceid == "S531" & inlist(procedure,"59400", "59409", "59410") & plan == "PMED2" ;
replace copay = 5 if plan == "PMED2" & procedure == "90853" ;

	* maybe S120 ;


};
  
replace noded=0 if noded==.;
replace deductible = 0 if noded==1 | (copay !=0 & dualcc !=1);  // testing AHS;
gen totcost = deductible;
  
/* Special case for ER visits, copay is waived if admitted, coinsurance must still be paid, ER copay paid only once per visit, deductible applies */;
gen ERvisit = 1 if (serviceid == "S600"); 

gsort personid plan srvcdt  -origcopay -allowedamt;
by personid plan srvcdt:  gen numER = sum(ERvisit);

bys personid plan srvcdt: egen sum_origded = sum(origded) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcoin = sum(origcoin) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcopay = sum(origcopay) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_allowedamt = sum(allowedamt) if ERvisit == 1;
replace allowedamt = sum_allowedamt if ERvisit == 1 & numER==1;  
replace origded = sum_origded if ERvisit == 1 & numER==1;  
replace origcoin = sum_origcoin if ERvisit == 1 & numER==1;  
replace origcopay = sum_origcopay if ERvisit == 1 & numER==1;  

replace allowedamt = 0 if ERvisit == 1 & numER>1; 
replace origded = 0 if ERvisit == 1 & numER>1; 
replace origcopay = 0 if ERvisit == 1 & numER>1; 
replace origcoin = 0 if ERvisit == 1 & numER>1; 

gsort personid srvcdt -origcopay -allowedamt;
gen admit = 0 if (serviceid == "S600") & origcopay == 0; 
replace admit = 1 if (serviceid == "S600") & admit != 0; 
by personid srvcdt: egen admitted=max(admit);

if `year' !=2011{;
 /* Special ER cases. */;
replace copay = 0 if (numER > 1 & (serviceid == "S600")); 
/* ER copay paid only once per visit*/;
replace copay= 0 if admitted == 0 & (serviceid == "S600"); 
/* if admitted ==0, it means the individual was admitted and the copay is waived*/;
replace copay = 100 if numER == 1 & admitted==1 & (serviceid == "S600") & allowedamt >= 100; 
/* if not admitted, copay of 100 applies. */;
replace copay = allowedamt if numER == 1 & admitted == 1 & (serviceid == "S600") & allowedamt < 100; 

};

replace coinsurance = 0 if NA == 1;
replace totcost = overallcost if NA == 1; 
replace deductible = 0 if NA == 1;

replace deductible = 0 if prev == 1;
replace totcost = 0 if prev == 1;

 

replace copay = 0 if copay == .;
replace coinsurance = 0 if coinsurance == .;

/* Replacing coinsurance to equal allowed amount if allowed amount is < coinsurance */;
replace coinsurance = allowedamt if allowedamt < coinsurance & coinsurance!=0 & allowedamt>=0;
/* Replacing copay to equal allowed amount if allowed amount is < copay */;
replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>=0;
replace coinsurance = 0 if allowedamt==copay & copay !=0;
replace copay = 0 if allowedamt==coinsurance & coinsurance !=0;

 

/* Calculating totcost at the margin where it just reaches the deductible:
assumes everything is OOP up to point where we hit hte duductible.  After we figure out where it hits the deductible;
* then it figures out how much the coins; 
* recalculate what the deductible is; */;

replace coinsurance = (allowedamt - copay) * coinsuranceperc if serviceid == "S600"; 

/* copay applies once per serviceid per family (?) per day*/;
/*this might be better by familyid*/;
gsort familyid plan serviceid srvcdt -copay linenum -allowedamt;
		by familyid plan serviceid srvcdt :  gen numcopay_cb = _n;

replace copay = 0 if (numcopay_cb > 1) & serviceid !="S299" ;


 

/***************************************************************************************************************************************************************************/;
/********************************************************************************CALCULATOR*******************************************************************************/;
/***************************************************************************************************************************************************************************/;
local ftype personid familyid;  /* this just stores the two variables into ftype */;

gen flag=0;
gen ded=.;
gen coin=.;
gen cop=.;

/* this is the equivalent of running 2 loops, one for personid and one for family id */;
/* rank puts individuals with a non-zero deductible AND  individuals with a non-zero deductible and non-zero coins first*/; 
/* based on claims data: want to rank so procedures on same date, the procedures that are below the duductible */;
/* come first and the claims that are paid for in full by the insurance come last*/;
foreach a of local ftype {;
sort `a' plan paiddt linenum; 

replace flag = 1 if origded!=0 & origcoin != 0 & origcopay !=0;
replace ded = 0 if origded!= 0;
replace ded = 1 if origded == 0;
assert ded !=.;

sort `a' plan network paiddt linenum; 
replace coin = 0 if origcoin!= 0;
replace coin = 1 if origcoin == 0;
assert coin !=.;

replace cop = 0 if origcopay!= 0;
replace cop = 1 if origcopay == 0;
assert cop !=.;

gsort `a' plan network paiddt linenum coin cop;
by `a' plan network paiddt: gen rank1`a' = _n;  

sort `a' plan network paiddt linenum ded origded flag; 
/* this puts ded=0 and flag=0 before ded=1 and flag=1*/;
by `a' plan network paiddt: gen rank`a' = _n;  
};

drop ded coin cop;
  
/* In N/A cases, the cost doesn't count towards the deductible or the maximum*/;
gsort personid plan network paiddt rankpersonid -allowedamt ;
by personid plan network: gen cum_totcost = sum(totcost*(noded !=1)); 

/*if NA==1 what is inside the parenthesis=0, if the statement is true it =1*/; 
by personid plan network: gen atmargin=1 if (cum_totcost[_n] >= maxdedind & cum_totcost[_n-1] < maxdedind) & (_n>1) & noded !=1;

by personid plan network: replace atmargin=2 if (cum_totcost[_n] > maxdedind) & (_n==1) & noded !=1;

replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxdedind) if (noded != 1  & (atmargin == 1 | atmargin == 2)) ;
replace deductible = (maxdedind - cum_totcost[_n-1]) if (noded !=1 & atmargin == 1);

replace deductible = maxdedind if (NA !=1 & atmargin == 2);
replace deductible = 0 if (prev == 1 | noded==1 );

replace totcost = deductible;
replace coinsurance = 0 if prev == 1;
replace copay = 0 if prev == 1;

/* Calculating  totcost if cumulative is greater than deductible */;
gsort personid plan network paiddt rankpersonid -allowedamt ;
by personid plan network: replace cum_totcost = sum(totcost*(noded !=1) ); 
by personid plan network: gen greater_ded = 1 if (cum_totcost > maxdedind) & (atmargin != 1) & (atmargin != 2);
replace deductible = 0 if (greater_ded == 1); 
/* Setting deductible to zero after it crosses limit */;

/* we need to limit the deductible on the claims where it crosses the deductible*/;

replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2); /* Setting coinsurance to zero before deductible is met */;
replace coinsurance = 0 if ( NA == 1 | prev == 1);
replace totcost = coinsurance if NA !=1 ; /* Setting totcost to equal coinsurance after deductible is met */;
replace totcost = overallcost if NA == 1; 
replace totcost = 0 if prev == 1;

/* check family deductible limit */;
sort familyid plan network paiddt rankfamilyid;
by familyid plan network: gen cumdedfam = sum(deductible);
by familyid plan network: replace atmargin = 3 if (cumdedfam[_n] >= maxded & cumdedfam[_n-1] < maxded) & (_n>1) & individual_ded == 0;
by familyid plan network: replace atmargin= 4 if (cumdedfam[_n] > maxded) & (_n==1) & individual_ded == 0;
replace coinsurance = coinsuranceperc*(cumdedfam[_n] - maxded) if (prev! = 1 & noded != 1 & (atmargin == 3 | atmargin == 4) & individual_ded ==0) ;
replace deductible = (maxded - cumdedfam[_n-1]) if ((noded != 1)  & atmargin == 3 & individual_ded == 0);
replace deductible = maxded if (noded !=1  & atmargin == 4 & individual_ded == 0);
replace deductible = 0 if prev == 1 & individual_ded == 0;
replace deductible=0 if noded==1;

replace totcost = deductible if individual_ded == 0;

sort familyid plan network paiddt rankfamilyid;
by familyid plan network: replace cumdedfam = sum(totcost*(noded !=1)); 
by familyid plan network: gen greater_dedfam = 1 if (cumdedfam > maxded) & (atmargin != 3) & (atmargin != 4) & individual_ded == 0;
replace deductible = 0 if (greater_dedfam == 1 & individual_ded == 0);
 
/* Setting deductible to zero after it crosses limit */;
replace coinsurance = coinsuranceperc* overallcost if (greater_dedfam == 1 & noded != 1 & prev != 1 & individual_ded == 0);
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & atmargin!=3 & atmargin!=4 & individual_ded == 0);  
/* Setting coinsurance to zero before deductible is met */;
replace coinsurance = 0 if ( NA== 1 | prev == 1);
replace totcost = coinsurance + copay; 
/*setting this for the oop max;*/ 
replace totcost = overallcost if NA == 1; 
replace totcost = 0 if prev == 1;

cap drop atmargin_max;

/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
sort personid plan network paiddt rank1personid;
	
by personid plan network: replace cum_totcost = sum(totcost*(nooop !=1));
by personid plan network: gen atmargin_max = 1 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1);
by personid plan network: replace atmargin_max = 2 if (cum_totcost[_n] > maxoopind) & (_n==1); 
replace coinsurance = maxoopind - cum_totcost[_n-1] if (atmargin_max == 1 & nooop !=1 );
replace coinsurance = maxoopind if (atmargin_max == 2 & nooop !=1 );

/* deal with NA cases - patient pays full cost as a "copay" */;
replace copay = overallcost if NA==1;
replace coinsurance = 0 if NA == 1;
replace coinsurance = 0 if prev == 1;
replace copay=0 if prev==1;
replace deductible=0 if noded==1;
 
/* Setting totcost to 0 past the coinsurance maximum limit */;
sort personid plan network paiddt rank1personid;
by personid plan network: replace cum_totcost = sum(totcost*(nooop !=1));
replace coinsurance = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1 ;
replace copay = 0 if (cum_totcost > maxoopind) & (atmargin_max != 1) & (atmargin_max != 2) & nooop !=1 ;
replace coinsurance = overallcost if NA == 1;
replace coinsurance = 0 if prev == 1;
replace totcost = coinsurance; 

/* check family oop limit */;
sort familyid plan network paiddt rankfamilyid;
by familyid plan network : gen cumoopfam = sum(totcost*(nooop !=1)) if individual_oop == 0;
by familyid plan network: replace atmargin_max = 3 if (cumoopfam[_n] >= maxoop & cumoopfam[_n-1] < maxoop) & (_n>1) & individual_oop == 0 & nooop !=1;
by familyid plan network: replace atmargin_max= 4 if (cumoopfam[_n] > maxoop) & (_n==1) & individual_oop == 0 & nooop !=1;
replace coinsurance = coinsuranceperc*(cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 3 | atmargin_max == 4) & individual_oop ==0 & coinsuranceperc !=0 );
replace copay = (cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 3 | atmargin_max == 4) & individual_oop ==0& coinsuranceperc ==0 & copay > (cumoopfam[_n] - maxoop) );

replace copay = (maxoop - cumoopfam[_n-1]) if ((nooop !=1) & atmargin_max == 3 & individual_oop == 0);
replace totcost = copay+coinsurance if individual_oop == 0;   

sort familyid plan network paiddt rankfamilyid;
by familyid plan network: replace cumoopfam = sum(totcost*(nooop !=1)); 
by familyid plan network: gen greater_oopfam = 1 if (cumoopfam > maxoop) & (atmargin_max != 3) & (atmargin_max != 4) & individual_oop == 0 & nooop!=1;
replace coinsurance = 0 if (greater_oopfam == 1 & individual_oop == 0  & nooop!=1); 
/* Setting coins to zero past limit */;
replace copay = 0 if (greater_oopfam == 1 & individual_oop == 0  & nooop!=1) ; 
/* Setting copay to zero past limit */;

gen oopcost = deductible + coinsurance + copay;
  
if `year' == 2009 {;
/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
replace acs = 0 if NA == 1;
replace acs = 1 if (inlist(serviceid,"S688", "S689","S443")) & NA! = 1;
gen acsinsurer = overallcost - oopcost if acs == 1;
sort personid plan paiddt; 
by personid plan: gen cum_acsinsurer = sum(acsinsurer);
by personid plan: gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2500 & cum_acs) & (cum_acsinsurer[_n-1] < 2500) & (_n>1);
by personid plan: replace acsmargin = 2 if (cum_acsinsurer[_n] > 2500) & (_n==1);
replace acsinsurer = 2500 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
replace acsinsurer = 2500 if (acsmargin == 2 & acs == 1);
sort personid plan paiddt; 
by personid plan: replace cum_acsinsurer = sum(acsinsurer);
gen bene_cost = overallcost - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
replace bene_cost = overallcost if (acs == 1 & cum_acsinsurer > 2500);
replace oopcost = bene_cost if acs == 1;
};

  

/* Make sure copay only applies once per claim id*/;

/* CB 3/5/15 this was: gsort personid plan claimid serviceid srvcdt linenum */;
*** I think we need to have it as: gsort personid plan claimid serviceid srvcdt -allowedamt;
*** because we set have copay = 0 if allowedamt = 0, so if the first linenum is allowedamt 0,;
*** and we set all copays after the first line in a claimid = 0 (as below), then we get too ;
*** many zeros, -copay may work too.;

gsort personid plan claimid serviceid srvcdt -allowedamt;
by personid plan claimid serviceid srvcdt :  gen numcopay = _n;

/* additional cost tier services 
 - for some charges, such as additional cost tier, the allowedamt is <500, but there were multiple serviced done under
this tier on a given servicedate.  As a result, the full $500 was charged, but distributed among the different services.  
We need a fix for this.  We're utilizing a variable from the beginning of the piece (copayGTallowedamt).
 For instance, see 2010: personid = "ATo21EbhToUo1QATosGt2ot" & chosen==1 */;
gsort personid plan claimid serviceid srvcdt linenum ;
by personid plan claimid serviceid srvcdt : gen cum_copaycost = sum(copay);
by personid plan claimid serviceid srvcdt: gen atmarginc_max = 1 if (cum_copaycost[_n] >= copayGTallowedamt) & (cum_copaycost[_n-1] < copayGTallowedamt)& (_n>1);
replace copay = copayGTallowedamt - cum_copaycost[_n-1] if (atmarginc_max == 1 ) & (serviceid=="S440" | serviceid=="S660" | serviceid=="S661") & allowedamt < copayGTallowedamt;
gen exempt=1 if (serviceid=="S440" | serviceid=="S660" | serviceid=="S661" ) & ((copayGTallowedamt > cum_copaycost) | atmarginc_max==1);
replace exempt=0 if exempt==.;
  
/* for duallcc charges, the copay only applies to the first instance */;
gsort personid plan serviceid provid srvc_id  srvcdt linenum -copay;
by personid plan serviceid provid srvc_id srvcdt: gen copaycount=_n if dualcc==1;
replace copay=0 if copaycount >1 & dualcc==1 & (allowedamt > copayGTallowedamt);

/* Make sure copay only applies once per claim id*/;
/*exception: DME in 2011 providence; // CHECK THIS IN THE CLAIMS*/;
gen exception=0;
replace exception=1 if (plan=="PMED2" | plan=="PMP2A") & (`planyear'==2010 | `planyear'==2011) & serviceid=="S700";
gsort personid plan claimid serviceid paiddt -copay;
replace numcopay=1 if exception==1;
replace copay = 0 if (numcopay > 1) & exempt !=1 & planfirst=="K"; 
/* part of ACT addition*/;

replace copay = 0 if allowedamt==deductible & deductible !=0; 
replace coinsurance = 0 if allowedamt==copay; 

gsort personid plan serviceid srvcdt -copay;
by personid plan serviceid srvcdt:  gen numcopay2 = _n;
replace numcopay2=1 if exception==1;
replace copay = 0 if (numcopay2 > 1) & planfirst=="K";

/* make sure dualcc charges are calculating the coins correctly */;
cap drop cost;
gen cost =allowedamt-copay if deductible==0 & dualcc==1;
replace coinsurance = coinsuranceperc*(cost) if deductible==0 & dualcc==1;



/***********************ADJUSTMENTS***********************/;

/*coinsurance*/;
replace coinsurance = 0 if allowedamt==copay; 

/*copay*/;
replace copay = 0 if allowedamt==coinsurance;
replace copay = 0 if allowedamt==deductible; 

gen group = 1;
} ;
tempfile prov_out`yplan';
save `prov_out`yplan'', replace;
global prov_out`yplan' `prov_out`yplan'';
