
#delimit;
/* Providence all years */;

set more off;
clear;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

local prov $prov;
local pyear $pyear;


/***************** IMPORTANT NOTE **************************
Copay only applies once per day for a particular service type.
Coinsurances apply for every single line of the claim.
**************************************************************/;
*Plans kept: "PMED1" "PMED2"  "PMP1A" "PMP2A"; 
/* ***********************************************************************************
|DERIVATION:
| - where are we storing NA values? 
| - family is 3 or more
|
|Plan structure
| - PMED2:
|		- deductible: $100/$300  *doesn't count towards oop max
|			- combined in-plan and out-of-plan benefits
|			- copays don't apply
|			- deductible carry over
|		- oop max $1200/$3600 in network.  $2400/700 out of network
|			- SEPARATE in-plan and out-of-plan benefits
|			- deductibles, copayments don't apply to oop max
|			- these procedures don't apply: Additional cost tier, sleep study
|			- max coinsurance paid (2011)
|			- max coinsurance AND COPAY paid (2011)
|
| - PMED2:
|		- deductible: $300/$900  *doesn't count towards oop max
|			- combined in-plan and out-of-plan benefits
|			- copays don't apply
|			- deductible carry over
|		- oop max $2000/$6000 in network.  $4000/12000 out of network
|			- SEPARATE in-plan and out-of-plan benefits
|			- deductibles, copayments don't apply to oop max
|			- these procedures don't apply: Additional cost tier, sleep study
|			- max coinsurance paid ( 2011)
|			- max coinsurance AND COPAY paid ( 2010)
************************************************************************************/;

use `prov`yplan'', clear;
if _N !=0 { ;
assert coinsuranceperc!=. if NA !=1;
assert copay!=. if NA !=1;

*Charge Submitted=Discount+Allowed Amount;
*Allowed Amount=NetPayment+Third Party (COB or Medicare) +Out of Pocket;
*Out of Pocket=Copayment+Coinsurance+Deductible;
*totcost = Out of Pocket - Copay;

/************ Dual copays and coinsurances ***********/;

gen dualcc=0;
replace dualcc=1 if 
		( substr(serviceid,1,3)=="S66"   // imaging;
		| serviceid=="S600" 			// ER;
		| serviceid=="S605" 			// ER;
		| serviceid=="S610"
		| serviceid=="S310"	
		| serviceid=="S111"	
		| serviceid=="S225"); 			

/************ DEDUCTIBLE ************/;
gen noded=0;
replace noded=1 if NA==1;
replace noded=1 if copay !=0 & dualcc ==0 & network==1;
if `year'==2010{;
replace noded = 1 if network == 1 ; 
};
/************ OOP MAX ***********/;
* neither deductibles or copayments are included towards the oop max; 
gen nooop=0; 

replace nooop=1 if 
		( substr(serviceid,1,3)=="S66" | // imaging;
		  serviceid=="S700" ); // DME;  
replace nooop=1 if copay !=0 & dualcc !=1;

replace nooop=1 if NA==1; 

/************ PREV SERVICES ************/;
replace prev = 0 if network == 0;

/* this should have been carried through below, but was not*/;
replace copay = 0 if prev == 1;

gen overallcost = allowedamt;
gen deductible = overallcost;

if `year'==2010{;

	/****** accounding for charges by day ******/;
	gen p_days = lastsrvcdt - srvcdt ; 
	replace p_days = 0 if by_day == 0 ; 
	bys personid plan claimid serviceid srvcdt:  gen dayssum = sum(p_days);
	replace dayssum=0 if dayssum>p_days; // I just want one line to have the number of days - the raw claims data has the days at each inpatient stay line, which in the case would make us double count; 
	/* for inpatient stay, mental health, inpatient and residential stay */;
	replace copay = 100*dayssum if (by_day == 1) & (plan=="PMED2" & network==1) ;
	replace copay = 200*dayssum if (by_day == 1) & (plan=="PMP2A" & network==1) ;
	*replace copay = 500 if copay >500 & (by_day == 1) & (plan=="PMED1" & network==1) ;
	replace deductible = (overallcost - copay) if (overallcost > copay & by_day == 1);
	
	* there may be a better way to do this, but it doesn't seem to exactly follow NA pattern, because OOP max appears to matter ; 
	replace copay = allowedamt if serviceid == "S111" & network == 1 ; 
	replace copay = 500 if copay > 500 & serviceid == "S111" & network == 1 ; 
	
};

if `year' == 2011 {;
	replace prev = 1 if serviceid == "S660" & plan == "PMED2" & procedure == "78815" ; 
	replace prev = 1 if serviceid == "S719" & plan == "PMED2" & procedure == "L8010" ; 	
	replace copay = 100 if serviceid == "S111" & plan == "PMED2" & inlist(procedure,"43239","43235") ;
	replace coinsuranceperc = 0.2 if network == 1 & serviceid == "S721" & procedure == "J1055" ; 
	
	replace NA = 0 if network == 1 & serviceid == "S721" & procedure == "J1055" ;
	
	* something in 661 with 76818 ;
} ;	

replace prev = 0 if network == 0 ;

*STOPPED EDITING HERE; 

/************  Special case for ER visits, copay is waived if admitted, coinsurance must still be paid, ER copay paid only once per visit, deductible applies ************/;
gen ERvisit = 1 if ((serviceid == "S600"));  
gsort personid plan srvcdt  -origcopay -allowedamt;

by personid plan srvcdt:  gen numER = sum(ERvisit);
		replace numER=0 if ERvisit==.; // added 4/29 ahs;

bys personid plan srvcdt: egen sum_origded = sum(origded) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcoin = sum(origcoin) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_origcopay = sum(origcopay) if ERvisit == 1; 
bys personid plan srvcdt: egen sum_allowedamt = sum(allowedamt) if ERvisit == 1;
replace allowedamt = sum_allowedamt if ERvisit == 1 & numER==1;  
replace origded = sum_origded if ERvisit == 1 & numER==1;  
replace origcoin = sum_origcoin if ERvisit == 1 & numER==1;  
replace origcopay = sum_origcopay if ERvisit == 1 & numER==1;  

replace allowedamt = 0 if ERvisit == 1 & numER>1; 
replace origded = 0 if ERvisit == 1 & numER>1; 
replace origcopay = 0 if ERvisit == 1 & numER>1; 
replace origcoin = 0 if ERvisit == 1 & numER>1; 

gsort personid srvcdt -origcopay -allowedamt;
gen admit = 0 if ((serviceid == "S600")) & origcopay == 0; 
replace admit = 1 if ((serviceid == "S600")) & admit != 0; 
by personid srvcdt: egen admitted=max(admit);

 // Special ER cases. 
replace copay = 0 if (numER > 1 & serviceid == "S600"); // ER copay paid only once per visit;
replace copay= 0 if admitted == 0 & serviceid == "S600"; // if admitted ==0, it means the individual was admitted and the copay is waived;
replace copay = 100 if numER == 1 & admitted==1 & (serviceid == "S600") & allowedamt >= 100; // if not admitted, copay of 100 applies. 
replace copay = allowedamt if numER == 1 & admitted == 1 & (serviceid == "S600") & allowedamt < 100; 

replace copay = 0 if admitted ==0  & ((serviceid == "S600")); // if admitted !=., it means the individual was admitted through the ER and the copay is waived;

/************  defining and modifying oop variables  ************/;
*coinsurance;
gen coinsurance = coinsuranceperc*(allowedamt);
replace coinsurance = 0 if NA == 1;
replace coinsurance = allowedamt if allowedamt < coinsurance & coinsurance!=0 & allowedamt>=0;
replace coinsurance = 0 if allowedamt==copay & copay !=0;
replace coinsurance = (allowedamt - copay) * coinsuranceperc if (serviceid == "S600"); 

  

*copay;
replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>=0;
replace copay = 0 if allowedamt==coinsurance & coinsurance !=0;

*deductible;

replace deductible = 0 if NA == 1 & network==1;
replace deductible = 0 if (prev == 1 & network==1);
replace deductible = 0 if noded==1 | (copay !=0 & dualcc !=1); 

*totcost;
gen totcost = deductible;
replace totcost = allowedamt if NA == 1; 
replace totcost = 0 if prev == 1;

/* Copay only once per serviceid per day. Does this help with 220 and 110 and 230 and 301? */;
/* CB 3/5/2014 - this was: 
gsort familyid plan claimid serviceid srvcdt -copay linenum -allowedamt;
		by familyid plan claimid serviceid srvcdt :  gen numcopay_cb = _n;*/;
		
/* changed to: */;
/* copay applies once per serviceid per family (?) per day*/;

/* while it does not seem correct, this may be better by paiddt*/;

gsort familyid plan srvcdt serviceid -copay -allowedamt;
	by familyid plan srvcdt serviceid :  gen numcopay_cb = _n;
	
replace copay = 0 if (numcopay_cb > 1) & serviceid !="S299";

/***************************************************************************************************************************************************************************/;
/********************************************************************************CALCULATOR*******************************************************************************/;

local ftype personid familyid;  /* this just stores the two variables into ftype */;

gen flag=0;
gen ded=.;
gen coin=.;
gen cop=.;

/* this is the equivalent of running 2 loops, one for personid and one for family id */;
* rank puts individuals with a non-zero deductible AND  individuals with a non-zero deductible and non-zero coins first; 
* based on claims data: want to rank so procedures on same date, the procedures that are below the duductible 
* come first and the claims that are paid for in full by the insurance come last;
foreach a of local ftype { ;
sort `a' plan paiddt linenum; 

replace flag = 1 if origded!=0 & origcoin != 0 & origcopay !=0;
replace ded = 0 if origded!= 0;
replace ded = 1 if origded == 0;
assert ded !=.;

sort `a' plan paiddt linenum; 
replace coin = 0 if origcoin!= 0;
replace coin = 1 if origcoin == 0;
assert coin !=.;

replace cop = 0 if origcopay!= 0;
replace cop = 1 if origcopay == 0;
assert cop !=.;

gsort `a' plan paiddt linenum coin cop;
by `a' plan paiddt: gen rank1`a' = _n;  

gsort `a' plan paiddt linenum ded origded -flag; // this puts ded=0 and flag=0 before ded=1 and flag=1;
by `a' plan paiddt: gen rank`a' = _n;  

} ;

drop ded coin cop;
 // 1;

 /************ Set deductible to equal the total oop cost (excluding copays) i.e. how much they would pay before deductible is met************/;
gen CopayGTaa=0;
replace CopayGTaa=copay if allowedamt < copay;

* Make sure copay only applies once per claim id;

/* CB 3/5/15 this was: gsort personid plan claimid serviceid srvcdt linenum */;
*** I think we need to have it as: gsort personid plan claimid serviceid srvcdt -allowedamt;
*** because we set have copay = 0 if allowedamt = 0, so if the first linenum is allowedamt 0,;
*** and we set all copays after the first line in a claimid = 0 (as below), then we get too ;
*** many zeros, -copay may work too.;

gsort personid plan claimid serviceid srvcdt -allowedamt;
by personid plan claimid serviceid srvcdt :  gen numcopay_c = _n;
gsort personid plan serviceid srvcdt -allowedamt;
by personid plan serviceid srvcdt :  gen numcopay_macro = _n;

/* additional cost tier services 
 - for some charges, such as additional cost tier, the allowedamt is <500, but there were multiple serviced done under
this tier on a given servicedate.  As a result, the full $500 was charged, but distributed among the different services.  
We need a fix for this.  We're utilizing a variable from the beginning of the piece (CopayGTaa).
 For instance, see 2010: personid = "ATo21EbhToUo1QATosGt2ot" & chosen==1 */;
gsort personid plan claimid serviceid srvcdt linenum;
by personid plan claimid serviceid srvcdt : gen cum_copaycost = sum(copay);
by personid plan claimid serviceid srvcdt: gen atmarginc_max = 1 if (cum_copaycost[_n] >= CopayGTaa) & (cum_copaycost[_n-1] < CopayGTaa)& (_n>1);
replace copay = CopayGTaa - cum_copaycost[_n-1] if (atmarginc_max == 1 ) & (substr(serviceid,1,3)=="S66") & allowedamt < CopayGTaa ;
gen exempt=1 if (substr(serviceid,1,3)=="S66") & ((CopayGTaa > cum_copaycost) | atmarginc_max==1);
replace exempt=0 if exempt==.;
replace copay = 0 if (numcopay_c > 1) & exempt==0;
replace coinsurance = 0 if (numcopay_c > 1) & exempt==0 & (serviceid=="S620" | serviceid=="S621" | serviceid=="S640" | serviceid=="S641");
/* this last line was difference and I think a mistake in the original code*/;
/* check in with Adrienne perhaps if there isn't clear evidence in the data on this*/;
/* `y'61 vs `y'62 issue and "Tier 2" vs (supp) in prov description*/;
/* I also added a number of codes to additional cost tier because they had Tier 2 in the description */;

 /****************** DEDUCTIBLE ********************/;
gsort personid plan network paiddt rankpersonid -allowedamt ;

by personid plan : gen cum_totcost = sum(totcost*(noded !=1) ); 
by personid plan : gen atmargin=1 if (cum_totcost[_n] >= maxdedind & cum_totcost[_n-1] < maxdedind) & (_n>1);
by personid plan : replace atmargin=2 if (cum_totcost[_n] > maxdedind) & (_n==1);
replace coinsurance = coinsuranceperc*(cum_totcost[_n] - maxdedind) if ( noded !=1 & (atmargin == 1 | atmargin == 2)) ;
replace deductible = (maxdedind - cum_totcost[_n-1]) if ((noded !=1) & atmargin == 1);
  
replace deductible = maxdedind if ((noded !=1) & atmargin == 2);
replace deductible = 0 if (prev == 1 | noded==1 | NA==1) & network==1;
replace totcost = deductible;
replace coinsurance = 0 if prev == 1;
 
// list personid allowedamt  origcopay copay origcoin coinsurance origded deductible serviceid provid srvc_id   srvcrule noded network paiddt  srvcdt plan if personid=="ATosaW6h5owolhATosaW6h5";
/* Calculating  totcost if cumulative is greater than deductible */;
gsort personid plan network paiddt rankpersonid -allowedamt ;
by personid plan : replace cum_totcost = sum(totcost*(noded !=1)); 
by personid plan : gen greater_ded = 1 if (cum_totcost > maxdedind) & (atmargin != 1) & (atmargin != 2);
replace deductible = 0 if (greater_ded == 1); /* Setting deductible to zero after it crosses limit */;
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & noded !=1); /* Setting coinsurance to zero before deductible is met */;
 
replace totcost=deductible;
replace totcost=allowedamt-deductible if deductible !=0 & noded==0;
replace copay = allowedamt-deductible if (deductible!=0 & noded !=1 & copay > totcost & copay !=0); /* Setting coinsurance to zero before deductible is met */;

/* check family deductible limit */;
sort familyid plan  paiddt rankfamilyid;
by familyid plan : gen cumdedfam = sum(deductible);
by familyid plan : replace atmargin = 3 if (cumdedfam[_n] >= maxded & cumdedfam[_n-1] < maxded) & (_n>1) & individual_ded == 0; 
by familyid plan : replace atmargin= 4 if (cumdedfam[_n] > maxded) & (_n==1) & individual_ded == 0;

replace coinsurance = coinsuranceperc*(cumdedfam[_n] - maxded) if (prev! = 1 & noded != 1 & (atmargin == 3 | atmargin == 4) & individual_ded ==0) ;
  
replace deductible = (maxded - cumdedfam[_n-1]) if ((noded !=1) & atmargin == 3 & individual_ded == 0);
replace deductible = maxded if ((noded !=1) & atmargin == 4 & individual_ded == 0);
replace deductible = 0 if prev == 1 & individual_ded == 0 & network==1;
replace deductible=0 if noded==1;
replace totcost = deductible if individual_ded == 0;   

sort familyid plan  paiddt rankfamilyid;
by familyid plan : replace cumdedfam = sum(totcost*(noded !=1)); 
by familyid plan : gen greater_dedfam = 1 if (cumdedfam > maxded) & (atmargin != 3) & (atmargin != 4) & individual_ded == 0;
replace deductible = 0 if (greater_dedfam == 1 & individual_ded == 0); /* Setting deductible to zero after it crosses limit */;
replace coinsurance = coinsuranceperc*allowedamt if (greater_dedfam == 1 & noded != 1 & prev != 1 & individual_ded == 0);
replace coinsurance = 0 if (deductible!=0 & atmargin!= 1 & atmargin!=2 & atmargin!=3 & atmargin!=4 & individual_ded == 0);  /* Setting coinsurance to zero before deductible is met */;
  
/* deal with dual copay and coinsurance charges:
1) deal with charges with non-zero deductible--take copay out first, then coinsurance; 
2) deal with charges with zero deductible--take coins out first, then copay
*/;
* 1) ;
gen cost =allowedamt-deductible if deductible !=0 & dualcc==1;
replace copay = cost if (noded !=1 & copay > cost & dualcc==1);
replace cost =allowedamt-deductible-copay if dualcc==1 & deductible !=0;
replace coinsurance = coinsuranceperc*(cost) if deductible !=0 & dualcc==1;
* 2);
replace cost =allowedamt if deductible==0 & dualcc==1;
replace coinsurance = coinsuranceperc*(cost) if deductible==0 & dualcc==1 & coinsurance !=0;
replace cost=allowedamt-coinsurance if deductible==0 & dualcc==1;
replace copay = cost if (noded !=1 & copay > cost & dualcc==1 & deductible==0);
  
/* for duallcc charges, the copay only applies to the first instance */;
gsort personid plan serviceid provid paiddt  -allowedamt;
by personid plan serviceid provid paiddt : gen copaycount=_n;
replace copay=0 if copaycount >1 & dualcc==1;
	drop copaycount;

/* for lab charges, copay and coinsurance just applies to the first */;
gsort personid plan serviceid  paiddt network  -allowedamt;
by personid plan serviceid  paiddt : gen copaycount=_n;
 
replace copay=0 if copaycount >1 & (serviceid=="S670" | serviceid=="S671"| serviceid=="S672");
* LOR = 0 LTG = 0 ;
* why do some people pay full cost of lab in our calculation, sometimes correct, sometimes now? ;

/* make sure dualcc charges are calculating the coins correctly */;
cap drop cost;
gen abs=abs(allowedamt-copay-deductible);
replace coinsurance = coinsuranceperc*(abs) if deductible==0 & dualcc==1 & coinsurance!=0;
replace coinsurance=0 if coinsurance <0 & allowedamt >0 & dualcc==1;
 
replace coinsurance = 0 if ( NA== 1 | prev == 1);
replace copay = 0 if allowedamt==deductible ;  
replace coinsurance = 0 if allowedamt==copay; 
replace coinsurance = 0 if allowedamt==deductible; 
  
replace totcost = 0 if prev == 1;
replace totcost = coinsurance if (NA !=1) & `planyear'==2011;
replace totcost = coinsurance + copay if (NA !=1) & `planyear'==2010;
replace totcost = allowedamt if NA == 1; 
replace totcost=0 if nooop==1;

/* Review to deal with incorrectly making coinsurances non-zero*/;


 /****************** OOP MAX ********************/;
/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;
* now just doing it for coins--sums up all the coins, and checks where it hits the maximum after which point
* it sets everythin g==0;  
*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum;
sort personid plan network paiddt rank1personid;
cap drop atmargin_max;

by personid plan network: replace cum_totcost = sum(totcost*(nooop==0));

by personid plan network: gen atmargin_max = 1 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1) & nooop !=1;
by personid plan network : replace atmargin_max = 2 if (cum_totcost[_n] > maxoopind) & (_n==1) & nooop !=1; 
replace coinsurance = (maxoopind - cum_totcost[_n-1]) if (atmargin_max == 1 & (nooop !=1) & coinsuranceperc !=0);
replace coinsurance = maxoopind if (atmargin_max == 2 & (nooop !=1) & coinsuranceperc !=0);
replace coinsurance = 0 if prev == 1; 
replace copay = 0 if prev == 1;
replace totcost = coinsurance  if (nooop ==0); /* for prov only coins counts to oop */;
replace totcost=0 if nooop==1;

 
/* Setting totcost to 0 past the coinsurance maximum limit */;
sort personid plan network paiddt rank1personid;
by personid plan network: replace cum_totcost = sum(totcost*(nooop !=1));
by personid plan:  replace atmargin_max = 3 if (cum_totcost[_n] >= maxoopind) & (cum_totcost[_n-1] < maxoopind)& (_n>1)  & NA !=1;
by personid plan:  replace atmargin_max = 4 if (cum_totcost[_n] > maxoopind) & (_n==1) & NA !=1;
replace coinsurance = 0 if (cum_totcost > maxoopind) & (atmargin_max != 3) & (atmargin_max != 4);
replace copay = 0 if (cum_totcost > maxoopind) & (atmargin_max != 3) & (atmargin_max != 4) & `planyear'==2010;
replace totcost = coinsurance; 
 

/* check family oop limit */;
sort familyid plan network paiddt rankfamilyid;
by familyid plan network : gen cumoopfam = sum(totcost*(nooop !=1)) if individual_oop == 0;
by familyid plan network: replace atmargin_max = 5 if (cumoopfam[_n] >= maxoop & cumoopfam[_n-1] < maxoop) & (_n>1) & individual_oop == 0 & nooop !=1;
by familyid plan network: replace atmargin_max= 6 if (cumoopfam[_n] > maxoop) & (_n==1) & individual_oop == 0 & nooop !=1;
replace coinsurance = coinsuranceperc*(cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 5 | atmargin_max == 6) & individual_oop ==0 & coinsurance !=0 );
replace copay = (cumoopfam[_n] - maxoop) if (prev! = 1 & nooop != 1 & (atmargin_max == 5 | atmargin_max == 6) & individual_oop ==0  & copay > (cumoopfam[_n] - maxoop));

replace copay = (maxoop - cumoopfam[_n-1]) if ((nooop !=1) & atmargin_max == 5 & individual_oop == 0);
replace totcost = copay+coinsurance if individual_oop == 0;   

sort familyid plan network paiddt rankfamilyid;
by familyid plan network: replace cumoopfam = sum(totcost*(nooop !=1)); 
by familyid plan network: gen greater_oopfam = 1 if (cumoopfam > maxoop) & (atmargin_max != 5) & (atmargin_max != 6) & individual_oop == 0 & nooop!=1;

 
* should this also have & nooop == 0? I think if a claim doesn't count towards oop max, you may still have to pay for it if you are past oop max ; 
replace coinsurance = 0 if (greater_oopfam == 1 & individual_oop == 0); /* Setting coins to zero past limit */;
replace copay = 0 if (greater_oopfam == 1 & individual_oop == 0 ) & `planyear'==2010; /* Setting copay to zero past limit */;

gen oopcost = deductible + coinsurance + copay;
  
/* Calculating total cost of Alternative Care Services to determine if it is past the benefit max */;
replace acs = 0;
replace acs = 1 if (inlist(serviceid,"S688", "S689","S443")) & NA! = 1;
gen acsinsurer = allowedamt - oopcost if acs == 1;
sort personid plan srvcdt; 
by personid plan: gen cum_acsinsurer = sum(acsinsurer);
by personid plan: gen acsmargin = 1 if (cum_acsinsurer[_n] >= 2000 & cum_acs) & (cum_acsinsurer[_n-1] < 2000) & (_n>1);
by personid plan: replace acsmargin = 2 if (cum_acsinsurer[_n] > 2000) & (_n==1);
replace acsinsurer = 2000 - cum_acsinsurer[_n-1] if (acsmargin == 1 & acs == 1);
replace acsinsurer = 2000 if (acsmargin == 2 & acs == 1);
sort personid plan srvcdt; 
by personid plan: replace cum_acsinsurer = sum(acsinsurer);
gen bene_cost = allowedamt - acsinsurer if (acs == 1 & (acsmargin == 1 | acsmargin == 2));
replace bene_cost = allowedamt if (acs == 1 & cum_acsinsurer > 2000);
replace oopcost = bene_cost if acs == 1;

/* deal with NA cases - patient pays full cost as a "copay" */;
replace copay = allowedamt if NA==1;
replace coinsurance = 0 if NA == 1;
replace coinsurance = 0 if prev == 1;
replace copay=0 if prev==1;
replace deductible=0 if NA==1;
replace deductible=0 if noded==1;

} ;
  
tempfile prov_out`yplan';
save `prov_out`yplan'', replace;
global prov_out`yplan' `prov_out`yplan'';
