/*** Project: 		Oregon Health Plan Choice Analysis 								*/
/*** Program: 		shell_base_fullrun_CB  											*/
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 				*/
/***				 --> code taken and adapted from Sean Sall and Adrienne Sabety  */
/*** Dates:			Transition: 	09/30/2014  									*/
/***				Modified: 		07/09/2016  									*/

#delimit ;
clear;
set more off;

pause off;

global directory /disk/agedisk3/oebb.work/cbehrer/oregon/;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

global cdate `cdate';
global ctime `ctime';
di "$cdate";

/*********************************CHANGE THIS ************************************/; 
local dodate "09_22_16";
	
global runtype "PF";
global runfull 1;
global justdrug 0; 
global acg 0;

if $acg == 0 {;
	local acgbase base;
};

if $acg == 1 {;
	local acgbase acg;
};
di "`acgbase'";
/********************************* NO CHANGE ************************************/;

/* Create log, output, and data directories */;
local do_dir $directory/do/2calculator/`acgbase'/june2015/rebuild/ ;
	
cap mkdir $directory/log/calculator/rebuild/`acgbase'/$cdate ;
cap mkdir $directory/data/calculator/rebuild/`acgbase'/$cdate ;
cap mkdir $directory/data/calculator/rebuild/`acgbase'/$cdate/calc_input;
cap mkdir $directory/data/calculator/rebuild/`acgbase'/$cdate/calc_output;
cap mkdir $directory/output/calculator/rebuild/`acgbase'/$cdate;

foreach shellyears in 2008 2009 2010 2011 2012 2013 {;

	cap mkdir $directory/log/calculator/rebuild/`acgbase'/$cdate/`shellyears';
	cap mkdir $directory/data/calculator/rebuild/`acgbase'/$cdate/;
	cap mkdir $directory/data/calculator/rebuild/`acgbase'/$cdate/calc_input/`shellyears';
	cap mkdir $directory/data/calculator/rebuild/`acgbase'/$cdate/calc_output/`shellyears';
	cap mkdir $directory/output/calculator/rebuild/`acgbase'/$cdate/`shellyears';
	
	/*Shell calculator program*/;
	di "Date is: $cdate";
	/* 0. Set run type and year locals, create Y year variable from YYYY variable, set program calling locals create log */;
	global claimyear `shellyears'; 
	local claimyear $claimyear;
	local runtype $runtype;
	di `claimyear';
	
	local yclaim = `claimyear' - 2000;
	global yclaim `yclaim';

	if "`runtype'" == "PB" {;
		global planyear "`claimyear' + 1";
		global yplan  "`yclaim' + 1";
		local w = "`yclaim' + 1";
	};

	if "`runtype'" == "PF" {;
		global planyear "`claimyear'"; 
		global yplan "`yclaim'";
		local w = "`yclaim'";
	};

	display "Y is `claimyear'";
	display `claimyear';

	local calculator_input "`do_dir'/1calculator_input_KP_`dodate'.do" ; 
	local calculator "`do_dir'/2oregon_calculator_KP_`dodate'.do"; 
	local calculator_test "`do_dir'/3calculator_KP_test_`dodate'.do";

	/*********************************running************************************/; 
	
	/* 1.Call component do files in order: 
	
		1calculator_input_`dodate'.do takes clean data from /disk/agedisk3/oebb.work/cbehrer/given/clean and manipulates it to create 6 files of medical claims, drug claims and plans for each year, saved within the calculator directory of data, in the appropriate subdirectory for acg/base, date, and year. 
		
		2oregoncalculator_`dodate'.do takes the files created by 1calculator_input_`dodate.do and calculates hypothetical out of pocket costs for each beneficiary in each plan in their choice set
		saved in the calc_output directory withing the appropriate data --> acg/base --> date directory 
		
		3calculator_test_`dodate.do tests the accuracy of the calculator by comparing the hypothetical cost calculated for an individual in the plan they were enrolled in with the observed cost for that beneficiary in the plan. This program creates an output excel file with errors in the appropriate output directory
	*/;
	 
	do `calculator_input';
	do `calculator';

	if "`runtype'"=="PF" { ; 
		*do `calculator_test';
	};
	display "$ctime";
	di "$cdate";
	display `claimyear';
	display `planyear';
};

! echo "Subject: Full run kaiser PF $cdate is done" | sendmail -f -io cbehrer@nber.org;