cap log close ;
#delimit ;
/* Project: Oregon Health Plan Choice Analysis						*/;
/* Program: calc_input	 										*/;
/* Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 	*/;

/* Dates:		Transition: 9/30/2014								*/;
/*			Modified:   09/24/2016								*/;

/* This do file creates a file with all benes in the specified year 	*/;
/* and the plans in their choice set based on district				*/;

/* The global $directory is $directory/ 							*/;
/* All globals are set in the shell file 0SHELL_fullrun_base_`do_date'	*/;

/* 0. Pass globals, set log 										*/;
set more off; 
local cdate $cdate;
local ctime $ctime;
local claimyear $claimyear;
local runtype $runtype;
local runfull $runfull;
local justdrug $justdrug;
local acg $acg;

if "`runtype'" == "PB" {;
local planyear = `claimyear' + 1;
};

if "`runtype'" == "PF" {;
local planyear = `claimyear'; 
};

local yplan = `planyear' - 2000;
local yclaim = `claimyear' - 2000;

if `acg' == 0 {;
	local acgbase base ;
};

if `acg' == 1 { ;
	local acgbase acg ;
} ;

cap log close;
log using $directory/log/calculator/rebuild/`acgbase'/`cdate'/`claimyear'/1calc_input`claimyear'_`runtype'_`acgbase'${unit}${cells}_`cdate'_`ctime'.log, replace;

/* Calculator Input file */;
di "Claim year: `claimyear'" ;
di "Plan year: `planyear'" ;
di "ACG vs Base: `acgbase'" ;
di "Runtype: `runtype'" ;
di "Just drug: `justdrug'" ;
di "Shell file run date: `c_date'" ;  
di "Shell file run time: `ctime'" ;
local sampledate 23_Sep_2016 ; 
local macros $directory/do/macros/;
local in_data $directory/data/given/clean;
local out_data $directory/data/calculator/rebuild/`acgbase'/`cdate'/calc_input;

clear all;

/* 1. Set conditions and create datafile locals 													*/;
if `acg' == 0 {;
	local entityplaninfo "$directory/data/built/premium/choiceset_29_Mar_2016.dta";
};

if `acg' == 1 {;
	local entityplaninfo "$directory/data/built/premium/choiceset_acg_29_Mar_2016.dta";
};
/* to create the plan choice by entity file */;
local entitynumbercrosswalk "`in_data'/package2/EntityNumberCrossWalk.csv";

local elig_data "$directory/data/cleaning/2deduplicated/deduplicated_eligibility_11_Jun_2015.dta" ; 
local facility "$directory/data/cleaning/3devoid/facility_trimmed_23_Sep_2016.dta" ; 
local professional "$directory/data/cleaning/3devoid/professional_trimmed_23_Sep_2016.dta" ;
local drug "$directory/data/cleaning/3devoid/drugs_trimmed_23_Sep_2016.dta" ; 

local ods_tos1 "`in_data'/treatmentcodematch/ods_tos.dta" ;
local ods_tos2 "`in_data'/treatmentcodematch/ods_tos_11-13.dta" ; 
local ods_tos3 "`in_data'/treatmentcodematch/oebb_mit_svc_descs_201303_201402.dta" ;
local ods_tos4 "`in_data'/treatmentcodematch/ods_xwalk_28_Sep_2015.dta" ;

local kaiser_orig "`in_data'/treatmentcodematch/KAISER_modified.txt"; 
local kaiserxwalk "`in_data'/treatmentcodematch/KAISER_claimsxwalk_12_May_2014.dta" ; 
local kaiserxwalk2 "`in_data'/treatmentcodematch/Kaiser_Crosswalk.txt"; 
local prov1 "`in_data'/treatmentcodematch/provxwalk_3-21.dta";
local prov2 "`in_data'/treatmentcodematch/prov_xwalkgaps_25_Aug_2015.dta" ;
local medicalservices_`planyear' "`in_data'/service_procedure_cwalk/`planyear'/rebuild/medicalservices`planyear'.csv";
local pharmacycopay "`in_data'/service_procedure_cwalk/`planyear'/rebuild/pharmacycopay`yplan'.csv";
local MODA_formulary`yplan' "`in_data'/formulary/MODA_July20`yplan'_Formulary.csv";
local Kaiser_formulary "`in_data'/formulary/KAISER_July2013_Formulary.csv" ;
local KaiserNDCxwalk "`in_data'/formulary/KaisermissingNDCxwalk.csv";
local plans 	"`in_data'/service_procedure_cwalk/plans.csv";
local acginputfile "`in_data'/acg/outputfiles/pieces/`planyear'/acginputfile`acg'.dta";	

/******** Conditions are set: data work begins here ******************** 							*/;
/*2. Creating the plan choice by entity file - a.k.a. What plans are in each choice set?			*/;
/* 	 Has all plan options (coded as "joint") available to each emp based on their choice set		*/; 
use `entityplaninfo', clear; /* specified at top of .do file */;
	display _N; // 33424; 
	keep if planyear==`planyear';
	if `acg' == 0 {;
		drop if entitynum=="" & empid=="" & memid==. ;
	};
	display _N; 
	duplicates drop;
	sort planyear;
save `out_data'/`claimyear'/planselection_entity`acgbase'`runtype'`yplan'.dta, replace;
local planselection_entity`yplan' "`out_data'/`claimyear'/planselection_entity`acgbase'`runtype'`yplan'.dta";
 
* Assigning all possible plans in the choice set (district) to each bene */;
* Read in eligibility data ; 
* Sample selection ; 
use `elig_data' ; 
	gen planyear = 2008 if eligmo_date >= mdy(10,1,2008) & eligmo_date <=mdy(9,30,2009);
	replace planyear = 2009 if eligmo_date >= mdy(10,1,2009) & eligmo_date <=mdy(9,30,2010);
	replace planyear = 2010 if eligmo_date >= mdy(10,1,2010) & eligmo_date <=mdy(9,30,2011);
	replace planyear = 2011 if eligmo_date >= mdy(10,1,2011) & eligmo_date <=mdy(9,30,2012);
	replace planyear = 2012 if eligmo_date >= mdy(10,1,2012) & eligmo_date <=mdy(9,30,2013); 
	replace planyear = 2013 if eligmo_date >= mdy(10,1,2013) & eligmo_date <=mdy(9,30,2014); 
	replace planyear = 2014 if eligmo_date >= mdy(10,1,2014) & eligmo_date <=mdy(9,30,2015);
	
	gen month = month(eligmo_date) ; 
	gen year = year(eligmo_date) ; 

	replace plan = trim(plan) ; 
	drop if substr(plan,1,3) == "OPT" ; 
	drop if substr(plan,1,2) == "NE" ; 
	drop if substr(plan,1,1) == "~" ; 
	
	* drop months in which beneficiary is retired or covered by COBRA ;
	gen empfirst=substr(empid, 1, 1);
	drop if empfirst=="R"; // retirees;
	drop if empfirst=="B"; // cobra;

	cap drop counter ; 
	gen counter = 1 ; 

	keep if planyear == `planyear' ;
	egen months_elig = sum(counter), by (personid) ;
	keep if months_elig == 12 ;
	drop months_elig ; 
	keep if planyear == `planyear' ;
	
	*** Some people aren't switching plans in October - if we are using that as our planyear cut off then we are going to have them in multiple plans in the same year, which is messy ; 
	*** in a perfect world we would have some differential planyear for entities that select for September, but it's such a small proportion that for now that I'm just dropping them ; 
	
	preserve ; 
		keep personidIE plan ; 
		duplicates drop ; 
		cap drop counter ;
		gen counter = 1 ; 
		egen dups = sum(counter), by(personidIE); 
		drop plan ; 
		duplicates drop ;
		tempfile multiplan ; 
		save `multiplan' ; 	
	restore ; 
	merge m:1 personidIE using `multiplan' ;
	assert _merge == 3 ; 
	drop _merge ; 
	drop if dups !=1; 
	drop dups ; 
	
	*** Some people are also covered by multiple plans - e.g. spouses covering each other or a child being covered by both parents. We don't want to try to analyse this because it's a complicated choice allowed by the ; 
	*** subsidies familyid is the subscriber ID, and the personidIE variable is unique to person, it doesn't have subscriber info in it, so if 1 personidIE has multiple familyid's then this person is covered by multiple policies; 
	*** and we want to drop them ; 
	preserve ; 
		keep personidIE familyid ; 
		duplicates drop ; 
		cap drop counter ;
		isid(personidIE familyid); 
		gen counter = 1 ; 
		egen dups = sum(counter), by(personidIE); 
		drop familyid ; 
		duplicates drop ; 
		tempfile multicover ; 
		save `multicover' ; 	
	restore ; 
	merge m:1 personidIE using `multicover' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	drop if dups !=1; 
	drop dups ; 
	* one observation per person - keep beginning of coverage month ; 
	keep if month==10 ; 
	keep if planyear == `planyear' ; 
	isid(personid) ; 
	
* Unmask entities ;
	* there are 4 entitynum values that have letters in them, but unmask.do treats entitynum numerically ;
	* these 4 entities are not involved in unmask, so patching around here ;
	replace entitynum = "0001" if substr(entitynum,1,4) == "S041";
	replace entitynum = "0002" if substr(entitynum,1,4) == "S399";
	replace entitynum = "0003" if substr(entitynum,1,4) == "U017";
	replace entitynum = "0004" if substr(entitynum,1,4) == "U018";
	replace entitynum = "0020" if entitynum == "00020"; 
	replace entitynum = "0020" if entitynum == "20"; 
	destring entitynum, replace;
	quietly do `macros'/unmask.do; 
	tostring entitynum, replace;
	replace entitynum = "S041" if entitynum == "0001" ;
	replace entitynum = "S399" if entitynum == "0002" ;
	replace entitynum = "U017" if entitynum == "0003" ;
	replace entitynum = "U018" if entitynum == "0004" ;
	
	keep if planyear == `planyear';
	
	* drop 5000 level entities ;
	*tostring entitynum, gen (entstring);
	gen entfirst=substr(entitynum, 1, 1);
	drop if entitynum=="7777"; // self-pay retirees, dropping;
	* running families ; 
	if `acg' == 1 {;
		* they need to be an individual, and be the policy holder for themselves ; 
		replace tiercd = "EMP" ; 
		drop familyid ; 
		gen familyid = personid ;
	} ;

* clean up tier variables etc. extract necessary code from below ;
**********************************************************************;

 // These two locals right below are set in the shell file.  ;
if `justdrug'==0 { ;
if `runfull'==1 { ;
	bys personid: egen eligstrt = min(eligmo_date);
	format eligstrt %d;
	
	gen planname = substr(plan, 1, 5);
	gen planfirst=substr(planname,1,1);
	
	gen drugplanname = substr(drugplan, 1, 4);
	replace drugplanname = trim(drugplanname) ; 
	
	* this was a mess before, using claimyear, not planyear, and with wrong treatment of the OMED to MMED ; 
	* transition ; 
	
if `planyear'==2012 { ;
	replace drugplanname ="ORXB" if planfirst=="O" & planname!="OMED9"; 
	// In 2012 there were no longer three diffeerent drug plans to choose from for ODS or 2 for Kaiser.  ;
	replace drugplanname ="KRX1" if planfirst=="K";
	} ;

if `planyear'==2013 { ;
	replace drugplanname ="MMED" if planfirst=="M" ;
	replace drugplanname ="KRX1" if planfirst=="K";
	} ;
		
if `planyear' < 2013 { ;
	replace drugplanname="OMED9" if drugplanname=="NE" & planname=="OMED9" & planfirst == "O";
	assert planfirst != "M" ; 
	
	replace drugplanname="ORXB" if drugplanname=="ORXA" & planyear>2011 & planfirst == "O"; 
	// We only want one name for 2012 - this is more or less a failsafe.  ;
	replace drugplanname="ORXB" if drugplanname=="NE" & planyear>2011 & planfirst == "O"; 
	// Same as above.  ;

	gen tag=1 if drugplanname =="NE";
	replace tag=0 if tag==.;
	bys personid: egen mintag=min(tag); 
	// We want to make sure that no personid has all bad drugplan names.  ;
	assert mintag==0; 
	drop if tag==1; drop mintag tag; 	
} ;
	drop if medcov==0;
	rename planname chosenplan;
	rename drugplanname chosendrgplan;
	gen tier = 1 if tiercd == "EMP"; // employee;
	replace tier = 2 if tiercd == "ESP"; // employee spouse;
	replace tier = 3 if tiercd == "ECH"; // employee child;
	replace tier = 4 if tiercd == "FAM"; // family;

	keep personid*  eligmo_date planyear familyid entitynum chosenplan chosendrgplan eligstrt tier memid empid sex age_yr ; 
	duplicates drop;
	
	// Let's inspect the tier variable, and then give everybody in the same family the same tier variable value.  ;
	* this seems like a good idea, but only effects 2 observations - what's unique about them?; 
	bys familyid: egen maxtier=max(tier);
	gen tag1=1 if maxtier !=tier;
	
	egen tag=count(tag1);
	assert tag <10;
	count if maxtier !=tier;
	replace tier=maxtier if maxtier !=tier;
	drop tag*  maxtier;
	preserve ; 
		keep personid* ;
		duplicates drop personidIE, force ; 
		// Force here means that we allow some people to be dropped even if we are missing information. All we want is a personid list basically. ;
		tempfile personid_xwalk`yplan' ; 
		save `personid_xwalk`yplan'', replace ;
	restore ; 
	preserve ; 
		keep personid personidIE planyear chosenplan chosendrgplan age_yr sex ; 
		duplicates drop ; 
		isid(personid planyear chosenplan) ; 
		tempfile chosenplans ; 
		save `chosenplans' ; 
	restore ; 	
	drop age* ; 
	drop sex ; 
	display "`planselection_entity`yplan''";
	if `acg' == 0{;
		joinby entitynum memid empid using `planselection_entity`yplan'', unmatched(both); // this file contains the employees choice set ;
	};
	
	if `acg' == 1 {;
		joinby planyear using `planselection_entity`yplan'', unmatched(both); // this file contains the employees choice set ;
	};
	
	drop if personid == "";
	* in what situation would someone not be matched here? ; 
	* if they are in a masked entity ; 
	* this would be done better by dropping masked from the master and asserting all matches ; 
	drop if _merge==2;
	gen entfirst=substr(entitynum, 1, 1);
	drop if entfirst=="5" & _merge==1;
	assert _merge !=1;
	keep if _merge==3;  drop _merge;
	
	cap drop planfirst ; 
	gen planfirst=substr(plan, 1, 1);
	gen drugplanfirst=substr(rxplan, 1, 1);
	gen chosen =.;
	replace chosen=1 if chosenplan==plan & chosendrgplan==rxplan & `planyear' < 2012;
	replace chosen=1 if chosenplan==plan & `planyear' > 2011;
	replace chosen=0 if chosen==.;	
	
	if "`acgbase'" == "base" {;
	bys personid entitynum memid empid: egen countchosen = sum(chosen);
	tab countchosen;
	assert countchosen < 2; drop countchosen;
	} ;
	assert chosenplan=="OMED9" if  chosendrgplan=="OMED9";
	rename rxplan drugplan;

	drop entfirst; 
	/*tostring entitynum, gen (entstring)*/;
	gen entfirst=substr(entitynum, 1, 1);
	if `acg'==0 { ;	
		merge m:1 personid familyid using $directory/data/built/sample/sample_`runtype'_`planyear'_`sampledate'.dta, keepusing(personid familyid) ;
	assert _merge != 2 ; 
	keep if _merge == 3 ; 
	drop _merge ; 
	} ; 
	* For ACG we run a perfect forecast - e.g. what are costs in 2009 for 2009 claims, but we require the PB sample because we needed prior year ; 
	* Claims and eligibility to create ACG score ; 
	if `acg'==1 { ;	
		merge m:1 personid using $directory/data/built/sample/sample_PB_`planyear'_`sampledate'.dta, keepusing(personid) ;


	assert _merge != 2 ; 
	keep if _merge == 3 ; 
	drop _merge ; 
	} ;  
	if `acg'==0 { ;		
		save `out_data'/`claimyear'/bene_PLANS_`runtype'_acg`acg'_`yplan'.dta, replace;
	} ;

	if `acg'==1 { ;
		save `out_data'/`claimyear'/bene_PLANS${unit}${cells}_`runtype'_acg`acg'_`yplan'.dta, replace;
	} ;
	
******************************************************************************************************************************* ;
* Read in claims data ; 
use `facility', clear ; 
	append using `professional' ; 
	drop if allowedamt < 0 ; 
	assert planyear!=. ;
	keep if  planyear == `claimyear';
	
	gen lastsrvcdt2 = date(lastsrvcdt, "MDY") ; 
	format lastsrvcdt2 %td ; 
	drop lastsrvcdt ; 
	rename lastsrvcdt2 lastsrvcdt ;
	
	if "`acgbase'" == "acg"	{ ;
		drop familyid ; 
		gen familyid = personid ; 
	} ;

	if `acg'==0 { ;	
	merge m:1 personid familyid using $directory/data/built/sample/sample_`runtype'_`planyear'_`sampledate'.dta, keepusing(personid familyid anymed) ;

	assert _merge == 3 if anymed == 1 ; 
	assert _merge == 2 if anymed == 0 ;
	assert anymed == 1 if _merge == 3; 
	assert anymed == 0 if _merge == 2;

	keep if _merge == 3 ; 
	drop _merge ; 
	drop anymed ; 
	} ; 

	if `acg'==1 { ;	
	merge m:1 personid using $directory/data/built/sample/sample_PB_`planyear'_`sampledate'.dta, keepusing(personid) ;
	* we can't assert having claims here because the sample & anymed indicator are PB but the claims are PF ; 
	keep if _merge == 3 ; 
	drop _merge ; 
	
	} ; 
	preserve ; 
		keep personidIE plan ; 
		duplicates drop ; 
		cap drop counter ; 
		gen counter = 1 ; 
		egen dups = sum(counter), by(personidIE); 
		drop plan ; 
		duplicates drop ; 
		tempfile multiplan2 ; 
		save `multiplan2' ; 	
	restore ; 
	merge m:1 personidIE using `multiplan2' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	assert dups == 1 ; 
	drop dups ; 

	merge m:1 personid personidIE using `chosenplans' ; 

	keep if _merge == 3 ; 
	drop _merge ; 
	drop counter age_yr sex ; 
	* This is only relevant if we are doing perfect forecast. Otherwise the chosenplan variable is from plan year and plan is from claim year (plan year - 1) ; 
	assert chosenplan == plan if "`runtype'" == "PF" ; 
	save `out_data'/`claimyear'/bene_CLAIMS${unit}${cells}_`runtype'_acg`acg'_`yplan'.dta, replace ; 
	
} ;

	if `acg'==0 { ;
		local bene_allplans`yplan' "`out_data'/`claimyear'/bene_PLANS_`runtype'_acg`acg'_`yplan'.dta";
	} ;
	if `acg'==1 { ;
		local   bene_allplans`yplan' "`out_data'/`claimyear'/bene_PLANS${unit}${cells}_`runtype'_acg`acg'_`yplan'.dta";
	} ;
	local bene_allclaims`yplan' "`out_data'/`claimyear'/bene_CLAIMS${unit}${cells}_`runtype'_acg`acg'_`yplan'.dta";
	display "`bene_allplans`yplan''";
	display "`bene_allclaims`yplan''";

/******************************************************************************************************** 
this is where we merge in procedure service.  This is where we merge in new spreadsheet with type of service and 
new spreadsheet with type of service and service id with all years. Year is a macro  
   1) we get ODS codes ready to merge into the claim data by TOS
   2) we get KAISER codes ready to merge into the claim data by claimid
   3) we get PROVIDENCE codes ready to merge into the claim data by claimid 
******************************************************** 1) ODS ********************************************************/ ; 

insheet using `in_data'/service_procedure_cwalk/`planyear'/rebuild/treatmentcodematch`yplan'ods.csv, names clear;
	keep tos serviceid ;
tempfile TOS`yplan';
save `TOS`yplan'';

/******************************************************** 2) KAISER  ********************************************************/; 
/********************************************* adding in kaiser codes *********************************************/; 
insheet using `kaiser_orig', delimit (" ") names clear ; 

		keep claimid v2 v3 v4;
		drop if _n==1;
		display _N; 
		egen INSSVCCLASSCD = concat(v2 v3), punct(" "); 
		egen code2 = concat(v3 v4) if v2=="", punct(" "); 
		replace INSSVCCLASSCD=code2 if v2=="";
		keep claimid INSSVCCLASSCD;

		duplicates drop claimid INSSVCCLASSCD, force; // 649360 obs deleted;
		bys claimid: gen dup=_N;

		* hand checked the duplicates and only occured 10 times, so picked one to drop; 
		drop if dup==2 & INSSVCCLASSCD==""; 
		drop dup ; 
		bys claimid: gen dup=_N; 
		drop if dup==2 & INSSVCCLASSCD=="PSC LPP"; 
		cap drop dup;
		bys claimid: gen dup=_N;
		assert dup==1;
		keep claimid INSSVCCLASSCD;
		rename INSSVCCLASSCD kaisercode;
		mdesc ; 
		drop if kaisercode==""; // spoke with Tina from truven about this.  She said that it was blank in the data;
		display _N; // 487588;
		replace claimid = trim(claimid) ; 
				
	tempfile kaiser1`yplan';
	save `kaiser1`yplan''; // connects claim to code;

/********************************************* adding in kaiser service id xwalk *********************************************/; 
insheet using `in_data'/service_procedure_cwalk/`planyear'/rebuild/treatmentcodematch`yplan'kaiser.csv, names clear;
	rename code kaisercode;
	rename description servicedesc;
	cap drop servicename;
	cap drop v*;
	***cap drop if _n==1;
	cap drop if kaisercode=="" & servicedesc=="";
	list kaisercode if serviceid=="";
	* the blank serviceids are because there were no claims under that code; 
	replace kaisercode = trim(kaisercode) ; 
	drop servicedesc ; 
	tempfile kaiser2`yplan';
save `kaiser2`yplan''; // connects code to service id; 

/********************************************* working with Kaiser xwalk to  *********************************************/; 

if `claimyear'>2009{ ;

	insheet using `kaiserxwalk2', nonames clear ; 
	foreach var of varlist _all { ;
		ren `var' `=`var'[1]' ;
	} ;
	drop in 1 ;
	rename claimnum claimid ;
	rename inssvcclass kaisercode ;
	rename proccode procedure ;
	rename revcode revenuecd ;
	drop lineitem firstdos lastdos paiddate ;
	
	replace procedure = trim(procedure) ;
	replace kaisercode = trim(kaisercode) ;
	replace claimid = trim(claimid) ;
	replace revenuecd = trim(revenuecd) ;
	
	destring allowedamt, replace ignore("$,") ;
	
	duplicates drop ; 
	
	tempfile kxwalk2; 
	save `kxwalk2';
	
	use `kaiserxwalk', clear; 
		gen file = 1 ; 
		append using `kxwalk2' ; 
		replace file = 2 if file == . ; 
		egen max_file = max(file), by(claimid kaisercode procedure revenuecd allowedamt) ; 
		drop if file != max_file ; 
		drop file max_file ; 
		
		replace kaisercode = trim(kaisercode) ;
		drop if kaisercode == "UNKNOWN" ;
				
		replace procedure = "~" if procedure == "" ; 
		replace revenuecd = "~" if revenuecd == "" ; 
		drop if kaisercode == "" ; 
	
		duplicates drop ;
		cap drop counter ;
		gen counter = 1 ; 
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ; 

		drop if dups == 4 & kaisercode != "PHOP MH" ;
		drop if dups == 3 & kaisercode == "PHOP OTH" ;
		drop if dups == 3 & kaisercode == "PSC LPP" ;
				
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ; 
		drop if dups == 2 & kaisercode == "PHOP OTH" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ; 
		drop if dups == 2 & kaisercode == "PSC ERF" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ; 
		drop if dups == 2 & kaisercode == "PSC CVF" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ; 
		drop if dups == 2 & kaisercode == "PSC LPP" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ; 
		drop if dups == 2 & kaisercode == "PSC RAP" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PSC THP" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PSC UCP" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PSC UCP" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PSC CRP" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPOVM MH" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPOVM PE" ;
				
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPOVM MM" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPOVM MM" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPOPS OF" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPOPS OF" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PH OTHER" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PPIPV R" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PHOPM ND" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PHOP MH" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PHIP S" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		drop if dups == 2 & kaisercode == "PHOP S" ;
		
		drop dups ;
		egen dups = sum(counter), by(claimid allowedamt revenuecd procedure) ;
		
		assert dups == 1 ;
		
		preserve ;
		drop allowedamt revenuecd procedure dups counter ;
		duplicates drop ;
		bys claimid: gen count=_N ;

		tab count ;
		tempfile a ;
		save `a' ;
		restore ;

	merge m:1 claimid kaisercode using `a' ;
	assert _merge==3; drop _merge ;

		preserve ;
		keep if count==1 ;
		drop allowedamt revenuecd procedure count counter dups ;
		duplicates drop ;
		replace claimid = trim(claimid) ;
		tempfile kaisercount1`yplan' ;
		save `kaisercount1`yplan'' ;
		restore ;

	keep if count!=1 ;
	drop count counter dups ;

	duplicates drop;
	isid (claimid allowedamt revenuecd procedure) ; 
	replace claimid = trim(claimid) ;
	replace procedure = trim(procedure) ;
	replace revenuecd = trim(revenuecd) ;
	tempfile kaisercount2`yplan';
	save `kaisercount2`yplan'';
} ;

/******************************************************** 3) Providence codes ********************************************************/; 
if `planyear' < 2012 { ;
		insheet using `in_data'/service_procedure_cwalk/`planyear'/rebuild/treatmentcodematch`yplan'prov.csv, names clear;
			cap drop srvc_desc ; 
			cap drop v8 v9;
			drop if provid=="";
			keep provid srvc_id serviceid ;  
			tempfile prov2`yplan';
		save `prov2`yplan''; 
	} ;
/****************************************************************************************************************************/; 
/******************************************************** merging in ********************************************************/; 
/****************************************************************************************************************************/; 
display "`bene_allclaims`yplan''";
use `bene_allclaims`yplan'', clear; /* made in this do file */;
	gen chosenplanfirst=substr(plan,1,1);
tempfile working;
save `working';
/*------ODS------*/;
		keep if (chosenplanfirst=="O" | chosenplanfirst=="M");
		duplicates drop;

		replace claimid = trim(claimid)  ;	
		preserve ;
			use `ods_tos1', clear ; 
			append using `ods_tos2' ;
			append using `ods_tos3' ;
			append using `ods_tos4' ;
			
			drop counter dups ; 
			replace claimid = trim(claimid) ;
			duplicates drop;
			drop tos_desc svc_desc requestmerge svc_rule ; 
			gen counter = 1 ; 
			egen dups = sum(counter), by(claimid linenum) ; 
			drop if dups == 2 & covtypcd == . ; 
			drop dups counter covtypcd ; 
			duplicates drop ; 
			isid claimid linenum ; 
			tempfile odstosall;
			save `odstosall';
		restore ;
		
		replace claimid = trim(claimid) ;
		merge m:1 claimid linenum using `odstosall';
		
		assert _merge != 1 ; 
		* Merge = 2 here are observations in our claims --> tos crosswalk for other years ; 
		* so long as merge != 1 here, we do not lose any claims because of this merge ; 
		drop if _merge==2;

		egen mode_tos = mode(tos) ;
		replace tos = mode_tos if tos == "" ; 
		drop mode_tos ; 

		rename _merge mergetos;
		merge m:1 tos using `TOS`yplan'';
			
		assert _merge!=1; 
		* merge == 1 means we do not have a serviceID (our variable) for the TOS. We should have one for every value of TOS, hence the assert  ; 
		* merge == 2 means that we have an observation for serviceID for a TOS that doesn't show up in claims. This is fine. ; 
		keep if _merge==3; 
		drop _merge ;
		tempfile ods`yplan';
	save `ods`yplan'';
	
/*------Kaiser------*/;
	use `working', clear;
	/* merge in kaiser by claim id */;
		keep if chosenplanfirst=="K";
		duplicates drop; 
		
	if `claimyear'>2009{ ;
	
		replace claimid = trim(claimid) ;
		replace procedure = trim(procedure) ;
		replace revenuecd = trim(revenuecd) ;
	
		replace procedure = "~" if procedure == "" ; 
		replace revenuecd = "~" if revenuecd == "" ; 
	
		merge m:1 claimid procedure allowedamt revenuecd using `kaisercount2`yplan'', keep(1 3); 
		preserve ;
		keep if _merge==3;
		rename _merge mergekaiser2;
		tempfile count2;
		save `count2';
		restore ;
		drop if _merge==3 ; 
		assert _merge==1 ; 
		drop kaisercode-_merge ;
		merge m:1 claimid using `kaisercount1`yplan'', keep(1 3); 
		drop if _merge==2; 
		rename _merge mergekaiser1;
		append using `count2';
		replace kaisercode = trim(kaisercode) ; 

		egen mode_k = mode(kaisercode) ;
		replace kaisercode = mode_k if kaisercode == "" ; 
		drop mode_k ; 

		merge m:1 kaisercode using `kaiser2`yplan'', keep(1 3) ; // merging in the treatmentcodematch info;
		drop if _merge==2 ; 
		assert _merge==3 ;
		rename _merge mergekaiser ; 
	} ;	

	
	if `claimyear'<2010{ ;
		merge m:1 claimid using `kaiser1`yplan'';
		tab _merge;
		drop if _merge==2; 
		rename _merge mergekaiser;

		egen mode_k = mode(kaisercode) ;
		replace kaisercode = mode_k if kaisercode == "" ; 
		drop mode_k ; 
		
		merge m:1 kaisercode using `kaiser2`yplan'';
		tab _merge;
		drop if _merge==2 ; 
		assert _merge==3 ;
		rename _merge mergekaiser2 ; 
	} ;

		*merging in specialist codes;
		gen prov=trim(providerid);
		drop providerid;
		rename prov providerid;
		
		merge m:1 providerid using `in_data'/service_procedure_cwalk/PPOVMOHV_ProviderSpecialties.dta, keep (1 3);
		drop _merge;
		
		replace serviceid = "S502" if specialist == 1 & serviceid == "S500" ; 
		replace serviceid = "S501" if specialist == 0 & serviceid == "S502" ; 
		replace serviceid = "S502" if specialist == 1 & serviceid == "S501" & `planyear' == 2008 ; 
		replace serviceid = "S111" if specialist == 1 & serviceid == "S101" ; 
		replace serviceid = "S101" if specialist == 0 & serviceid == "S111" ; 

		*** Modifying claims within select Kaiser codes based on procedure codes ;
		*** Make sure setting prev = 1 actually makes these cost 0 ;
		replace procedure = trim(procedure) ;
		replace serviceid = "S312" if serviceid == "S599" & inlist(procedure,"92504","92511") ;
		replace serviceid = "S430" if serviceid == "S599" & inlist(procedure,"96101","96155") ;
		replace serviceid = "S440" if serviceid == "S599" & inlist(procedure,"76512","92317","92070") ;
		replace serviceid = "S502" if serviceid == "S599" & inlist(procedure,"90901","95971","97802","97803","97804","99024","99195","99211","99212") ;
		replace serviceid = "S502" if serviceid == "S551" & inlist(procedure,"96372","97802","97803","97804","99024") ;
		replace serviceid = "S502" if serviceid == "S599" & inlist(procedure,"92526","92610","92611","96150","96151","96152","96153","96154","96154") ;
		replace serviceid = "S551" if serviceid == "S599" & inlist(procedure,"96360","96372","96374","96912") ;
		replace serviceid = "S640" if serviceid == "S599" & inlist(procedure,"96365","96900","96910") ;
		replace serviceid = "S670" if serviceid == "S599" & inlist(procedure,"95805","95810","95811") ;
		replace serviceid = "S680" if serviceid == "S599" & inlist(procedure,"96111","96374","96912") ;

		replace serviceid = "S239" if serviceid == "S900" & inlist(procedure,"H0005") ;
		replace serviceid = "S580" if serviceid == "S900" & inlist(procedure,"98961","98962","96040") ;
		replace serviceid = "S681" if serviceid == "S900" & inlist(procedure,"97762") ;
		replace serviceid = "S671" if serviceid == "S900" & inlist(procedure,"G0399") ;	
				
		if `claimyear'==2011{ ;
			*** 1) Labs ; 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"80061","82274","82746","82950","83550","83896","83903","83908","83912") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"84153","84163","86038","86580","86703","87040","87045","87046","87340") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"87491","87621","88141","88342","88312","88175","88174","88399","88386"); 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"82677","88347","88331","90384","P9016","P9040","Q0091","88313","88309"); 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"88275","88262","88237","88185","88173","87902","87901","87640","87591"); 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"87536","87522","87497","87449","87209","87107","87106","87075","86849"); 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"86817","86800","86790","86780","86710","86696","86665","86658","86645"); 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"86618","86617","86341","86334","86235","86225","86146","85520","85307"); 
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"83914","83919","83970","84154","84305","84586","85230","85245","85306");
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"83909","83905","83904","83789","83664","83655","83630","83527","83021");
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"83010","83018","82951","82785","82677","82672","82668","82525","82507");
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"82491","82140","82103","82088","82024","82017","81220","81213","80299");
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"80201","80202","80200","80197","80182","","","","");
		};
		
		if `claimyear'==2012{;
			*** 1) Labs ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"80051","80102","82248") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"82274","82491","82950","83516","83540","83690","84153","84163","84165") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"86038","86235","86580","86703","86900","86901","87040","87045","87046") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"87389","87449","87621","88141","88174","88175","88141","88342","88312") ;
		};
			
		if `claimyear'==2013{ ;
			*** 1) Labs ; 
			*** why are we incorrectly 0 so often? ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"36415","80061","80102","82248","82274","82306","82491","82670","82950") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"83002","83540","83615","83690","83921","84153","84163","84165","86038") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"80061","86200","86225","86255","86580","86696","86704","86747","86803") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"87389","87491","87449","87591","86592","87621","88141","88142","88173") ;
			replace prev = 1 if serviceid == "S671" & inlist(procedure,"88174","88312","G0103","86901","86900") ;
		} ;
		*** 2) Imaging ; 
		replace prev = 1 if serviceid == "S661" & inlist(procedure, "G0202","71275","77002","77051","77052","77057","93010","Q9965","Q9967") ;
		
		*** 3) Prenatal ; 
		replace prev = 1 if inlist(procedure,"0500F", "0502F") ;
		
		*** 4) Outpatient surgery ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"11406","11423","11442","11462","14020","14060","19125","19300","19301") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"19325","19380","20670","23700","24358","24359","24635","25111","25390") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"25440","25447","26160","26567","27814","28072","28118","28285","28445") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"28515","29806","29822","29825","29827","29870","29879","29880","29888") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"31255","31267","31288","33212","36475","36478","37183","38525","41112") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"41112","42825","42830","43262","44377","45990","46020","47563","51600") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"52204","52224","52601","54161","54163","57288","58353","58561","58563") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"58565","59320","59820","60280","64622","64718","65426","65435","65756") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"67917","68815","69424","69610","69620","69631","78195","85025","88106") ;
		replace prev = 1 if serviceid == "S210" & inlist(procedure,"88185","92960","93508","97001","99218","C1884","G0260") ;
		
		replace serviceid = "S312" if serviceid == "S210" & inlist(procedure,"59841","62311","77414","77785","90471") ;
		
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"99396","99395","97110","88305","88142","88141","88173","88305","88307") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"90716","90734","90736","94060","99070","J0585","P9021","11101","11641") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"62311","56501","51701","45385","45378","43239","43235","29425","29125") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"99397","99393","99392","99386","99385","99384","99383","99215","92014") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"92004","90669","88112","86850","85379","84153","76942","69200","68115") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"67840","67800","67515","67228","67210","67145","65222","64721","64626") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"64612","64493","64490","64483","64455","64450","64435","62310","62270") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"62264","58340","57522","57061","56820","56605","52332","51741","51729") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"51726","51725","46320","46083","43760","41100","40808","38221","36569") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"36470","31579","31505","29705","29405","29105","29086","29075","29065") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"28470","28400","27824","27501","26725","26605","25630","25500","25075") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"24650","23500","21931","21556","20610","20526","17280","17250","17108") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"17107","16020","15576","14060","13101","12052","12046","12044","12034") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"12032","12020","12002","11740","11604","11603","11601","11420","11403") ;
		replace prev = 1 if serviceid == "S312" & inlist(procedure,"11311","11201","11055","10061","10040") ;
		
		*** 5) Assorted fixed by procedure code ; 
		replace prev = 1 if serviceid == "S440" & inlist(procedure,"92310") ;
		
		replace prev = 1 if (serviceid == "S500" | serviceid == "S501" | serviceid == "S502") & (substr(procedure,1,1)=="2" | substr(procedure,1,1)=="5"| substr(procedure,1,1)=="7"| substr(procedure,1,1)=="8"| substr(procedure,1,1)=="V") ;
		replace prev = 1 if (serviceid == "S500" | serviceid == "S501" | serviceid == "S502") & inlist(procedure,"90632","90669","90675","90707","90713","90716","90744","90746","98966") ;
		replace prev = 1 if (serviceid == "S500" | serviceid == "S501" | serviceid == "S502") & inlist(procedure,"98967","98968","99071","99211","P9021","90734","90716","90660","90691") ;
		replace prev = 1 if (serviceid == "S500" | serviceid == "S501" | serviceid == "S502") & inlist(procedure,"90384","90471","90723","90649","90648","90738","90747","96040","96152") ;
		replace prev = 1 if (serviceid == "S500" | serviceid == "S501" | serviceid == "S502") & inlist(procedure,"96365","96375","99499","A4500","E0603","E0607","J1950","90371") ;
		
		/* fixing DME copays. kaisercode=="PPO DME"*/;
		replace origcoin=origcopay if kaisercode=="PPO DME";
		replace origcopay=0 if kaisercode=="PPO DME";
	
		/* fixing hearing aids */;
		replace origcoin=origcopay if kaisercode=="PHIP SNF";
		replace origcopay=0 if kaisercode=="PHIP SNF" ;
		
		tempfile kaiser`yplan';
		save `kaiser`yplan'';

/*------Providence------*/;
if `planyear' < 2012 { ;

use `prov2' ; 
	drop paiddt first last; 	
	gen package = 2 ; 
	append using `prov1' ;
	replace package = 1 if package == . ; 
	
	drop if srvc_id == "" ;
	drop srvcrule_desc srvc_desc;	
	duplicates drop ; 
	sort claimid linenum ; 
	cap drop counter ; 	
	
	gen counter = 1 ; 
	egen dups = sum(counter) , by (claimid linenum) ;
	drop if report_cat == "" & dups > 1 ;
	
	drop counter dups ; 
	duplicates drop ; 
	egen max_pack = max(package), by(claimid linenum) ; 
	keep if package == max_pack ; 

	drop package max_pack ; 
	duplicates drop ; 
	
	isid claimid linenum ; 	
	
tempfile provall ; 
save `provall' ; 

use `working', clear;
	preserve ;
		keep if chosenplanfirst=="P";
		duplicates drop;
		merge m:1 claimid linenum using `provall', keep(1 3);  // prov1 is coming from provclaimsxwalk.do;
		rename _merge mergeprov;
		rename report_cat provid;			
		mdesc provid srvc_id ; 	
		replace srvc_id = "OVIM" if srvc_id == "(*)" ;
		replace provid = "DRG" if srvc_id == "*RG" ;

		egen mode_p = mode(provid) ;
		gen test_s = srvc_id if provid == mode_p ; 
		replace test_s = "" if provid != mode_p ; 
		egen mode_s = mode(test_s) ;
		replace provid = mode_p if provid == "" ;
		replace srvc_id = mode_s if srvc_id == "" ;
		drop mode_s ; 
		merge m:1 provid srvc_id using `prov2`yplan'', keep (1 3);
		assert provid=="" if _merge==1; 


		keep if _merge==3;	
		drop _merge;
		drop if substr(srvcrule,1,1) == "D" ; 
		
		replace network=0 if provnetwork=="N";

		replace network=1 ;
		tab network ; 
		replace network=0 if ref_ind=="V";
		
		gen out=1 if srvcrule=="505" | srvcrule=="507";
		replace network=0 if out==1;
		
		* why are the vision claims below or provid 2J srvc_id SRIP out of network? b/c of the srvcrule 505 - not great ; 
		replace serviceid = "S101" if serviceid == "S102" & procedure == "1499" ;
		replace serviceid = "S430" if serviceid == "S301" & inlist(procedure, "90853","90870","90847") ;
		
		replace network = 1 if `planyear' == 2008 & origcoin == 0 & provid == "2H" & srvc_id == "VIS" ; 
		
		replace network = 0 if `planyear' == 2008 & origcoin != 0 & origcoin != . ; 
		replace network = 0 if `planyear' == 2009 & origcoin != 0 & origcoin != . ;
		replace network = 0 if `planyear' == 2010 & origcoin != 0 & origcoin != . ;
		replace network = 0 if `planyear' == 2011 & origcoin != 0 & origcoin != . & inlist(serviceid, "S430", "S500") ;
		
		gen obs_perc = origcoin / allowedamt ;
		gen obs_perc_rd = round(obs_perc,0.0001) ;
		
		replace network = 0 if `planyear' == 2011 & obs_perc_rd == 0.5000 ; 
		replace network = 0 if `planyear' == 2011 & obs_perc == 0.5 ;
		drop obs_perc obs_perc_rd ; 
		
		replace network = 1 if origcoin == 0 & origded == 0 & origded == 0 ; 
		
		* replace serviceid=1172 if srvcrule=="" & (origcopay !=0 | origcoin !=0 | origded !=0) & `planyear'==2011;

		tempfile prov`yplan';
		save `prov`yplan'';
	restore ;  
} ;
	
use `ods`yplan'', clear;
gen keep = 1 if tos != "";

append using `kaiser`yplan'';
replace keep = 1 if kaisercode != ""  ;

if `planyear' < 2012 { ;
	append using `prov`yplan''; 
} ; 

	cap replace keep = 1 if provid!= "" & srvc_id != "" ;
	replace keep = 0 if keep!=1;
	assert keep == 1 ; 
	drop merge* keep;

	replace network=1 if network==.; // making addition so we don't drop a ton of claims;
	
	drop plan planyear provnetwork chosenplanfirst ;
	cap drop ref_ind ;
	cap drop srvcrule ; 
	cap drop out ;
	cap drop specialtycodedescription ;
	
	cap drop treattypename ;
	duplicates drop ;
	compress ;

	di "`planyear'";
	
tempfile ip;
save `ip';

	use `bene_allplans`yplan'', clear; /* made in this do file */;	
		drop if chosenplan !="OMED9" & chosendrgplan=="OMED9";
		drop drugplan chosen;
		display _N;	
		keep personid* entitynum memid empid memid plan familyid eligstrt tier chosenplan chosendrgplan ;
		duplicates drop;
		gen chosen =(chosenplan == plan);
		bys personid: egen max_test=max(chosen);
		assert max_test==1;	
		drop max_test ; 
		tempfile allmedplan`yplan';
		save `allmedplan`yplan'';
		
use `ip', clear;	
	joinby personid using `allmedplan`yplan'', unmatched(both); /* made right above*/;  
	keep if _merge==3;
	drop _merge;

	* Everything in kaiser is in-network ; 
	replace network = 1 if substr(plan,1,1) == "K" ;
	
	/* Check that no claims  happened before the eligibility start date */;
	assert srvcdt >= eligstrt & srvcdt !=. & eligstrt !=. if "`runtype'"=="PF"; 
	assert srvcdt !=. & eligstrt !=. if "`runtype'"=="PB";
	
	if `claimyear' == 2011 | `claimyear' == 2012 {;
	gen ratio = origcoin / allowedamt ; 
	replace ratio = round(ratio, 0.1) ; 
	
	tab ratio network if plan == "OMED4" & chosen == 1 ; 
	replace network = 0 if network == 1 & ratio == float(0.5) & plan == "OMED4" ;
	replace network = 1 if network == 0 & ratio == float(0.2) & plan == "OMED4" ;
	tab ratio network if plan == "OMED4" & chosen == 1 ;
};

preserve ; /* getting medical services 411 ready for a merge with working data set */;
display "`medicalservices_`planyear''";
insheet using `medicalservices_`planyear'', clear; /* specified at top of .do file */;
keep plan network serviceid copay coinsurance na acs by_day;


notes coinsurance: these are from the medicalservices`planyear' file;
notes copay: these are from the medicalservices`planyear' file;
cap rename na NA;
replace NA=0 if NA==.;
duplicates drop;
rename coinsurance coinsuranceperc;


tempfile planinfo`yplan';
save `planinfo`yplan'';
restore ;

/* merging in medical services information */; 
	merge m:1 plan network serviceid using `planinfo`yplan'';
	assert _merge != 1 ;
	assert tos == "" if _merge == 1 ; 
	keep if _merge == 3;
	drop _merge;
	
/* secondary insurance: first 9 characters are the subscriber, last nine are the member -- DROPPING */;
if "`acgbase'" == "base" { ;
		gen subscriber=substr(personid, 1, 9) ;
		assert subscriber==familyid; 
		gen member=substr(personid, 15, 23) ;
		cap drop count ;
		preserve ;
			keep subscriber member personid ;
			duplicates drop ;
			bys member: gen count=_N ;
			keep count personid ;
			tempfile count ;
			save `count';
		restore ;
		merge m:1 personid using `count' ;
		assert _merge==3 ;
		tab count ;
		assert count==1 ;
		drop _merge ; 
	} ;
	drop if personid == "" ; 
	cap drop cat ;
	cap drop subcat ;
	cap drop subsubcat ;
	cap drop requestmerge ;
	cap drop tos_desc ;
	cap drop svc_rule ;
	cap drop svc_desc ; 
if `acg'==0 { ;
	save `out_data'/`claimyear'/bene_allclaim_plan_acg`acg'_`runtype'_`yplan'.dta, replace;
} ;

if `acg'==1 { ; 
	di `acg';
	save `out_data'/`claimyear'/bene${unit}${cells}_allclaim_plan_acg`acg'_`runtype'_`yplan'.dta, replace;
} ;
};
if `acg'==0 { ;
	local bene_allplans`yplan' "`out_data'/`claimyear'/bene_PLANS_`runtype'_acg`acg'_`yplan'.dta";
} ;
if `acg'==1 { ;
	local   bene_allplans`yplan' "`out_data'/`claimyear'/bene_PLANS${unit}${cells}_`runtype'_acg`acg'_`yplan'.dta";
} ;
local bene_allclaims`yplan' "`out_data'/`claimyear'/bene_CLAIMS${unit}${cells}_`runtype'_acg`acg'_`yplan'.dta";

display "`bene_allplans`yplan''";
display "`bene_allclaims`yplan''";

********************************************;
***DRUG CLAIMS******************************;
********************************************;
use `drug', clear; 
* Restricting to planyear ;
keep if planyear == `claimyear';
drop planyear network;

	if "`acgbase'" == "acg"	{ ;
		drop familyid ; 
		gen familyid = personid ; 
	} ;

	if `acg'==0 { ;	
		merge m:1 personid familyid using $directory/data/built/sample/sample_`runtype'_`planyear'_`sampledate'.dta, keepusing(personid familyid anydrug) ;
		
		assert _merge == 3 if anydrug == 1 ; 
		assert _merge == 2 if anydrug == 0 ;
		assert anydrug == 1 if _merge == 3; 
		assert anydrug == 0 if _merge == 2;

		keep if _merge == 3 ; 
		drop _merge ; 
		drop anydrug ; 
	} ; 
	if `acg'==1 { ;	
	merge m:1 personid using $directory/data/built/sample/sample_PB_`planyear'_`sampledate'.dta, keepusing(personid) ;
	* we can't assert having claims here because the sample & anydrug indicator are PB but the claims are PF ; 
		keep if _merge == 3 ; 
		drop _merge ; 
	} ; 


***************************ASSUMPTIONS: imposing restrictions on empty variables;
replace retail=1 if retail==.; // this is an assumption we are imposing--setting them to retail; 
*************************** secondary insurance - dropping;
/* secondary insurance calculation: first 9 characters are the subscriber, last nine are the member -- DROPPING */;
if `acg' == 0 {;
cap drop subscriber member; 
gen subscriber=substr(personid, 1, 9);
assert subscriber==familyid if personid!=""; // ATo2114M5oeohQATo2114M5;
gen member=substr(personid, 15, 23);
cap drop count;
	preserve ;
		keep subscriber member personid;
		drop if personid=="";
		duplicates drop;
		bys member: gen count=_N;
		keep count personid;
		
		tempfile count`yplan';
		save `count`yplan'';
	restore ;
	merge m:1 personid using `count`yplan'';
	assert _merge==3;
	drop _merge;
	tab count;

	* should be no double covered if sample select is consistent ; 
	assert count == 1 ; 
} ;
replace retail=1 if retail==.; 
*generic definition;
gen generic = 1 if drugtier == 1;
replace generic = 2 if drugtier == 2;
replace generic = 3 if drugtier == 3;
replace generic = 1 if drugtier == 4; * CB added - data dictionary calls 4 "Multisource generic", so calling it generic here ; 

gen drugclaim = 1;


if `planyear' == 2013 { ; 
label define generic 0 "Value" 1 "Generic" 2 "Brand  Name Formulary" 3 "Brand Non-Formulary"; 
*MODA ; 
replace generic = 0 if substr(plan,1,1) == "M" & origcopay== 0  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "M" & origcopay== 0  & dayssupply < 32 & (allowedamt != origcopay) ;
 
replace generic = 1 if substr(plan,1,1) == "M" & origcopay== 8  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "M" & origcopay== 8  & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "M" & origcopay== 24  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "M" & origcopay== 24  & (allowedamt != origcopay) ;

replace generic = 1 if substr(plan,1,1) == "M" & origcopay== 16 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "M" & origcopay== 16 & dayssupply > 31 & (allowedamt != origcopay) ;

*kaiser ; 
replace generic = 1 if substr(plan,1,1) == "K" & origcopay== 5  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "K" & origcopay== 5  & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "K" & origcopay== 25 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "K" & origcopay== 25 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "K" & origcopay== 10 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "K" & origcopay== 10 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "K" & origcopay== 50 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "K" & origcopay== 50 & (allowedamt != origcopay) ;
} ;

if `planyear'> 2009 & `planyear' < 2013 { ; 
label define generic 0 "Value" 1 "Generic" 2 "Brand  Name Formulary" 3 "Brand Non-Formulary"; 
*OMED ; 
replace generic = 0 if substr(plan,1,1) == "O" & origcopay== 4  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "O" & origcopay== 4  & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "O" & origcopay== 8  & dayssupply < 32 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "O" & origcopay== 8  & dayssupply < 32 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "O" & origcopay== 25 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "O" & origcopay== 25 & (allowedamt != origcopay) ;
replace generic = 0 if substr(plan,1,1) == "O" & origcopay== 8  & dayssupply > 31 & (allowedamt != origcopay) ;
replace retail =  0 if substr(plan,1,1) == "O" & origcopay== 8  & dayssupply > 31 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "O" & origcopay== 16 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "O" & origcopay== 16 & dayssupply > 31 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "O" & origcopay== 50 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "O" & origcopay== 50 & dayssupply > 31 & (allowedamt != origcopay) ;
*Providence ; 
replace generic = 0 if substr(plan,1,1) == "P" & origcopay== 4  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "P" & origcopay== 4  & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "P" & origcopay== 8  & dayssupply < 32 & (allowedamt != origcopay) ;

replace generic = 2 if substr(plan,1,1) == "P" & origcopay== 25 & (allowedamt != origcopay) ;

replace generic = 0 if substr(plan,1,1) == "P" & origcopay== 8  & dayssupply > 31 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "P" & origcopay== 8  & dayssupply > 31 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "P" & origcopay== 16 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "P" & origcopay== 16 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "P" & origcopay== 50 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "P" & origcopay== 50 & (allowedamt != origcopay) ;
*Kaiser ; 
replace generic = 1 if substr(plan,1,1) == "K" & origcopay== 5  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "K" & origcopay== 5  & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "K" & origcopay== 25 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "K" & origcopay== 25 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "K" & origcopay== 10 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "K" & origcopay== 10 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "K" & origcopay== 50 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "K" & origcopay== 50 & (allowedamt != origcopay) ;
} ;

if `planyear'< 2010{ ;
label define generic 1 "Generic" 2 "Brand  Name Formulary" 3 "Brand Non-Formulary"; 
* OMED;
replace generic = 1 if substr(plan,1,1) == "O" & origcopay== 5  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "O" & origcopay== 5  & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "O" & origcopay== 25 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "O" & origcopay== 25 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "O" & origcopay== 10 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "O" & origcopay== 10 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "O" & origcopay== 50 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "O" & origcopay== 50 & (allowedamt != origcopay) ;
 
*Providence ; 
replace generic = 1 if substr(plan,1,1) == "P" & origcopay== 5  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "P" & origcopay== 5  & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "P" & origcopay== 15 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "P" & origcopay== 15 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "P" & origcopay== 10 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "P" & origcopay== 10 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "P" & origcopay== 30 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "P" & origcopay== 30 & (allowedamt != origcopay) ;
*Kaiser ; 
replace generic = 1 if substr(plan,1,1) == "K" & origcopay== 5  & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "K" & origcopay== 5  & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "K" & origcopay== 15 & (allowedamt != origcopay) ;
replace retail  = 1 if substr(plan,1,1) == "K" & origcopay== 15 & (allowedamt != origcopay) ;
replace generic = 1 if substr(plan,1,1) == "K" & origcopay== 10 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "K" & origcopay== 10 & (allowedamt != origcopay) ;
replace generic = 2 if substr(plan,1,1) == "K" & origcopay== 30 & (allowedamt != origcopay) ;
replace retail  = 0 if substr(plan,1,1) == "K" & origcopay== 30 & (allowedamt != origcopay) ;

} ;

label values generic generic;
notes generic: this variable is based off of drugtier; 

replace generic=1 if generic==.; 
* We can do better than this assumption. But it is affecting ~ 1.5% of data, at least in 2013 ; 

drop plan ; 
duplicates drop ; 
tempfile drugclaims`yplan';
save `drugclaims`yplan'';
save `out_data'/`claimyear'/bene${unit}${cells}_DRUGCLAIMS_acg`acg'_`yplan'.dta, replace;

local drugclaims`yplan' `out_data'/`claimyear'/bene${unit}${cells}_DRUGCLAIMS_acg`acg'_`yplan'.dta;

/*****************************************Working with choice set *****************************************/;
use `bene_allplans`yplan'', clear; 
		replace drugplan = "OMED9" if plan == "OMED9" ; 
		replace drugplan = "MMEDH" if plan == "MMEDH" ;
		replace chosendrgplan = "OMED9" if chosenplan == "OMED9" ;
		replace chosendrgplan = "MMEDH" if chosenplan == "MMEDH" ;
		drop if chosenplan !="OMED9" & chosendrgplan=="OMED9" ;
		drop if chosenplan !="MMEDH" & chosendrgplan=="MMEDH" ;

		drop if chosenplan !=plan & chosen==1;
		drop familyid plan chosen; // added "plan" AHS 1/30; 

		gen chosen = 1 if chosendrgplan == drugplan;
		replace chosen=0 if chosen==.;
		bys personid: egen max_test=max(chosen);
		assert max_test==1;
		drop max_test ; 
		duplicates drop;
tempfile alldrugplan`yplan'`acg';		
save `alldrugplan`yplan'`acg'';	

keep if chosen==1;
keep drugplan personid eligstrt;
duplicates drop;

tempfile restricted_drugplan`yplan';
save `restricted_drugplan`yplan'';

/****************************taking care of the RX oop payment claims issue ****************************
purpose: this fixes the "original" oop variables.  Only necessary for PF runs because those are the only runs where we 
use the original oop variables
rules:
	1- Kaiser: all amounts are copays
	2- Providence: 
		a-> all generic payment tiers are copays
		b-> all brand formulary payment tiers are copays 
		c-> all brand non-formulary payment tiers are coinsurance
	3- OMED9
		a-> all RX amounts are coinsurances
	4- ORXA:
		a-> all generic payment tiers are copays
		b-> all brand formulary payment tiers are coinsurance
		c-> all brand non-formulary payment tiers are coinsurances
	5- ORXB:
		a-> all generic payment tiers are copays
		b-> all brand formulary payment tiers are copays
		c-> all brand non-formulary payment tiers are coinsurances
			- unless the copay is $100 and the allowed amt >$200, then it is a copayment 
			- PY 08 and 09: copay is $50 and the allowed amt >100, then it is a copayment 
							copay is $100 and the allowed amt > than $200, then it is a copayment 
	6- ORXC:
		-> all payment tiers are coinsurances
		
******************************************************************************************/;

use `drugclaims`yplan'', clear; 
merge m:1 personid using `restricted_drugplan`yplan''; 
keep if _merge==3; drop  _merge;
drop if srvcdt < eligstrt & srvcdt !=. & eligstrt !=. & "`runtype'"=="PF";
tab drugplan if drugtier==.;
* CB - can we impute any of these missing tiers? ; 
* we have generic values for them in 2013 at least? ;
* I'm not going to mess with prior years right now, but at least for 2013, trying a work-around ; 
if `claimyear' == 2013 { ;
	egen max_copay = max(origcopay), by(ndc drugplan) ; 
	replace drugtier = 0 if max_copay == 0 & drugtier == . ; 
	
	gen obs_perc = origcopay  / allowedamt ;
	replace obs_perc = round(obs_perc, 0.01) ; 
	* MMEDH has some claims with a deductible, so the observed copay is 0 ; 
	* set this obs perc variable to .2 for claims with origded != 0 ; 
	replace obs_perc = 0.2 if origded != 0 & drugplan == "MMEDH"; 
	* for MMED there is a max on the coinsurance, replace the percent to the approp value if the copay ; 
	* is exactly = that max ; 
	replace obs_perc = 0.25 if origcopay == 50  & retail == 1 ;
	replace obs_perc = 0.5  if origcopay == 150 & retail == 0 ;
	replace obs_perc = 0.25 if origcopay == 100 & retail == 1 ;
	replace obs_perc = 0.5  if origcopay == 300 & retail == 0 ;
	
	egen md_obs_perc = mode(obs_perc), by(ndc drugplan) ;
	
	replace drugtier = 0 if md_obs_perc == float(0) & drugplan == "MMEDH" & drugtier == . ; 
	replace generic = 0 if md_obs_perc == float(0) & drugplan == "MMEDH" & drugtier == . ; 
	
	replace drugtier = 2 if md_obs_perc == float(0.2) & drugplan == "MMEDH" & drugtier == . ; 
	replace generic = 2 if md_obs_perc == float(0.2) & drugplan == "MMEDH" & drugtier == . ; 
	
	replace drugtier = 0 if md_obs_perc == float(0) & drugplan == "MMED" & drugtier == . ; 
	replace generic = 0 if md_obs_perc == float(0) & drugplan == "MMED" & drugtier == . ;
	
	replace drugtier = 2 if md_obs_perc == float(0.25) & drugplan == "MMED" & drugtier == . ; 
	replace generic = 2 if md_obs_perc == float(0.25) & drugplan == "MMED" & drugtier == . ; 
	
	replace drugtier = 3 if md_obs_perc == float(0.5) & drugplan == "MMED" & drugtier == . ; 
	replace generic = 3 if md_obs_perc == float(0.5) & drugplan == "MMED" & drugtier == . ; 
	
	* 32 wierd observations left. tier = 2 is an okay approximation ; 
	replace drugtier = 2 if drugtier == . ; 
	drop obs_perc md_obs_perc max_copay ; 
} ;
drop if drugtier==.;

/* 2 - Providence */;
replace origcoin=origcopay if drugplan=="PRX1" & drugtier==3;  
replace origcopay=0 if drugplan=="PRX1" & drugtier==3; 

/* 3- OMED9 */;
replace origcoin=origcopay if drugplan=="OMED9"; 
replace origcopay=0 if drugplan=="OMED9";

/* 4- ORXA */;
replace origcoin=origcopay if drugplan=="ORXA" & drugtier !=1; 
replace origcopay=0 if drugtier !=1 & drugplan=="ORXA";

/* 5- ORXB */;
gen exception=.;
replace exception=1 if origcopay==100 & allowedamt >200 & drugplan=="ORXB";

if `claimyear'==2008 | `claimyear'==2009 { ;
replace exception=1 if origcopay==50 & allowedamt >100 & drugplan=="ORXB";
replace exception=1 if origcopay==100 & allowedamt >200 & drugplan=="ORXB";
 } ;
replace exception=0 if exception==.;
replace origcoin=origcopay if drugplan=="ORXB" & drugtier==3 & exception !=1;
replace origcopay=0 if drugplan=="ORXB" & drugtier==3 & exception !=1;

/* 6- ORXC */;
replace origcoin=origcopay if drugplan=="ORXC";
replace origcopay=0 if drugplan=="ORXC";

drop exception drugplan; // data set now has the same variables as `drugclaims';

/****************************** matching the total choice set with the individual claim ******************************/;
joinby personid using `alldrugplan`yplan'`acg'', unmatched(both); 
tab _merge;  assert _merge !=1;
keep if _merge==3; // the _merge==2s should be guys w/ med claims but w/o drug claims;
drop _merge;
display _N;

********************************prepping;
gen oop=origcoin + origcopay + origded;
count if oop==allowedamt;

tempfile form_input`yplan';
tempfile working`yplan';
save `form_input`yplan'';
save `working`yplan'';

/************************************************** making formulary **************************************************/; 
/******************************************************** KAISER ******************************************************/; 
 if `planyear' > 2012 { ;
	insheet using `Kaiser_formulary', clear;  

	split ndc, parse("-") g(ndc); //";
	drop ndc;
	egen ndc=concat(ndc1 ndc2 ndc3);
	keep ndc generic;
	rename generic genericform;

	drop if ndc=="52769046001" & generic==1;
	duplicates drop;
	tempfile form_k`yplan';
	save `form_k`yplan'';

	insheet using `KaiserNDCxwalk', clear;
	drop v*;
	gen current = string(currentndc,"%011.0f");
	gen new = string(newndc,"%011.0f");
	drop *ndc;
	rename current ndc;
	duplicates drop;
	tempfile newkcode`yplan';
	save `newkcode`yplan'';
} ;
/******************************************************** ODS ******************************************************/; 
if `planyear' > 2010 { ;
	insheet using `MODA_formulary`yplan'', clear; 
	gen ndc = string(ndccode , "%011.0f");
	drop ndccode; cap drop n v3;
	gen retail=.;

	replace retail=2 if (tier=="SP1" | tier=="SP2" | tier=="SP3" | tier=="Specialty"); 
		cap replace retail=2 if specialtyyn=="Y";
		tab tier;
		egen maxretail=max(retail); assert maxretail==2; drop maxretail;/* check */;
		gen generic=0 if tier=="V" | tier=="V*";
		gen noODS9=1 if tier=="V*";
		replace generic=1 if tier=="1" | tier=="SP1";
		replace generic=2 if tier=="2" | tier=="SP2";
		replace generic=3 if tier=="3" | tier=="SP3";
		gen free=1 if tier=="P" | tier=="Vac" | tier=="vac" | tier=="Vaccine";
		replace generic=0 if free==1;  // I'm looping free vaccines into Value, even though it's not technically correct;

		keep ndc generic retail noODS9 free;
		renvars, postfix("_f");
		rename ndc_f ndc;
	tempfile form_moda`yplan';
	save `form_moda`yplan'';	
} ;

*********defining choice set so every drugplan is assigned an ndc code (backing out formulary);
	***********ndc codes;
	use `form_input`yplan'', clear;
	keep ndc;
	duplicates drop;
	gen join=1;
	tempfile ndc`yplan';
	save `ndc`yplan'';

	***defining CHOICE SET; /* this is where we restrict to the set of plans that exist in every year */;
	insheet using `plans', names clear; 

	cap label drop generic;
	cap label drop retail;

	label define retail 0 "Mail" 1 "Retail" 2 "Specialty";
	label define generic 0 "Value" 1 "Generic" 2 "Brand  Name Formulary" 3 "Brand Non-Formulary";

	label values generic generic;
	label values retail retail;
	drop if drugplan=="KRX1" & retail==2; // speciality tier doesn't exist in Kaiser;
	drop if drugplan=="KRX1" & generic==0; // value tier doesn't exist in Kaiser;
	if `planyear'< 2010{ ;
		drop if retail==2; // speciality tier didn't exist before 2010;
		drop if generic==0; // value tier didn't exist before 2010;
		drop if drugplan=="KRX1" & generic==3; // non-preferred = brand non-form tier doesn't exist in Kaiser;
		
		if `planyear'==2008{ ;
			drop if drugplan=="PRX1" & generic==3; // non-preferred = brand non-form tier doesn't exist in Prov;
		} ;
	} ;
	if `planyear'==2011 { ;
		keep if inlist(drugplan, "KRX1", "OMED9", "ORXA", "ORXB", "ORXC", "PRX1");
	} ;
	if `planyear'==2012{ ;
		keep if drugplan=="OMED9" | drugplan=="KRX1" | drugplan=="ORXB";
	} ;
	if `planyear'==2013{ ;
		keep if drugplan=="KRX1" | drugplan=="MMED"| drugplan=="MMEDH";
	} ;
	gen join=1;
 
	joinby join using `ndc`yplan'', unmatched(both);
	assert _merge==3;
	drop _merge join generic;

	gen ODS=(drugplan=="ORXA" | drugplan=="ORXB" | drugplan=="ORXC" | drugplan=="OMED9" | drugplan=="MMED" | drugplan=="MMEDH");
	tempfile choiceset`yplan';
	save `choiceset`yplan''; // this then gives us the choice set with EVERY ndc code; 

	/********************************** pharm copay 411 **********************************/; 
	/* get oop information ready for merge */;
	insheet using `pharmacycopay', clear; /* specified at top of .do file */; 
	rename coinsurance coinsuranceperc;
	display _N;
	duplicates drop;
	rename deductible max_deductible;

	cap drop _merge;
	replace na=0 if na==.;
	drop planname;
	duplicates drop;
	compress; //  drugplan retail generic dayssupply ;

	tempfile pharmcopay`yplan';
	save `pharmcopay`yplan'';

	drop if na==1;
	keep generic retail copay drugplan;
	duplicates drop;
	bys drugplan copay: gen count=_N;
	keep if count==1;
	rename retail retail_2;
	rename generic generic_2;

	tempfile pharmcopay`yplan'_2;
	save `pharmcopay`yplan'_2';
	
	
**********************************************BACKING OUT FORMULARY;
use `form_input`yplan'', clear; // formulary input;
 
	keep if chosen==1;
	rename chosenplan planname;
	drop if planname=="NE   " | planname=="OPT  " | planname=="~    ";
	gen claimcount=1;

	preserve ;
		drop if allowedamt==origcopay;
		drop if allowedamt==origcoin;
		drop if allowedamt==origded;
		drop if origcoin!=0;
		
		keep personid familyid drugplan claimid origcopay generic retail ndc allowedamt recordid;
		duplicates drop;
		rename origcopay copay;
		rename generic generic_o;
		rename retail retail_o;
 
		merge m:1 drugplan copay using `pharmcopay`yplan'_2', keep(1 3);
		tab drugplan _merge;
		drop if _merge==1; 
		assert _merge==3; 
		drop _merge;
		
		replace generic_o=generic_2 if generic_o !=generic_2 & generic_2!=.;
		replace retail_o=retail_2 if retail_o!=retail_2 & retail_2!=.; 
		drop generic_2 retail_2;
		gen copaycheck=round(copay);
		assert copaycheck==copay; drop copaycheck;
		tempfile correction;
		save `correction';
	restore ;

	merge 1:1 personid familyid drugplan claimid ndc allowedamt recordid using `correction';
		tab _merge drugplan;
		replace generic=generic_o if _merge==3 & generic_o !=generic & generic_o!=.;
		replace retail=retail_o if _merge==3 & retail_o!=retail & retail_o!=.;
		drop generic_o retail_o copay _merge;
	/* keeping the most frequent pairings -- backing out the formulary */;
	collapse (sum) claimcount, by (ndc retail generic chosendrgplan );
	bys ndc  retail chosendrgplan: egen maxclaim=max(claimcount);
	gen keep=1;
	replace keep=0 if maxclaim !=claimcount;
	rename chosendrgplan drugplan;
 
	/* redefine tiers for ORXC using formulary from ORXA and ORXB -- this is to derive value */;
	if `planyear' <2011 {;
		gen ODS=(drugplan=="ORXA" | drugplan=="ORXB");
		bys  retail ndc: egen maxcount=max(claimcount) if ODS==1;
		bys  retail ndc: gen ODStier=generic if maxcount==claimcount;
		bys  retail ndc: egen MINgen=min(ODStier);
		drop ODS;
		gen ODS=(drugplan=="ORXA" | drugplan=="ORXB" | drugplan=="ORXC" | drugplan=="OMED9");
		tab drugplan if MINgen==.;

		replace generic=MINgen if ODS==1 & MINgen !=.;
	} ;

	if `planyear'>2010{ ;
		gen ODS=(drugplan=="ORXA" | drugplan=="ORXB" | drugplan=="ORXC" | drugplan=="MMED"| drugplan=="MMEDH");
		bys  retail ndc: egen maxcount=max(claimcount) if ODS==1;
		bys  retail ndc: gen ODStier=generic if maxcount==claimcount;
		bys  retail ndc: egen MINgen=min(ODStier);
		drop ODS;
		gen ODS=(drugplan=="ORXA" | drugplan=="ORXB" | drugplan=="ORXC" | drugplan=="OMED9" | drugplan=="MMED" | drugplan=="MMEDH" );

		replace generic=MINgen if ODS==1 & MINgen!=.;
		* this results on a not insignificant percent of changes. ; 
		* maybe revisit ; 
	} ;
	
	tab keep;
	keep if keep==1;  
	drop ODStier ; 
	duplicates drop ;

	/* dealing with claims that tie */;
	bys ndc retail drugplan: gen temp_keep=_n;
		tab temp_keep;

		keep if temp_keep==1; // drops ~1% of observations;
			drop MINgen ODS maxcount maxclaim keep temp_keep;

	**********************************************now assigning actual data with choice set;
	gen ODS=(drugplan=="ORXA" | drugplan=="ORXB" | drugplan=="ORXC" | drugplan=="OMED9" | drugplan=="MMED"| drugplan=="MMEDH" );
	bys ndc retail ODS: egen max=max(claimcount);
	gen keep=(max==claimcount);
	keep if keep==1;

	/* dealing with claims that tie */;
	bys ndc retail ODS: gen temp_keep=_n;
		tab temp_keep;
		keep if temp_keep==1; // drops ~2% of observations;
	drop keep drugplan max claimcount temp_keep;
	duplicates drop;

	merge 1:m ndc ODS retail using `choiceset`yplan'';
	assert _merge !=1;
	bys ndc ODS retail: egen MINgen=min(generic); // there are 1% of conflicts, going to choose the lowest number;

	replace generic=MINgen if generic==.; 
		drop MINgen;

	bys ndc ODS : egen MINgen=min(generic);  // there are 1% of conflicts, going to choose the lowest number;
	replace generic=MINgen if generic==.; 
		drop MINgen;

	bys ndc: egen MINgen=min(generic);
	replace generic=MINgen if generic==.; 
		* this isn't great - can we go across years within insurer? ; 
	assert generic !=.;
	drop MINgen ODS _merge;
	duplicates drop;

	/* exceptions that we won't want to change using the formulary (because the form. isn't year specific) */;
	if `planyear'< 2010{ ;
		replace retail=1 if retail==2; // specialty tier didn't exist before 2010;
		replace generic=1 if generic==0; // value tier didn't exist before 2010;
		replace generic=2 if drugplan=="KRX1" & generic==3; // non-preferred = brand non-form tier doesn't exist in Kaiser;
		if `planyear'==2008{ ;
			replace generic=2 if drugplan=="PRX1" & generic==3; // non-preferred = brand non-form tier doesn't exist in Prov;
			} ;
		} ;
		if `planyear'==2012{ ;
		keep if drugplan=="OMED9" | drugplan=="KRX1" | drugplan=="ORXB" ;
		} ;
		if `planyear'==2013{ ;
		keep if drugplan=="MMEDH" | drugplan=="KRX1" | drugplan=="MMED" ;
		} ;
		*******************************formularies;
		if `planyear' > 2010 { ;
			/* working with ODS claims */;
			preserve;
			keep if drugplan=="ORXA" | drugplan=="ORXB" | drugplan=="ORXC" | drugplan=="OMED9" | drugplan=="MMED" | drugplan=="MMEDH";
			merge m:1 ndc using `form_moda`yplan'', keep (1 3);
			
			bys ndc drugplan: egen maxretail=max(retail);
			replace retail=retail_f if _merge==3 & retail_f==2 & maxretail!=2;
			drop if retail!=retail_f & _merge==3 & retail_f==2 & maxretail==2;
			replace generic=generic_f if _merge==3 & generic_f !=.;
			drop if retail==2 & retail_f !=2;
			gen na_f=1 if noODS9_f==1 & (drugplan=="OMED9" | drugplan=="MMEDH"); 
			drop na_f;
			replace generic=0 if free_f==1;
				rename free_f free;
			drop _merge noODS9_f generic_f  retail_f;
			if `planyear'< 2010 { ;
			drop if retail==2; // specialty tier didn't exist before 2010;
			drop if generic==0; // value tier didn't exist before 2010;
			} ;
			duplicates drop;
			gen formulary=1;
			tempfile odsform`yplan';
			save `odsform`yplan'';
			restore; 
		} ;

		if `planyear' > 2012 { ;
			/* working with Kaiser claims */;
			preserve;
			keep if drugplan=="KRX1";

			*** This change of NDC code causes the changed codes to not match in a merge below. ;
			*** Chris Behrer does not understand why there are changes for >2012 kaiser drug claims...data for 2013 calculator was not available when this code was written.?;
			*** For now (10 august 2015) commenting out this change in NDC codes; 
			*** merge m:1 ndc using `newkcode`yplan'', keep (1 3);
			***	replace ndc=new if _merge==3;							
			***	rename _merge merge1;
			***	drop new;
			***	duplicates drop;
			***	bys drugplan retail  ndc: gen count=_N;
			***	bys ndc: egen max=max(merge1);

			***	drop if merge1==1 & max==3 & count>1; cap drop max;
 
				merge m:1 ndc using `form_k`yplan'', keep (1 3);	
				count if _merge==3 & generic==genericform;
				count if _merge==3 & generic!=genericform;
				rename _merge merge2;
				drop genericform merge*;
				cap drop count;
				if `planyear'< 2010{ ;
					drop if generic==0; // value tier didn't exist before 2010;
					* why drop? ; 
					drop if drugplan=="KRX1" & generic==3; // non-preferred = brand non-form tier doesn't exist in Kaiser;
					
					if `planyear'==2008{ ;
						drop if drugplan=="PRX1" & generic==3; // non-preferred = brand non-form tier doesn't exist in Prov;
					} ;
				} ;
				duplicates drop;
				gen formulary=1;
				tempfile kaiserform`yplan';
			save `kaiserform`yplan'';
			restore ; 
		} ;

		if `planyear'==2011 | `planyear'==2012 | `planyear'==2013{ ;
			gen drugplanfirst=substr(drugplan ,1,1);
			keep if drugplanfirst=="K" | drugplanfirst=="P";
			append using `odsform`yplan'';
			tab drugplan; 
		 } ;

		if `planyear' > 2012 { ;
			use `odsform`yplan'', clear; 
			append using `kaiserform`yplan'';
			drop retail maxretail free; 
			duplicates drop ;
			egen mingen = min(generic), by(ndc drugplan) ; 
			replace generic = mingen ; 
			drop mingen ; 
			duplicates drop ; 
		} ;
		cap drop network;
		duplicates drop;
		preserve ;
			tempfile formulary`yplan';
			save `formulary`yplan'';
		restore ;	

		if `planyear' > 2010 & `planyear' < 2013  { ;
			keep drugplan ndc retail formulary;
			keep if retail==2;
			rename retail retail_specialty;
			replace formulary=0 if formulary==.;
			tab drugplan formulary;
			tempfile formretail;
			save `formretail';
		} ;
		/********************************** merge formulary and oop 411 into claims**********************************/; 
		use `working`yplan'', clear;
		rename generic origgeneric;
		rename formulary origformulary;
		if `planyear' > 2010 & `planyear' < 2013 { ;
			gen formulary=.;
			replace formulary=(drugplanfirst=="O") if planyear==2011;
			replace formulary=(drugplanfirst=="O") if planyear==2012;
			replace formulary=(drugplanfirst=="M" | drugplanfirst=="K") if planyear==2013;
			merge m:1 drugplan ndc formulary using `formretail', keep(1 3);

			replace retail=retail_specialty if _merge==3 & formulary==1;
			drop retail_specialty _merge;
		} ;
		if `planyear' > 2012 { ;
			merge m:1 drugplan ndc using `formulary`yplan'', keep (1 3); 
		} ;
		if `planyear' < 2013 { ;
		merge m:1 drugplan ndc retail using `formulary`yplan'', keep (1 3); 
		/* merging in formulary based generic variable */;
		} ;	
		assert _merge ==3;
		drop _merge;

		/* creating dayssupply variable */;
		rename dayssupply origdayssupply;
		gen dayssupply=0;
		replace dayssupply=30 if retail==0 & drugplan=="KRX1" & origdayssupply <31;
		replace dayssupply=31 if retail==0 & drugplan=="KRX1" & origdayssupply <61 & origdayssupply >30;
		replace dayssupply=61 if retail==0 & drugplan=="KRX1" & origdayssupply >60;
		replace dayssupply=30 if retail==1 & drugplan=="KRX1";

		replace dayssupply=90 if retail==0 & drugplan=="PRX1";
		replace dayssupply=31 if retail==1 & drugplan=="PRX1";
		replace dayssupply=31 if retail==2 & drugplan=="PRX1" & generic !=0;

		replace dayssupply=90 if retail==0 & (drugplan=="OMED9");
		replace dayssupply=31 if (retail==1 | retail==2) & (drugplan=="OMED9");
		if `planyear' < 2012 { ;
			foreach l in A B C { ;
				replace dayssupply=90 if retail==0 & drugplan=="ORX`l'";
				replace dayssupply=31 if (retail==1 | retail==2) & drugplan=="ORX`l'";
				replace dayssupply=0  if retail==2 & drugplan=="ORX`l'" & generic==0;
			} ; 
		} ;
		if `planyear' > 2011 { ;
			local l B;
			replace dayssupply=90 if retail==0 & (drugplan=="ORX`l'"| drugplan=="MMED"| drugplan=="MMEDH");
			replace dayssupply=31 if (retail==1 | retail==2) & (drugplan=="ORX`l'"| drugplan=="MMED"| drugplan=="MMEDH");
		} ;

assert dayssupply !=.; 
* CB: 12-2 2013: there are some generic variables where we have changed the value ; 
* of the variable in 2013 when all of the observed values were consistent ; 
* if there is no variation in the observed generic, I'm going to try setting it ; 
* back to what it was. I'm not 100% behind the formularies above. Something isn't ; 
* working with the value tier == 0. Look at tab below. So setting back to orig generic ; 
* if generic == value & origgeneric == generic ; 
* And this seems that it will definitely improve accuracy; 
tab origcopay if generic == 0 & origgeneric == 1 & chosen == 1 ;
if `planyear' > 2012 {;
replace generic = origgeneric if generic == 0 & origgeneric == 1 ; 
};
/* making sure Kaiser doesn't have a value tier */;
replace generic=1 if generic==0 & drugplan=="KRX1";
/* want to merge this in on the new defn generic but on the old definition of dayssupply */;
merge m:1 drugplan retail generic dayssupply using `pharmcopay`yplan''; /* merging in oop information*/;
assert _merge !=1; drop if _merge==2;
keep if _merge == 3;
drop _merge;



if `acg'==0 { ;
	save `out_data'/`claimyear'/bene_alldrugclaim_plan_acg`acg'_`runtype'_`yplan'.dta, replace;
} ;

if `acg'==1 { ; di `acg';
	save `out_data'/`claimyear'/bene${unit}${cells}_alldrugclaim_plan_acg`acg'_`runtype'_`yplan'.dta, replace;
} ;

clear;
capture log close; 