cap log close;
#delimit ;
/* Project: 	Oregon Health Plan Choice Analysis												*/;

/* Program: 	oregon_calculator																*/;
/* Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 								*/;
/*				--> code from Sean Sean and Adrienne Sabety										*/;
/* Dates:		Transition: 	9/30/2014														*/;
/*				Modified: 		10/15/2014														*/;

/* This takes the input files created by 1calc_input_`do_date'.do and calculates costs for 
   each beneficiary for the hypothetical choice of each plan in their choice set				*/;

/* The global $directory is /disk/agedisk3/oebb.work/cbehrer/oregon/ 							*/;
/* All globals are set in the shell file 0SHELL_fullrun_base_`do_date'							*/;

/* 0. Pass globals, set log 																	*/;
set more off; 
local cdate $cdate;
local ctime $ctime;
local claimyear $claimyear;
local year `claimyear';
local runtype $runtype;
local y $yplan;
local runfull $runfull;
local justdrug $justdrug;
local acg $acg;

if `acg' == 0 {;
	local acgbase base;
};

if `acg' == 1 {;
	local acgbase acg;
};
cap log close;
log using $directory/log/calculator/rebuild/`acgbase'/`cdate'/`claimyear'/2calculator`claimyear'_`runtype'_`acgbase'${unit}${cells}_`cdate'_`ctime'.log, replace;

/* Oregon Calculator */;
di "Claim year: `claimyear'";
di "ACG vs Base: `acgbase'";
di "Runtype: `runtype'";
di "Just drug: `justdrug'";
di "Shell file run date: `c_date'";
di "Shell file run time: `ctime'";

local clean $directory/data/given/clean;
local pieces_do $directory/do/2calculator/pieces_calc/rebuild;
local macros $directory/do/macros/;
local in_data $directory/data/calculator/rebuild/`acgbase'/`cdate'/calc_input;
local out_data $directory/data/calculator/rebuild/`acgbase'/`cdate'/calc_output;

if "`runtype'" == "PB" {;
local planyear = `claimyear' + 1;
};

if "`runtype'" == "PF" {;
local planyear = `claimyear'; 
};
local yplan = `planyear' - 2000;
local yclaim = `claimyear' - 2000;
local pyear=`planyear'-1;
assert `yplan'==`y';  di `planyear'; di `y';

/* specifying locals for input files																*/; 
if `acg'==0 { ;
	local bene_claim "`in_data'/`claimyear'/bene_allclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
	/* This file came from the calcinput.do file */;
	local bene_alldrugclaim_plan "`in_data'/`claimyear'/bene_alldrugclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
	/* This file came from the calcinput.do file */;
} ;
if `acg'==1 { ; di `acg';
	local bene_claim "`in_data'/`claimyear'/bene${unit}${cells}_allclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
	/* This file came from the calcinput.do file */;
	local bene_alldrugclaim_plan "`in_data'/`claimyear'/bene${unit}${cells}_alldrugclaim_plan_acg`acg'_`runtype'_`yplan'.dta"; 
/* This file came from the calcinput.do file */; 
} ;
local limits "`clean'/limits.csv";
local prevyear_out `out_data'/`pyear'/calcrun_acg`acg'_`cdate'_`runtype'.dta;

if `planyear'< 2010{;
	local kaiserdo `pieces_do'/Calculate_Kaiser2.do;
	local provdo `pieces_do'/Calculate_Prov2.do;
};
if `planyear'> 2009{;
	local kaiserdo `pieces_do'/Calculate_Kaiser_10_7252.do;
	local provdo `pieces_do'/Calculate_Prov_10_7302.do;
};
di "`kaiser`yplan'";

/******Creating a tempfile for all facility and professional claims***********************/;
use `bene_claim', clear ;
drop if personid == "" ; 

replace procedure = trim(procedure) ; 
*** Global procedure code level modifications ; 
replace copay = 0 if substr(procedure,1,3) == "G89" ;
replace coinsurance = 0 if substr(procedure,1,3) == "G89" ;

tab chosenplan if chosen==1;
cap drop chosenplanfirst;
gen chosenplanfirst=substr(chosenplan, 1, 1);
cap drop planfirst;
gen planfirst=substr(plan,1,1);
tab planfirst ; 

keep if planfirst=="K" | planfirst == "P" ;

sort plan network;
cap drop max_deductible;
cap drop max_oopcost;

* Merging in family vs individual plan info (individual and family oop and deductible limits by plan and network);
preserve ;
clear ;
insheet using `limits', clear;
keep if planyear == `planyear';
cap drop v*;
sort plan network;
desc;
tempfile limit`yplan';
save `limit`yplan'', replace;
restore ;

merge m:1 plan network tier using `limit`yplan'', keep (1 3);
assert _merge==3;
drop _merge;

do `pieces_do'/ods_dedmax_fix.do; 

replace maxded = min_ded * 2 if sumd == 2 ; 
* in providence, family deductible only applies to families of 3 or more ; 
* for families of 2, each person has individual deductible ; 

* getting rid of claims where servicedate is < eligible startdate ;
assert srvcdt >= eligstrt if "`runtype'"=="PF";
destring entitynum, replace; 

* We used to try to model the cross year deductible credit here. We don't do this now ; 

* creating individual specification ;
gen ded1=maxded if tier==1;
bys plan network: egen maxdedind=max(ded1);

gen oop1=maxoop if tier==1;
bys plan network: egen maxoopind=max(oop1);
drop oop1 ded1;

gen individual_ded=0;
replace individual_ded=1 if tier==1;
replace individual_ded=1 if maxded==maxdedind;	

gen individual_oop=0;
replace individual_oop=1 if tier==1;	
replace individual_oop=1 if maxoop==maxoopind;

/* separating out Kaiser plans in order to run separately */;
preserve ;
	keep if planfirst=="K";

	tempfile kaiser`yplan';
	save `kaiser`yplan'', replace;
	global kaiser`yplan' `kaiser`yplan'';
restore ;

/* separating out Prov plans in order to run separately */;
preserve ;
	keep if planfirst=="P" ; 

	tempfile prov`yplan';
	save `prov`yplan'';
	global prov`yplan' `prov`yplan'';
restore ;

/* bringing in drug claims (will do separately as well) */;
/*Creating a tempfile for all drug claims*/;
use `bene_alldrugclaim_plan', clear; 
/* this comes from calculator*/;
cap drop networkpaid;
cap drop provnetwork;
destring entitynum, replace;
gen drug=1;

/* getting rid of claims where servicedate is < eligible startdate;*/;
assert srvcdt >= eligstrt if "`runtype'"=="PF";

/* to keep just kaiser / prov*/
drop if substr(drugplan,1,1) == "O" | substr(drugplan,1,1) == "M";

drop if (drugplan == "OMED9" | drugplan=="MMEDH");
tempfile drugclaims`yplan';
save `drugclaims`yplan'', replace;

local fullrun 1;


/***************** IMPORTANT NOTE **************************
Copay only applies once per day for a particular service type.
Coinsurances apply for every single line of the claim.
**************************************************************/;
*Plans kept: "KMED1" "KMED2" "PMED1" "PMED2" "KMP1A" "PMP1A" "PMP2A"; 

if `fullrun'==1 { ;
	preserve ;
	include `kaiserdo';
	restore ;
} ;

if `fullrun'==1  { ;
	if `planyear' < 2012 { ;
		preserve ;
		include `provdo' ;
		restore ;
	} ;
} ; 

if `fullrun'==1  { ;

	/*** PHARMACY CLAIMS ***/;

	/* there should be no determination based on network*/;
	use `drugclaims`yplan'', clear;
	if _N !=0 { ;
		assert coinsuranceperc!=.;
		assert copay!=.;

		/* sorting the order of the claims based on original claims data: rank = ded, rank1 = coins */;
		sort personid drugplan paiddt; 
		sort personid drugplan paiddt ;
		by personid drugplan paiddt: gen rank1 = _n;  

		/* Calculating coinsurance amount */;
		gen coinsurance = coinsuranceperc * (allowedamt); 

		/* Replacing copay to equal allowed amount if allowed amount is < copay*/;
		replace copay = allowedamt if allowedamt < copay & copay!=0 & allowedamt>0 ;
		replace coinsurance = 0 if allowedamt==copay & copay !=0;

		/********************taking care of the RX oop payment claims algorithm ****************************
		rules:
			1- Kaiser: all amounts are copays
			2- Providence: 
				a-> all generic payment tiers are copays
				b-> all brand formulary payment tiers are copays 
				c-> all brand non-formulary payment tiers are coinsurance
			3- OMED9
				a-> all RX amounts are coinsurances
			4- ORXA:
				a-> all generic payment tiers are copays
				b-> all brand formulary payment tiers are coinsurance
				c-> all brand non-formulary payment tiers are coinsurances
			5- ORXB:
				a-> all generic payment tiers are copays
				b-> all brand formulary payment tiers are copays
				c-> all brand non-formulary payment tiers are coinsurances
					- unless the copay is $100 and the allowed amt >$200, then it is a copayment 
					- PY 08 and 09: copay is $50 and the allowed amt >100, then it is a copayment 
									copay is $100 and the allowed amt > than $200, then it is a copayment 
			6- ORXC:
				-> all payment tiers are coinsurances
				
		******************************************************************************************/;
		/* Kaiser */;
		replace copay=coinsurance if drugplan=="KRX1" & copay==0;
		replace coinsurance=0 if drugplan=="KRX1";

		/* 2 - Providence */;
		replace copay=coinsurance if generic !=3 & copay==0 & drugplan=="PRX1"; /* (a) and (b)*/;
		replace coinsurance=0 if generic !=3 & drugplan=="PRX1"; /*(a) and (b)*/;
		replace coinsurance=copay if drugplan=="PRX1" & generic==3 & coinsurance==0;  
		replace copay=0 if drugplan=="PRX1" & generic==3; /*may have to modified for year !=2008, ie, ... | drugplan=="PRX2"*/;

		/* 4- ORXA */;
		replace copay=coinsurance if drugplan=="ORXA" & generic==1 & copay==0; //*(a)*/;
		replace coinsurance=0 if drugplan=="ORXA" & generic==1; /*(a)*/;
		replace coinsurance=copay if drugplan=="ORXA" & generic !=1 & coinsurance==0; /* (b) and (c)*/;  
		replace copay=0 if generic !=1 & drugplan=="ORXA"; /* (b) and (c)*/; 

		/* 5- ORXB */;
		replace copay=coinsurance if drugplan=="ORXB" & generic !=3 & copay==0; //*(a)*/;
		replace coinsurance=0 if drugplan=="ORXB" & generic !=3; /*(a)*/;

		gen exception=.;
		replace exception=1 if copay==100 & allowedamt >200 & drugplan=="ORXB";

		if `year'==2008 | `year'==2009{;
		replace exception=1 if copay==50 & allowedamt >100 & drugplan=="ORXB";
		replace exception=1 if copay==100 & allowedamt >200 & drugplan=="ORXB";
		};
		replace exception=0 if exception==.;

		replace copay=coinsurance if drugplan=="ORXB" & generic==3 & exception==1 & copay==0;
		replace coinsurance=0 if drugplan=="ORXB" & generic==3 & exception==1;

		replace coinsurance=copay if drugplan=="ORXB" & generic==3 & exception !=1 & coinsurance==0;
		replace copay=0 if drugplan=="ORXB" & generic==3 & exception !=1;

		/* 6- ORXC */;
		replace coinsurance=copay if drugplan=="ORXC" & coinsurance==0;
		replace copay=0 if drugplan=="ORXC";

		drop exception;

		/******************************************************************************************/;
		/* N/A cases. Assumption: Patient pays the full amount and it does not count towards deductible or max_oopcost*/;
		cap drop NA;
		cap drop na;

		gen NA=.;

		gen prev = 1 if (generic==0) & (drugplan == "KRX1");
		cap replace prev = 1 if free==1;
		replace prev = 1 if generic==0 & `claimyear' > 2012;

		/* Calculating OOP cost for each claim and cumulative OOP cost */;
		gen totcost = copay + coinsurance; 
		/*No deductible for pharmacy plans and both copay and coinsurance counts towards max*/;
		replace totcost = allowedamt if NA == 1;

		/* Check to see if for Rx Option B the non-preffered drug cost is past the max limit */ ;
		/* CB 25 Jan 2016 hmm. this doesn't seem to be working, but the code looks correct...?*/ ; 
		/* we need to check how this maximum is imposed in years after 2008/2009*/ ;
		/* particularly 2011 and 2012. Is there any maximum?*/;
		gen planBgeneric3 = 1 if (drugplan == "ORXB") & (generic == 3) ; 
		replace planBgeneric3 = 1 if (drugplan == "MMED") & (generic == 2 | generic == 3) ;
		gen max_drug = . ; 
		replace max_drug = 50 if (planBgeneric3 == 1) & (retail == 1) & `planyear' < 2013 ;
		replace max_drug = 50 if (planBgeneric3 == 1) & (retail == 1) & (generic == 2) & `planyear' > 2012 ;
		replace max_drug = 150 if (planBgeneric3 == 1) & (retail == 1) & (generic == 3) & `planyear' > 2012 ;
		
		replace max_drug = 100 if (planBgeneric3 == 1) & (retail == 0) & `planyear' < 2013 ;
		replace max_drug = 100 if (planBgeneric3 == 1) & (retail == 0) & (generic == 2) & `planyear' > 2012 ;
		replace max_drug = 300 if (planBgeneric3 == 1) & (retail == 0) & (generic == 3) & `planyear' > 2012 ;

		replace totcost = max_drug if (planBgeneric3 == 1) & (totcost > max_drug) & NA!=1 ;
		replace coinsurance = max_drug if (planBgeneric3 == 1) & (coinsurance > max_drug) ;
		
		sort personid drugplan paiddt rank1;
		by personid drugplan : gen cum_totcost = sum(totcost) ; 

		replace coinsurance = 0 if (prev == 1 | dayssupply==1);
		replace copay=0 if (prev==1 | dayssupply==1);

		/* Calculating  totcost at the margin where it just reaches the coinsurance maximum*/;

		/*In N/A cases, we assume the cost doesn't count towards the deductible or the maximum*/;
		sort personid drugplan  paiddt rank1;
		by personid drugplan : gen atmargin_max = 1 if (cum_totcost[_n] >= max_oopcost) & (cum_totcost[_n-1] < max_oopcost)& (_n>1);
		by personid drugplan : replace atmargin_max = 2 if (cum_totcost[_n] > max_oopcost) & (_n==1); 
		replace totcost = max_oopcost - cum_totcost[_n-1] if (atmargin_max == 1);
		replace totcost = max_oopcost if (atmargin_max == 2);
		replace coinsurance = totcost - copay if ((atmargin_max == 1 | atmargin_max == 2) & coinsuranceperc !=0 ); 
		replace coinsurance = 0 if prev == 1;
		replace copay = 0 if prev == 1; 
		replace totcost = copay + coinsurance; 

		/* Setting totcost to 0 past the coinsurance maximum limit */;
		sort personid drugplan  paiddt rank1;
		by personid drugplan : replace cum_totcost = sum(totcost);
		replace coinsurance = 0 if (cum_totcost > max_oopcost) & (atmargin_max != 1) & (atmargin_max != 2) ;
		replace copay = 0 if (cum_totcost > max_oopcost) & (atmargin_max != 1) & (atmargin_max != 2) ;

		replace totcost = copay + coinsurance;

		replace coinsurance = 0 if (prev == 1 | dayssupply==1);
		replace copay=0 if (prev==1 | dayssupply==1);
	} ;
	tempfile drug_out`yplan';
	save `drug_out`yplan'', replace;
} ;

/********* APPENDING ALL FINAL OUTPUT FILES *********************/;

di "`kaiser_out`yplan''";
 
use `kaiser_out`yplan'', clear;
if `planyear' < 2012 {;
	append using `prov_out`yplan'';
};
append using `drug_out`yplan'';

label variable group "This variable indicates if claim is from a HMO, ODS, ODS9 or DRUG claim";
label define group 1 "HMO" 2 "OMED" 3 "OMED9" 4 "DRUG";
label values group group;
notes group: created in oregoncalculator do file `cdate'; 

/* cleaning */;
destring memid, replace;
destring entitynum, replace;
compress;

cap drop v5*;
cap drop v1* ; 
cap drop empcode ;
cap drop customcode ;
cap drop covtypcd ;
cap drop condi* ;
cap drop entfirst ;
cap drop empfirst ;
cap drop entstring ;
cap drop _merge ;
cap drop count ;
cap drop first ;
cap drop flag* ;
cap drop diagnosis* ;
cap drop eligtag ;
cap drop lifestyle* ;
cap drop procmodcd ;
cap drop group;
cap drop planyear;

gen planyear=`planyear';

/*** CB added*/;
local list deductible coinsurance copay origcoin origcopay origded;
	foreach var of local list { ;
	replace `var'=0 if `var'==.;
};

gen orig_sum = round(origcopay+origcoin+origded,0.01);
gen calc_sum = round(copay+coinsurance+deductible,0.01);

gen cb_diff = orig_sum - calc_sum ; 

gen wrong = 1 if abs(cb_diff) > 0.02 ; 
replace wrong = 0 if wrong == .;
replace wrong = . if chosen != 1;
* fail safe ; 

if deductible > maxded replace deductible = maxded ; 

keep personid* familyid plan drugplan drug copay coinsurance deductible origcopay origcoin origded allowedamt network nooop noded chosen ;

if `acg'==0 { ;
save  "`out_data'/`claimyear'/calcrun_acg`acg'_`cdate'_`runtype'.dta", replace;
} ;

if `acg'==1 { ; 
	di `acg';
	save  "`out_data'/`claimyear'/calcrun_${unit}${cells}acg`acg'_`cdate'_`cdate'_`runtype'_${piece}.dta", replace;
} ;

display `year';
display `y';
clear ;
capture log close;
/* modifications: 4-1: For providence, deductible the same no matter out of network or in.  OOP max DIFFERS for in network v. out of network--modification made */;