#delimit;

/*************************************************************************************
--------------- fits into Oregon_input_acg-parentfile.do----------------------------------------
making sure everything is in the correct form as specified below
Description:
1) personid--string--unique person identified
2) age--numeric--patient age
3) sex--string--M/F
4) dx`i'--string--the actual diagnosis code
5) srv_beg--date--the service begin date
6) prov_stnd_specialty--string--Standardized specialty for provider identified by either NPI Taxonomy code or (CMS) Specialty Code. This field will be used for
	understanding the plan-specific specialty codes. If NPI taxonomy or CMS specialty is not available, the plan-specific codes can be mapped to NUCC standards
7) srvcplc--string--place of service in a format that segments inpatient (IP), ED and OP settings for medical services.
	recommended formatting is the CMS place of service coding, ie: IP or 21 for inpatient setting.
8) revcode--string--A code for facility-based services. Identifies inpatient confinements through the presence of a room and board revenue center. A recommended format is 	the CMS revenue center coding, ie 0110
9) procedure--string--the procedure performed by teh servicing provider.  The recommended format is CPT42 and / or HCPCS.  Ie, 99201

---------tag divisions of claims in to separte runs for:
1) mental health
	- outpatient services
	- inpatient services
	- residential services
	- day treatment services
	
2) Physician OV
	- Routine exam
	- Immunizations
	- Well-baby exam
	- Office visits
	- Specialist visits 
	- Maternity
	- Routine newborn nursery care
	- Urgent care
	- Free under the ACA preventive services
	- Therapy
	- Routine eye exam
	- Chiro/naturo/acupuncture
	- Massage therapy
	- Smoking cessation
	- Allergy supplies/ testing / injections
	- Biofeedback, dental services, etc.
	
3) everything else medical related
	- Outpatient maternity care
	- delivery
	- ER copay
	- inpatient care
	- transplant
	- Outpatient surgery
	- Lab/xray/diagnostics
	- ambulance
	- Skilled Nursing Facility Care
	- DME/supplies
	- home health care
	- hospice
	- Weight watchers 
	- misc.  related to ER or after hours
	- TMJ, Dialysis, misc.
	- medical services not covered
4) rx
	- med drug code too;
*************************************************************************************/;
keep if chosen==1 ;
mdesc age*; 

drop planfirst ; 
replace chosenplan = trim(chosenplan);
gen planfirst = substr(chosenplan,1,1) ; 

drop chosendrgplan drugplanfirst drugplan plan;
duplicates drop;
order personid;

/* putting the variabels in the correct form */;
tostring entitynum, replace;

tab sex;
gen sexs="F" if sex==1;
replace sexs="M" if sex==2;
replace sexs="M" if sex==0; // these are missing values.  there weren't a lot so I just set them = M;
drop sex; rename sexs sex;

tostring provtyp, replace;
gen srvcplace2=srvcplace;
tostring srvcplace2, replace; drop srvcplace; rename srvcplace2 srvcplace;

tostring ndc, replace;

rename chosenplan benefit_plan;

/* ------------ dividing into categories: */;
if `claimyear'==2008 { ;
local y 9;

gen physicianOV=0;
replace physicianOV=1 if 
	serviceid==`y'54 | //  routine exam
	serviceid==`y'52 | // immunizations
	serviceid==`y'51 | // well-baby exam
	serviceid==`y'55 | // well-baby exam
	serviceid==`y'65 | // offive visits
	serviceid==`y'64 | // specialist
	serviceid==`y'67 | // maternity 
	serviceid==`y'70 | // routine newborn nursery care 
	serviceid==`y'66 | // therapy
	serviceid==`y'61 | // routine eye exam
	serviceid==`y'22 | // chiro/acu/naturo 
	serviceid==`y'23 | // massage therapy 
	serviceid==`y'21 | // smoking cessation 
	serviceid==`y'13 | // allergy supplies/testing/injections
	serviceid==`y'16 | // Biofeedback, dental services, etc
	serviceid==`y'53 ; //office visit - speech/hearing exam ; 

replace drug=1 if serviceid==`y'11; // drugs;

* 3) everything else medical related;
gen medother=0;
replace medother=1 if
	serviceid==`y'72 | // add mental health to other 
	serviceid==`y'73 | // add mental health to other 
	serviceid==`y'74 | // add mental health to other 
	serviceid==`y'75 | // add mental health to other 
	serviceid==`y'69 | // Outpatient maternity care
	serviceid==`y'71 | // delivery
	serviceid==`y'04 | // er copay
	serviceid==`y'81 | // urgent care 
	serviceid==`y'31 | // inpatient care and transplant
	serviceid==`y'33 | // outpatient surgery
	serviceid==`y'91 | // lab/xray/diag
	serviceid==`y'32 | // ambulance
	serviceid==`y'39 | // SNF
	serviceid==`y'19 | // DME
	serviceid==`y'57 | // home health
	serviceid==`y'58 | // hospice
	serviceid==`y'09 | // misc
	serviceid==`y'15 | // TMJ
	serviceid==`y'17 | // non-covered
	serviceid==`y'07 ; //Speech, occupational, other therapy ; 
} ;


if `claimyear'==2009 { ;
local y 10 ;

gen physicianOV=0;
replace physicianOV=1 if 
	serviceid==`y'54 | //  routine exam
	serviceid==`y'52 | // immunizations
	serviceid==`y'55 | // well-baby exam
	serviceid==`y'51 | // well-baby exam
	serviceid==`y'65 | // office visits
	serviceid==`y'64 | // specialist
	serviceid==`y'63 | // offive visits
	serviceid==`y'62 | // specialist
	serviceid==`y'60 | // specialist
	serviceid==`y'70 | // routine newborn nursery care 
	serviceid==`y'66 | // therapy
	serviceid==`y'61 | // routine eye exam
	serviceid==`y'22 | // chiro/acu/naturo 
	serviceid==`y'23 | // massage therapy 
	serviceid==`y'21 | // smoking cessation 
	serviceid==`y'13 | // allergy supplies/testing/injections
	serviceid==`y'16 | // hearing aids
	serviceid==`y'93 ; // hearing aids

replace drug=1 if serviceid==`y'11; // drugs;

* 3) everything else medical related;
gen medother=0;
replace medother=1 if
	serviceid==`y'72 | // add mental health to other 
	serviceid==`y'73 | // add mental health to other 
	serviceid==`y'74 | // add mental health to other 
	serviceid==`y'75 | // add mental health to other 
	serviceid==`y'69 | // Outpatient maternity care
	serviceid==`y'67 | // Outpatient maternity care
	serviceid==`y'71 | // delivery
	serviceid==`y'04 | // er copay
	serviceid==`y'81 | // urgent care 
	serviceid==`y'31 | // inpatient care and transplant
	serviceid==`y'33 | // outpatient surgery
	serviceid==`y'91 | // lab/xray/diag
	serviceid==`y'32 | // ambulance
	serviceid==`y'39 | // SNF
	serviceid==`y'19 | // DME
	serviceid==`y'57 | // home health
	serviceid==`y'58 | // hospice
	serviceid==`y'15 | // TMJ
	serviceid==`y'17 | // non-covered;
	serviceid==`y'24 | // non-office visit services; 
	serviceid==`y'50 | // bundled	
	serviceid==`y'30 | // misc services	
	serviceid==`y'90 | // ispecified maging
	serviceid==`y'10 | // non-covered;	
	serviceid==`y'36 | // DME
	serviceid==`y'34 | // anesthesia
	serviceid==`y'92 ;// imaging
} ;

if `claimyear'==2010 { ;
local y 11;

gen physicianOV=0;
replace physicianOV=1 if 

	serviceid==`y'54 | //  routine exam
	serviceid==`y'52 | // immunizations
	serviceid==`y'63 | // offive visits
	serviceid==`y'62 | // specialist
	serviceid==`y'60 | // specialist
	serviceid==`y'64 | // specialist
	serviceid==`y'66 | // therapy
	serviceid==`y'20 | // weight watchers - cb added. 
	serviceid==`y'22 | // chiro/acu/naturo 
	serviceid==`y'13 | // allergy supplies/testing/injections
	serviceid==`y'93 ; // hearing aids

replace drug=1 if serviceid==`y'11; // drugs;

* 3) everything else medical related;
gen medother=0;
replace medother=1 if
	serviceid==`y'51 | // surgery - cb moved.
	serviceid==`y'72 | // add mental health to other 
	serviceid==`y'73 | // add mental health to other 
	serviceid==`y'74 | // add mental health to other 
	serviceid==`y'67 | // Outpatient maternity care
	serviceid==`y'71 | // routine newborn nursery care / delivery
	serviceid==`y'04 | // er copay
	serviceid==`y'81 | // urgent care 
	serviceid==`y'31 | // inpatient care and transplant
	serviceid==`y'33 | // outpatient surgery
	serviceid==`y'91 | // lab/xray/diag
	serviceid==`y'32 | // ambulance
	serviceid==`y'39 | // SNF
	serviceid==`y'36 | // DME
	serviceid==`y'19 | // DME
	serviceid==`y'57 | // home health
	serviceid==`y'58 | // hospice
	serviceid==`y'61 | // additional cost tier
	serviceid==`y'34 | // anesthesia
	serviceid==`y'92 | // imaging
	serviceid==`y'50 | // bundled	
	serviceid==`y'30 | // misc services	
	serviceid==`y'90 | // ispecified maging
	serviceid==`y'70 | // Outpatient maternity care
	serviceid==`y'10; // non-covered;
} ;


if `claimyear'==2011 { ;
local y 12;

gen physicianOV=0;
replace physicianOV=1 if 
	serviceid==`y'54 | //  routine exam
	serviceid==`y'52 | // immunizations
	serviceid==`y'51 | // well-baby exam
	serviceid==`y'63 | // offive visits
	serviceid==`y'62 | // specialist
	serviceid==`y'60 | // specialist
	serviceid==`y'66 | // therapy
	serviceid==`y'22 | // chiro/acu/naturo 
	serviceid==`y'51 | // weight watchers
	serviceid==`y'13 | // allergy supplies/testing/injections
	serviceid==`y'93 ; // hearing aids

replace drug=1 if serviceid==`y'11; // drugs;

* 3) everything else medical related;
gen medother=0;
replace medother=1 if
	serviceid==`y'72 | // add mental health to other 
	serviceid==`y'73 | // add mental health to other 
	serviceid==`y'74 | // add mental health to other 
	serviceid==`y'70 | // Outpatient maternity care
	serviceid==`y'71 | // routine newborn nursery care / delivery
	serviceid==`y'04 | // er copay
	serviceid==`y'81 | // urgent care 
	serviceid==`y'31 | // inpatient care and transplant
	serviceid==`y'33 | // outpatient surgery
	serviceid==`y'91 | // lab/xray/diag
	serviceid==`y'90 | // imaging
	serviceid==`y'92 | // upper endoscopies
	serviceid==`y'32 | // ambulance
	serviceid==`y'61 | // additional cost tier
	serviceid==`y'39 | // SNF
	serviceid==`y'19 | // DME
	serviceid==`y'57 | // home health
	serviceid==`y'58 | // hospice
	serviceid==`y'20 | 
	serviceid==`y'30 | // misc services
	serviceid==`y'10 | // non-covered
	serviceid==`y'50; // bundled
} ;

if `claimyear'==2012 { ;
local y 13;

gen physicianOV=0;
replace physicianOV=1 if 
	serviceid==`y'54 | //  routine exam
	serviceid==`y'55 | // well-baby exam
	serviceid==`y'52 | // immunizations
	serviceid==`y'63 | // offive visits
	serviceid==`y'62 | // specialist
	serviceid==`y'60 | // specialist
	serviceid==`y'65 | // office visits
	serviceid==`y'66 | // therapy
	serviceid==`y'22 | // chiro/acu/naturo 
	serviceid==`y'13 | // allergy supplies/testing/injections
	serviceid==`y'93 ; // hearing aids

replace drug=1 if serviceid==`y'11; // drugs;

* 3) everything else medical related;
gen medother=0;
replace medother=1 if
	serviceid==`y'72 | // add mental health to other 
	serviceid==`y'73 | // add mental health to other 
	serviceid==`y'74 | // add mental health to other 
	serviceid==`y'70 | // Outpatient maternity care
	serviceid==`y'71 | // routine newborn nursery care / delivery
	serviceid==`y'04 | // er copay
	serviceid==`y'81 | // urgent care 
	serviceid==`y'31 | // inpatient care and transplant
	serviceid==`y'33 | // outpatient surgery
	serviceid==`y'91 | // lab/xray/diag
	serviceid==`y'32 | // ambulance
	serviceid==`y'39 | // SNF
	serviceid==`y'19 | // DME
	serviceid==`y'57 | // home health
	serviceid==`y'58 | // hospice
	serviceid==`y'61 | // additional cost tier
	serviceid==`y'92 | // imaging
	serviceid==`y'90 | // ispecified maging
	serviceid==`y'20 | // weight watchers
	serviceid==`y'21 | // bariatric surgery
	serviceid==`y'10 | // non-covered;
	serviceid==`y'30 | // other-covered;
	serviceid==`y'50; // bundled	
} ;

gen one=1 if physicianOV==0 & medother==0 & drug==0 ;

tab tos if one == 1 ; 

assert one !=1 ; 
drop one ;
gen sumservice=physicianOV+medother+drug ;
assert sumservice==1; drop sumservice ;