#delimit;
clear;
cap log close;
set more off;
local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);
local directory /disk/agedisk3/oebb.work/cbehrer/oregon/ ;
log using `directory'/do/JHUacg/log/Oregon_input_acg2011_`cdate'_`ctime'.log, replace;
pause off ;

/*************************************************************************************
Created 10/22 AHS
- specific to Oregon, but can be easily modified using locals below
*************************************************************************************/;
/*************************************************************************************
------------------------Define locals and var types------------------------			
	- we want to exclude claims associated with DME, lab and imaging.  If
	these claims have a procedure and place of service code ACG will automatically
	exclude them.  However, please ensure that all of these claims have non-empty
	procedure and place of service codes.
	- also ensure that the variables are the correct data type, which is
	indicated below
Description:
1) personid--string--unique person identified
2) age--numeric--patient age
3) sex--string--M/F
4) dxtype--string--indicates if the diagnosis codes (dx`i') are ICD 9, 10 or 10-cm. 
5) dx`i'--string--the actual diagnosis code
6) srv_beg--date--the service begin date
7) srv_end--date--the service end date
8) provid--string--the servicing provider
9) prov_specialty--string--primary specialty of servicing provider.  Ie, "FP"
9) prov_stnd_specialty--string--Standardized specialty for provider identified by either NPI Taxonomy code or (CMS) Specialty Code. This field will be used for
	understanding the plan-specific specialty codes. If NPI taxonomy or CMS specialty is not available, the plan-specific codes can be mapped to NUCC standards
10) srvcplc--string--place of service in a format that segments inpatient (IP), ED and OP settings for medical services.
	recommended formatting is the CMS place of service coding, ie: IP or 21 for inpatient setting.
11) revcode--string--A code for facility-based services. Identifies inpatient confinements through the presence of a room and board revenue center. A recommended format is 	the CMS revenue center coding, ie 0110
12) procedure--string--the procedure performed by the servicing provider.  The recommended format is CPT42 and / or HCPCS.  Ie, 99201
*************************************************************************************/;
local claimyear 2010 ;
local y 11 ;
local planyear 2011 ; 

local modadate 28_Sep_2016 ; 
local sample /disk/agedisk3/oebb.work/cbehrer/oregon/data/built/sample/sample_PB_`planyear'_23_Sep_2016.dta ;
* Even though we have two version of the calculator, we just need the claims ; 
* all the claims are in the 'moda' version of the calculator input files ; 
local medinputfile1 `directory'/data/calculator/june2015/base/`modadate'/calc_input/`claimyear'/bene_allclaim_plan_acg0_PB_`y'.dta ;
local druginputfile1 `directory'/data/calculator/june2015/base/`modadate'/calc_input/`claimyear'/bene_alldrugclaim_plan_acg0_PB_`y'.dta ;
local cleaning `directory'/do/JHUacg/1-ACGinputfile_12-6.do ;
local list2  rxcost OV  other ;

foreach var of local list2 { ;
/*------------------------defining the types of runs we want---------------------------------*/;
di "`var'";
local runtype `var';
di "`runtype'";
/*---------------------------------------------------------*/;
local personid personid ;  
local age age_yr ; 
local sex sex ; 
local employer_group_id entitynum ;
local employer_group_name entityname ;
local dxtype "9" ; 
local dx1 diagnosis1 ; 
local dx2 diagnosis2 ; 
local dx3 diagnosis3 ; 
local dx4 diagnosis4 ; 
local dx5 diagnosis5 ; 

local srv_beg srvcdt ; 
* local srv_end ;

* local provid  ;
* local prov_specialty ;
local prov_stnd_specialty provtyp ;
local srvcplc srvcplace ; 
local revcode revenuecd ;
local procedure procedure ;

local rx_code_type "N" ;
local rx_code ndc ;
local rx_days_supply dayssupply ; 
local rx_fill_date srvcdt ; 

/*************************************************************************************
start of run, specific to Oregon
*************************************************************************************/;
***** need to clean oregon file *****;
use `medinputfile1', clear ;
keep if chosen==1 ;
	gen drug=0 ;
	cap drop provnetwork ;

append using `druginputfile1' ;
keep if chosen==1 ;
	replace drug=1 if drug==. ;
	cap drop provnetwork ;
	drop origserviceid ;
	replace plan = drugplan if plan == "" ;
assert plan != "" ; 
tab plan ; 
keep if substr(plan,1,1) == "O" | substr(plan,1,1) == "M" ;
tempfile OMED ; 
save `OMED' ; 

use `medinputfile1' ;
keep if chosen==1 ;
	gen drug = 0 ;
	cap drop provnetwork ; 
	
append using `druginputfile1' ; 
keep if chosen==1 ;
	replace drug=1 if drug==. ;

	cap drop provnetwork ; 
	drop prev ;
	replace plan = drugplan if plan == "" ;
	assert plan != "" ; 

	preserve ; 
		keep if substr(plan,1,1) == "K" ; 
		tempfile kaiser ; 
		save `kaiser' ; 
	restore ; 
	if `y' < 12 {;
		keep if substr(plan,1,1) == "P" ; 
		tempfile providence ; 
		save `providence' ; 
	};
	drop if _n > 0 ; 
	append using `kaiser' ; 	
	if `y' < 12 { ; 
		append using `providence' ;
	} ;
tempfile rebuild ; 
save `rebuild' ; 
append using `OMED' ; 
tempfile claims ; 
save `claims' ; 

* we need age and sex ; 
* also a good check that everyone is in sample ; 
use `sample' ; 
keep personid familyid age_yr sex personidIE ;
	merge 1:m personid familyid personidIE using `claims' ; 
assert _merge != 2 ; 
drop if _merge == 1 ; 
drop _merge ; 

assert procedure != "" if drug == 0 ; 
assert provtyp != . if drug == 0 ; 

include `cleaning';

/*--------------------applying restrictions---------------------------------*/;
di "`var'";
if "`var'"=="rxcost" { ;
	keep if drug==1; } ;
if "`var'"=="OV"{ ;	
	keep if physicianOV==1; } ;
if "`var'"=="other" { ;
	keep if medother==1; } ;

rename `personid' patient_id;

/************************* make patient data file *************************/;
preserve ;
	rename `age' age;
	rename `sex' sex;

	gen company="Kaiser" if planfirst=="K";
	replace company="Providence" if planfirst=="P";
	replace company="ODS" if planfirst=="O" | planfirst == "M";
	mdesc age sex company entitynum drug benefit_plan ; 

	rename entitynum employer_group_id;
 
	collapse (sum) allowedamt, by(patient_id age employ* sex company drug benefit_plan); 
		gen pharmacy_cost=allowedamt if drug==1;
		gen total_cost=allowedamt if drug==0;
		replace pharmacy_cost=0 if pharmacy_cost==.;
		replace total_cost=0 if total_cost==.;

	collapse (sum) total_cost pharmacy_cost, by(patient_id age employ* sex company benefit_plan); 

		bys patient_id: gen count=_N;
		tab count;

		replace sex="F" if count>1;

	collapse (sum) total_cost pharmacy_cost, by(patient_id age employ* sex company benefit_plan); 
		bys patient_id: gen count=_N;
		tab count;
		drop if count ==2 & age == . ; 
		drop count ; 
		bys patient_id: gen count=_N ;
		tab count ; 
		assert count==1;

	keep patient_id age sex pharmacy_cost total_cost employer_group_id company benefit_plan;

	* generating strings;
	forvalues i= 1/8 { ;
	gen placeholder_`i'="";
	} ;

	gen placeholder_19="";


	* generating numeric;
	forvalues i= 9/18 { ;
	gen placeholder_`i'=.;
	} ;

	order patient_id 
	age 
	sex 
	placeholder_1 // line of business 
	company 
	placeholder_2 // product
	employer_group_id 
	placeholder_3 // employer group name
	benefit_plan // benefit plan
	placeholder_4 // health system
	placeholder_5 // pcp_id
	placeholder_6 // pcp_name
	placeholder_7 // pcp_group_id
	placeholder_8 // pcp_group_name
	placeholder_9 // pregnant
	placeholder_10 // delivered
	placeholder_11 // low_birthweight
	pharmacy_cost 
	total_cost
	placeholder_12 // inpatient_stays
	placeholder_13 // emergency_visits
	placeholder_14 // outpatient_visits
	placeholder_15 // dialysis_service
	placeholder_16 // nursing_service
	placeholder_17 // major_procedure
	placeholder_18 // cancer_treatment
	placeholder_19; // care_management_program;

	outsheet using `directory'/do/JHUacg/inputfiles/Oregon_patientdataoutput_`planyear'_`runtype'.csv, names comma replace;
restore ;

/************************* make medical output file *************************/;
preserve ;
	drop if drug==1;
	assert procedure !="";
	assert srvcplace !="";

	forvalues i=1/5 { ;
	gen dx_version_`i'=`dxtype';
	rename `dx`i'' dx_cd_`i';
	replace dx_cd_`i'="" if dx_cd_`i'=="~";
	replace dx_cd_`i'="" if dx_cd_`i'=="~        ";
	replace dx_cd_`i'="" if dx_cd_`i'=="~       ";
	} ;

	gen year=year(`srv_beg'); tostring year, replace;

	gen month=month(`srv_beg'); tostring month, replace;
	gen lengthm=length(month);
	gen zero="0";
	egen tmonth=concat(zero month) if lengthm==1;
	replace month=tmonth if lengthm==1;

	gen day=day(`srv_beg'); tostring day, replace;
	gen lengthd=length(day);
	egen tday=concat(zero day) if lengthd==1;
	replace day=tday if lengthd==1;

	egen service_begin_date=concat(year month day), punct(-);

	* rename service_end_date=`srv_end';

	* rename `provid' provider_id;
	* rename `prov_specialty' provider_specialty;
	rename `prov_stnd_specialty' prov_stnd_specialty; tostring prov_stnd_specialty, replace;
	rename `srvcplc' service_place;
	rename `revcode' revenue_code;
	rename `procedure' procedure_code;

	keep patient_id dx_version_* dx_cd* service_begin_date prov_stnd_specialty service_place revenue_code procedure_code ;

	gen placeholder_1=. ;
	forvalues i=2/5{ ;
		gen placeholder_`i'="" ;
	} ;
	
	tostring dx_version_1, replace;
	tostring dx_version_2, replace;
	tostring dx_version_3, replace;
	tostring dx_version_4, replace;
	tostring dx_version_5, replace;
	
	forvalues i=1/5 { ;
		tostring dx_version_`i', replace;
		replace dx_version_`i'="ICD" + dx_version_`i';
	} ;

	order patient_id dx_version_1 dx_cd_1 dx_version_2 dx_cd_2 dx_version_3 dx_cd_3 dx_version_4 dx_cd_4 dx_version_5 dx_cd_5 service_begin_date 
	placeholder_1 // service end date
	placeholder_2 // provider id
	placeholder_3 // provider specialty
	prov_stnd_specialty 
	service_place 
	revenue_code 
	procedure_code
	placeholder_4 // revennue code type
	placeholder_5; // procedure code type;

	outsheet using `directory'/do/JHUacg/inputfiles/Oregon_medicaloutput_`planyear'_`runtype'.csv, names comma replace;
restore ;

/************************* make pharmacy data file *************************/;
preserve ;
	keep if drug==1;
	rename `rx_code' rx_code;
	rename `rx_days_supply' rx_days_supply;
	gen year=year(`rx_fill_date'); tostring year, replace;
	gen month=month(`rx_fill_date'); tostring month, replace;
	gen lengthm=length(month);
	gen zero="0";
	egen tmonth=concat(zero month) if lengthm==1;
	replace month=tmonth if lengthm==1;
	gen day=day(`rx_fill_date'); tostring day, replace;
	gen lengthd=length(day);
	egen tday=concat(zero day) if lengthd==1;
	replace day=tday if lengthd==1;
	egen rx_fill_date=concat(year month day), punct(-);
	gen rx_code_type="N";
	tostring rx_code, replace;
	replace rx_code="n_d_c" + rx_code;
	keep patient_id  rx_code rx_code_type rx_fill_date rx_days_supply;
	order patient_id rx_fill_date  rx_code  rx_code_type rx_days_supply;

	outsheet using `directory'/do/JHUacg/inputfiles/Oregon_pharmacyoutput_`planyear'_`runtype'.csv, names comma replace;
restore ;

shell sed -e 's/ICD9/9/g' `directory'do/JHUacg/inputfiles/Oregon_medicaloutput_`planyear'_`runtype'.csv >! `directory'do/JHUacg/inputfiles/Oregon_medicaloutput_`planyear'_"`runtype'"_2.csv;

shell sed -e 's/n_d_c//g' `directory'do/JHUacg/inputfiles/Oregon_pharmacyoutput_`planyear'_`runtype'.csv >! `directory'do/JHUacg/inputfiles/Oregon_pharmacyoutput_`planyear'_"`runtype'"_2.csv;
} ;

assert 0==1;
/* THE BELOW HAS TO BE RUN IN THE UNIX ENVIORNMENT */;
* STEP 1: HAVE TO RUN IN UNIX;
local list2  rxcost OV  other;
* specific form;
* Step 1 command 1: rxcost ; 
shell jhuacg -new-acg-file /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/outputfiles/output_2011_rxcost_30_Sep_2016 -patient /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_patientdataoutput_2011_rxcost.csv -patient-format COMMA -patient-skip -medical /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_medicaloutput_2011_rxcost_2.csv -medical-format COMMA -medical-skip -pharmacy /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_pharmacyoutput_2011_rxcost_2.csv -pharmacy-format COMMA -pharmacy-skip -all-models -delim COMMA

* Step 1 command 2: other ; 
shell jhuacg -new-acg-file /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/outputfiles/output_2011_other_30_Sep_2016 -patient /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_patientdataoutput_2011_other.csv -patient-format COMMA -patient-skip -medical /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_medicaloutput_2011_other_2.csv -medical-format COMMA -medical-skip -pharmacy /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_pharmacyoutput_2011_other_2.csv -pharmacy-format COMMA -pharmacy-skip -all-models -delim COMMA 

* Step 1 command 3: OV ; 
shell jhuacg -new-acg-file /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/outputfiles/output_2011_OV_30_Sep_2016 -patient /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_patientdataoutput_2011_OV.csv -patient-format COMMA -patient-skip -medical /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_medicaloutput_2011_OV_2.csv -medical-format COMMA -medical-skip -pharmacy /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_pharmacyoutput_2011_OV_2.csv -pharmacy-format COMMA -pharmacy-skip -all-models -delim COMMA 

* STEP 2: HAVE TO RUN IN UNIX FROM DIRECTORY WHERE .acgd FILES ARE SAVED ;

* this must be run in unix command line from the directory where the above commands save .acgd datasets ; 
* There are two commands for each of rxcost other and OV ; 
jhuacg -export SUMMARY -acg-file output_2011_rxcost_30_Sep_2016.acgd -export-file output_2011_summary_rxcost_30_Sep_2016
jhuacg -export PATIENT -acg-file output_2011_rxcost_30_Sep_2016.acgd -export-file output_2011_patient_rxcost_30_Sep_2016.csv
                                           
jhuacg -export SUMMARY -acg-file output_2011_other_30_Sep_2016.acgd -export-file output_2011_summary_other_30_Sep_2016
jhuacg -export PATIENT -acg-file output_2011_other_30_Sep_2016.acgd -export-file output_2011_patient_other_30_Sep_2016.csv
                                           
jhuacg -export SUMMARY -acg-file output_2011_OV_30_Sep_2016.acgd -export-file output_2011_summary_OV_30_Sep_2016
jhuacg -export PATIENT -acg-file output_2011_OV_30_Sep_2016.acgd -export-file output_2011_patient_OV_30_Sep_2016.csv

/* This code is from a prior RA, it states the general form of the above ACG commands 
* general form;
shell jhuacg -new-acg-file /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/outputfiles/output_`planyear'_`runtype'_`cdate' -patient /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_patientdataoutput_`planyear'_`runtype'.csv -patient-format COMMA -patient-skip -medical /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_medicaloutput_`planyear'_`runtype'_2.csv -medical-format COMMA -medical-skip -pharmacy /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/inputfiles/Oregon_pharmacyoutput_`planyear'_`runtype'_2.csv -pharmacy-format COMMA -pharmacy-skip -all-models -delim COMMA ;

* general form;
shell jhuacg –export PATIENT –acg-file /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/outputfiles/output_2008_OV_26_Oct_2015.acgd -delim COMMA –export-file /disk/agedisk3/oebb.work/cbehrer/oregon/do/JHUacg/outputfiles/output_summary_2008_OV_26_Oct_2015.csv -headers DESC ;

shell jhuacg  –export patient –acg-file /disk/agedisk3/oebb.work/ahsabety/Oregon/acg/outputfiles/output_`planyear'_`runtype'_`cdate'.acgd -delim COMMA –export-file /disk/agedisk3/oebb.work/ahsabety/Oregon/acg/outputfiles/output_summary_`planyear'_`runtype'_`cdate'.csv -headers DESC;
*/;
