#delimit ;
clear ;

cap log close ;
set more off ;
pause off ;
local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;
local runtype "PF" ; 
local directory /disk/agedisk3/oebb.work/cbehrer/oregon ;
/* set as base or acg*/
global acgbase base ;
di "${acgbase}" ;
cap mkdir `directory'/log/analysis/${acgbase}/`cdate'/ ;
log using `directory'/log/analysis/${acgbase}/`cdate'/analysis_empcosts_`cdate'_`ctime'_`runtype'_${acgbase}_dv.log, replace;
ssc inst _gwtmean ;

/* CB updated 7/22/2014 to take over project. */ ; 
/* This file analyses employee costs given their out of pocket costs in whatever calculation output file we're using as our input file (this is something the do file user can change).  
Please view the following for the various input files and their description:
(1) `directory'/data/Calculator/'acgbase'/calc_output/`year'/calcrun_acg0_`dateofrun'_`runtype'.dta
	- this is the calculator output file made in the latest version of "`directory'/do/Calculator/`acgbase'/oregoncalculator_`latestversion'.do", which can be run in the shell file "'samepathname'/shell_`acgbase'_`year'_fullrun.do"
	- it contains each individual-year run through every plan in their choice set given a certain set of medical and rx claims;
(2) "`directory'/data/calculator/'acgbase'/calc_input/`claimyear'/bene_PLANS_`runtype'_acg`0/1'_`yclaim'.dta" for 'yclaim' = 8/9/10/11/12/13 for 2008/2009 etc.
	- this file is made in "`directory'/do/Calculator/`acgbase'/calcinput_`latestversion'.do"
	- it contains each individual matched to every plan in their choice set. Variables include: entity*, memid, empid, familyid, personid, personidIE (xwalked personid), eligible start date, fulltime, choseplan, chosendrugplan, tier, plan drugplan, chosen.
(3) "`directory'/data/given/finalpremium_`latestdate.dta"
	- Dataset copied from Adrienne's directory here: /disk/agedisk3/oebb.work/ahsabety/Oregon/premium
	- Taken as given by Chris - this file came from `directory'/analysis/computeempprem_8-16.do	*/;

di "`cdate'" ;
di "`ctime'" ;
di "`runtype'" ;

local run1 "half" ;
local run2 "half" ;
local unit "familyid" ;
local statruntype "savingsaccount" ;
local dateofrun "30_Sep_2016" ;
local contributiondate "29_Mar_2016" ; 
local premiumfiledate "29_Mar_2016" ; /* see "analysis-premium.do" */;
local sampledate "23_Sep_2016" ; 

global calc_date 28_Sep_2016 ; 

di "`stat'";
di "`run2'";
di "`unit'";
di "`statruntype'";

cap mkdir `directory'/data/analysis/`dateofrun'/;

**********************************************start of file *****************************************************************;
	if "`runtype'" == "PF" { ;
			local end 2013 ;
		} ;
		
		if "`runtype'" == "PB" { ;
			local end 2012 ;
		} ;


if "`run1'"!="half" { ;
	forvalues claimyear=2008/`end' { ; 
		local claimyear `claimyear' ;
		global claimyear `claimyear' ;
		if "`runtype'" == "PF" { ;
			local yclaim = `claimyear' - 2000 ;
			local yplan = `claimyear' - 2000 ;
			local planyear = `claimyear' ;
		} ;
		
		if "`runtype'" == "PB" { ;
			local yclaim = `claimyear' - 2000 ; 
			local yplan = `claimyear' - 1999 ;
			local planyear = `claimyear' + 1 ;
		} ;
		
		di `claimyear' ; 
		di `yclaim';
		di `planyear' ; 
		
		if "`run2'"!="half" { ;
			include `directory'/do/3analysis/analysis-firstpiece.do;
		} ;
};
};

if "`run1'"!="stat" { ;
	forvalues claimyear=2013/`end' { ; 
	local claimyear `claimyear' ;
	global claimyear `claimyear' ;
		
	if "`runtype'" == "PF" { ;
		local yclaim = `claimyear' - 2000 ;
		local yplan = `claimyear' - 2000 ;
		local planyear = `claimyear' ;
	} ;
	
	if "`runtype'" == "PB" { ;
		local yclaim = `claimyear' - 2000 ; 
		local yplan = `claimyear' - 1999 ;
		local planyear = `claimyear' + 1 ;
	} ;
	
	di `claimyear' ; 
	di `yclaim';
	di `planyear' ;
		
		*************** getting the vision and dental information embedded ***************;
		use `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_`planyear'_`runtype'_`dateofrun'.dta, clear;
		
		isid (personid plan drugplan) ;
		
		include `directory'/do/3analysis/analysis-dv.do;
		
		isid (personid plan drugplan) ;

		* make these assert tests somehow ; 
		unique(personid visioncov dentcov) ;
		unique(personid allowedamt_med) ; 
		unique(personid allowedamt_rx) ;
		unique(personid) ;
		
		preserve ; 
			use  personid familyid using /disk/agedisk3/oebb.work/cbehrer/oregon/data/built/sample/sample_`runtype'_`planyear'_`sampledate'.dta, clear ;
			duplicates drop ; 
			tempfile sample ; 
			save `sample' ;
		restore ; 
		
		merge m:1 personid family using `sample' ; 
		pause ;
		keep if _merge == 3 ; 
		drop _merge ; 
		
		tempfile working ;
		save `working' ;
		describe ;
		di _N ;

		* taking the average dental and vision premium by choice set ;
		* this is somewhat complicated because we want to use an enrollment weighted average ;
		* however, we do not have enrollment data for 2008 and 2009, so we will use 2010 weights ; 
		* for 2008 and 2009, where we can. For entity / emp / memid's where we do not have 2010 enrollment we will ; 
		* use a straight average. For entity / emp / memid's that added plans from 2008/2009 to 2010, the 2010 ;
		* weights will not sum to 1 in 2008/2009 because not all plans available in 2010 are available in earlier ; 
		* years. In those cases we will re-weight with the sum of available plan weights as the new denominator ; 
		* in order to normalize weights to 1. All weights should sum to 1 within entitynum empid memid cells ; 
		* and we have two weights for each cell for vision and for dental, one for all plans and one for non-kaiser ; 
		* plans. We also set weights for a plan available in 2008/9 but never chosen in 2010 to 0, which is a bit of ;
		* an assumption, because the plan may or may not have been available in 2010, but we are limited to assume ; 
		* that it was available and just never chosen ; 
		use `directory'/data/built/premium/finalpremium_`premiumfiledate'.dta, clear; 
		
		keep if planyear==`planyear';
		gen planfirst=substr(plan, 1,1);
		gen dentplantype=substr(dentalplan, 1, 1);
		gen visplantype=substr(visplan, 1, 1);
			assert planfirst=="K" if visplantype=="K" ;
			assert planfirst=="K" if dentplantype=="K" ;
			
		preserve ;
			
			drop if dentalplan == "" ; 
			keep entitynum empid memid planyear dentalplan dentplantype ratestructure dentalpremium* ;
			duplicates drop ; 
			
			* get and compute weights ; 
				* `dent_wt_`year' dataset is created in the analysis-dv.do file called above ; 
				merge m:1 entitynum empid memid dentalplan using `dent_wt_`planyear'' ; 
				drop if _merge == 2; 
		
				pause ; 
				egen max_merge = max(_merge), by(entitynum empid memid) ; 
				
				* Weights need to add up to 1. If the weights from 2010 do no add to 1, because more plans were introduced ; 
				* Then reweight by 2010 enrollment among those plans available in 2008 / 2009 ; 
				egen check = sum(dental_all_weight), by(entitynum empid memid) ;
				gen re_wght_all = dental_all_weight / check ; 
				replace dental_all_weight = re_wght_all if dental_all_weight !=1 & _merge == 3 ; 
				drop check ; 
				egen check = sum(dental_all_weight), by(entitynum empid memid) ;
				replace check = round(check, 0.00001) ; 
				tab check ; 
				assert check == 1 | check == 0 ; 
				
				egen check2 = sum(dental_nonK_weight), by(entitynum empid memid) ; 
				gen re_wght_nonK = dental_nonK_weight / check2 ; 
				replace dental_nonK_weight = re_wght_nonK if dental_nonK_weight !=1 & _merge == 3 ;  
				
				drop check2 ; 
				egen check2 = sum(dental_nonK_weight), by(entitynum empid memid) ;
				replace check2 = round(check, 0.00001) ; 
				assert check2 == 1 | check == 0 ; 
				
				* If the entitynum / empid / memid cell had not enrollment information in 2010 (or did not exist) ; 
				* Then take a straight average of the available plans ; 
				gen counter = 1 ; 
				egen countplans = sum(counter), by(entitynum empid memid) ; 
				replace dental_all_weight = counter / countplans if max_merge == 1 ; 
				
				replace counter = 0 if substr(dentalplan,1,1) == "K" ; 
				drop countplans ; 
				egen countplans = sum(counter), by(entitynum empid memid) ; 
				replace dental_nonK_weight = counter / countplans if max_merge == 1 ; 
				
				pause ; 
				* if a plan is available in an entity that has enrollment data in 2010, and has a weight = . ; 
				* then it was never chosen in 2010, and it's weight should be 0 ; 
				replace dental_all_weight = 0 if dental_all_weight == . & max_merge > 1 ;
				
				gen nonKmerge = _merge if substr(dentalplan,1,1) != "K" ; 
				egen max_nonK = max(nonKmerge), by(entitynum empid memid) ; 
				
				* Dealing with when only a kaiser was chosen in 2010 - reweight nonKaiser by straight average ; 
				drop counter countplans ;
				gen counter = 1 if max_nonK == 1 & dental_nonK_weight == . & substr(dentalplan,1,1) != "K" ;
				egen countplans = sum(counter), by(entitynum empid memid) ;

				replace dental_nonK_weight = counter / countplans if dental_nonK_weight == . & max_nonK == 1 & substr(dentalplan,1,1) != "K" ;
				
				replace dental_nonK_weight = 0 if dental_nonK_weight == . &  max_nonK>1 & substr(dentalplan,1,1) != "K" ;
				 
				* kaiser plans should always have 0 non-Kaiser weights ; 
				replace dental_nonK_weight = 0 if substr(dentalplan,1,1) == "K" & dental_nonK_weight == . ; 
				 
				assert dental_nonK_weight == 0 if substr(dentalplan,1,1) == "K" ; 
				drop _merge - countplans ; 

				* need to go up one to entitynum level for stray observations - we will do this in actual creation of ;
				* premium variable below, not in weights ; 
				
				* all weights should sum to 1 or 0 by entitynum empid memid ; 
				* if it sums to 0 here, then there were not plans available to that entity / empid / memid ; 
				* we will have to assign a higher level mean below ; 
				egen check2 = sum(dental_nonK_weight), by(entitynum empid memid) ;
				replace check2 = round(check2, 0.00001) ; 
				tab check2 ; 
				assert check2 == 1 | check2 == 0 ;
				
				egen check = sum(dental_all_weight), by(entitynum empid memid) ;
				replace check = round(check, 0.00001) ; 
				tab check ; 
				assert check == 1 | check == 0 ;
			
				drop check check2 ; 
			
			* Apply weights ; 
			isid (entitynum empid memid planyear dentalplan);
			cap drop kaiser ; 
			gen kaiser = (dentplantype=="K");
			gen tier = 1 if ratestructure =="T" ;
			replace tier = 2 if ratestructure == "C" ; 
			
			forvalues x=1/4{ ;
				sort entitynum empid memid planyear ;
				pause ; 
				egen mean_T_dental_nonK_`x'=wtmean(dentalpremium`x') if tier==1 & kaiser==0 , by(entitynum empid memid planyear) weight(dental_nonK_weight) ;
				pause ; 
				egen mean_T_dental_`x'=wtmean(dentalpremium`x') if tier==1, by(entitynum empid memid planyear) weight(dental_all_weight) ;
				
				bys entitynum empid memid planyear: egen maxmean_T_dental_nonK=max(mean_T_dental_nonK_`x'); 
				assert maxmean_T_dental_nonK==mean_T_dental_nonK_`x' if mean_T_dental_nonK_`x'!=.;
				replace mean_T_dental_nonK_`x'=maxmean_T_dental_nonK if mean_T_dental_nonK_`x'==.; 
				cap drop maxmean_T_dental_nonK ;			
			} ;
		 
			egen mean_C_dental_nonK=wtmean(dentalpremium) if tier == 2 & kaiser==0, by(entitynum empid memid planyear) weight(dental_nonK_weight) ;
			egen mean_C_dental=wtmean(dentalpremium) if tier == 2 , by(entitynum empid memid planyear) weight(dental_all_weight) ;
					
			bys entitynum empid memid planyear: egen maxmean_C_dental_nonK=max(mean_C_dental_nonK);
			assert maxmean_C_dental_nonK==mean_C_dental_nonK if mean_C_dental_nonK!=.;
			replace mean_C_dental_nonK=maxmean_C_dental_nonK if mean_C_dental_nonK==.; cap drop maxmean_C_dental_nonK;
			
			pause ; 
			
			keep entitynum empid memid planyear dentalplan dentplantype ratestructure mean_* ; 
			tempfile dental_means; 
			save `dental_means' ; 
			
			restore ; 
			preserve ; 
			drop if visplan == "" ; 
			keep entitynum empid memid planyear visplan visplantype ratestructure vispremium* ;
			duplicates drop ; 
			
			pause ; 
			
			* get and compute weights ; 
				* `vis_wt_`year' dataset is created in the analysis-dv.do file called above ; 
				merge m:1 entitynum empid memid visplan using `vis_wt_`planyear'' ; 
				drop if _merge == 2; 
		
				pause ; 
				egen max_merge = max(_merge), by(entitynum empid memid) ; 
				
				* Weights need to add up to 1. If the weights from 2010 do no add to 1, because more plans were introduced ; 
				* Then reweight by 2010 enrollment among those plans available in 2008 / 2009 ; 
				egen check = sum(vision_all_weight), by(entitynum empid memid) ;
				gen re_wght_all = vision_all_weight / check ; 
				replace vision_all_weight = re_wght_all if vision_all_weight !=1 & _merge == 3 ; 
				drop check ; 
				egen check = sum(vision_all_weight), by(entitynum empid memid) ;
				replace check = round(check, 0.00001) ; 
				tab check ; 
				assert check == 1 | check == 0 ; 
				
				egen check2 = sum(vision_nonK_weight), by(entitynum empid memid) ; 
				gen re_wght_nonK = vision_nonK_weight / check2 ; 
				replace vision_nonK_weight = re_wght_nonK if vision_nonK_weight !=1 & _merge == 3 ;  
				
				drop check2 ; 
				egen check2 = sum(vision_nonK_weight), by(entitynum empid memid) ;
				replace check2 = round(check, 0.00001) ; 
				assert check2 == 1 | check == 0 ; 
				
				* If the entitynum / empid / memid cell had not enrollment information in 2010 (or did not exist) ; 
				* Then take a straight average of the available plans ; 
				gen counter = 1 ; 
				egen countplans = sum(counter), by(entitynum empid memid) ; 
				replace vision_all_weight = counter / countplans if max_merge == 1 ; 
				
				replace counter = 0 if substr(visplan,1,1) == "K" ; 
				drop countplans ; 
				egen countplans = sum(counter), by(entitynum empid memid) ; 
				replace vision_nonK_weight = counter / countplans if max_merge == 1 ; 
				
				pause ; 
				* if a plan is available in an entity that has enrollment data in 2010, and has a weight = . ; 
				* then it was never chosen in 2010, and it's weight should be 0 ; 
				replace vision_all_weight = 0 if vision_all_weight == . & max_merge > 1 ;
				
				gen nonKmerge = _merge if substr(visplan,1,1) != "K" ; 
				egen max_nonK = max(nonKmerge), by(entitynum empid memid) ; 
				
				* Dealing with when only a kaiser was chosen in 2010 - reweight nonKaiser by straight average ; 
				drop counter countplans ;
				gen counter = 1 if max_nonK == 1 & vision_nonK_weight == . & substr(visplan,1,1) != "K" ;
				egen countplans = sum(counter), by(entitynum empid memid) ;

				replace vision_nonK_weight = counter / countplans if vision_nonK_weight == . & max_nonK == 1 & substr(visplan,1,1) != "K" ;
				
				replace vision_nonK_weight = 0 if vision_nonK_weight == . &  max_nonK>1 & substr(visplan,1,1) != "K" ;
				 
				* kaiser plans should always have 0 non-Kaiser weights ; 
				replace vision_nonK_weight = 0 if substr(visplan,1,1) == "K" & vision_nonK_weight == . ; 
				 
				assert vision_nonK_weight == 0 if substr(visplan,1,1) == "K" ; 
				drop _merge - countplans ; 

				* need to go up one to entitynum level for stray observations - we will do this in actual creation of ;
				* premium variable below, not in weights ; 
				
				* all weights should sum to 1 or 0 by entitynum empid memid ; 
				* if it sums to 0 here, then there were not plans available to that entity / empid / memid ; 
				* we will have to assign a higher level mean below ; 
				egen check2 = sum(vision_nonK_weight), by(entitynum empid memid) ;
				replace check2 = round(check2, 0.00001) ; 
				tab check2 ; 
				assert check2 == 1 | check2 == 0 ;
				
				egen check = sum(vision_all_weight), by(entitynum empid memid) ;
				replace check = round(check, 0.00001) ; 
				tab check ; 
				assert check == 1 | check == 0 ;
			
				drop check check2 ; 
			
			* Apply weights ; 
			isid (entitynum empid memid planyear visplan);
			cap drop kaiser ; 
			gen kaiser = (visplantype=="K");
			gen tier = 1 if ratestructure =="T" ;
			replace tier = 2 if ratestructure == "C" ; 
			
			forvalues x=1/4{ ;
				sort entitynum empid memid planyear ;
				pause ; 
				egen mean_T_vis_nonK_`x'=wtmean(vispremium`x') if tier==1 & kaiser==0 , by(entitynum empid memid planyear) weight(vision_nonK_weight) ;
				pause ; 
				egen mean_T_vis_`x'=wtmean(vispremium`x') if tier==1, by(entitynum empid memid planyear) weight(vision_all_weight) ;
				
				bys entitynum empid memid planyear: egen maxmean_T_vis_nonK=max(mean_T_vis_nonK_`x'); 
				assert maxmean_T_vis_nonK==mean_T_vis_nonK_`x' if mean_T_vis_nonK_`x'!=.;
				replace mean_T_vis_nonK_`x'=maxmean_T_vis_nonK if mean_T_vis_nonK_`x'==.; 
				cap drop maxmean_T_vis_nonK ;			
			} ;
		 
			egen mean_C_vis_nonK=wtmean(vispremium) if tier == 2 & kaiser==0, by(entitynum empid memid planyear) weight(vision_nonK_weight) ;
			egen mean_C_vis=wtmean(vispremium) if tier == 2 , by(entitynum empid memid planyear) weight(vision_all_weight) ;
					
			bys entitynum empid memid planyear: egen maxmean_C_vis_nonK=max(mean_C_vis_nonK);
			assert maxmean_C_vis_nonK==mean_C_vis_nonK if mean_C_vis_nonK!=.;
			replace mean_C_vis_nonK=maxmean_C_vis_nonK if mean_C_vis_nonK==.; cap drop maxmean_C_vis_nonK;
			
			pause ; 
			
			keep entitynum empid memid planyear visplan visplantype ratestructure mean_* ; 

			tempfile vision_means; 
			save `vision_means' ; 
		
		restore ; 
		
		merge m:1 entitynum empid memid planyear dentalplan dentplantype ratestructure using `dental_means' ; 
		tab _merge ; 
		rename _merge dentmeanmerge ; 
		
		pause ; 
		
		assert dentalplan == "" if dentmeanmerge == 1 ; 
				
		pause ; 
		merge m:1 entitynum empid memid planyear visplan visplantype ratestructure using `vision_means' ; 
		tab _merge ; 
		rename _merge vismeanmerge ;
		
		pause ; 
		
		assert visplan == "" if vismeanmerge == 1 ; 
		
		pause ; 
		drop vismeanmerge dentmeanmerge ; 
		
		local listvar empamt empamt1 empamt2 empamt3 empamt4;
		foreach var of local listvar { ;
			replace `var'=0 if `var'==.;
		} ;

		preserve ;
		
		* This section of manipulating vision and dental premiums fills in the composite rate and tiered rates for each dental / vision plan on one line, identified by entity empid memid planyear and vision/dental plan ; 
		* The max function is just used to pull the value across lines, it could be min/mode etc. and wouldn't change results ; 
		
		pause ; 
		
		gen kaiser = (visplantype=="K");
		keep entitynum empid memid planyear visplan vispremium* kaiser ;
		rename visplan visionplan;
		drop if visionplan=="";
		
		duplicates drop;

		bys  entitynum empid memid planyear visionplan kaiser : gen count=_N;
		bys  entitynum empid memid planyear visionplan kaiser : egen max=max(vispremium);
		recast double max;
		format vispremium %9.2f	;

		replace vispremium=max if vispremium==. & count  >1 ;
		forvalues x=1/4 { ;
			bys  entitynum empid memid planyear visionplan kaiser : egen max`x'=max(vispremium`x');
			replace vispremium`x'=max`x' if vispremium`x'==. & count  >1 ; 
			format vispremium`x' %9.2f;						
		} ;
		
		drop count max*;  
		duplicates drop ;
		isid(entitynum empid memid planyear visionplan kaiser) ;
		pause ; 
		tempfile visprem;
		save `visprem';
		restore ;

		preserve ;
		
		gen kaiser = (dentplantype=="K");
		keep entitynum empid memid planyear dentalplan dentalpremium* kaiser ;

		drop if dentalplan=="";	
		bys  entitynum empid memid planyear dentalplan kaiser : gen count=_N;
		bys  entitynum empid memid planyear dentalplan kaiser : egen max=max(dentalpremium);
		recast double max;
		format dentalpremium %9.2f	;
		replace dentalpremium=max if dentalpremium==. & count  >1 ;
		forvalues x=1/4 { ;
			bys  entitynum empid memid planyear dentalplan kaiser : egen max`x'=max(dentalpremium`x');
			replace dentalpremium`x'=max`x' if dentalpremium`x'==. & count  >1 ; 
			format dentalpremium`x' %9.2f;						
		} ;

		drop count max*;
		duplicates drop;
		isid (entitynum empid memid planyear dentalplan) ;

		duplicates drop entitynum empid memid planyear dentalplan, force;
		tempfile dentprem;
		save `dentprem';

		restore ;				

		list in 1;
		drop dentalplan dentalpremium* visplan* vispremium* dentplantype;
		duplicates drop;	
		gen kaiser=(planfirst=="K");
		
		* this file is not just dental or vision, it is medical and drug premiums and average dental/visions ; 
		list entitynum memid empid planyear plan rate mean_T_v* if entitynum == 2252 | entitynum == 2103 | entitynum == 2148 ;
		
		* Here we need to replace missing means that result from no observations at an entitynum / empid / memid level ; 
		* ideally we would only have to go up one level, but in some cases we have to go up to the entitynum level ; 
		forvalues x=1/4 { ;
			bys  entitynum planyear : egen mean_eT_vis_nonK`x'=mean(mean_T_vis_nonK_`x') ;
			replace mean_T_vis_nonK_`x'=mean_eT_vis_nonK`x' if mean_T_vis_nonK_`x'==. & ratestructure =="T" ; 			
		} ;
		list entitynum memid empid planyear plan rate mean_T_v* mean_eT_v* if entitynum == 2252 | entitynum == 2103 | entitynum == 2148 ;
		pause ; 
		forvalues x=1/4 { ;
			bys  entitynum planyear : egen mean_eT_dental_nonK`x'=mean(mean_T_dental_nonK_`x') ;
			replace mean_T_dental_nonK_`x'=mean_eT_dental_nonK`x' if mean_T_dental_nonK_`x'==. & ratestructure =="T" ;		
		} ;
		
		bys  entitynum planyear : egen mean_eC_vis_nonK=mean(mean_C_vis_nonK) ;
		replace mean_C_vis_nonK=mean_eC_vis_nonK if mean_C_vis_nonK==. & ratestructure =="C" ;
		
		bys  entitynum planyear : egen mean_eC_dental_nonK=mean(mean_C_dental_nonK) ;
		replace mean_C_dental_nonK=mean_eC_dental_nonK if mean_C_dental_nonK==. & ratestructure =="C" ;
		
		isid (entitynum empid memid planyear plan drugplan kaiser) ;
		tempfile dentvispost10;
		save `dentvispost10';	
	
		tempfile dentvispre10;
		save `dentvispre10';
		* Use pre10 for all premiums, use post10 just for med/rx premiums, dent/vis premiums are added separately because we observe dent/vis plan post10 ; 
		
		use `working', clear;
		
		* There is one entitynum / empid / memid / planyear cell, in which there was no OMED vision plan offered ; 
		* However, there was a Kaiser vision plan offered. How do we model these individuals who chose Kaiser in an OMED plan? There is no hypothetical vision plan whose premium was can assign. We do not consider vision claims. I'm dropping them for today (9/15/2015) and emailing jon and jason about it. ;

		di "Prior to DV merge";
		unique(personid);
		if `planyear' < 2010 { ;
			merge m:1 entitynum empid memid planyear plan drugplan kaiser using `dentvispre10', keep (1 3);
			* merge on premium amounts. Vision and dental will not be counted below if dent/viscov respectively = 0 ; 
			tab _merge; 
			di "Post DV merge";
			unique(personid);
			unique(personid dentcov visioncov);
			
			gen entfirst=floor(entitynum/1000);
			* drop masked entities - I do not think we should have any by now ; 
			drop if entfirst==5; 
			assert _merge==3;  
		} ;	
		
		* why 3 merges? ;
		if `planyear' >2009 { ;	
			cap drop kaiser;
			gen visplantype=substr(visionplan, 1, 1);
			gen kaiser=(visplantype=="K");

			gen entfirst=floor(entitynum/1000);
			drop if entfirst==5;
			
			merge m:1 entitynum empid memid planyear visionplan kaiser using `visprem', keep (1 3);
			
		
			pause ; 
			
			assert _merge==1 if visionplan==""; rename _merge mergevis;

			* this effects a small number of people ; 
			drop if visioncov==1 & mergevis ==1 ; // need to fix this -- see email to Mary about weird vision plans;
			
			pause ; 
			assert visioncov ==0 if mergevis ==1;

			cap drop kaiser;
			cap drop dentplantype ; 
			gen dentplantype=substr(dentalplan, 1, 1);
			gen kaiser=(dentplantype=="K");
			
			merge m:1 entitynum empid memid planyear dentalplan kaiser using `dentprem', keep (1 3);
			pause ; 
			assert _merge==1 if dentalplan==""; rename _merge mergedent;
			pause ; 
			assert dentcov==0 if mergedent==1 ; 
			
			cap drop kaiser;
			gen kaiser=(planfirst=="K");
			merge m:1 entitynum empid memid planyear plan drugplan kaiser using `dentvispost10', keep (1 3); 
			pause ; 
			assert _merge==3;
			* no MMEDH ; 
			rename dentalplan chosendentalplan;
			rename visionplan chosenvisionplan;
			
			tab _merge; cap drop entfirst;
			gen entfirst=floor(entitynum/1000);
			drop if entfirst==5;
		} ;
		
		* checks on data ;
		pause ; 
		assert _merge==2 if planyear !=`planyear'; cap drop _merge;
		assert planyear !=.;

		gen tag=1 if  premium_rxmed ==. & premium_rxmed1 ==. & premium_rxmed2 ==. & premium_rxmed3 ==. & premium_rxmed4 ==.;
		assert tag !=1; drop tag;
		
		* dealing with medical==5 - note that there are individuals with medical==5 and missing empamts;
		* in the dental vision runs we're going to drop medical=5 because we are considering district contributions;
		assert medical ~=.;
		bys personid: egen medmax=max(medical);
		
		tab medmax ; 
	
		drop if medmax==5; 

		assert sum_cc_in !=.;
		assert sum_cc_out !=.;
		assert sum_uncap !=.;
		assert sum_cc_drug !=.;
		assert sum_deductible !=.;

		gen orig_sum = orig_sum_med + orig_sum_drug ; 
		replace orig_sum = round(orig_sum,0.01) ;
		unique(personid orig_sum) ; 
		unique(personid) ; 

		pause ; 
		
		* assigning all premium costs to premium;
		replace premium_rxmed=premium_rxmed1 if tier==1 & ratestructure=="T" & premium_rxmed==.;
		replace premium_rxmed=premium_rxmed2 if tier==2 & ratestructure=="T" & premium_rxmed==.;
		replace premium_rxmed=premium_rxmed3 if tier==3 & ratestructure=="T" & premium_rxmed==.;
		replace premium_rxmed=premium_rxmed4 if tier==4 & ratestructure=="T" & premium_rxmed==.;
			assert premium_rxmed !=.;
			
		replace medpremium=medpremium1 if tier==1 & ratestructure=="T" & medpremium==.;
		replace medpremium=medpremium2 if tier==2 & ratestructure=="T" & medpremium==.;
		replace medpremium=medpremium3 if tier==3 & ratestructure=="T" & medpremium==.;
		replace medpremium=medpremium4 if tier==4 & ratestructure=="T" & medpremium==.;
			assert medpremium !=. if `planyear' < 2011;
			
		replace rxpremium=rxpremium1 if tier==1 & ratestructure=="T" & rxpremium==.;
		replace rxpremium=rxpremium2 if tier==2 & ratestructure=="T" & rxpremium==.;
		replace rxpremium=rxpremium3 if tier==3 & ratestructure=="T" & rxpremium==.;
		replace rxpremium=rxpremium4 if tier==4 & ratestructure=="T" & rxpremium==.;
			assert rxpremium !=. if `planyear' < 2011;
		
		pause ; 
		
		* assigning all employee costs to empamt;
		
		replace empamt = . if ratestructure == "T" ;
		
		pause ;
		
		replace empamt=empamt1 if tier==1 & ratestructure=="T";
		replace empamt=empamt2 if tier==2 & ratestructure=="T";
		replace empamt=empamt3 if tier==3 & ratestructure=="T";
		replace empamt=empamt4 if tier==4 & ratestructure=="T";
			assert empamt !=.;
		
	
		pause ; 
		
		unique(personid plan empamt);
		unique(personid plan);
		* CB: we've lost observations, but still have multiple observations per person per plan;
		*empamt does not vary within a person/plan combination in 2008;
		* as of 10/21 by the end of the dental vision section this is not the case and is a problem;
		forvalues x=1/4 { ;
			drop premium_rxmed`x';
			drop empamt`x';
		} ;

		
		* coding for different cases;
		* the empamt currently does not include dental and vision amounts -- MODIFYING to include; 

		gen dentamt=.;
		gen visamt=.;
		cap drop tag;
		
		pause ; 
		
		if `planyear' < 2010 { ;

			* apply the chosen dental premium to the contribution amount, code for exceptions;
			forvalues x=1/4 { ;
				gen dentamt`x'=mean_T_dental_`x' if ratestructure=="T" & dentcov==1 & planfirst=="K";
				
				replace dentamt`x'=mean_T_dental_nonK_`x' if ratestructure=="T" & dentcov==1 & planfirst!="K";
				gen tag=1 if dentamt`x'==. & ratestructure =="T" & dentcov ==1;  
				assert tag==.; cap drop tag;
			} ;
	
			replace dentamt=mean_C_dental if ratestructure=="C" & dentcov==1 & planfirst=="K";
			replace dentamt=mean_C_dental_nonK if ratestructure=="C" & dentcov==1 & planfirst!="K";
			gen tag=1 if dentamt==. & ratestructure =="C" & dentcov ==1;  
			assert tag==.;  
			cap drop tag;
			
			* apply the chosen vision premium to the contribution amount, code for exceptions ;
			forvalues x=1/4 { ;
				gen visamt`x'=mean_T_vis_`x' if ratestructure=="T" & visioncov==1 & planfirst=="K";
				pause ;
				replace visamt`x'=mean_T_vis_nonK_`x' if ratestructure=="T" & visioncov==1 & planfirst!="K";
				gen tag=1 if visamt`x'==. & ratestructure =="T" & visioncov ==1;  
				assert tag==.; 
				cap drop tag;
			} ;
	
			replace visamt=mean_C_vis if ratestructure=="C" & visioncov==1 & planfirst=="K";
			replace visamt=mean_C_vis_nonK if ratestructure=="C" & visioncov==1 & planfirst!="K";
			gen tag=1 if visamt==. & ratestructure =="C" & visioncov ==1;
			
			assert tag==.;
			cap drop tag;

		} ;
		
		pause ; 
		
		if `planyear' > 2009 { ;

			* apply the chosen dental premium to the contribution amount, code for exceptions ;
			gen dentfirst=substr(chosendentalplan, 1, 1);
			
			forvalues x=1/4 { ;
				gen dentamt`x'=dentalpremium`x' if ratestructure=="T" & dentcov==1 & dentfirst=="K" & planfirst=="K";
				replace dentamt`x'=dentalpremium`x' if ratestructure=="T" & dentcov==1 & dentfirst!="K" ;
				replace dentamt`x'=mean_T_dental_`x' if ratestructure=="T" & dentcov==1 & planfirst=="K" & dentamt`x'==. ;
				replace dentamt`x'=mean_T_dental_nonK_`x' if ratestructure=="T" & dentcov==1 & dentfirst=="K"  & planfirst!="K" & dentamt`x'==. ;
				gen tag=1 if dentamt`x'==. & ratestructure =="T" & dentcov ==1;
				assert tag==.;
				cap drop tag;
			} ;

			replace dentamt=dentalpremium if ratestructure=="C" & dentcov==1 & dentfirst=="K" & planfirst=="K";
			replace dentamt=dentalpremium if ratestructure=="C" & dentcov==1 & dentfirst!="K" ;
			replace dentamt=mean_C_dental if ratestructure=="C" & dentcov==1 & planfirst=="K" & dentamt==. ;
			replace dentamt=mean_C_dental_nonK if ratestructure=="C" & dentcov==1 & planfirst!="K" & dentamt==. ;
			
			gen tag=1 if dentamt==. & ratestructure =="C" & dentcov ==1;
			
			assert tag==.;
			cap drop tag;
			
			* apply the chosen vision premium to the contribution amount, code for exceptions ;
			gen visfirst=substr(chosenvisionplan, 1, 1);
			
			forvalues x=1/4 { ;
				gen visamt`x'=vispremium`x' if ratestructure=="T" & visioncov==1 & visfirst=="K" & planfirst=="K";
				replace visamt`x'=vispremium`x' if ratestructure=="T" & visioncov==1 & visfirst!="K" ;
				replace visamt`x'=mean_T_vis_`x' if ratestructure=="T" & visioncov==1 & planfirst=="K" & visamt`x'==. ;
				replace visamt`x'=mean_T_vis_nonK_`x' if ratestructure=="T" & visioncov==1 & visfirst=="K"  & planfirst!="K" & visamt`x'==. ;
				gen tag=1 if visamt`x'==. & ratestructure =="T" & visioncov ==1;  assert tag==.; cap drop tag;
			} ;

			replace visamt=vispremium if ratestructure=="C" & visioncov==1 & visfirst=="K" & planfirst=="K";
			replace visamt=vispremium if ratestructure=="C" & visioncov==1 & visfirst!="K" ;
			replace visamt=mean_C_vis if ratestructure=="C" & visioncov==1 & planfirst=="K" & visamt==. ;
			replace visamt=mean_C_vis_nonK if ratestructure=="C" & visioncov==1 & planfirst!="K" & visamt==. ;
			
			gen tag=1 if visamt==. & ratestructure =="C" & visioncov ==1;
			
			assert tag==.;
			cap drop tag;
		} ;
		
		* we've gained observations since the last pause point ;
		* but we've lost people, perhaps we do not have dental/vision plan info on them.  ;
		* we still have the numerical precision issue with 8 observations, but now we have ;
		* 124,388 person/ttl_allowed combinations in 2008, rather than 126,012 ;
	
		gen empamt_dv=.;
		
		* we need to calculate total premium that the employee faces ; 
		* empamt already takes into account the subsidy applied to the medical / rx premium ; 
		* if it is a fixed contribution, and there is any left for dental / vision, then we are okay ; 
		* the current empamt will be negative, and we can just add, provided the contribution is allowed to go to dental / vision ; 
		* this is indicated by dental/vision indicators ; 
		* the complication is for non-fixed district contributions ; 
		* we need to apply the % based subsidies to dental and vision ; 
		* AND make sure that any fixed employee amounts are not increased by dental and vision premiums ; 
		
		* these two don't necessarily have to be true - but if they are not then below gets a lot more complicated ; 
		tab vision visioncov ; 
		tab dental dentcov ; 
		
		* in 2013 one entity 4821 has excess contribution that is not allowed to go to dental and vision ; 
		* thankfully the HSA and HRA contributions for that entity are flat, and not calculated out of excess ; 
		* so we need to set the empamt here to 0 so we can add dental and vision premiums to them below ; 
		replace empamt = 0 if empamt < 0 & entitynum == 4821 ; 
		
		replace subsidy_pct_comp = 0 if subsidy_pct_comp == . ; 
		replace subsidy_pct_t1 = 0 if subsidy_pct_t1 == . ; 
		replace subsidy_pct_t2 = 0 if subsidy_pct_t2 == . ; 
		replace subsidy_pct_t3 = 0 if subsidy_pct_t3 == . ; 
		replace subsidy_pct_t4 = 0 if subsidy_pct_t4 == . ; 
		
		assert subsidy_pct_comp == 0 if fixeddesc != 8 ; 
		assert subsidy_pct_t1 == 0 if fixeddesc != 7 ; 
		assert subsidy_pct_t2 == 0 if fixeddesc != 7 ; 
		assert subsidy_pct_t3 == 0 if fixeddesc != 7 ; 
		assert subsidy_pct_t4 == 0 if fixeddesc != 7 ; 
		di "this following assert doesn't have to be true, but would be unexpected and would complicated below" ; 
		assert ratestructure !="C" if fixeddesc == 7 ; 
		gsort -fixeddesc personid plan ; 
		
		
		gen gross_prem = . ; 
		replace gross_prem=premium_rxmed + dentamt +visamt if ratestructure=="C" & dentcov==1 & visioncov==1 ; 
		replace gross_prem=premium_rxmed + dentamt if ratestructure=="C" & dentcov==1 & visioncov==0 ; 
		replace gross_prem=premium_rxmed + visamt if ratestructure=="C" & visioncov==1 & dentcov==0 ; 
		replace gross_prem=premium_rxmed if dentcov==0 & visioncov==0 ;
		
		gen gross_dent_prem = dentamt if ratestructure =="C" & dentcov == 1 ; 
		gen gross_vis_prem = visamt if ratestructure == "C" & visioncov == 1 ;
		
		forvalues x=1/4 { ;
		replace gross_prem=premium_rxmed + dentamt`x' + visamt`x' if ratestructure=="T" & dentcov==1 & visioncov==1 & tier == `x' & gross_prem == .  ;
		replace gross_prem=premium_rxmed + dentamt`x' if ratestructure=="T" & dentcov==1 & visioncov==0 & tier == `x' & gross_prem == . ;
		replace gross_prem=premium_rxmed + visamt`x' if ratestructure=="T" & dentcov==0 & visioncov==1 & tier == `x' & gross_prem == .  ;
		replace gross_prem=premium_rxmed if dentcov==0 & visioncov==0 & tier == `x' & gross_prem == .  ; 
		
		replace gross_dent_prem = dentamt`x' if ratestructure == "T" & tier == `x' & gross_dent_prem == . & dentcov == 1;
		replace gross_vis_prem = visamt`x' if ratestructure == "T" & tier == `x' & gross_vis_prem == . & visioncov == 1 ;		
		} ;
		
		replace gross_dent_prem = 0 if dentcov == 0 ; 
		replace gross_vis_prem = 0 if visioncov == 0 ; 
		
		assert gross_prem != . ;	
		assert gross_dent_prem != . ; 
		assert gross_vis_prem != . ; 

		sum dentamt if fixeddesc == 8 ;
		sum visamt if fixeddesc == 8 ; 
		replace dentamt = (1-subsidy_pct_comp)*dentamt if fixeddesc == 8 ; 
		replace visamt = (1-subsidy_pct_comp)*visamt if fixeddesc == 8 ; 
		
		sum dentamt if fixeddesc == 8 ;
		sum visamt if fixeddesc == 8 ; 
		
		sum dentamt1 if fixeddesc == 7 ;
		sum visamt1 if fixeddesc == 7 ; 
		sum dentamt2 if fixeddesc == 7 ;
		sum visamt2 if fixeddesc == 7 ;
		forvalues x=1/4 { ;
			replace dentamt`x' = (1-subsidy_pct_t`x')*dentamt`x' if fixeddesc == 7 & ratestructure == "T"  ; 
			replace visamt`x' = (1-subsidy_pct_t`x')*visamt`x' if fixeddesc == 7  & ratestructure == "T"  ; 
			replace dentamt`x' = (1-subsidy_pct_comp)*dentamt`x' if fixeddesc == 8  & ratestructure == "T"  ; 
			replace visamt`x' = (1-subsidy_pct_comp)*visamt`x' if fixeddesc == 8 & ratestructure == "T" ; 
			gen empamt_dv`x'=empamt + dentamt`x' if ratestructure=="T" & dentcov==1 & visioncov==0 & fixeddesc != 5 ;
			replace empamt_dv`x'=empamt + dentamt`x' + visamt`x' if ratestructure=="T" & dentcov==1 & visioncov==1 & fixeddesc != 5 ;
			replace empamt_dv`x'=empamt +  visamt`x' if ratestructure=="T" & dentcov==0 & visioncov==1 & fixeddesc != 5 ;
			replace empamt_dv`x'=empamt if dentcov==0 & visioncov==0 & fixeddesc != 5 ;
			replace empamt_dv`x'=empamt if fixeddesc == 5 ;  
		} ;
		sum dentamt1 if fixeddesc == 7 ;
		sum visamt1 if fixeddesc == 7 ; 
		sum dentamt2 if fixeddesc == 7 ;
		sum visamt2 if fixeddesc == 7 ; 
		pause ; 
		replace empamt_dv=empamt + dentamt +visamt if ratestructure=="C" & dentcov==1 & visioncov==1 & fixeddesc != 4 ; 
		replace empamt_dv=empamt + dentamt if ratestructure=="C" & dentcov==1 & visioncov==0 & fixeddesc != 4 ; 
		replace empamt_dv=empamt + visamt if ratestructure=="C" & visioncov==1 & dentcov==0 & fixeddesc != 4 ; 
		replace empamt_dv=empamt if dentcov==0 & visioncov==0 & fixeddesc != 4 ;
		replace empamt_dv=empamt if fixeddesc == 4 ; 
		
		* assigning all employee costs to empamt ;
		replace empamt_dv=empamt_dv1 if tier==1 & ratestructure=="T" & empamt_dv==.;
		replace empamt_dv=empamt_dv2 if tier==2 & ratestructure=="T" & empamt_dv==.;
		replace empamt_dv=empamt_dv3 if tier==3 & ratestructure=="T" & empamt_dv==.;
		replace empamt_dv=empamt_dv4 if tier==4 & ratestructure=="T" & empamt_dv==.;
		assert empamt_dv !=.;
		
		gen subsidy = gross_prem - empamt_dv ; 
		pause ; 
		
		* check that everyone has an amount ;
		gen empty=0;
		replace empty=1 if  empamt_dv==. &  (dentcov==1 | visioncov==1);
		assert empty==0; 
		
		pause ; 
		
		forvalues x=1/4 { ;
			drop empamt_dv`x';
		} ;

		sum dentamt, detail ; 
		sum dentamt1, detail ; 
		sum dentamt2, detail ; 
		sum dentamt3, detail ; 
		sum dentamt4, detail ; 
		
		sum visamt, detail ; 
		sum visamt1, detail ; 
		sum visamt2, detail ; 
		sum visamt3, detail ; 
		sum visamt4, detail ; 		
		
		drop *first empamt empty   mean* dentamt-visamt4 ;  cap drop visplantype; cap drop vispremium-mergedent; 
		cap drop tag;

		pause ; 
		
		duplicates drop;
		* 0 obs dropped in 2008 - same as prior comment ;
		
		replace orig_sum_med = round(orig_sum_med, 0.001) ;
		replace orig_sum_drug = round(orig_sum_drug, 0.001) ;
		
		unique(personid) ; 
		unique(personid allowedamt_rx) ;
		unique(personid allowedamt_med) ;
		unique(personid orig_sum) ; 
		unique(personid orig_sum_med) ; 
		unique(personid orig_sum_drug) ;

		* we used to assign employee to the first person that showed up, if there wasn't an employee. ;
		* I think we should drop them...if the subscriber was dropped b/c they weren't eligible or something then we shouldn't have their dependents ; 
		gen subscriber=substr(personid, 15, 9) ;
		gen employee=(subscriber ==familyid) ;
		bys familyid: egen maxemployee=max(employee) ;
		tab maxemployee ;

		 
		di "CHECK subscribers" ;

		pause ; 
		drop if maxemployee == 0 ; 
		
		* for ods plans assigned to more than one drug plan, just keep their actual chosen plan ;
		bys personid plan: gen count=_N if ods==1;
		gen numericdrug=1 if drugplan=="ORXA" & ods==1 & count !=1;
		replace numericdrug=2 if drugplan=="ORXB" & ods==1 & count !=1 ;
		replace numericdrug=3 if drugplan=="ORXC" & ods==1 & count !=1 ;

		gen replacerxtemp=numericdrug if chosen==1 & ods==1 & plan !="OMED9";
		bys familyid ods: egen replacerx1=mode(replacerxtemp) if ods==1 & count !=1; set type double; 
		* ideal, take chosen orx plan;
		di "Check when chosen drug is missing"  ;
		tab numericdrug ; 
		pause ; 
		
		bys familyid plan ods: egen minprem=min(premium_rxmed) if ods==1 & replacerx1==. & count !=1; // second ideal, choose minimum premium;
		replace replacerx1=numericdrug if minprem==premium_rxmed & ods==1 & replacerx1==. & count !=1 ; // second ideal;
 
		if `planyear' > 2010 { ;
			gsort personid plan -chosen drugplan;
			egen tag2=tag(personid plan) if ods==1 & count !=1; // fourth ideal, just randomly choose one;
			replace replacerx1=numericdrug if tag2==1 & replacerx1==. & ods==1 & count !=1; 
			bys familyid ods: egen replacerx=max(replacerx1) if count !=1 & ods==1;
		} ;

		if `planyear' < 2011 { ;
			bys familyid ods: egen replacerx=mode(replacerx1) if count !=1 & ods==1; 
			bys familyid ods: egen replacerx2 = max(replacerx1) if count!=1 & ods == 1; 
			replace replacerx = replacerx2 if count!=1 & ods == 1 & replacerx == .; 
		} ;
		
		assert replacerx !=. if ods==1 & count !=1 & plan != "OMED9";
		drop if numericdrug != replacerx & ods==1 & plan!="OMED9" & count !=1 & replacerx!=. & numericdrug!=. ;
		di "Check if this drug stuff is necessary" ; 
		pause ; 
		* still at 124,388 people for 2008 though;
		bys personid plan dentcov visioncov: gen count2=_N if ods==1 ;
		assert count2==1 if ods==1 & plan!="OMED9" ;  
		drop count* replacerx* minprem numericdrug ; 
		cap drop tag2 ;
	

		unique(personid plan) ; 
		unique(personid plan empamt_dv) ; 
		* make sure there is no variation in empamt_dv within personid plan ; 
		isid (personid plan) ;
		di "Check empamt_dv variation" ;
		pause ; 
		
		* make sure premium only applies once per family ;
		replace gross_prem =0 if employee==0;
		replace gross_vis_prem =0 if employee==0;
		replace gross_dent_prem =0 if employee==0;
		replace premium_rxmed=0 if employee==0;
		replace empamt_dv=0 if employee==0;
		replace subsidy = 0 if employee == 0 ; 
		replace medpremium = 0 if employee == 0 ; 
		replace rxpremium = 0 if employee == 0 ; 
		bys familyid: egen maxprem=max(premium_rxmed);
		gen check = (premium_rxmed!=0) ; 
		egen check2 = sum(check), by(familyid plan) ; 
		tab check2 ; 
		assert check2 == 1 ; 
		assert maxprem !=0;
		drop maxprem;
		drop check check2 ; 

		gen totallowedamt=round(allowedamt_rx+allowedamt_med,10);
		* make sure there is no variation in totallowedamt within personid plan ; 
		unique(personid plan) ; 
		isid (personid plan) ; 

		drop allowedamt*;

		di "planyear is `planyear'";
		di "claimyear is `claimyear'" ;
		compress;
		
		duplicates drop;

		di "PRE COLLAPSE DATASET DESCRIPTION";
		describe;
		di _N;
		unique(personid);
		unique(personid plan);
		isid (personid plan);
		unique(familyid) ;
		unique(familyid plan) ;
		
		pause ;
		
		if `unit'==familyid { ;
			replace chosen=0 if chosen==.;
			collapse (sum) sum_cc_in sum_cc_out sum_uncap sum_cc_drug sum_deductible orig_sum orig_sum_med orig_sum_drug totallowedamt subsidy gross_prem gross_dent_prem gross_vis_prem medpremium rxpremium empamt_dv prem* (max) dentcov visioncov, by (entitynum memid empid chosen familyid plan drugplan tier planyear ods ratestructure) ;
		} ;
		
		di "POST COLLAPSE DATASET DESCRIPTION" ;
		describe ;
		di _N ;
		unique(familyid) ;
		unique(familyid totallowedamt) ;
		unique(familyid plan) ;
		isid (familyid plan) ;

		gen oopcost_med = sum_cc_in + sum_cc_out + sum_uncap + sum_deductible ; 
		gen oopcost_drug = sum_cc_drug ; 
		gen ooptot = oopcost_drug + oopcost_med ;
		
		gen test9 = sum_cc_in + sum_cc_out + oopcost_drug + sum_deductible ;
		replace test9 = . if (plan != "OMED9" & plan != "MMEDH") ; 
		
		bys plan tier : sum sum_cc_in, detail ; 
		bys plan tier : sum sum_cc_out, detail ; 
		bys plan tier : sum sum_deductible, detail ; 
		bys tier : sum test9, detail ; 
		pause on ; 
		pause ; 
		egen tag=tag(familyid plan) if ods==1 & planyear ==2011 ;
		assert tag==1 if planyear==2011 & ods==1 ; 
		drop tag ;
		di "STOP" ; 

		***********************SAVINGS ACCOUNTS***********************;
		
		preserve ;
		pause ; 
		insheet using `directory'/data/built/premium/ContributionInfoSurveys_`contributiondate'.csv, names comma clear;
		
		pause ;
		tab planyear medical ;
		keep if planyear==`planyear'; 
		keep if medical==1;
		destring hracontribution, replace; 
		describe ; 

		pause ; 

		local list hsacontribution_fixed_indiv hsaoffered hsapercentageofexcess hsacontributionfamily minhsa maxhsa hraoffered hrapercentageofexcess hracontribution minhra maxhra ;
		
		foreach var of local list { ; 
			di "`var'" ;
			destring `var', replace ; 
			replace `var'=0 if `var'==.;
		} ;
		pause ; 
		
		local mo hsacontribution_fixed_indiv hsacontributionfamily hracontribution minhra maxhra  minhsa maxhsa;
		
		foreach var of local mo { ;
			di `var';
			replace `var'=`var'*12; 
		} ;
		
		keep entitynum memid empid *hsa* *hra*;
		duplicates drop;
		tempfile save;
		save `save';
		
		pause ;
		
		restore ;

		merge m:1 entitynum memid empid using `save', keep(1 3);
		
		pause ; 
		
		assert _merge !=1; drop _merge; 

		gen planfirst=substr(plan, 1, 1);

		assert hraoffered !=. ; 
		assert hsaoffered !=. ;
		
		tab plan hsaoffered ;
		tab plan hraoffered ;
		*** None of our issues == 2 flow through to the calculator;		
		
		pause ;
		
		preserve ; 
		keep if plan == "OMED9" & hsaoffered==1;
		if _N != 0 {;
			keep entitynum memid empid tier ratestructure;
			duplicates drop;
			list;
		};
		restore ;
		
		****************** applying rules ******************;
		****HSA****;
		local type hsa ;
		gen HD=1 if plan=="OMED9" | plan=="MMEDH" ; 
		gen tag=1 if HD==1 & `type'offered>0 & (planfirst=="O" | planfirst=="M") ;

		*** CB: I don't understand why we refer to difference`type' here and not `type'_offered . ; 
		
		gen excess=	0-empamt_dv if tag==1 & empamt_dv<0 & `type'offered==1 ;
		gen hsaelig = tag*hsaoffered ; 
		sum excess, detail ; 
		pause ; 
		
		* this also seems strange - why let 0 = 100% contibution? why not just code as 1 in the excel ; 
		* I'm doing that now. CB 2-22-2016. ; 
		gen potential_`type'=0 ;
		replace potential_`type'=excess if  tag==1 & `type'offered ==1 & excess!=. &  `type'percentageofexcess==0 ; 
		* this stores the excess contribution;
		tab tag ; 
		
		pause ; 
		
		replace potential_`type'=excess*`type'percentageofexcess if tag==1 & `type'offered==1 & excess!=. &  `type'percentageofexcess!=0;  
		replace potential_`type'=potential_`type'+ `type'contribution_fixed_indiv if tag==1 & `type'contribution_fixed_indiv!=0 & tier==1 & `type'offered==1 & empamt_dv<0;
		replace potential_`type'=potential_`type'+ `type'contributionfamily if tag==1 & `type'contributionfamily!=0 & tier > 1 & `type'offered==1 & empamt_dv<0;
		
		replace potential_`type'=`type'contribution_fixed_indiv if tag==1 & `type'contribution_fixed_indiv!=0 & tier==1;
		replace potential_`type'=`type'contributionfamily if tag==1 & `type'contributionfamily!=0 & tier > 1 ;
	
		tab maxhsa;
		
		replace potential_`type'=maxhsa if potential_hsa > maxhsa & maxhsa > 0 & tag==1;

		* CB CHECK - this entity has a negative subsidy in 2013 somehow ; 
		* special cases ;
	
		pause ; 
			replace empamt_dv=empamt_dv+(125*12) if tier==1 & potential_`type' > 0 & tag==1 & entitynum==9914 & `planyear'==2013 & inlist(empid,"CF","LF","FF")  ;
			replace empamt_dv=empamt_dv+(250*12) if tier >1 & potential_`type' > 0 & tag==1 & entitynum==9914 & `planyear'==2013 & inlist(empid,"CF","LF","FF") ;
			replace subsidy =subsidy-(125*12) if tier==1 & potential_`type' > 0 & tag==1 & entitynum==9914 & `planyear'==2013 & inlist(empid,"CF","LF","FF")  ;
			replace subsidy=subsidy-(250*12) if tier >1 & potential_`type' > 0 & tag==1 & entitynum==9914 & `planyear'==2013 & inlist(empid,"CF","LF","FF") ;
		pause ; 
			
		** legal maxes and mins **;	

		if `planyear'==2008 { ;
			replace potential_hsa=2900 if potential_hsa > 2900 & tier==1 & tag==1;
			replace potential_hsa=5800 if potential_hsa > 5800 & tier>1 & tag==1;  } ;
			
		if `planyear'==2009 { ;
			replace potential_hsa=3000 if potential_hsa > 3000 & tier==1 & tag==1;
			replace potential_hsa=5950 if potential_hsa > 5950 & tier>1 & tag==1;  } ;
			
		if `planyear'==2010 { ;
			replace potential_hsa=3050 if potential_hsa > 3050 & tier==1 & tag==1;
			replace potential_hsa=6150 if potential_hsa > 6150 & tier>1 & tag==1;  } ;
				
		if `planyear'==2011 { ;
			replace potential_hsa=3050 if potential_hsa > 3050 & tier==1 & tag==1;
			replace potential_hsa=6150 if potential_hsa > 6150 & tier>1 & tag==1;  } ;
			
		if `planyear'==2012 { ;
			replace potential_hsa=3100 if potential_hsa > 3100 & tier==1 & tag==1;
			replace potential_hsa=6250 if potential_hsa > 6250 & tier>1 & tag==1;  } ;
				
		if `planyear'==2013 { ;
			replace potential_hsa=3250 if potential_hsa > 3250 & tier==1 & tag==1;
			replace potential_hsa=6450 if potential_hsa > 6450 & tier>1 & tag==1;  } ;
		
		cap drop excess tag;
		
		***HRA****; 
		* One entity 1935 is complex, 100% of excess - a flat monthly amount. We need to fix this so that this deduction only applies when there ; 
		* actually is an excess, right now it is aggregative to savings accounts increasing oop costs ; 
		
		local type hra;
		gen hraelig=1 if HD==. & `type'offered >0 & (planfirst=="O" | planfirst=="M"); 
		gen excess=	0-empamt_dv if hraelig==1 & empamt_dv<0 & `type'offered==1;
		
		tab hraelig ; 
		sum excess, detail ;

		pause ; 
		
		gen potential_`type'=0;
		replace potential_`type'=excess if  hraelig==1 & `type'offered & excess!=. &  `type'percentageofexcess==0 & empamt_dv<0; // this stores the excess contribution;
		
		replace potential_`type'=excess*`type'percentageofexcess if hraelig==1 & `type'offered==1 & excess!=. &  `type'percentageofexcess!=0 & empamt_dv<0;  
		replace potential_`type'=potential_`type'+ `type'contribution if hraelig==1 & `type'contribution!=0 & `type'offered==1 & empamt_dv<0; // check 1933;
		replace potential_`type'=`type'contribution if hraelig==1 & `type'contribution!=0 & `type'offered==0; // check 1933;

		tab maxhra;
		
		replace potential_`type'=max`type' if potential_`type' > max`type' & max`type'> 0 & hraelig==1;
		replace potential_`type'=0 if potential_`type' < min`type' &  min`type' > 0 & hraelig==1; // 1923;
			
		* special cases;
		if `planyear'==2013 { ;
			replace potential_`type'=0 if entitynum==4131 & plan!="MMEDG" & hraelig==1 ;
		} ;
		
		*** legal maxes and mins ***;	

		if `planyear'==2008 { ;
			replace potential_hra=5600 if potential_hra > 5600 & tier==1 & hraelig==1;
			replace potential_hra=11200 if potential_hra > 11200 & tier>1 & hraelig==1;  
		} ;

		if `planyear'==2009 { ;
			replace potential_hra=5800 if potential_hra > 5800 & tier==1 & hraelig==1;
			replace potential_hra=11600 if potential_hra > 11600 & tier>1 & hraelig==1;  
		} ;

		if `planyear'==2010 { ;
			replace potential_hra=5950 if potential_hra > 5950 & tier==1 & hraelig==1;
			replace potential_hra=11900 if potential_hra > 11900 & tier>1 & hraelig==1;  
		} ;

		if `planyear'==2011 { ;
			replace potential_hra=5950 if potential_hra > 5950 & tier==1 & hraelig==1;
			replace potential_hra=11900 if potential_hra > 11900 & tier>1 & hraelig==1;  
		} ;
			
		if `planyear'==2012 { ;
			replace potential_hra=6050 if potential_hra > 6050 & tier==1 & hraelig==1;
			replace potential_hra=12100 if potential_hra > 12100 & tier>1 & hraelig==1; 
		} ;
			
		if `planyear'==2013 { ;
			replace potential_hra=6250 if potential_hra > 6250 & tier==1 & hraelig==1;
			replace potential_hra=12500 if potential_hra > 12500 & tier>1 & hraelig==1;  
		} ;	
	
		assert potential_hra==0 if (planfirst=="K" | planfirst=="P");
		assert potential_hsa==0 if (planfirst=="K" | planfirst=="P");
	
		sum potential_hra if potential_hra > 0;
		sum potential_hsa if potential_hsa > 0;				
		
		***************** deriving oop costs each employee faces *****************;
		
		sum empamt_dv, detail ; 
		sum potential_hra, detail ; 
		sum potential_hsa, detail ; 

		pause ; 
		replace empamt_dv=0 if empamt_dv < 0;
		replace potential_hsa=0 if potential_hsa < 0;
		replace potential_hra=0 if potential_hra < 0;
		
		sum empamt_dv, detail ; 
		sum potential_hra, detail ; 
		sum potential_hsa, detail ; 		
	
		pause ; 
		gen oopttot_savings=0;
		replace oopttot_savings=ooptot- potential_hsa if HD==1;
		replace oopttot_savings=ooptot- potential_hra if HD==.;
		replace oopttot_savings=0 if oopttot_savings < 0 ;

		sum potential_hra, detail ; 
		sum potential_hsa, detail ; 
		sum ooptot, detail ; 
		sum oopttot_savings, detail ; 
		
		gen costtot=oopttot_savings + empamt_dv ;
		assert costtot!=.; 
		
		sum costtot, detail ; 
		
		pause ;
		
		describe;

		save /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`dateofrun'/NOCAPwk_ana_precollap_`planyear'_`cdate'_savingsaccount_${acgbase}_`runtype'.dta, replace;
		
		duplicates drop;
		
		isid (familyid planyear plan) ; 

		if `unit'==familyid { ;
			replace chosen=0 if chosen==.;
			collapse (sum) ooptot oopcost_drug oopcost_med orig_sum orig_sum_med orig_sum_drug oopttot_savings totallowedamt empamt_dv costtot subsidy gross_prem gross_dent_prem gross_vis_prem medpremium rxpremium potential_hra potential_hsa premium* (max) dentcov visioncov, by (entitynum memid empid chosen familyid plan drugplan tier planyear ods ratestructure hsaelig hraelig);
		 } ;
		
		sum costtot, detail ; 
		pause ;
		pause off ; 
		save /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`dateofrun'/NOCAPworking_analysis_`planyear'_`cdate'_savingsaccount_${acgbase}_`runtype'.dta, replace;
	
	} ;
} ;

if "`runtype'" == "PF" {;
forvalues year=2008/2013 { ;
local working`year' /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`dateofrun'/NOCAPworking_analysis_`year'_`cdate'_savingsaccount_${acgbase}_`runtype'.dta;
} ;

use `working2008', clear;
forvalues year=2009/2013 { ;
append using `working`year'';
};
};

if "`runtype'" == "PB" {;
forvalues year=2009/2013 { ;
local working`year' /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`dateofrun'/NOCAPworking_analysis_`year'_`cdate'_savingsaccount_${acgbase}_`runtype'.dta;
} ;

use `working2009', clear;
forvalues year=2010/2013 { ;
append using `working`year'';
};
};

bys planyear : sum costtot, detail ; 

pause ;

tab planyear; 
cap drop _merge;
mdesc ; 
pause ; 

save /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`dateofrun'/NOCAPworking_analysis_allyears_`dateofrun'_savingsaccount_${acgbase}_`runtype'.dta, replace;

* include `directory'/do/3analysis/analysis-statistics.do ;

preserve ; // test that tier makes sense;
keep planyear familyid tier ;
duplicates drop ;
bys familyid planyear: gen count=_N ;
assert count==1 ;
restore ;