#delimit ;
clear ;

cap log close ;
set more off ;
pause off ;
local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;
local runtype "PF" ; 
local directory /disk/agedisk3/oebb.work/cbehrer/oregon ;

/* set as base or acg*/
global acgbase acg ;
di "${acgbase}" ;
cap mkdir `directory'/log/analysis/${acgbase}/`cdate'/ ;
log using `directory'/log/analysis/${acgbase}/`cdate'/analysis_firstpiece_`cdate'_`ctime'_`runtype'_${acgbase}.log, replace;
ssc inst _gwtmean ;

* just run first piece to get person level total costs ; 

local dateofrun "30_Sep_2016" ;
local sampledate "23_Sep_2016" ; 

local a_date _3_Oct_2016 ; 
local calc_date 28_Sep_2016 ; 

cap mkdir `directory'/data/analysis/`dateofrun'/;

**********************************************start of file *****************************************************************;
forvalues claimyear=2009/2013 { ; 
local claimyear `claimyear' ;
global claimyear `claimyear' ;
		
local yclaim = `claimyear' - 2000 ;
local yplan = `claimyear' - 2000 ;
local planyear = `claimyear' ;

use  personid using `directory'/data/built/sample/sample_PB_`planyear'_`sampledate'.dta, clear ;
duplicates drop ; 
drop if personid == "" ; 
tempfile personlist ; 
save `personlist' ; 

use `directory'/data/calculator/for_analysis/`dateofrun'/`claimyear'/calcrun_acg1_`a_date'_ACG.dta, clear ; 
merge m:1 personid using `personlist' ;
* only people in the sample were modelled in the calculator ; 
assert _merge != 1 ; 
keep if _merge == 3 ; 
drop _merge ; 
assert network != . if drug != 1 ; 

cap drop orig_sum ; 
gen orig_sum = origcopay + origcoin + origded ; 
replace orig_sum = round(orig_sum,0.01) ;
assert orig_sum != . ; 

keep familyid personid plan drugplan drug copay coinsurance deductible orig_sum allowedamt network nooop noded chosen ;
assert drugplan !="" | plan !="" ; 
assert personid != "" ; 
	
***separating out drug and med and then combining them together *****;
	replace drug=1 if drugplan=="OMED9";
	replace drugplan = "OMED9" if drug == 1 & drugplan == "" & plan == "OMED9"; 
	replace copay=0 if copay==.;
	replace coinsurance=0 if coinsurance==.;
	replace deductible=0 if deductible==.;
	gen cop_coin=copay+coinsurance;
	gen drugs=(drugplan!="");
	gen meds=(plan !="");
	
preserve ; 
* choice set ;
	use `directory'/data/calculator/june2015/acg/`calc_date'/calc_input/`claimyear'/bene_PLANS_PF_acg1_`yplan'.dta, clear;
	keep familyid personid plan drugplan chosen memid empid entitynum tier  ;
	duplicates drop;
	merge m:1 personid using `personlist' ; 
	* choice set data and sample list include the same people ; 
	assert _merge == 3 ; 
	keep if _merge == 3 ; 
	drop _merge ; 
	tempfile choiceset;
	save `choiceset';
restore ;	

replace noded = 0 if noded == . ; 
assert deductible == 0 if noded == 1 ; 
replace nooop = 0 if nooop == . ; 

preserve ; 
* separating out drug claims ;
	keep if drug==1;
	gen cop_coin_drug = copay + coinsurance ;
	assert cop_coin_drug !=. ;
	assert drugplan != "" ; 
	rename orig_sum orig_sum_drug ; 
	rename deductible deductible_drug ;

	collapse (sum) cop_coin_drug allowedamt orig_sum_drug deductible_drug, by (personid drugplan);

	joinby personid drugplan using `choiceset', unmatched(both) ; 
 
	* joining in choice set to assign a medplan to each drugplan ; 
	* THIS GIVES PEOPLE WITH NO DRUG CLAIMS 0 COST AND INCLUDES THEM IN THE SAMPLE ;
	replace allowedamt=0 if allowedamt==.;
	replace cop_coin_drug=0 if cop_coin_drug==.;
	replace deductible_drug=0 if deductible_drug==.;
	rename allowedamt allowedamt_rx; 
	assert _merge!=1;
	drop _merge ;
	
	tempfile drugoop;
	save `drugoop';
restore ;

preserve ; 
* separating out med claims;
	drop if drug == 1 ;
	gen capped_med = . ; 
	gen uncapped_med = . ; 
	
	* There are 4 cases: 
		* 1) Nooop = 1 plan == omed - neither copay nor coinsurance are capped_med
		* 2) Nooop = 0 plan == omed - coinsurance is capped copay is not
		* 3) Nooop = 1 plan == kaiser - neither copay nor coinsurance are capped ; 
		* 4) Nooop = 0 plan == kaiser - copay & consurance are capped ; 
	
	replace capped_med = coinsurance if nooop == 0 & (substr(plan,1,1)=="O" | substr(plan,1,1)=="P" | substr(plan,1,1)=="M") ; 
	replace uncapped_med = coinsurance + copay if nooop == 1 & (substr(plan,1,1)=="O" | substr(plan,1,1)=="P" | substr(plan,1,1)=="M") ; 
	replace uncapped_med = copay if nooop == 0 & (substr(plan,1,1)=="O" | substr(plan,1,1)=="P" | substr(plan,1,1)=="M") ;
	replace capped_med = 0 if nooop == 1 ; 
	replace capped_med = coinsurance + copay if nooop == 0 & substr(plan,1,1)=="K" ; 
	replace uncapped_med = 0 if nooop == 0 & substr(plan,1,1)=="K" ; 
	replace uncapped_med = coinsurance + copay if nooop == 1 & substr(plan,1,1)=="K" ; 
	replace capped_med = 0 if nooop == 1 & substr(plan,1,1)=="K" ; 

	gen test1 = uncapped_med + capped_med ; 
	gen test2 = copay + coinsurance ; 
	gen diff = test2 - test1 ; 
	sum diff ; 

	assert diff < 0.01 ; 
	drop diff test1 test2 ; 

	assert capped_med!=. ;
	assert uncapped_med!=. ;
	rename orig_sum orig_sum_med ;
	assert plan != "" ; 
	gen rd_capped_med = round(capped_med,0.01) ;
	gen rd_uncapped_med = round(uncapped_med,0.01) ;
	gen rd_allowedamt = round(allowedamt,0.01) ;
	gen rd_orig_sum_med = round(orig_sum_med,0.01) ;
	replace capped_med = rd_capped_med ;
	replace uncapped_med = rd_uncapped_med ;
	replace allowedamt = rd_allowedamt ;
	replace orig_sum_med = rd_orig_sum_med ;
	drop rd* ; 
	rename deductible deductible_med ;
	
	gen uncap_oop_med = uncapped_med ; 
	gen cap_oop_med = capped_med ;
	
	assert network == 0 | network == 1 ; 
	gen cc_med_in = cap_oop_med if network == 1 ; 
	gen cc_med_out = cap_oop_med if network == 0 ;  

	replace cc_med_out=0 if cc_med_out==. ;
	replace cc_med_in=0 if cc_med_in==. ;

	collapse (sum) cc_med_in cc_med_out uncap_oop_med deductible_med allowedamt orig_sum_med, by (personid plan) ;

	joinby personid plan using `choiceset', unmatched(both) ; 
	
	* joining in choice set to assign a drugplan to each medplan ;
	* THIS GIVES PEOPLE WITH NO MED CLAIMS 0 COST AND INCLUDES THEM IN THE SAMPLE ;
	replace allowedamt=0 if allowedamt==. ;
	replace cc_med_out=0 if cc_med_out==. ;
	replace cc_med_in=0 if cc_med_in==. ;
	replace uncap_oop_med=0 if uncap_oop_med==. ;
	replace deductible_med=0 if deductible_med==. ;

	rename allowedamt allowedamt_med ;
	assert _merge!=1;
	drop _merge;
	tempfile medoop;
	save `medoop';
restore ;

use `drugoop', clear;
joinby familyid personid memid empid entitynum tier plan drugplan using `medoop', unmatched(both);

	replace cc_med_out=0 if cc_med_out==. ;
	replace cc_med_in=0 if cc_med_in==. ;
	replace cop_coin_drug=0 if cop_coin_drug==. ;
	replace uncap_oop_med=0 if uncap_oop_med==. ;
	replace deductible_med=0 if deductible_med==. ;
	replace deductible_drug=0 if deductible_drug==.;
	replace uncap_oop_med=0 if uncap_oop_med==. ;
		
	replace allowedamt_med=0 if allowedamt_med==. & allowedamt_rx !=.;
	replace allowedamt_rx=0 if allowedamt_rx==. & allowedamt_med !=.;
	cap drop planyear;	 	
	
	gen planyear=`planyear'; 
	tab _merge ; 
	* the drugs data set and meds dataset have both been joined with the choice set, and should have 0 drug/med costs for beneficiaries with no claims ; 
	* so the list of beneficiaries and their familyid, choice set (empid memid entity), tier and plan data should be the same in both med and drug ; 
	assert _merge == 3 ; 
	drop _merge; 

gen planfirst=substr(plan,1,1);
gen drugplanfirst=substr(drugplan,1,1);
gen ods=(planfirst=="O" | drugplanfirst=="O" | planfirst=="M" | drugplanfirst=="M");
gen prov=(planfirst=="P" | drugplanfirst=="P");
gen kaiser=(planfirst=="K" | drugplanfirst=="K");

gen rd_med = round(allowedamt_med, 0.01) ;
gen rd_rx = round(allowedamt_rx, 0.01) ;

replace allowedamt_med = rd_med ; 
replace allowedamt_rx = rd_rx ; 

drop rd_med rd_rx ; 

unique(personid) ; 
unique(personid allowedamt_med) ; 
unique(personid allowedamt_rx) ; 
* The above should all return the same count ; 
* This is not always true because of trivial rounding differences ; 
* Below tests that the same same total allowedamt (as proxy for same set of claims) is included in all counterfactual plans ; 
preserve ; 
	keep personid allowedamt_med ; 
	duplicates drop ; 
	egen max = max(allowedamt_med), by(personid) ; 
	egen min = max(allowedamt_med), by(personid) ; 
	gen diff = max - min ; 
	sum diff ; 
	assert diff < 0.001 ; 
restore ; 

preserve ; 
	keep personid allowedamt_rx ; 
	duplicates drop ; 
	egen max = max(allowedamt_rx), by(personid) ; 
	egen min = max(allowedamt_rx), by(personid) ; 
	gen diff = max - min ; 
	sum diff ; 
	assert diff < 0.001 ; 
restore ; 

replace orig_sum_drug = 0 if orig_sum_drug == . ; 
replace orig_sum_med = 0 if orig_sum_med == . ; 

mdesc ; 
gen sum_cc_in = cc_med_in ;
gen sum_cc_out = cc_med_out ;
gen sum_uncap = uncap_oop_med ; 
gen sum_cc_drug = cop_coin_drug ; 
gen sum_deductible = deductible_drug + deductible_med ;
drop cc_med_in cc_med_out uncap_oop_med cop_coin_drug deductible_drug deductible_med ; 
di "Planyear is: `planyear'";
di "Claimyear is: `claimyear'" ;
compress ;

save `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_`planyear'_ACG_`cdate'.dta, replace;
};

use `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_2009_ACG_`cdate'.dta, clear;
	append using `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_2010_ACG_`cdate'.dta ;
	append using `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_2011_ACG_`cdate'.dta ;
	append using `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_2012_ACG_`cdate'.dta ;
	append using `directory'/data/analysis/`dateofrun'/working_analysis_p1_${acgbase}_2013_ACG_`cdate'.dta ;

save `directory'/data/analysis/`dateofrun'/ACG_individuals_calcout_grossoop_noHSAHRAoffsets_`cdate'.dta, replace ; 
	
log close ; 