#delimit;
pause off ; 
di "`cdate'";
di "`ctime'";

di `planyear';
di `claimyear';
di "`statruntype'";
di "`unit'";
di "`dateofrun'";
local directory /disk/agedisk3/oebb.work/cbehrer/oregon ;
local macros `directory'/do/macros/ ;
local elig_data "/disk/agedisk3/oebb.work/cbehrer/oregon/data/cleaning/2deduplicated/deduplicated_eligibility_11_Jun_2015.dta" ;
**********************************************context *****************************************************************;
* list in 1; di _N;
di "analysis-dv `cdate'";
**********************************************start of file *****************************************************************;
tempfile working;
save `working';

/* Get dental / vision plans and coverage status */ ;
use `elig_data'; 

	tab visionplan ; 
	tab dentalplan; 
	gen structure=substr(dentalplan, 6,1) ;
	replace dentalplan=substr(dentalplan, 1, 6) if (structure=="1" | structure=="2") ; 
	replace dentalplan=substr(dentalplan, 1, 5) if (structure=="C" | structure=="T") ;  
	drop structure ;
	
	replace visionplan=substr(visionplan, 1, 5)  ;   

	tab visionplan ; 
	tab dentalplan; 
	
	drop empcode eligsrce eligflag statusgrp msa max_file popcount state mhsacov union updatedt zipcd ;
	
	gen eligdt = date(eligmonth,"MDY") ;
	format eligdt %d ;

	gen eligst = date(eligstart,"MDY") ;
	gen year = year(eligst) ;
	drop eligst ;
	gen month = month(eligdt) ;

	gen planyear = 2008 if eligdt>=mdy(10,1,2008) & eligdt <=mdy(9,30,2009) ;
	replace planyear = 2009 if eligdt >= mdy(10,1,2009) & eligdt <= mdy(9,30,2010) ;
	replace planyear = 2010 if eligdt >= mdy(10,1,2010) & eligdt <= mdy(9,30,2011) ;
	replace planyear = 2011 if eligdt >= mdy(10,1,2011) & eligdt <= mdy(9,30,2012) ;  
	replace planyear = 2012 if eligdt >= mdy(10,1,2012) & eligdt <= mdy(9,30,2013) ; 
	replace planyear = 2013 if eligdt >= mdy(10,1,2013) & eligdt <= mdy(9,30,2014) ;
	replace planyear = 2014 if eligdt >= mdy(10,1,2014) & eligdt <= mdy(9,30,2015) ;
	replace planyear = 2015 if eligdt >= mdy(10,1,2015) & eligdt <= mdy(9,30,2016) ;
	tab planyear ;
	
	* Weird new entitynums in later years ; 
	drop if substr(entitynum,1,4) == "S041";
	drop if substr(entitynum,1,4) == "S399";
	drop if substr(entitynum,1,4) == "U017";
	drop if substr(entitynum,1,4) == "U018";

	replace entitynum = "0020" if entitynum == "00020" ; 
	replace entitynum = "0020" if entitynum == "20" ; 
	
	destring entitynum, replace ;
		quietly do `macros'/unmask.do ; 

	/* cleaning dent/vision names */ ;
	* CB: I think we can just use the first 5 digits, as long as we also use 5 in the premium file ; 

	replace dentalplan = trim(dentalplan) ;
	
	gen Dplan6=substr(dentalplan,6,1) ;
	replace dentalplan=substr(dentalplan, 1, 6) if (Dplan6!="C" & Dplan6!="T") ;
	replace dentalplan=substr(dentalplan, 1, 5) if (Dplan6=="C" | Dplan6=="T") ;
	replace visionplan=substr(visionplan, 1, 5) ;
	replace plan=substr(plan, 1, 5) ;
	tab dentalplan ; 
	
	drop Dplan6 ;
	replace dentcov=0 if dentalplan=="DEC" ;
	replace dentcov=0 if dentalplan=="NE" ;
	replace visioncov=0 if visionplan=="DEC" ;
	replace visioncov=0 if visionplan=="NE" ;
	replace visionplan="" if visioncov==0 ;
	replace dentalplan="" if dentcov==0 ;
	replace dentcov=0 if dentalplan=="" & `planyear' > 2009 ;

	tempfile allprems ; 
	save `allprems' ; 
	
	* We want to use enrollment weighted averages for dental and vision plan premiums at entity/mem/emp/yr level ; 
	* We need to calculate them here. We will use 2010 enrollment for 2008 and 2009, where we do no observe plan ; 
	* we need an enrollment average among all plans, and among non-kaiser plans for vision and dental = 4 weights ; 
	* but what population? Lets use the population that we run through the calculator ; 
	
	if `claimyear' < 2010 { ;
	use `directory'/data/calculator/for_analysis/`dateofrun'/2010/calcrun_acg0_`dateofrun'_`runtype'.dta, clear;
	} ; 
	
	if `claimyear' > 2009 { ;
	use `directory'/data/calculator/for_analysis/`dateofrun'/`claimyear'/calcrun_acg0_`dateofrun'_`runtype'.dta, clear;
	} ; 
	
	keep personid ; 
	duplicates drop ; 
	replace personid = trim(personid) ; 
	tempfile beneficiaries ; 
	save `beneficiaries' ;
	
	use `allprems', clear ; 
	replace personid = trim(personid) ; 
	merge m:1 personid using `beneficiaries' ; 
	
	keep if _merge == 3 ;
	if (`planyear' == 2008 | `planyear' == 2009 | `planyear' == 2010) keep if planyear == 2010 ; 
	if `planyear' > 2010 keep if planyear == `planyear' ; 
	
	drop _merge ; 
	
	tempfile weights ; 
	save `weights' ; 	

		keep if dentcov == 1 ; 
		keep familyid entitynum memid empid dentalplan ;
		duplicates drop ;
		sort entitynum empid memid dentalplan ; 
		gen counter = 1 ;
		egen all = sum(counter), by(entitynum memid empid) ;
		egen planct = sum(counter), by(entitynum empid memid dentalplan) ;
		gen dental_all_weight = planct / all ;
		keep entitynum memid empid dentalplan all planct dental_all_weight ;
		duplicates drop ;

		egen check = sum(dental_all_weight), by(entitynum memid empid) ; 
		replace check = round(check, 0.000001) ; 
		tab check ; 
		assert check == 1; 

		drop all planct check ;
		
		tempfile dent_wt_all_`planyear' ; 
		save `dent_wt_all_`planyear'' ; 
		
	use `weights', clear ; 
		keep if dentcov == 1 ; 
		drop if substr(dentalplan,1,1) == "K" ;
		keep familyid entitynum memid empid dentalplan ;
		duplicates drop ;
		sort entitynum empid memid dentalplan ; 
		gen counter = 1 ;
		egen all = sum(counter), by(entitynum memid empid) ;
		egen planct = sum(counter), by(entitynum empid memid dentalplan) ;
		gen dental_nonK_weight = planct / all ;
		keep entitynum memid empid dentalplan all planct dental_nonK_weight ;
		duplicates drop ;

		egen check = sum(dental_nonK_weight), by(entitynum memid empid) ; 
		replace check = round(check, 0.000001) ; 
		tab check ; 
		assert check == 1; 
		drop all planct check ;
		
		tempfile dent_wt_nonK_`planyear' ; 
		save `dent_wt_nonK_`planyear'' ; 
		
	use `dent_wt_all_`planyear'', clear ; 
		merge 1:1 entitynum empid memid dentalplan using `dent_wt_nonK_`planyear'' ; 
		drop _merge ;
	tempfile dent_wt_`planyear' ; 
	save `dent_wt_`planyear'' ;
	
	use `weights', clear ; 
		keep if visioncov == 1 ; 
		keep familyid entitynum memid empid visionplan ;
		duplicates drop ;
		sort entitynum empid memid visionplan ; 
		gen counter = 1 ;
		egen all = sum(counter), by(entitynum memid empid) ;
		egen planct = sum(counter), by(entitynum empid memid visionplan) ;
		gen vision_all_weight = planct / all ;
		keep entitynum memid empid visionplan all planct vision_all_weight ;
		duplicates drop ;

		egen check = sum(vision_all_weight), by(entitynum memid empid) ; 
		replace check = round(check, 0.000001) ; 
		tab check ; 
		assert check == 1; 
		
		drop all planct check ;

		tempfile vis_wt_all_`planyear' ; 
		save `vis_wt_all_`planyear'' ; 
		
	use `weights', clear ; 
		
		keep if visioncov == 1 ; 
		drop if substr(visionplan,1,1) == "K" ;
		keep familyid entitynum memid empid visionplan ;
		duplicates drop ;
		sort entitynum empid memid visionplan ; 
		gen counter = 1 ;
		egen all = sum(counter), by(entitynum memid empid) ;
		egen planct = sum(counter), by(entitynum empid memid visionplan) ;
		gen vision_nonK_weight = planct / all ;
		keep entitynum memid empid visionplan all planct vision_nonK_weight ;
		duplicates drop ;

		egen check = sum(vision_nonK_weight), by(entitynum memid empid) ; 
		replace check = round(check, 0.000001) ; 
		tab check ; 
		assert check == 1; 
		
		drop all planct check ;
		
		tempfile vis_wt_nonK_`planyear' ; 
		save `vis_wt_nonK_`planyear'' ; 
		
	use `vis_wt_all_`planyear'', clear ; 
		merge 1:1 entitynum empid memid visionplan using `vis_wt_nonK_`planyear'' ; 
		drop _merge ;
		rename visionplan visplan ; 
		tempfile vis_wt_`planyear' ; 
		save `vis_wt_`planyear'' ;
	* End of calculating weights ; 

use `allprems', clear ; 
	keep if planyear == `planyear' ;
	
	keep if month==10 ; // restrict to employees who appeared in October; 
	keep personid planyear entitynum empid memid familyid dentalplan visionplan dentcov visioncov plan ;
	duplicates drop ;
	
	tab dentalplan ; 
	tab visionplan ; 
	tab dentcov visioncov ; 
	
	if `planyear' > 2009 { ;
	drop plan;

	duplicates drop;

	tempfile eligpost10;
	save `eligpost10'; } ;

	if `planyear' < 2010 { ;
		keep personid planyear entitynum empid memid dentcov visioncov;
		duplicates drop;
	tempfile personid;
	save `personid';
	* We do not observe dental and/or vision plan prior to 2010. We assume that if a beneficiary selected dental and/or vision coverage, then they would chose to have (or not have) that coverage in any plan, so we just need indicators by person for dental coverage and vision coverage. We will assign average dental or vision premium of those plans available to each individual in the core analysis program ; 
	} ;	

use `working', clear;
/* this brings use back to one obs per person/plan/drugplan dataset*/
destring entitynum, replace ; 

if `planyear' > 2009 { ;
	merge m:1 personid entitynum empid memid familyid using `eligpost10', keep(1 3);
	assert _merge==3 ; 
	drop _merge; 
} ;

if `planyear' < 2010 { ;
	merge m:1 personid entitynum empid memid using `personid', keep(1 3);
	tab _merge;
	keep if _merge==3;
	drop _merge; 
} ;