#d ; 
set more off ; 
pause off ; 
set maxvar 59000 ; 
global directory /disk/agedisk3/oebb.work/cbehrer/oregon ;
local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;

local runtype $runtype ;
local claimyear $claimyear ;
local planyear $claimyear ; 
local y $yplan ;
local runfull $runfull ;
local justdrug $justdrug ;
local acg $acg ;

* This file takes John's Hopkin's ACG software's output of predicted risk (continuous variable) ; 
* and divides the sample into cells, using 3 different months, based on a beneficiaries risk    ;

local sampledate 23_Sep_2016 ; 
local acgdate 30_Sep_2016 ;
local a_date _3_Oct_2016 ; 

local input_directory ${directory}/do/JHUacg/outputfiles ; 
local output_directory ${directory}/data/built/sample/acg/ ;
local calc_data ${directory}/data/analysis/`acgdate'/ ;

log using "${directory}/log/analysis/acg/HM/00_create_cells_`cdate'_`ctime'.log" ;

* Method 1: 3 cells - top bottom and everything else ;
foreach year in 2009 2010 2011 2012 2013 { ; 
	di "Year is: `year'" ;
	*** Get year N sample;
	use ${directory}/data/built/sample/sample_PB_`year'_`sampledate'.dta, clear ; 
		keep personid personidIE familyid ;
		duplicates drop ; 
		gen count1=_N ;
	tempfile basepeople_`year';
	save `basepeople_`year'';

	*** Read in ACG status based on year N-1 to form sextiles;
	local list OV rxcost other ;
	foreach quantype of local list { ;
		insheet using `input_directory'/output_`year'_patient_`quantype'_`acgdate'.csv, clear ;
		keep patient_id unscaled_total_cost_resource_ind ; 
		rename unscaled_total_cost_resource_ind unscaledtotalcostresourceind;
		rename patient_id patientid;
		rename patientid personid;
		keep personid unscaledtotalcostresourceind; 
			
		merge 1:1 personid using `basepeople_`year'';
		
		* 1 = has ACG status, but not in sample ; 
		* 2 = in sample, but no ACG, so no claims in prior year, set costs = 0  ; 
		* 3 = in sample with ACG status ;
		drop if _merge == 1 ; 
		assert _merge!=1 ;
		replace unscaledtotalcostresourceind=0 if unscaledtotalcostresourceind==. & _merge==2 ; 
		drop _merge ;
		assert	unscaledtotalcostresourceind!=. ;

		xtile quan_`quantype'=unscaledtotalcostresourceind  if unscaledtotalcostresourceind!=0, n(5) ;
		mdesc quan_`quantype' ;

		gen orig_quan_`quantype' = quan_`quantype' ; 
		replace quan_`quantype' = orig_quan_`quantype' + 1 ; 
		
		replace quan_`quantype' = 1 if unscaledtotalcostresourceind == 0 ; 											
		assert quan_`quantype' !=. ; 
		gen count2=_N; assert count1==count2 ;
		tab quan* ;
		
		gen planyear  = `year' ; 

		keep personid quan* planyear ;

		tempfile quan_`quantype'_`year' ;
		save `quan_`quantype'_`year'' ;
	} ;

	use `quan_OV_`year'', clear ;
	merge 1:1 personid using `quan_rxcost_`year'' ;
	assert _merge==3 ; drop _merge ;
	merge 1:1 personid using `quan_other_`year'' ;
	assert _merge==3 ; drop _merge ;

	merge 1:1 personid using `basepeople_`year'' ; 
	assert _merge==3 ; drop _merge ;

	gen count2=_N ;
	assert count1 == count2 ;
	drop count1 count2 ; 
	
	keep personid quan_rxcost quan_other quan_OV planyear ; 
	tostring quan_OV, replace ; 
	tostring quan_other, replace ; 
	tostring quan_rxcost, replace ; 
	sort personid ; 
	duplicates drop ; 
	gen cell = quan_OV + "_" + quan_rxcost + "_" + quan_other ;
	drop quan* ; 
	sort personid ; 
	isid(personid);

	gen counter = 1 ; 
	egen size = sum(counter), by(cell) ; 

	preserve ; 
		keep cell size ; 
		duplicates drop ; 
		gsort -size ; 
		di "Year is: `year'" ;
		list ; 
	restore ; 

	gen newcell = "" ; 
	replace newcell = "1_1_1" if cell == "1_1_1" ;
	replace newcell = "6_6_6" if cell == "6_6_6" ;
	replace newcell = "3_3_3" if (cell != "1_1_1" & cell != "6_6_6") ;
	assert newcell != "" ; 
	drop cell ; 
	rename newcell cell3 ; 
	tab cell3 ; 
	drop size counter ; 
	
	save `output_directory'/temp/sample_w_3cells_`year'_`cdate', replace ; 
} ; 

* Method 2: decile plus one for zero costs ;
foreach year in 2009 2010 2011 2012 2013 { ; 
	di "Year is: `year'" ;
	*** Get year N sample ;
	use ${directory}/data/built/sample/sample_PB_`year'_`sampledate'.dta, clear ; 
	keep personid personidIE familyid ;
	duplicates drop ; 
	gen count1=_N ;
	
	tempfile basepeople_`year' ;
	save `basepeople_`year'' ;

	*** Read in ACG status based on year N-1 to form sextiles ;
	local list OV rxcost other ;
	foreach quantype of local list { ;
	insheet using `input_directory'/output_`year'_patient_`quantype'_`acgdate'.csv, clear ;

		keep patient_id unscaled_total_cost_resource_ind ; 
		
		rename unscaled_total_cost_resource_ind cost_`quantype' ;
		rename patient_id patientid ;
		rename patientid personid ;
		
		keep personid cost ; 
		tempfile cost_`quantype'_`year' ;
		save `cost_`quantype'_`year'' ;
	} ; 

	use `basepeople_`year'', clear ; 
		merge 1:1 personid using `cost_OV_`year'' ; 
		drop if _merge == 2 ; * with acg output, not in sample ; 
		replace cost_OV = 0 if _merge == 1 ; 
		drop _merge ; 
		merge 1:1 personid using `cost_rxcost_`year'' ; 
		drop if _merge == 2 ; * with acg output, not in sample ; 
		replace cost_rxcost = 0 if _merge == 1 ; 
		drop _merge ; 
		merge 1:1 personid using `cost_other_`year'' ; 
		drop if _merge == 2 ; * with acg output, not in sample ; 
		replace cost_other = 0 if _merge == 1 ; 
		drop _merge ; 

		gen totalcost = cost_other + cost_OV + cost_rxcost ; 
		assert totalcost != . ; 

		xtile cell =totalcost  if totalcost!=0, n(10) ;
		gen orig_cell = cell ;
		replace cell = cell + 1 ; 
		
		replace cell = 1 if totalcost == 0 ; 											
		assert cell !=. ; 
		gen count2=_N ; 
		assert count1==count2 ;
		tab cell ;
		gen planyear  = `year' ; 
		
	keep personid cell planyear ; 
	rename cell celldec ; 
	sort personid ; 
	unique(personid) ;

	gen counter = 1 ; 
	egen size = sum(counter), by(celldec) ; 
	di "Year is `year'" ;

	preserve ; 
		keep celldec size ; 
		duplicates drop ; 
		gsort -size ; 
		list ; 
	restore ; 
	drop counter size ; 
	save `output_directory'/temp/sample_w_deccells_`year'_`cdate', replace ; 
} ;

* Method 3 : regression predicted ;
foreach year in 2009 2010 2011 2012 2013 {; 
	di "Year is: `year'" ;

	*** Get year N sample;
	use ${directory}/data/built/sample/sample_PB_`year'_`sampledate'.dta, clear ; 
	keep personid personidIE familyid ;
	duplicates drop ; 
	gen count1=_N;
	 
	tempfile basepeople_`year';
	save `basepeople_`year'';

	*** Read in ACG status based on year N-1 to form sextiles;
	local list OV rxcost other ;
	foreach quantype of local list { ;
	insheet using `input_directory'/output_`year'_patient_`quantype'_`acgdate'.csv, clear;

		keep patient_id unscaled_total_cost_resource_ind ; 
		
		rename unscaled_total_cost_resource_ind unscaledtotalcostresourceind;
		rename patient_id patientid;
		rename patientid personid;
		
		keep personid unscaledtotalcostresourceind; 
			
		merge 1:1 personid using `basepeople_`year'';
		
		* 1 = has ACG status, but not in sample ; 
		* 2 = in sample, but no ACG, so no claims in prior year, set costs = 0  ; 
		* 3 = in sample with ACG status ;
		drop if _merge == 1; 
		assert _merge!=1;
		replace unscaledtotalcostresourceind=0 if unscaledtotalcostresourceind==. & _merge==2; drop _merge;
			assert	unscaledtotalcostresourceind!=.;

		xtile quan_`quantype'=unscaledtotalcostresourceind  if unscaledtotalcostresourceind!=0, n(10);
		gen orig_quan_`quantype' = quan_`quantype'; 
		replace quan_`quantype' = orig_quan_`quantype' + 1; 
		
		replace quan_`quantype' = 1 if unscaledtotalcostresourceind == 0; 											
		assert quan_`quantype' !=.; 
		gen count2=_N; assert count1==count2;
		tab quan*;
		
		gen planyear  = `year'; 

		keep personid quan* planyear;

		tempfile quan_`quantype'_`year';
		save `quan_`quantype'_`year'';
	} ;

	use `basepeople_`year'', clear ; 
	
	merge 1:1 personid using `quan_OV_`year'' ;
	assert _merge==3; drop _merge;
	
	merge 1:1 personid using `quan_rxcost_`year'';
	assert _merge==3; drop _merge;

	merge 1:1 personid using `quan_other_`year'';
	assert _merge==3; drop _merge;

	* we need calculator output for year after choice for the set of people in the ACG sample ; 
	* this is output of all people in the PB sample run through all possible plans as individuals ; 
	* we will keep the choise plan ; 
	
	merge 1:m personid using `calc_data'/working_analysis_p1_acg_`year'_ACG_`a_date'.dta ;
	assert _merge==3; drop _merge;
	keep if chosen == 1 ; 
	assert chosen == 1 ; 
	assert tier == 1 ; 
	
	gen ooptot = sum_cc_in + sum_cc_out + sum_uncap + sum_cc_drug + sum_deductible ;

	gen count2=_N ;
	assert count1 == count2 ;
	drop count1 count2 ;

	keep personid quan_OV quan_rxcost quan_other planyear ooptot ;
	regress ooptot quan_OV quan_rxcost quan_other;
	predict decile_predict_cost, xb ; 

	xtile cell = decile_predict_cost, nq(10) ; 

	tab cell ; 

	keep personid cell planyear ; 
	rename cell cellreg ; 
	sort personid ; 
	
	unique(personid) ;
	gen counter = 1 ; 
	egen size = sum(counter), by(cellreg) ; 
	di "Year is `year'" ;
	preserve ; 
		keep cellreg size ; 
		duplicates drop ; 
		gsort -size ; 
		list ; 
	restore ; 
	drop counter size ; 
	
	save `output_directory'/temp/sample_w_regcells_`year'_`cdate', replace ;
} ;

foreach year in 2009 2010 2011 2012 2013 { ; 
	di "Year is: `year'" ;
	*** Get year N sample;
	use ${directory}/data/built/sample/sample_PB_`year'_`sampledate'.dta, clear ; 
		keep personid personidIE familyid ;
		duplicates drop ; 

		merge 1:1 personid using `output_directory'/temp/sample_w_3cells_`year'_`cdate' ;
		assert _merge == 3 ; 
		drop _merge ; 
		merge 1:1 personid using `output_directory'/temp/sample_w_deccells_`year'_`cdate' ;
		assert _merge == 3 ; 
		drop _merge ; 
		merge 1:1 personid using `output_directory'/temp/sample_w_regcells_`year'_`cdate' ;
		assert _merge == 3 ; 
		drop _merge ; 
	save `output_directory'/sample_w_allcells_`year'_`cdate', replace ; 
} ;
	
log close ; 