#delimit ;
clear ;
set more off ;
pause off ; 
/*** Project: 		Oregon Health Plan Choice Analysis 								*/ ;
/*** Program: 		0_informed_enrollment											*/ ;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 				*/ ;
/*** Dates:			Created: 	07 June 2015										*/ ;
/***				Modified: 	06 Oct 2016											*/ ;

/*** Purpose & Description: 
	Data building
		1) Collect informed enrollment tool data for families in final sample
		
	We are rebuilding this file basically from scratch as of June 7 2016 
	Truven made enough mistakes in creating the aftertool data sheet that we have decided to ignore it
	and develop this dataset and analysis from the raw sheets 
*/ ;
*** 0. Initializations and log ;
global directory /disk/agedisk3/oebb.work/cbehrer/oregon/ ;

local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;
global cdate `cdate' ;
global ctime `ctime' ;
di "$cdate" ;

cap mkdir "$directory/log/informedenrollment/`cdate'/" ;
cap mkdir "$directory/data/informedenrollment/`cdate'/" ;

log using "$directory/log/informedenrollment/`cdate'/0_informed_enrollment_`cdate'_`ctime'.log" ;
local sample /disk/agedisk3/oebb.work/cbehrer/oregon/data/built/sample/sample_PB_2013_23_Sep_2016.dta ;
local indata1 "$directory/data/analysis/formal_reg_datasets" ;
local indata2 "$directory/data/given/clean/informedenrollment/2013" ;
local outdata "$directory/data/informedenrollment/`cdate'/" ;
local outdata2 "$directory/data/analysis/formal_reg_datasets" ;

local calcoutdate 31_Oct_2016 ;
local premiumdate 29_Mar_2016 ;
local entity_name_num_xwalk "/disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/package2/EntityNumberCrossWalk.csv" ;

*** 1. Get sample and calculator output  ;
use "`indata1'/temp/analysis_dataset_HM_ACG_2K_`calcoutdate'.dta" , clear ; 

keep if PB == 1 ; 
keep if year == 2013 ; 
gen counter = 1 ; 
egen size = sum(counter), by(familyid) ;
tab size ; 
* Table 1 row 1: unique families in 2013 PB/ACG sample ; 
unique(familyid); 

drop minpaid maxpaid famcell3 famcelldec famcellreg memid_str empid_str PF PB ACG totallowedamt_PB sharp_inertia ;
drop age* sex* contrib_* union *_PF free_* *_in *_out hsaelig hraelig potential_hsa potential_hra individual tiercd dentcov visioncov *_change ;


drop gross_observed_ooptotal_PB gross_calc_ooptotal_PB combined_medrx gross_prem_med gross_prem_rx gross_prem_dent gross_prem_vis gross_prem_rxmed ;

rename fuzzy_inertia inertia ; 
gen resid_prem = net_premium - gross_premium ; 

drop subsidy ;

tempfile calcoutput ; 
save `calcoutput' ;

clear ; 
import excel using "`indata2'/MITData_December2013.xlsx", sheet("Entities") ;
drop A ; 
rename B entitynum ; 
rename C entityname ; 
rename D arm ; 
drop if _n == 1 ; 
destring entitynum, replace ; 
destring arm, replace ; 
duplicates drop ; 

tempfile arm ; 
save `arm' ; 

use `calcoutput', clear ; 
merge m:1 entitynum using `arm' ; 

egen minmerge = min(_merge), by(entitynum) ; 
egen maxmerge = max(_merge), by(entitynum) ; 
assert minmerge == maxmerge ; 

keep if _merge == 3 ; 
drop minmerge maxmerge _merge ; 

* Table 1 row 2: unique families in entities assigned to an arm of the experiment ; 
unique(familyid); 
preserve ; 
	keep familyid arm ; 
	duplicates drop ; 
	tab arm ; 
restore ; 

preserve ; 
	clear ; 
	import excel using "`indata2'/MITData_December2013.xlsx", sheet("ModelDetail") ;
	drop K - W ; 
	rename A rowid ; 
	rename B uniqueID ; 
	rename C familyid ; 
	rename D cost_rank_tool ; 
	rename E plan ; 
	rename F planname ; 
	rename G lowcostplan_tool ; 
	rename H premium_tool ; 
	rename I est_oop_tool ;
	rename J totalcost_tool ; 
	
	drop if _n == 1 ; 

	tab plan ; 

	replace plan = "KMED1" if plan == "MP1" ; 
	replace plan = "KMP1A" if plan == "MP2" ; 
	replace plan = "MMEDA" if plan == "MPA" ; 
	replace plan = "MMEDB" if plan == "MPB" ; 
	replace plan = "MMEDC" if plan == "MPC" ; 
	replace plan = "MMEDD" if plan == "MPD" ; 
	replace plan = "MMEDE" if plan == "MPE" ; 
	replace plan = "MMEDF" if plan == "MPF" ; 
	replace plan = "MMEDG" if plan == "MPG" ; 
	replace plan = "MMEDH" if plan == "MPH" ; 
	
	sort familyid totalcost_tool  ; 
	rename cost_rank_tool rank ; 
	destring rank, replace ; 
	destring totalcost_tool, replace ; 
	keep familyid plan rank totalcost_tool ; 
	duplicates drop ; 

	tempfile modeldetail ; 
	save `modeldetail' ; 
restore ; 
	
merge 1:1 familyid plan using `modeldetail' ;
egen minmerge = min(_merge), by(familyid) ;
egen maxmerge = max(_merge), by(familyid) ;
tab minmerge maxmerge ;

drop if minmerge != maxmerge ; 
gen hasrec = 1 if _merge == 3 ; 
replace hasrec = 0 if _merge !=3 ; 
drop if _merge == 2 ; 
drop minmerge maxmerge _merge ; 
tab arm hasrec ;  

* Table 1 row 3:with correct choice set modelled in tool ; 
unique(familyid); 
preserve ; 
	keep familyid arm ; 
	duplicates drop ; 
	tab arm ; 
restore ; 

* we used to drop if they added dependents, but we don't need to to assess whether tool had impact ; 
preserve ; 

use "`sample'", clear ; 
keep if planyear == 2013 ; 
keep familyid ; 
duplicates drop ; 
tempfile fam_in_samp ; 
save `fam_in_samp' ; 
restore ; 

merge m:1 familyid using `fam_in_samp' ; 
assert _merge != 1 ; 

keep if _merge ==3 ; 
drop _merge ; 

* Table 1 row 4: unique families meet sample inclusion criteria ; 
unique(familyid); 
preserve ; 
	keep familyid arm ; 
	duplicates drop ; 
	tab arm ; 
restore ; 
 
replace plan = trim(plan) ; 
tabulate plan, generate(plan_) ;
gen recommended = 1 if rank == 1 ; 
replace recommended = 0 if recommended == . ; 
gen treatment = 1 if arm == 2 ; 
replace treatment = 0 if arm == 1 ;

preserve ; 
cap drop counter ; 
gen counter = 1 ; 
unique(familyid plan) ;
keep familyid plan counter treatment tier; 
egen sizeIE = sum(counter), by(familyid) ; 
keep familyid sizeIE treatment tier; 
duplicates drop ; 
isid(familyid) ;

keep familyid sizeIE ; 
rename sizeIE choice_set_sizeIE ; 

tempfile size ; 
save `size' ; 
restore ;
 
merge m:1 familyid using `size' ; 
assert _merge == 3 ; 
drop _merge ; 
assert size == choice_set_sizeIE ; 
drop size ; 
rename choice_set_sizeIE choice_set_size ; 

levelsof choice_set_size, local(sizes) ; 

foreach i in `sizes' {;
	gen sizedum_`i' = 1 if choice_set_size == `i' ; 
	replace sizedum_`i' = 0 if choice_set_size != `i' ; 
} ;

replace total_calc_cost_PB = round(total_calc_cost_PB,0.01) ;

egen min_costtot = min(total_calc_cost_PB), by(familyid) ; 

gen lowest_cost = 1 if round(total_calc_cost_PB,0.01) == round(min_costtot,0.01) ; 
egen ct_lowcost = sum(lowest_cost), by(familyid) ; 
assert ct_lowcost != 0 ; 
drop ct_lowcost ; 
replace lowest_cost = 0 if lowest_cost == . ;
gen overspending = total_calc_cost_PB - min_costtot ; 
drop acg_median* acg_sd* acg_p* ;

save "`outdata'/IE2013_regress_input_`cdate'.dta", replace ;
save "`outdata2'/IE2013_regress_input_`cdate'.dta", replace ;

log close ; 