#delimit ;
clear;
set more off;

* 04 Oct 2016 version of this file was run pulling data from an excel sheets with errors ; 
* specifically: /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv ; 
* and corresponding files for later years ; 
* These sheets have been corrected ; 
* This file and all ensuing files are being re-run on 12/20/2017 ; 

/*** 0. Initializations and log*/;
pause off ;
global directory /disk/agedisk3/oebb.work/cbehrer/oregon/;
local directory /disk/agedisk3/oebb.work/cbehrer/oregon  ;
local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);
global cdate `cdate';
global ctime `ctime';
di "$cdate";

local indatePF 30_Sep_2016 ; 
local indatePB 30_Sep_2016 ; 

local famcelldate _4_Oct_2016 ; 

local premiumfiledate "29_Mar_2016" ;
local sampledate "23_Sep_2016" ;

log using "$directory/log/regressionanalysis/0build_dataset_`cdate'_`ctime'.log" ;

local outdir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets" ;
local indir "/disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`indatePF'" ;
local indirPB "/disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/`indatePB'" ;
local elig_data "$directory/data/cleaning/2deduplicated/deduplicated_eligibility_11_Jun_2015.dta" ; 
local choiceset "$directory/data/built/premium/choiceset_`premiumfiledate'.dta" ; 

* get fixed desc variable from premium dataset sheet to create variable identifying contribution type ; 
use `directory'/data/built/premium/finalpremium_`premiumfiledate'.dta, clear;
drop if medical == 5 ; 
drop medical ; 
keep planyear fixeddesc entitynum empid memid ratestructure ;
duplicates drop ; 
isid (planyear entitynum empid memid ratestructure); 
tempfile fixeddesc ; 
save `fixeddesc' ; 

* Get PB ; 
use "`indirPB'/NOCAPworking_analysis_allyears_`indatePB'_savingsaccount_base_PB.dta", clear ;

	rename ooptot ooptot_PB ; 
	rename oopttot_savings oopttot_savings_PB ;
	rename totallowedamt totallowedamt_PB ; 
	rename costtot costtot_PB ; 
	rename orig_sum orig_sum_PB ; 
	rename empamt_dv bene_paid ; 
	preserve ; 
	* make dataset to test how well PF and PB premium variables match ; 
		drop ooptot_PB oopttot_savings_PB totallowedamt_PB costtot_PB orig_sum_PB oopcost_drug oopcost_med orig_sum_drug orig_sum_med; 
		foreach premiumvar in bene_paid subsidy gross_prem gross_dent_prem gross_vis_prem medpremium rxpremium potential_hra potential_hsa premium_rxmed { ;
			replace `premiumvar' = ceil(`premiumvar') ;
		};	

		tempfile testpb ; 
		save `testpb' ; 
	restore ; 
	drop bene_paid subsidy gross_prem gross_dent_prem gross_vis_prem medpremium rxpremium potential_hra potential_hsa premium_rxmed oopcost_drug oopcost_med orig_sum_drug orig_sum_med ;
	
tempfile pb ; 
save `pb' ; 
	
* Get PF & merge ; 
use "`indir'/NOCAPworking_analysis_allyears_`indatePF'_savingsaccount_base_PF.dta", clear ; 

	rename ooptot ooptot_PF ; 
	rename oopttot_savings oopttot_savings_PF ;
	rename totallowedamt totallowedamt_PF ; 
	rename costtot costtot_PF ;
	rename orig_sum orig_sum_PF ; 
	rename empamt_dv bene_paid ; 
	
	rename oopcost_drug oopdrug_PF ;
	rename oopcost_med oopmed_PF ;
	
	drop orig_sum_drug orig_sum_med ; 

	preserve ; 
		keep familyid tier planyear ; 
		duplicates drop ; 
		tempfile tier ; 
		save `tier' ; 
	restore ; 
	
	preserve ; 
		* Test how well the premium variables match - should be perfect, it's not quite ; 
		* The difference here is in dental and vision premiums, which results from different populations in each sample ; 
		* and the fact that we take a weighted average of selected dental and vision plans, so a change in sample composition ; 
		* will change these weights and averages ; 
		drop if planyear == 2008 ; 
		drop ooptot_PF oopttot_savings_PF totallowedamt_PF costtot_PF orig_sum_PF ; 
		foreach premiumvar in bene_paid subsidy gross_prem gross_dent_prem gross_vis_prem medpremium rxpremium potential_hra potential_hsa premium_rxmed { ;
			replace `premiumvar' = ceil(`premiumvar') ;
		};
		foreach var in bene_paid subsidy gross_prem gross_dent_prem gross_vis_prem potential_hra potential_hsa medpremium rxpremium { ;
			rename `var' `var'_PF ; 
		} ;
		merge 1:1 entitynum empid memid familyid tier drugplan plan chosen planyear ods ratestructure hsaelig hraelig dentcov visioncov using `testpb' ;
		*assert _merge == 3; 
		drop _merge ; 
		
		* All of these variables should be identical between PF and PB - they aren't quite. But maximum differnces is about $20. ; 
		* This results from population weighted averages and different populations just use the PF premium figures ; 
		foreach var2 in bene_paid subsidy gross_prem gross_dent_prem gross_vis_prem potential_hra potential_hsa medpremium rxpremium {;
			gen diff_`var2' = `var2'_PF - `var2' ; 
			sum diff_`var2', detail ; 
		};

	restore ;

	merge 1:1 drugplan entitynum memid empid familyid tier plan chosen planyear ods ratestructure hsaelig hraelig dentcov visioncov using `pb' ; 
 
	* not perfect merge - we don't have PB output for 2008 ; 
	* also not perfect merge because we use different samples in order to have new beneficiaries in the PF sample ; 
	tab _merge planyear ; 
	* but we should never have PB output for someone we do not have PF output for ; 
	assert _merge != 2 ; 
	
	drop _merge ; 
	drop ods ; 
	
	gen insurer =""; 
	replace insurer = "KAISER" if substr(plan,1,1) == "K" ;
	replace insurer = "PROVIDENCE" if substr(plan,1,1) == "P" ;
	replace insurer = "MODA" if (substr(plan,1,1) == "M" | substr(plan,1,1) == "O") ;
	assert insurer != "" ; 
	replace insurer = trim(insurer) ; 
	tempfile working0 ; 
	save `working0' ; 

	keep familyid planyear ; 
	duplicates drop ; 
	tempfile families ; 
	save `families' ; 
	
	* construct experience variable as number of times the family chose an insurance plan in OEBB ; 
	use `elig_data', clear ; 
	gen planyear = 2008 if eligmo_date >= mdy(10,1,2008) & eligmo_date <=mdy(9,30,2009) ;
	replace planyear = 2009 if eligmo_date >= mdy(10,1,2009) & eligmo_date <=mdy(9,30,2010) ;
	replace planyear = 2010 if eligmo_date >= mdy(10,1,2010) & eligmo_date <=mdy(9,30,2011) ;
	replace planyear = 2011 if eligmo_date >= mdy(10,1,2011) & eligmo_date <=mdy(9,30,2012) ;
	replace planyear = 2012 if eligmo_date >= mdy(10,1,2012) & eligmo_date <=mdy(9,30,2013) ;
	replace planyear = 2013 if eligmo_date >= mdy(10,1,2013) & eligmo_date <=mdy(9,30,2014) ;
	replace planyear = 2014 if eligmo_date >= mdy(10,1,2014) & eligmo_date <=mdy(9,30,2015) ;
	replace planyear = 2007 if eligmo_date < mdy(10,1,2008) ;
	assert planyear != . ; 
		
	drop if planyear == 2014 ; 
	drop if planyear == 2007 ;
	
	replace plan = substr(plan,1,5) ;
	replace plan = trim(plan) ;
	drop if plan == "NE" ; 
	drop if plan == "OPT" ; 
	drop if plan == "~";
	tab plan ; 

	keep familyid planyear ; 
	duplicates drop ; 
	sort planyear familyid ; 
	bys familyid planyear : gen ct = _n ;
	replace ct = . if ct !=1 ;
	sort familyid planyear ;
	bysort familyid : gen experience0 = sum(ct) ;
	egen experience = max(experience0), by(familyid planyear) ;
	merge 1:1 familyid planyear using `families' ; 
	drop experience0 ct ;

	* no one should be in our sample if they aren't in the eligibility file ; 
	assert _merge != 2 ; 
	keep if _merge == 3 ; 
	drop _merge ; 

	tempfile exper ; 
	save `exper' ; 
	
	* get demographic variables ; 
	use `elig_data', clear ; 
	gen planyear = 2008 if eligmo_date >= mdy(10,1,2008) & eligmo_date <=mdy(9,30,2009) ;
	replace planyear = 2009 if eligmo_date >= mdy(10,1,2009) & eligmo_date <=mdy(9,30,2010) ;
	replace planyear = 2010 if eligmo_date >= mdy(10,1,2010) & eligmo_date <=mdy(9,30,2011) ;
	replace planyear = 2011 if eligmo_date >= mdy(10,1,2011) & eligmo_date <=mdy(9,30,2012) ;
	replace planyear = 2012 if eligmo_date >= mdy(10,1,2012) & eligmo_date <=mdy(9,30,2013) ;
	replace planyear = 2013 if eligmo_date >= mdy(10,1,2013) & eligmo_date <=mdy(9,30,2014) ;
	replace planyear = 2014 if eligmo_date >= mdy(10,1,2014) & eligmo_date <=mdy(9,30,2015) ;
	replace planyear = 2007 if eligmo_date < mdy(10,1,2008) ;
	assert planyear != . ; 
		
	drop if planyear == 2014 ; 
	drop if planyear == 2007 ;
	
	replace plan = substr(plan,1,5) ;
	replace plan = trim(plan) ;
	drop if plan == "NE" ; 
	drop if plan == "OPT" ; 
	drop if plan == "~";
	tab plan ; 
	merge m:1 familyid planyear using `families' ; 
	keep if _merge == 3 ; 
	drop _merge ; 
	gen month = month(eligmo_date) ;
	keep if month == 10 ; 
	keep age_yr tiercd memid entitynum empid familyid personidIE personid sex relat planyear relat union; 
	duplicates drop ; 
 
	sort planyear familyid relat personid ; * puts policy holder first ; 
	
	by planyear familyid : gen size = _n ;
	levelsof size, clean local (sizes) separate("  ") ;
	di `sizes' ; 
	
	label values sex sexkey;
	
	foreach i in `sizes' { ;
	gen age_`i' = age_yr if size == `i' ; 
	gen sex_`i' = sex if size == `i' ; 
	} ;
	drop sex age_yr relat ; 
	label values sex* sexkey;

	collapse (max) age_* sex_* , by(familyid planyear empid memid entitynum tiercd union) ;
	destring(entitynum), replace ; 

	tempfile demos ; 
	save `demos' ; 
	
	
	use `working0', clear ; 
	merge m:1 familyid planyear using `exper' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	merge m:1 familyid planyear using `demos' ; 
	assert _merge == 3 ; 
	drop _merge ;

	* tests to make sure we've constructed premium variables properly ; 
	gen test1 = medpremium + rxpremium ; 
	gen diff1 = abs(test1 - premium_rxmed) ; 
	assert (diff1 < 0.01 | diff1 == .) ; 
	drop test1 diff1 ; 
	
	gen test2 = gross_dent_prem + gross_vis_prem + premium_rxmed ; 
	gen diff2 = abs(test2 - gross_prem) ;
	assert (diff2 < 0.01 | diff2 == .) ; 
	
	bys planyear plan drugplan tier ratestructure : egen min=min(premium_rxmed) ;
	bys planyear plan drugplan tier ratestructure : egen max=max(premium_rxmed) ;
	gen diffprem = max - min ; 
	sum diffprem, detail ; 
	
	gen combined_medrx = 1 if rxpremium == 0 ; 
	replace combined_medrx = 0 if rxpremium !=0 ; 
	
	tab planyear combined_medrx ; 
	tab plan combined_medrx ; 
 
	tempfile working ; 
	save `working' ; 
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv, clear ; 
	keep plan network individual deductible  ; 
	gen planyear = 2008 ; 
	replace deductible = 0 if deductible == . ; 
	duplicates drop ; 
	reshape wide  deductible, i(plan planyear individual) j(network) ;
	tempfile ded08 ; 
	save `ded08';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2009/medicalservices2009.csv, clear ; 
	keep plan network individual deductible  ; 
	gen planyear = 2009 ; 
	replace deductible = 0 if deductible == . ;
	duplicates drop ; 	
	reshape wide  deductible, i(plan planyear individual) j(network) ;
	tempfile ded09 ; 
	save `ded09';	
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2010/medicalservices2010.csv, clear ; 
	keep plan network individual deductible  ; 
	gen planyear = 2010 ; 
	replace deductible = 0 if deductible == . ; 
	duplicates drop ; 
	reshape wide deductible, i(plan planyear individual) j(network) ;
	tempfile ded10 ; 
	save `ded10';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2011/medicalservices2011.csv, clear ; 
	keep plan network individual deductible  ; 
	gen planyear = 2011 ; 
	replace deductible = 0 if deductible == . ;  
	duplicates drop ; 
	reshape wide deductible, i(plan planyear individual) j(network) ;
	tempfile ded11 ; 
	save `ded11';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2012/medicalservices2012.csv, clear ; 
	keep plan network individual deductible ; 
	gen planyear = 2012 ; 
	replace deductible = 0 if deductible == . ; 
	duplicates drop ; 
	reshape wide deductible, i(plan planyear individual) j(network) ;
	tempfile ded12 ; 
	save `ded12';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2013/medicalservices2013.csv, clear ; 
	keep plan network individual deductible ; 
	drop if network == 2 ; 
	gen planyear = 2013 ; 
	replace deductible = 0 if deductible == . ; 
	duplicates drop ; 
	reshape wide deductible, i(plan planyear individual) j(network) ;
	tempfile ded13 ; 
	save `ded13';
	
	use `ded08', clear ; 
	append using `ded09' ; 
	append using `ded10' ; 
	append using `ded11' ; 
	append using `ded12' ; 
	append using `ded13' ;
	rename deductible0 ded_out ; 
	rename deductible1 ded_in ; 
	
	tempfile deductible ; 
	save `deductible' ; 

	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv, clear ; 
	keep plan network individual max_oopcost ; 
	gen planyear = 2008 ; 
	replace max_oopcost = 0 if max_oopcost == . ; 
	duplicates drop ; 
	reshape wide max_oopcost , i(plan planyear individual) j(network) ;
	tempfile oop08 ; 
	save `oop08';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2009/medicalservices2009.csv, clear ; 
	keep plan network individual max_oopcost ; 
	gen planyear = 2009 ; 
	replace max_oopcost = 0 if max_oopcost == . ; 
	duplicates drop ; 
	reshape wide max_oopcost , i(plan planyear individual) j(network) ;
	tempfile oop09 ; 
	save `oop09';	
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2010/medicalservices2010.csv, clear ; 
	keep plan network individual max_oopcost ; 
	gen planyear = 2010 ; 
	replace max_oopcost = 0 if max_oopcost == . ;
	duplicates drop ; 	
	reshape wide max_oopcost , i(plan planyear individual) j(network) ;
	tempfile oop10 ; 
	save `oop10';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2011/medicalservices2011.csv, clear ; 
	keep plan network individual max_oopcost ; 
	gen planyear = 2011 ; 
	replace max_oopcost = 0 if max_oopcost == . ; 
	duplicates drop ; 
	reshape wide max_oopcost , i(plan planyear individual) j(network) ;
	tempfile oop11 ; 
	save `oop11';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2012/medicalservices2012.csv, clear ; 
	keep plan network individual max_oopcost ; 
	gen planyear = 2012 ; 
	replace max_oopcost = 0 if max_oopcost == . ; 
	duplicates drop ; 
	reshape wide max_oopcost , i(plan planyear individual) j(network) ;
	tempfile oop12 ; 
	save `oop12';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2013/medicalservices2013.csv, clear ; 
	keep plan network individual max_oopcost ; 
	drop if network == 2 ; 
	gen planyear = 2013 ; 
	replace max_oopcost = 0 if max_oopcost == . ; 
	duplicates drop ; 
	reshape wide max_oopcost , i(plan planyear individual) j(network) ;
	tempfile oop13 ; 
	save `oop13';
	
	use `oop08', clear ; 
	append using `oop09'; 
	append using `oop10'; 
	append using `oop11'; 
	append using `oop12'; 
	append using `oop13';
	rename max_oopcost0 max_oop_out ; 
	rename max_oopcost1 max_oop_in ; 
	tempfile oop ; 
	save `oop' ; 
	
	* now we need 8 payment variables - copay and coinsurance (2) by in versus out of network (*2) and primary care versus specialist (*2) ; 
	* this could be a loop ; 
	* pcp coinsurance ; 
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv, clear ; 
	keep if serviceid == 865 ; 
	keep plan network copay ; 
	gen planyear = 2008 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile pcpcopay08 ; 
	save `pcpcopay08';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2009/medicalservices2009.csv, clear ; 
	keep if serviceid == 965 ;
	keep plan network copay ; 
	gen planyear = 2009 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile pcpcopay09 ; 
	save `pcpcopay09';	
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2010/medicalservices2010.csv, clear ; 
	keep if serviceid == 1060 ;
	keep plan network copay ; 
	gen planyear = 2010 ; 
	replace copay = 0 if copay == . ;
	duplicates drop ; 	
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile pcpcopay10 ; 
	save `pcpcopay10';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2011/medicalservices2011.csv, clear ; 
	keep if serviceid == 1160 ;
	keep plan network copay ; 
	gen planyear = 2011 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile pcpcopay11 ; 
	save `pcpcopay11';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2012/medicalservices2012.csv, clear ;
	keep if serviceid == 1260 ;
	keep plan network copay ; 
	gen planyear = 2012 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile pcpcopay12 ; 
	save `pcpcopay12';

	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2013/medicalservices2013.csv, clear ; 
	keep if serviceid == 1360 ;
	keep plan network copay ; 
	drop if network == 2 ; 
	gen planyear = 2013 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile pcpcopay13 ; 
	save `pcpcopay13';	
	
	use `pcpcopay08', clear ; 
	append using `pcpcopay09'; 
	append using `pcpcopay10'; 
	append using `pcpcopay11'; 
	append using `pcpcopay12'; 
	append using `pcpcopay13'; 
	
	rename copay0 pcp_copay_out ; 
	rename copay1 pcp_copay_in ; 
	tempfile pcpcopay ; 
	save `pcpcopay' ; 
	
	* pcp coinsurance ; 
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv, clear ; 
	keep if serviceid == 865 ; 
	keep plan network coinsurance ; 
	gen planyear = 2008 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile pcpcoin08 ; 
	save `pcpcoin08';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2009/medicalservices2009.csv, clear ; 
	keep if serviceid == 965 ;
	keep plan network coinsurance ; 
	gen planyear = 2009 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile pcpcoin09 ; 
	save `pcpcoin09';	
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2010/medicalservices2010.csv, clear ; 
	keep if serviceid == 1060 ;
	keep plan network coinsurance ; 
	gen planyear = 2010 ; 
	replace coinsurance = 0 if coinsurance == . ;
	duplicates drop ; 	
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile pcpcoin10 ; 
	save `pcpcoin10';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2011/medicalservices2011.csv, clear ; 
	keep if serviceid == 1160 ;
	keep plan network coinsurance ; 
	gen planyear = 2011 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile pcpcoin11 ; 
	save `pcpcoin11';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2012/medicalservices2012.csv, clear ; 
	keep if serviceid == 1260 ;
	keep plan network coinsurance ; 
	gen planyear = 2012 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile pcpcoin12 ; 
	save `pcpcoin12';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2013/medicalservices2013.csv, clear ; 
	keep if serviceid == 1360 ;
	keep plan network coinsurance ; 
	drop if network == 2 ; 
	gen planyear = 2013 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile pcpcoin13 ; 
	save `pcpcoin13';
	
	use `pcpcoin08', clear ; 
	append using `pcpcoin09'; 
	append using `pcpcoin10'; 
	append using `pcpcoin11'; 
	append using `pcpcoin12'; 
	append using `pcpcoin13'; 	
	rename coinsurance0 pcp_coin_out ; 
	rename coinsurance1 pcp_coin_in ; 
	tempfile pcpcoin ; 
	save `pcpcoin' ; 
	
	* specialist copay ; 	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv, clear ;  
	keep if serviceid == 864 ; 
	keep plan network copay ; 
	gen planyear = 2008 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile speccopay08 ; 
	save `speccopay08';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2009/medicalservices2009.csv, clear ; 
	keep if serviceid == 964 ;
	keep plan network copay ; 
	gen planyear = 2009 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile speccopay09 ; 
	save `speccopay09';	
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2010/medicalservices2010.csv, clear ;
	keep if serviceid == 1062 ;	
	keep plan network copay ; 
	gen planyear = 2010 ; 
	replace copay = 0 if copay == . ;
	duplicates drop ; 	
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile speccopay10 ; 
	save `speccopay10';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2011/medicalservices2011.csv, clear ; 
	keep if serviceid == 1162 ;
	keep plan network copay ; 
	gen planyear = 2011 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile speccopay11 ; 
	save `speccopay11';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2012/medicalservices2012.csv, clear ; 
	keep if serviceid == 1262 ;
	keep plan network copay ; 
	gen planyear = 2012 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile speccopay12 ; 
	save `speccopay12';
		
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2013/medicalservices2013.csv, clear ; 
	keep if serviceid == 1362 ;
	keep plan network copay ; 
	gen planyear = 2013 ; 
	replace copay = 0 if copay == . ; 
	duplicates drop ; 
	reshape wide copay , i(plan planyear) j(network) ;
	tempfile speccopay13 ; 
	save `speccopay13';

	use `speccopay08', clear ; 
	append using `speccopay09'; 
	append using `speccopay10'; 
	append using `speccopay11'; 
	append using `speccopay12'; 
	append using `speccopay13'; 
	rename copay0 spec_copay_out ; 
	rename copay1 spec_copay_in ; 
	tempfile speccopay ; 
	save `speccopay' ; 
	
	* specialist coinsurance ; 
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2008/medicalservices2008.csv, clear ;  
	keep if serviceid == 864 ; 
	keep plan network coinsurance ; 
	gen planyear = 2008 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile speccoin08 ; 
	save `speccoin08';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2009/medicalservices2009.csv, clear ; 
	keep if serviceid == 964 ;
	keep plan network coinsurance ; 
	gen planyear = 2009 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile speccoin09 ; 
	save `speccoin09';	
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2010/medicalservices2010.csv, clear ; 
	keep if serviceid == 1062 ;
	keep plan network coinsurance ; 
	gen planyear = 2010 ; 
	replace coinsurance = 0 if coinsurance == . ;
	duplicates drop ; 	
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile speccoin10 ; 
	save `speccoin10';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2011/medicalservices2011.csv, clear ; 
	keep if serviceid == 1162 ;
	keep plan network coinsurance ; 
	gen planyear = 2011 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile speccoin11 ; 
	save `speccoin11';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2012/medicalservices2012.csv, clear ; 
	keep if serviceid == 1262 ;
	keep plan network coinsurance ; 
	gen planyear = 2012 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile speccoin12 ; 
	save `speccoin12';
	
	insheet using /disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/service_procedure_cwalk/2013/medicalservices2013.csv, clear ;
	keep if serviceid == 1362 ;	
	keep plan network coinsurance ; 
	gen planyear = 2013 ; 
	replace coinsurance = 0 if coinsurance == . ; 
	duplicates drop ; 
	reshape wide coinsurance , i(plan planyear) j(network) ;
	tempfile speccoin13 ; 
	save `speccoin13';

	use `speccoin08', clear ; 
	append using `speccoin09'; 
	append using `speccoin10'; 
	append using `speccoin11'; 
	append using `speccoin12'; 
	append using `speccoin13'; 
	rename coinsurance0 spec_coin_out ; 
	rename coinsurance1 spec_coin_in ; 
	tempfile speccoin ; 
	save `speccoin' ; 

	use `pcpcopay', clear ; 	
		merge m:1 planyear plan using `pcpcoin' ;
		drop _merge ; 
		merge m:1 planyear plan using `speccopay' ;
		drop _merge ; 
		merge m:1 planyear plan using `speccoin' ;
		drop _merge ; 
		
		replace pcp_copay_out = 0 if substr(plan,1,1) == "K" ;
		replace pcp_coin_out = 0 if substr(plan,1,1) == "K" ;
		replace spec_coin_out = 0 if substr(plan,1,1) == "K" ;
		replace spec_copay_out = 0 if substr(plan,1,1) == "K" ;
		
		replace pcp_coin_out = 0.3 if planyear == 2010 & plan == "OMED3" ; 
		replace pcp_coin_out = 0.4 if planyear == 2010 & plan == "OMED4" ;
		replace pcp_coin_out = 0.4 if planyear == 2010 & plan == "OMED5" ;
		replace pcp_coin_out = 0.5 if planyear == 2010 & plan == "PMED2" ;
		replace pcp_coin_out = 0.5 if planyear == 2010 & plan == "PMP2A" ;
		
		replace pcp_coin_in  = 0.2 if planyear == 2010 & plan == "OMED6" ;
		replace pcp_coin_in  = 0.2 if planyear == 2010 & plan == "OMED7" ;
		replace pcp_coin_in  = 0.2 if planyear == 2010 & plan == "OMED8" ;
		replace pcp_coin_in  = 0.2 if planyear == 2010 & plan == "OMED9" ;
		replace pcp_coin_out = 0.4 if planyear == 2010 & plan == "OMED6" ;
		replace pcp_coin_out = 0.4 if planyear == 2010 & plan == "OMED7" ;
		replace pcp_coin_out = 0.4 if planyear == 2010 & plan == "OMED8" ;
		replace pcp_coin_out = 0.4 if planyear == 2010 & plan == "OMED9" ;
		
		replace pcp_copay_in = 10 if planyear == 2010 & plan == "KMED1" ;
		replace pcp_copay_in = 20 if planyear == 2010 & plan == "KMP1A" ;
		
		replace pcp_copay_in = 20 if plan == "MMEDA" ;
		replace pcp_copay_in = 20 if plan == "MMEDB" ;
		replace pcp_copay_in = 20 if plan == "MMEDC" ;
		replace pcp_copay_in = 30 if plan == "MMEDD" ;
		replace pcp_copay_in = 30 if plan == "MMEDE" ;
		replace pcp_copay_in = 30 if plan == "MMEDF" ;
		replace pcp_copay_in = 30 if plan == "MMEDG" ;	
		
		gen paytype_pcp_in = . ; 
		gen paytype_pcp_out = . ; 
		gen paytype_spec_in = . ; 
		gen paytype_spec_out = . ; 
		
		* 1 = copay 2 = coinsurance ;
		replace paytype_pcp_in = 1 if pcp_copay_in != 0 ; 
		replace paytype_pcp_out = 1 if pcp_copay_out != 0 ; 
		replace paytype_spec_in = 1 if spec_copay_in != 0 ; 
		replace paytype_spec_out = 1 if spec_copay_out != 0 ; 
		replace paytype_pcp_in = 1 if substr(plan,1,1) == "K" ;
		replace paytype_pcp_out = 1 if substr(plan,1,1) == "K" ; 
		replace paytype_spec_in = 1 if substr(plan,1,1) == "K" ;
		replace paytype_spec_out = 1 if substr(plan,1,1) == "K" ;
		
		replace paytype_pcp_in = 2 if pcp_coin_in != 0 ; 
		replace paytype_pcp_out = 2 if pcp_coin_out != 0 ; 
		replace paytype_spec_in = 2 if spec_coin_in != 0 ; 
		replace paytype_spec_out = 2 if spec_coin_out != 0 ;
		
	tempfile payments ; 
	save `payments' ; 	
* end collection of 8 payment variables ; 
	
use `working', clear ; 
	gen individual = (tier == 1) ; 
	merge m:1 planyear plan individual using `deductible' ;
	assert _merge == 3 ; 
	drop _merge ; 
	merge m:1 planyear plan individual using `oop' ;
	assert _merge == 3 ; 
	drop _merge ; 	
	merge m:1 planyear plan using `payments' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	sort familyid planyear plan ; 

tempfile working2 ; 
save `working2' ; 
	
use `elig_data', clear ; 
	gen planyear = 2008 if eligmo_date >= mdy(10,1,2008) & eligmo_date <=mdy(9,30,2009) ;
	replace planyear = 2009 if eligmo_date >= mdy(10,1,2009) & eligmo_date <=mdy(9,30,2010) ;
	replace planyear = 2010 if eligmo_date >= mdy(10,1,2010) & eligmo_date <=mdy(9,30,2011) ;
	replace planyear = 2011 if eligmo_date >= mdy(10,1,2011) & eligmo_date <=mdy(9,30,2012) ;
	replace planyear = 2012 if eligmo_date >= mdy(10,1,2012) & eligmo_date <=mdy(9,30,2013) ;
	replace planyear = 2013 if eligmo_date >= mdy(10,1,2013) & eligmo_date <=mdy(9,30,2014) ;
	replace planyear = 2014 if eligmo_date >= mdy(10,1,2014) & eligmo_date <=mdy(9,30,2015) ;
		
	drop if planyear == 2014 ; 
	drop if planyear == 2007 ;
	replace plan = substr(plan,1,5) ;
	replace plan = trim(plan) ;
	drop if plan == "NE" ; 
	drop if plan == "OPT" ; 
	drop if plan == "~" ; 
	keep if eligflag == 1 ; 
	gen month = month(eligmo_date) ; 
	sort familyid planyear eligmo_date ;
	by familyid planyear : gen id = _n ;
	unique(familyid planyear) ;
	keep if id == 1 ; 
	unique(familyid planyear) ;
	
	tab month ;

	keep familyid planyear plan entitynum empid memid tier ; 
	duplicates drop ; 
	isid (familyid planyear) ;
	replace planyear = planyear + 1 ; 
	
	/* we need to get entitynum empid memid etc. from the following year*/; 
	/* to accurately capture choice sets of people who switched entities*/;
	drop if substr(entitynum,1,4) == "S041";
	drop if substr(entitynum,1,4) == "S399";
	drop if substr(entitynum,1,4) == "U017";
	drop if substr(entitynum,1,4) == "U018";
	replace entitynum = "0020" if entitynum == "00020"; 
	replace entitynum = "0020" if entitynum == "20"; 
	
	destring entitynum, replace;

	gen tier = 1 if tiercd == "EMP"; // employee;
	replace tier = 2 if tiercd == "ESP"; // employee spouse;
	replace tier = 3 if tiercd == "ECH"; // employee child;
	replace tier = 4 if tiercd == "FAM"; // family;
	drop tiercd ; 
	
	rename plan plan_last_year ; 
	rename entitynum entitynum_last ; 
	rename empid empid_last ; 
	rename memid memid_last ;
	rename tier tier_last ; 		
tempfile lastyear ; 
save `lastyear' ; 
	
use `working2', clear ; 
	merge m:1 familyid planyear using `lastyear' ; 
	tab _merge ; 
	
	drop if _merge == 2 ; 
	drop _merge ; 
	
	gen status_change = 0 ; 
	replace status_change = 1 if entitynum != entitynum_last ; 
	replace status_change = 1 if empid != empid_last ; 
	replace status_change = 1 if memid != memid_last ; 
		
	gen tier_change = 0 ; 
	replace tier_change = 1 if tier != tier_last ; 
	
	replace tier_change = . if planyear == 2008 ; 
	replace status_change = . if planyear == 2008 ; 
	
	gen sharp_inertia = 1 if plan == plan_last_year ; 
	replace sharp_inertia = 0 if sharp_inertia == . & planyear != 2008 ; 
	
	gen fuzzy_inertia = 0 ; 
	replace fuzzy_inertia = 1 if 
		(plan == "MMEDH" & plan_last_year == "OMED9" & planyear == 2013 ) |
		(plan == "KMED1" & plan_last_year == "KMED1" & planyear == 2013 ) |
		(plan == "KMP1A" & plan_last_year == "KMP1A" & planyear == 2013 ) |
		(plan == "MMEDE" & plan_last_year == "OMED8" & planyear == 2013 ) |
		(plan == "MMEDC" & plan_last_year == "OMED7" & planyear == 2013 ) |
		(plan == "MMEDA" & plan_last_year == "OMED3" & planyear == 2013 ) ;
	drop if planyear == 2014 ; 
	tab fuzzy_inertia planyear ; 
	
	bys familyid planyear : egen minpaid = min(bene_paid) ;
	bys familyid planyear : egen maxpaid = max(bene_paid) ;
	gen free_any = 1 if minpaid == 0 ; 
	gen free_all = 1 if maxpaid == 0 ; 
	replace free_any = 0 if minpaid > 0 ; 
	replace free_all = 0 if maxpaid > 0 ; 
	merge m:1 entitynum memid empid planyear ratestructure using `fixeddesc' ; 

	assert _merge != 1 ; 
	drop if _merge == 2 ; 
	drop _merge ; 
	gen contrib_pct = . ; 
	gen contrib_fix = . ; 
	gen contrib_spc = . ; 
	
	replace contrib_pct = 1 if inlist(fixeddesc,7,8,9) ;
	replace contrib_fix = 1 if inlist(fixeddesc,1,2,3,6) ;
	replace contrib_spc = 1 if inlist(fixeddesc,4,5) ;
	replace contrib_fix = 0 if contrib_fix == . ;
	replace contrib_pct = 0 if contrib_pct == . ;
	replace contrib_spc = 0 if contrib_spc == . ;
	
* Get ACG cells - we have a different method for distributions that we add in the next .do file 0_1 ; 
* We don't need these cells for analysis, but we will used them to check how closely ACG matches ; 
* PF by cell ; 
* We used to get individual cells too, but that information is contained within the family cell variable ; 
preserve ; 
	use "${directory}/data/built/sample/acg/family_allcells_2009_`famcelldate'.dta", clear ; 
		gen planyear = 2009 ; 
	append using "${directory}/data/built/sample/acg/family_allcells_2010_`famcelldate'.dta" ; 
		replace planyear = 2010 if planyear == . ; 
	append using "${directory}/data/built/sample/acg/family_allcells_2011_`famcelldate'.dta" ; 
		replace planyear = 2011 if planyear == . ; 
	append using "${directory}/data/built/sample/acg/family_allcells_2012_`famcelldate'.dta" ; 
		replace planyear = 2012 if planyear == . ; 
	append using "${directory}/data/built/sample/acg/family_allcells_2013_`famcelldate'.dta" ; 
		replace planyear = 2013 if planyear == . ; 

	keep familyid famcell3 famcell10 famcellreg planyear ; 
	duplicates drop ; 
	unique(familyid planyear) ;
	mdesc ; 

	tempfile ACGfamily ; 
	save `ACGfamily' ; 

restore ; 

	merge m:1 familyid planyear using `ACGfamily' ; 
	* we know we don't have a perfect match here. ; 
	assert _merge != 2 ;
	assert _merge == 1 if planyear == 2008 ; 
	
	* legitimate reasons to not merge ; 
	*1) Merge == 1 for people in the sample, but with no ACG output because they are the PF sample, and did not have prior year information ; 
		* This set of people fall into 2 groups - first is easy to count ;
		* 1 those with experience == 1 - this is the first year in which they chose a plan, so we can't have had prior year claims to get an ACG group for them ; 
		* 2 those with experience greater than 1 (they chose a plan previously), but without complete eligibility in that prior year, so we also can't include them because their prior year claims are incomplete and do not given an accurate acg score ; 
	
	replace _merge = . if _merge == 1 & experience == 1 ; 
	* now check that the remaining _merge == 1 observations can be explained by incomplete prior year eligibility ; 
	* e.g. all of the _merge == 1 people should be PF observations that are not included for PB / ACG . ; 
	* so the PB variables should be missing for these _merge == 1  people ; 

	replace _merge = . if _merge == 1 & costtot_PB == . ;
	rename _merge mergeacg ; 
		
	assert mergeacg != 1 ; 
	* All mergeacg == 1 ACG observations explained and kept ; 
	assert mergeacg == 3 | mergeacg == . ; 

	destring entitynum, replace ; 

	mdesc ; 
	
	rename planyear year ; 
	rename gross_prem gross_premium ; 
	rename bene_paid net_premium ; 
	rename premium_rxmed gross_prem_rxmed ; 
	rename medpremium gross_prem_med ; 
	rename rxpremium gross_prem_rx ; 
	rename gross_dent_prem gross_prem_dent ; 
	rename gross_vis_prem gross_prem_vis ; 
	rename ooptot_PF gross_calc_ooptotal_PF ; 
	rename oopdrug_PF gross_calc_drugtotal_PF ; 
	rename oopmed_PF gross_calc_medtotal_PF ; 
	rename oopttot_savings_PF net_calc_ooptotal_PF ; 
	rename costtot_PF total_calc_cost_PF ; 
	rename orig_sum_PF gross_observed_ooptotal_PF ; 
	rename ooptot_PB gross_calc_ooptotal_PB ; 
	rename oopttot_savings_PB net_calc_ooptotal_PB ; 
	rename costtot_PB total_calc_cost_PB ; 
	rename orig_sum_PB gross_observed_ooptotal_PB ; 
	
	rename famcell10 famcelldec ; 
	rename fixeddesc contrib_type ;
	
	replace hsaelig = 0 if hsaelig == . ; 
	replace hraelig = 0 if hraelig == . ;
	tab year hsaelig ; 
	tab year hraelig ; 

	drop min max *last* diff* test* ;
	
	order familyid entitynum memid empid year experience tier individual ratestructure plan drugplan chosen insurer sharp_inertia fuzzy_inertia status_change tier_change ded_in ded_out max_oop_in max_oop_out pcp_copay_in pcp_coin_in paytype_pcp_in pcp_copay_out pcp_coin_out paytype_pcp_out spec_copay_in spec_coin_in paytype_spec_in spec_copay_out spec_coin_out paytype_spec_out hsaelig hraelig totallowedamt_PF totallowedamt_PB gross_observed_ooptotal_PF gross_observed_ooptotal_PB gross_premium gross_prem_rxmed gross_prem_med gross_prem_rx gross_prem_dent gross_prem_vis subsidy net_premium potential_hra potential_hsa gross_calc_ooptotal_PF gross_calc_drugtotal_PF gross_calc_medtotal_PF net_calc_ooptotal_PF total_calc_cost_PF gross_calc_ooptotal_PB net_calc_ooptotal_PB total_calc_cost_PB free_any free_all contrib_fix contrib_pct contrib_spc contrib_type ; 
	label drop _all ; 

	drop age_13 age_14 age_15 age_16 age_17 age_18 ; 
	drop sex_13 sex_14 sex_15 sex_16 sex_17 sex_18 ; 

	gen memid_str = "" ; 
	replace memid_str = "OEA" if memid == 1 ; 
	replace memid_str = "OSEA" if memid == 2 ; 
	replace memid_str = "AFT" if memid == 3 ; 
	replace memid_str = "Non rep" if memid == 4 ; 
	replace memid_str = "Other" if memid == 5 ; 
	replace memid_str = "Other" if memid == 6 ; 
	replace memid_str = "PFTA" if memid == 7 ; 
	
	gen empid_str = "" ; 
	replace empid_str = "Administrator Licensed Full Time" if empid == "AF" ; 
	replace empid_str = "Administrator Licensed Part Time" if empid == "AP" ; 
	replace empid_str = "Superintendent" if empid == "AS" ; 
	replace empid_str = "Classified Full Time" if empid == "CF" ; 
	replace empid_str = "Classified Part Time" if empid == "CP" ; 
	replace empid_str = "Confidential Full Time" if empid == "DF" ; 
	replace empid_str = "Confidential Part Time" if empid == "DP" ; 
	replace empid_str = "Community College Exempt Non Instructional Full Time" if empid == "EF" ; 
	replace empid_str = "Community College Exempt Non Instructional Part Time" if empid == "EP" ; 
	replace empid_str = "Community College Faculty Full Time" if empid == "FF" ; 
	replace empid_str = "Community College Faculty Part Time" if empid == "FP" ; 
	replace empid_str = "Licensed Full Time" if empid == "LF" ; 
	replace empid_str = "Licensed Part Time" if empid == "LP" ; 
	replace empid_str = "Administrator Non Licensed Full Time" if empid == "NF" ; 
	replace empid_str = "Administrator Non Licensed Part Time" if empid == "NP" ; 
	assert empid_str != "" ; 
	assert memid_str != "" ; 
	
	preserve ; 
	
	use "$directory/data/built/sample/sample_PF_2008_`sampledate'.dta", clear ; 		
		append using "$directory/data/built/sample/sample_PF_2009_`sampledate'.dta" ; 		
		append using "$directory/data/built/sample/sample_PF_2010_`sampledate'.dta" ; 		
		append using "$directory/data/built/sample/sample_PF_2011_`sampledate'.dta" ; 		
		append using "$directory/data/built/sample/sample_PF_2012_`sampledate'.dta" ; 		
		append using "$directory/data/built/sample/sample_PF_2013_`sampledate'.dta" ; 		
		
		keep entitynum memid empid familyid planyear tier ; 
		rename planyear year ; 
		duplicates drop ; 
		isid(familyid year) ;
	tempfile sample ; 
	save `sample' ; 

	restore ; 
	merge m:1 familyid year entitynum memid empid tier using `sample' ; 
	assert _merge == 3 ; 

	drop _merge ; 
	
	* not sure why we need to do this - I thought we had droppped them all in sample selection ; 
	* check on this ; 
	gen counter = 1 ; 
	egen size = sum(counter), by(familyid year) ; 
	di "Any left with choice set size of 1?";

	drop if size == 1 ; 
	drop size ; 
	* okay - we're good ; 
	
	preserve ; 
		keep familyid year ; 
		duplicates drop ; 
		tab year ; 
	restore ; 
	gen PF = 1 if total_calc_cost_PF != . ;
	replace PF = 0 if total_calc_cost_PF == . ;
	gen PB = 1 if total_calc_cost_PB != . ;
	replace PB = 0 if total_calc_cost_PB == . ;

	gen ACG = 1 if mergeacg == 3 ; 
	replace ACG = 0 if mergeacg !=3 ; 
	drop mergeacg ; 
	
	tab PF ; 
	tab PB ; 
	tab ACG ; 
	tab PB ACG ; 
	tab PF ACG ; 
	tab PB PF ; 

	drop counter ; 
	sort familyid year plan drugplan ; 
	label drop _all ; 
	foreach var of varlist _all { ;
	label var `var' "" ;
	} ;
 
	label define sexkey 1 "Female" 2 "Male" 0 "Missing";
	label values sex* sexkey;
	
	save "`outdir'/temp/analysis_dataset_PBPF_`cdate'.dta", replace ; 
	
log close ; 