#delimit ;
clear ;
set more off ;
pause off ; 
/*** Project: 		Oregon Health Plan Choice Analysis 								*/ ;
/*** Program: 		0_balance_checks												*/ ;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu)	 				*/ ;
/*** Dates:			Created: 	07 June 2015										*/ ;
/***				Modified: 	04 October 2016									*/ ;

/*** Purpose & Description: 
Test arm balance ;
*/ ;
*** 0. Initializations and log ;
global directory /disk/agedisk3/oebb.work/cbehrer/oregon/ ;

local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;
global cdate `cdate' ;
global ctime `ctime' ;
di "$cdate" ;

cap mkdir "$directory/log/informedenrollment/`cdate'/" ;
cap mkdir "$directory/data/informedenrollment/`cdate'/" ;
cap mkdir "$directory/output/informedenrollment/`cdate'/" ;

log using "$directory/log/informedenrollment/`cdate'/0_balance_tests_`cdate'_`ctime'.log" ;
local indir "$directory/data/analysis/formal_reg_datasets" ;

* File /disk/agedisk3/oebb.work/cbehrer/oregon/do/5regressionanalysis/0_1addIE__6_Oct_2016.do adds IE arm to analysis dataset ; 

*** 1. Get data ;
use "`indir'/temp/analysis_dataset_2KandIE_31_Oct_2016.dta" , clear ; 
label drop _all ; 
 
keep if year == 2012 | year == 2013 ; 
keep if PB == 1 ; 

keep familyid entitynum tier year age* sex* arm PB ACG chosen net_premium totallowedamt_PF gross_observed_ooptotal_PF plan potential_hra potential_hsa ;
*CREATE TABLE SHOWING AGE, GENDER, BREAKDOWN OF TIERS, PRIOR YEAR EXPENDITURES, PRIOR YEAR TOTAL COSTS, PRIOR YEAR NUMBER OF PLANS ;

gen net_observed_ooptotal_PF = gross_observed_ooptotal_PF - potential_hra - potential_hsa ; 
replace net_observed_ooptotal_PF = 0 if net_observed_ooptotal_PF < 0 ; 
sum net_observed_ooptotal_PF ; 

keep if year == 2012 ; 
keep familyid plan net_premium totallowedamt_PF net_observed_ooptotal_PF chosen ; 
gen total_observed_costs_2012  = net_observed_ooptotal_PF + net_premium ; 
gen counter = 1 ; 
egen num_choices_2012 = sum(counter), by(familyid) ; 
rename totallowedamt_PF totallowedamt_2012 ; 
keep if chosen == 1 ; 
isid(familyid) ; 
keep familyid total_observed_costs_2012 num_choices_2012 totallowedamt_2012 ; 

tempfile lastyear ; 
save `lastyear' ; 

clear ; 
use "`indir'/temp/analysis_dataset_2KandIE_31_Oct_2016.dta" , clear ; 
keep if year == 2013 ; 
keep familyid entitynum plan age* sex* tier arm PB ACG chosen ; 

keep if chosen == 1 ; 
keep if PB == 1 ; 

isid (familyid) ; 
drop plan ; 
merge 1:1 familyid using `lastyear' ; 

keep if _merge == 3 ; 
drop _merge ;
drop if arm == . ; 

assert _N == 21072 ; 
tab arm ; 
assert ACG == 1 ; 
assert PB == 1 ; 
drop ACG PB ;
drop if arm == . ; 
mdesc ; 

gen tierdum1 = (tier == 1) ;
gen tierdum2 = (tier == 2) ;
gen tierdum3 = (tier == 3) ;
gen tierdum4 = (tier == 4) ;

bys arm : tab tier ; 
bys arm : sum total_observed_costs_2012 ; 
bys arm : sum num_choices_2012 ; 
bys arm : sum totallowedamt_2012 ; 
bys arm : sum age_1 ; 
bys arm : tab sex_1 ; 

reg total_observed_costs_2012 arm, cluster(entitynum)  ;
reg num_choices_2012 arm, cluster(entitynum)  ;
reg totallowedamt_2012 arm, cluster(entitynum)  ;
reg age_1 arm, cluster(entitynum) ;
reg tierdum1 arm, cluster(entitynum) ;
reg tierdum2 arm, cluster(entitynum) ;
reg tierdum3 arm, cluster(entitynum) ;
reg tierdum4 arm, cluster(entitynum) ;
reg sex_1 arm, cluster(entitynum) ;

preserve ; 
keep familyid arm entitynum ; 
mdesc ; 

tempfile arm ; 
save `arm' ; 

restore ;
preserve ; 
keep familyid sex* age* ; 
reshape long sex_ age_, i(familyid) j(member) ;
merge m:1 familyid using `arm' ; 
rename age_ age ; 
rename sex_ sex ; 
drop if age == . ; 
mdesc ; 
bys arm : tab sex ; 
bys arm : sum age ; 

reg age arm, cluster(entitynum) ; 
reg sex arm, cluster(entitynum) ; 
restore ; 

log close ; 