#delimit ;
clear;
set more off;
/*** Project: 		Oregon Health Plan Choice Analysis 								*/;
/*** Program: 		1_IE_recommendation_regs										*/;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 				*/;
/*** Dates:			Created: 	08 October 2015										*/;
/***				Modified: 	06 October 2016										*/;

/*** Purpose & Description: 
1) Run preliminary regressions investigation the effect of the recommendation on plan choice ; 
*/;

/*** 0. Initializations and log*/;
pause off;
global directory /disk/agedisk3/oebb.work/cbehrer/oregon/;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);
global cdate `cdate';
global ctime `ctime';
di "$cdate";
log using "$directory/log/informedenrollment/`cdate'/1_IE_recommend_regs_analysisdir_`cdate'_`ctime'.log";
local datadate 31_Oct_2016 ; 
cap mkdir "$directory/log/informedenrollment/`cdate'/";
cap mkdir "$directory/data/informedenrollment/`cdate'/";
local outdata "$directory/data/analysis/formal_reg_datasets/";

use "`outdata'/IE2013_regress_input_`datadate'.dta", clear ; 

	egen maxhasrec = max(hasrec), by(familyid) ;
	gen rank1 = (rank==1) ; 
	gen rank2 = (rank==2) ; 
	gen rank3 = (rank==3) ; 
	
	replace recommended = 0 if rank != 1 ; 
	replace recommended = 1 if rank == 1 ; 
	
	replace gross_premium = gross_premium / 1000 ; 
	replace resid_prem = resid_prem / 1000 ; 
	replace net_premium = net_premium / 1000 ; 
	replace total_calc_cost_PB = total_calc_cost_PB / 1000 ; 
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB / 1000 ; 
	replace min_costtot = min_costtot / 1000 ; 
		
	gen tier_1 = (tier==1) ;
	gen tier_2 = (tier==2) ;
	gen tier_3 = (tier==3) ;
	gen tier_4 = (tier==4) ;
	
	foreach i in 1 2 3 4 { ;
		foreach j in 1 2 3 4 5 6 7 8 9 10 { ;
			gen tierplan_dum_t`i'_p`j' = tier_`i'*plan_`j' ; 
		} ;
	} ;
	
	drop tierplan_dum_t1_p1 ; 
	drop tierplan_dum_t2_p1 ; 
	drop tierplan_dum_t3_p1 ; 
	drop tierplan_dum_t4_p1 ; 
	
	
	tempfile all ; 
	save `all' ; 
	
	keep if hasrec == 1 ; * keeps only those with recommendation ; 
	assert maxhasrec == 1 ; 
	
	egen minrank = min(rank), by(familyid) ;
	assert minrank == 1 ; 
	unique(familyid) ;

	clogit recommended net_calc_ooptotal_PB gross_premium resid_prem tierplan_dum_t*, group(familyid) ; 
	estimates store prob_rec1 ; 
	
	use `all', clear ; 
	estimates restore prob_rec1 ; 
	predict pred_rec_prob, pc1 ; 
	
	gen prob_times_cost = pred_rec_prob * total_calc_cost_PB ; 
	egen predicted_recommended_cost = sum(prob_times_cost), by(familyid) ; 
	gen predicted_overspending = predicted_recommended_cost - min_costtot ; 
	
	gen test = total_calc_cost_PB - min_costtot ;
	gen test2 = pred_rec_prob * test ; 
	egen test3 = sum(test2), by(familyid) ; 
	
	corr test3 predicted_overspending ; 
	sum predicted_overspending, detail ; 
	replace predicted_overspending = 0 if predicted_overspending < 0 ; 
	drop test test2 test3 ; 
	
	gen pred_low = pred_rec_prob*lowest_cost ;
	gen treat_pred_low = treatment*pred_rec_prob*lowest_cost ; 
	
	gen pred_save = pred_rec_prob*predicted_overspending ;
	gen treat_pred_save = treatment*pred_rec_prob*predicted_overspending ; 
	
	describe sizedum_* ; 
	
	forvalues i = 3(1)10 { ;
		gen pred_rec_choicedum`i' = pred_rec_prob*sizedum_`i' ;
	} ;	
	
	* Model for table 4.5A ; 	
	clogit chosen c.pred_rec_prob##treatment net_calc_ooptotal_PB gross_premium resid_prem tierplan_dum_t* lowest_cost pred_low treat_pred_low inertia##tier_1 inertia##tier_2 inertia##tier_3 inertia##tier_4 c.pred_rec_prob##tier_1 c.pred_rec_prob##tier_2 c.pred_rec_prob##tier_3 c.pred_rec_prob##tier_4 pred_rec_choicedum*, group(familyid) ;
	
	* Model for table 4.5B ; 	
	clogit chosen c.pred_rec_prob##treatment net_calc_ooptotal_PB gross_premium resid_prem tierplan_dum_t* lowest_cost pred_low  inertia##tier_1 inertia##tier_2 inertia##tier_3 inertia##tier_4 c.pred_rec_prob##tier_1 c.pred_rec_prob##tier_2 c.pred_rec_prob##tier_3 c.pred_rec_prob##tier_4 pred_rec_choicedum*, group(familyid) ;
	
	save "`outdata'/IE2013_simulation_data_`cdate'.dta", replace ; 
	
log close;