#delimit ;
clear;
set more off;

/*** Project: 		Oregon Health Plan Choice Analysis 									*/;
/*** Program: 		1_IE_recommendation_regs											*/;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 						*/;
/*** Dates:			Created: 		28 October 2015									*/;
/***					Modified: 	07 October 2016									*/;

/*** Purpose & Description: 
1) Run simulations of control group as a treatment group ; 
*/;

/*** 0. Initializations and log*/;

pause off;

global directory /disk/agedisk3/oebb.work/cbehrer/oregon/;
local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);
global cdate `cdate';
global ctime `ctime';
di "$cdate";
cap mkdir "$directory/log/informedenrollment/`cdate'/" ; 
log using "$directory/log/informedenrollment/`cdate'/1_2_IE_choice_simulation_analysisdir_`cdate'_`ctime'.log";
local simuldate _6_Oct_2016 ; 

local indata "$directory/data/analysis/formal_reg_datasets/";

use "`indata'/IE2013_simulation_data_`simuldate'.dta", clear ;
cap drop counter ; 
* cost values are already scaled down by dividing by 1000 ; 
* tier and tier plan dummies exist ; 
* pred_prob1 exists, generated in prior .do file as:  
	* clogit recommended net_calc_ooptotal_PB gross_premium resid_prem tierplan_dum_t*, group(familyid) ; 
	* estimates store prob_rec1 ;
	* use `all', clear ; 
	* estimates restore prob_rec1 ; 
	* predict pred_rec_prob, pc1 ;

gen prob_times_oop = pred_rec_prob * net_calc_ooptotal_PB ;
egen predicted_recommended_oop = sum(prob_times_oop), by(familyid) ;
gen prob_times_gross = pred_rec_prob * gross_premium ;
egen predicted_recommended_gross = sum(prob_times_gross), by(familyid) ;
gen prob_times_resid = pred_rec_prob * resid_prem ;
egen predicted_recommended_resid = sum(prob_times_resid), by(familyid) ;
gen prob_times_net = pred_rec_prob * net_premium ;
egen predicted_recommended_net = sum(prob_times_net), by(familyid) ;
preserve ;
	unique(familyid) ;
	unique(familyid predicted_recommended_cost) ;
	replace predicted_recommended_cost = predicted_recommended_cost * 1000 ;
	replace predicted_recommended_gross = predicted_recommended_gross * 1000 ;
	replace predicted_recommended_resid = predicted_recommended_resid * 1000 ;
	replace predicted_recommended_net = predicted_recommended_net * 1000 ;
	replace predicted_recommended_oop = predicted_recommended_oop * 1000 ;
	replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
	replace gross_premium = gross_premium * 1000 ;
	replace resid_prem = resid_prem * 1000 ;
	replace net_premium = net_premium * 1000 ;
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;

	keep if chosen == 1 ;
	bys treatment : sum predicted_recommended_cost, detail ;
	bys treatment : sum predicted_recommended_gross, detail ;
	bys treatment : sum predicted_recommended_resid, detail ;
	bys treatment : sum predicted_recommended_net, detail ;
	bys treatment : sum predicted_recommended_oop, detail ;
	bys treatment : sum total_calc_cost_PB, detail ;
	bys treatment : sum gross_premium, detail ;
	bys treatment : sum resid_prem, detail ;
	bys treatment : sum net_premium, detail ;
	bys treatment : sum net_calc_ooptotal_PB, detail ;
	egen sum_chosen_probrec = sum(pred_rec_prob), by(treatment) ;
	gen counter = 1 ;
	isid(familyid) ;
	egen grpsize = sum(counter), by(treatment) ;
	gen average_adherance = sum_chosen_probrec / grpsize ;
	bys treatment : sum average_adherance, detail ;
restore ;

* Model for table 4.5A ; 	
clogit chosen c.pred_rec_prob##treatment net_calc_ooptotal_PB gross_premium resid_prem tierplan_dum_t* lowest_cost pred_low treat_pred_low inertia##tier_1 inertia##tier_2 inertia##tier_3 inertia##tier_4 c.pred_rec_prob##tier_1 c.pred_rec_prob##tier_2 c.pred_rec_prob##tier_3 c.pred_rec_prob##tier_4 pred_rec_choicedum*, group(familyid) ;
estimates store prob_choice1 ;

preserve ;
	keep if treatment == 0 ;
	estimates restore prob_choice1;
	predict pred_choice1, pc1 ;
	replace gross_premium = gross_premium * 1000 ;
	replace resid_prem = resid_prem * 1000 ;
	replace net_premium = net_premium * 1000 ;
	replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;
	gen wght_pred_grossprem = pred_choice1 * gross_premium ;
	gen wght_pred_residprem = pred_choice1 * resid_prem ;
	gen wght_pred_netprem = pred_choice1 * net_prem ;
	gen wght_pred_total_calc_cost_PB = pred_choice1 * total_calc_cost_PB ;
	gen wght_pred_oop = pred_choice1 * net_calc_ooptotal_PB ;
	egen pred_grossprem = sum(wght_pred_grossprem), by(familyid) ;
	egen pred_residprem = sum(wght_pred_residprem), by(familyid) ;
	egen pred_netprem = sum(wght_pred_netprem), by(familyid) ;
	egen pred_total_calc_cost_PB = sum(wght_pred_total_calc_cost_PB), by(familyid) ;
	egen pred_oop = sum(wght_pred_oop), by(familyid) ;
	unique(familyid) ;
	unique(familyid pred_grossprem) ;
	unique(familyid pred_residprem) ;
	unique(familyid pred_netprem) ;
	unique(familyid pred_total_calc_cost_PB) ;
	unique(familyid pred_oop) ;
	gen simulated_choice = pred_choice1 * pred_rec_prob ;
	tab treatment ;
	egen sum_simulated = sum(simulated_choice), by(treatment) ;

	keep if chosen == 1 ;
	gen counter = 1 ;
	isid(familyid) ;
	egen grpsize = sum(counter), by(treatment) ;
	gen average_simulated = sum_simulated / grpsize ;
	bys treatment : sum average_simulated, detail ;
	pause ;

	sum pred_total_calc_cost_PB, detail ;
	sum pred_oop, detail ;
	sum pred_grossprem, detail ;
	sum pred_residprem, detail ;
	sum pred_netprem, detail ;
restore ;

preserve ;
	keep if treatment == 0 ;
	replace treatment = 1 ;
	estimates restore prob_choice1 ;
	predict pred_choice2, pc1 ;

	replace gross_premium = gross_premium * 1000 ;
	replace resid_prem = resid_prem * 1000 ;
	replace net_prem = net_premium * 1000 ;
	replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;
	gen wght_pred_grossprem = pred_choice2 * gross_premium ;
	gen wght_pred_residprem = pred_choice2 * resid_prem ;
	gen wght_pred_netprem = pred_choice2 * net_prem ;
	gen wght_pred_total_calc_cost_PB = pred_choice2 * total_calc_cost_PB ;
	gen wght_pred_oop = pred_choice2 * net_calc_ooptotal_PB ;
	egen pred_grossprem = sum(wght_pred_grossprem), by(familyid) ;
	egen pred_residprem = sum(wght_pred_residprem), by(familyid) ;
	egen pred_netprem = sum(wght_pred_netprem), by(familyid) ;
	egen pred_total_calc_cost_PB = sum(wght_pred_total_calc_cost_PB), by(familyid) ;
	egen pred_oop = sum(wght_pred_oop), by(familyid) ;
	unique(familyid) ;
	unique(familyid pred_grossprem) ;
	unique(familyid pred_residprem) ;
	unique(familyid pred_netprem) ;
	unique(familyid pred_total_calc_cost_PB) ;
	unique(familyid pred_oop) ;
	gen simulated_choice = pred_choice2 * pred_rec_prob ;
	tab treatment ;
	egen sum_simulated = sum(simulated_choice), by(treatment) ;
	keep if chosen == 1 ;
	gen counter = 1 ;
	isid(familyid) ;
	egen grpsize = sum(counter), by(treatment) ;
	gen average_simulated = sum_simulated / grpsize ;
	bys treatment : sum average_simulated, detail ;
	pause ;
	sum pred_total_calc_cost_PB, detail ;
	sum pred_oop, detail ;
	sum pred_grossprem, detail ;
	sum pred_residprem, detail ;
	sum pred_netprem, detail ;
restore ;
preserve ; 
keep if chosen == 1 ;
keep if treatment == 0 ;
replace gross_premium = gross_premium * 1000 ;
replace resid_prem = resid_prem * 1000 ;
replace net_premium = net_premium * 1000 ;
replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;
keep familyid gross_premium resid_prem net_premium total_calc_cost_PB net_calc_ooptotal_PB ;
duplicates drop ;
unique(familyid) ;

sum total_calc_cost_PB, detail ;
sum net_calc_ooptotal_PB, detail ;
sum gross_premium, detail ;
sum resid_prem, detail ;
sum net_premium, detail ;
restore ; 



* Model for table 4.5B ; 	
clogit chosen c.pred_rec_prob##treatment net_calc_ooptotal_PB gross_premium resid_prem tierplan_dum_t* lowest_cost pred_low  inertia##tier_1 inertia##tier_2 inertia##tier_3 inertia##tier_4 c.pred_rec_prob##tier_1 c.pred_rec_prob##tier_2 c.pred_rec_prob##tier_3 c.pred_rec_prob##tier_4 pred_rec_choicedum*, group(familyid) ;
estimates store prob_choice2 ;

preserve ;
	keep if treatment == 0 ;
	estimates restore prob_choice2 ;
	predict pred_choice1, pc1 ;
	replace gross_premium = gross_premium * 1000 ;
	replace resid_prem = resid_prem * 1000 ;
	replace net_premium = net_premium * 1000 ;
	replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;
	gen wght_pred_grossprem = pred_choice1 * gross_premium ;
	gen wght_pred_residprem = pred_choice1 * resid_prem ;
	gen wght_pred_netprem = pred_choice1 * net_prem ;
	gen wght_pred_total_calc_cost_PB = pred_choice1 * total_calc_cost_PB ;
	gen wght_pred_oop = pred_choice1 * net_calc_ooptotal_PB ;
	egen pred_grossprem = sum(wght_pred_grossprem), by(familyid) ;
	egen pred_residprem = sum(wght_pred_residprem), by(familyid) ;
	egen pred_netprem = sum(wght_pred_netprem), by(familyid) ;
	egen pred_total_calc_cost_PB = sum(wght_pred_total_calc_cost_PB), by(familyid) ;
	egen pred_oop = sum(wght_pred_oop), by(familyid) ;
	unique(familyid) ;
	unique(familyid pred_grossprem) ;
	unique(familyid pred_residprem) ;
	unique(familyid pred_netprem) ;
	unique(familyid pred_total_calc_cost_PB) ;
	unique(familyid pred_oop) ;
	gen simulated_choice = pred_choice1 * pred_rec_prob ;
	tab treatment ;
	egen sum_simulated = sum(simulated_choice), by(treatment) ;

	keep if chosen == 1 ;
	gen counter = 1 ;
	isid(familyid) ;
	egen grpsize = sum(counter), by(treatment) ;
	gen average_simulated = sum_simulated / grpsize ;
	bys treatment : sum average_simulated, detail ;
	pause ;

	sum pred_total_calc_cost_PB, detail ;
	sum pred_oop, detail ;
	sum pred_grossprem, detail ;
	sum pred_residprem, detail ;
	sum pred_netprem, detail ;
restore ;

preserve ;
	keep if treatment == 0 ;
	replace treatment = 1 ;
	estimates restore prob_choice2 ;
	predict pred_choice2, pc1 ;

	replace gross_premium = gross_premium * 1000 ;
	replace resid_prem = resid_prem * 1000 ;
	replace net_prem = net_premium * 1000 ;
	replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;
	gen wght_pred_grossprem = pred_choice2 * gross_premium ;
	gen wght_pred_residprem = pred_choice2 * resid_prem ;
	gen wght_pred_netprem = pred_choice2 * net_prem ;
	gen wght_pred_total_calc_cost_PB = pred_choice2 * total_calc_cost_PB ;
	gen wght_pred_oop = pred_choice2 * net_calc_ooptotal_PB ;
	egen pred_grossprem = sum(wght_pred_grossprem), by(familyid) ;
	egen pred_residprem = sum(wght_pred_residprem), by(familyid) ;
	egen pred_netprem = sum(wght_pred_netprem), by(familyid) ;
	egen pred_total_calc_cost_PB = sum(wght_pred_total_calc_cost_PB), by(familyid) ;
	egen pred_oop = sum(wght_pred_oop), by(familyid) ;
	unique(familyid) ;
	unique(familyid pred_grossprem) ;
	unique(familyid pred_residprem) ;
	unique(familyid pred_netprem) ;
	unique(familyid pred_total_calc_cost_PB) ;
	unique(familyid pred_oop) ;
	gen simulated_choice = pred_choice2 * pred_rec_prob ;
	tab treatment ;
	egen sum_simulated = sum(simulated_choice), by(treatment) ;
	keep if chosen == 1 ;
	gen counter = 1 ;
	isid(familyid) ;
	egen grpsize = sum(counter), by(treatment) ;
	gen average_simulated = sum_simulated / grpsize ;
	bys treatment : sum average_simulated, detail ;
	pause ;
	sum pred_total_calc_cost_PB, detail ;
	sum pred_oop, detail ;
	sum pred_grossprem, detail ;
	sum pred_residprem, detail ;
	sum pred_netprem, detail ;
restore ;
keep if chosen == 1 ;
keep if treatment == 0 ;
replace gross_premium = gross_premium * 1000 ;
replace resid_prem = resid_prem * 1000 ;
replace net_premium = net_premium * 1000 ;
replace total_calc_cost_PB = total_calc_cost_PB * 1000 ;
replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ;
keep familyid gross_premium resid_prem net_premium total_calc_cost_PB net_calc_ooptotal_PB ;
duplicates drop ;
unique(familyid) ;

sum total_calc_cost_PB, detail ;
sum net_calc_ooptotal_PB, detail ;
sum gross_premium, detail ;
sum resid_prem, detail ;
sum net_premium, detail ;

log close ; 