#delimit ;
clear ;
set more off ;
pause off ; 
/*** Project: 		Oregon Health Plan Choice Analysis 								*/ ;
/*** Program: 		2_IE_observedcosts_trteffect.do									*/ ;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 					*/ ;
/*** Dates:			Created: 	07 June 2015										*/ ;
/***					Modified: 	07 October 2016								*/ ;

/*** Purpose & Description: 
Tabulate costs in treatment vs control arms to describe treatment effect
*/ ;

* From 8th October 2016, I am just calculating these statistics for the subset of people with PB / ACG ; 
* Output in both 2012 and 2013, because this is what we report in the paper ; 

*** 0. Initializations and log ;
global directory /disk/agedisk3/oebb.work/cbehrer/oregon/ ;

local c_date = c(current_date) ;
local cdate = subinstr("`c_date'", " ", "_", .) ;
local ctime = c(current_time) ;
global cdate `cdate' ;
global ctime `ctime' ;
di "$cdate" ;

cap mkdir "$directory/log/informedenrollment/`cdate'/" ;
cap mkdir "$directory/data/informedenrollment/`cdate'/" ;

log using "$directory/log/informedenrollment/`cdate'/2_IE_observedcosts_trteffect_`cdate'_`ctime'.log" ;

local elig_data "$directory/data/cleaning/2deduplicated/deduplicated_eligibility_11_Jun_2015.dta" ; 

local indata1 "$directory/data/analysis/formal_reg_datasets" ;
local indata2 "$directory/data/given/clean/informedenrollment/2013" ;
local outdata "$directory/data/informedenrollment/`cdate'/" ;

local calcoutdate 31_Oct_2016 ;
local regdate 31_Oct_2016 ;
local premiumdate 29_Mar_2016 ;
local calcfiledate 28_Sep_2016 ; 
local sampledate 23_Sep_2016 ; 

local entity_name_num_xwalk "/disk/agedisk3/oebb.work/cbehrer/oregon/data/given/clean/package2/EntityNumberCrossWalk.csv" ;

local macros $directory/do/macros/ ;

*** 1. Get sample and calculator output  ;
* Here we want observed costs in 2012 and 2013 for anyone with complete data for both years ; 
* This means the observed costs from the 2012 PF data (2012 claims + 2012 premium) and 2013 PF data (2013 claims + 2013 premium) ; 
* For all individuals in the 2013 PB sample (those with complete 2012 & 2013 eligibility) ; 

use "`indata1'/temp/analysis_dataset_2KandIE_`calcoutdate'.dta" , clear ; 
keep if year == 2013 ; 
keep if PB == 1 ; 
assert ACG == 1 ; 
keep if chosen == 1 ; 

keep familyid entitynum memid empid year tier ratestructure plan drugplan gross_observed_ooptotal_PF net_calc_ooptotal_PB potential_hsa potential_hra net_premium acg_mean_2k_cellreg ; 

isid(familyid);

* acg_mean_20k_cell_reg is already net of hsa & hra ; 
gen net_acg_oop = acg_mean_2k_cellreg ;
replace net_acg_oop = 0 if net_acg_oop < 0 ; 

gen costtot_acg = net_acg_oop + net_premium ; 

gen net_observed_oopPF = gross_observed_ooptotal_PF - potential_hsa - potential_hra ;
replace net_observed_oopPF = 0 if net_observed_oopPF < 0 ; 

gen costtot_obs = net_observed_oopPF + net_premium ; 
gen costtot_pb = net_calc_ooptotal_PB + net_premium ; 

keep familyid entitynum memid empid year tier ratestructure plan drugplan costtot_obs costtot_pb costtot_acg net_acg_oop potential_hra potential_hsa net_observed_oopPF net_premium ;
foreach var in entitynum memid empid year tier ratestructure plan drugplan costtot_obs costtot_pb costtot_acg net_acg_oop potential_hra potential_hsa net_observed_oopPF net_premium { ;
	rename `var' `var'13 ; 
} ;
preserve ; 
use "`indata1'/temp/analysis_dataset_2KandIE_`calcoutdate'.dta" , clear ; 
* We are just getting PB here for people that we have it for. ; 
* We will get observed from the claims below for everyone in 2013 sample - not anymore - just subset with PB/ACG in both years ; 
keep if year == 2012 ; 
keep if PB == 1 ;
assert ACG == 1 ;
keep if chosen == 1 ;  
keep familyid entitynum memid empid year tier ratestructure plan drugplan gross_observed_ooptotal_PF net_calc_ooptotal_PB net_premium potential_hra potential_hsa acg_mean_2k_cellreg ; 
keep if year == 2012 ; 
gen net_observed_oopPF = gross_observed_ooptotal_PF - potential_hsa - potential_hra ;
replace net_observed_oopPF = 0 if net_observed_oopPF < 0 ; 

isid(familyid);
* acg_mean_20k_cell_reg is already net of hsa & hra ; 
gen net_acg_oop = acg_mean_2k_cellreg ;
replace net_acg_oop = 0 if net_acg_oop < 0 ; 

gen costtot_acg = net_acg_oop + net_premium ; 
gen costtot_obs = net_observed_oopPF + net_premium ; 
gen costtot_pb = net_calc_ooptotal_PB + net_premium ;  

keep familyid entitynum memid empid year tier ratestructure plan drugplan gross_observed_ooptotal_PF potential_hra potential_hsa net_premium costtot_obs costtot_pb costtot_acg net_acg_oop ;
foreach var in entitynum memid empid year tier ratestructure plan drugplan gross_observed_ooptotal_PF potential_hra potential_hsa net_premium costtot_obs costtot_pb costtot_acg net_acg_oop { ;
	rename `var' `var'12 ; 
} ;
tempfile data12 ; 
save `data12' ; 
restore ; 

merge 1:1 familyid using `data12'; 
rename _merge pb2012merge ; 

tempfile calcoutput ; 
save `calcoutput' ;
	
use "`indata1'/IE2013_regress_input_`regdate'.dta", replace ;
cap drop _merge ; 
keep if chosen == 1 ; 

merge 1:1 familyid using `calcoutput' ; 
assert _merge != 1 ; 
drop if _merge == 2 ; 
drop _merge ; 

drop if pb2012merge == 1 ; 

gen diff_cost_pb = costtot_pb13 - costtot_pb12 ;
gen diff_cost_obs = costtot_obs13 - costtot_obs12 ;
gen diff_cost_acg = costtot_acg13 - costtot_acg12 ;
save "`outdata'/IE2013_observedcost_trteffect_data_`cdate'.dta", replace ;
save "`indata1'/IE2013_observedcost_trteffect_data_`cdate'.dta", replace ; 

bys arm : sum costtot_obs13 ;
bys arm : sum costtot_obs12 ;
bys arm : sum diff_cost_obs ;

bys arm : sum costtot_acg13 ;
bys arm : sum costtot_acg12 ;
bys arm : sum diff_cost_acg ;

bys arm : sum costtot_pb13 ;
bys arm : sum costtot_pb12 ;
bys arm : sum diff_cost_pb ;

preserve ; 
	keep if hasrec == 1 ; 
	bys arm : sum costtot_obs13 ;
	bys arm : sum costtot_obs12 ;
	bys arm : sum diff_cost_obs ;
		
	bys arm : sum costtot_acg13 ;
	bys arm : sum costtot_acg12 ;
	bys arm : sum diff_cost_acg ;
	
	bys arm : sum costtot_pb13 ;
	bys arm : sum costtot_pb12 ;
	bys arm : sum diff_cost_pb ;

restore ; 

log close ; 
