#delimit ;
clear;
set more off;

/*** Project: 		Oregon Health Plan Choice Analysis 									*/;
/*** Program: 		9_IE_recommendation_only_simulations									*/;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 						*/;
/*** Dates:			Created: 	7 January 2015											*/;
/***					Modified: 22 July 2016										*/;

/*** Purpose & Description: 
1)Specifically, using the model in Tab 4.2, we can generate probabilities: a) taking the model as given (LHS, “treatment as treatment”) and b) setting recommendation = 0 for all plans.  We can see how total costs, premiums, OOP costs and the probability of choosing a recommended plan (analogue of row 31, but computed just by literally asking what fraction of beneficiaries chose the actually recommended plan) by looking only at the subset of people who received a recommendation.

2) We can also reproduce that table in a counterfactual where we set the recommendation = 1 for the lowest cost plan, 0 for all other plans, regenerate the choice probabilities using the model and then recompute all the numbers in Panel A including the probability of choosing a recommended plan in control and treatment scenarios with the new recommendation variable.
*/;

/*** 0. Initializations and log*/;
pause off;

global directory /disk/agedisk3/oebb.work/cbehrer/oregon/;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

global cdate `cdate';
global ctime `ctime';
di "$cdate";

local simuldate _6_Oct_2016 ; 

cap mkdir "$directory/log/informedenrollment/`cdate'/" ; 
log using "$directory/log/informedenrollment/`cdate'/9_IE_recommendation_only_simulations_`cdate'_`ctime'.log";

local indata "$directory/data/analysis/formal_reg_datasets";

use "`indata'/IE2013_simulation_data_`simuldate'.dta", clear ;

	tab hasrec ; 
	keep if hasrec == 1 ; 
	unique(familyid) ;

	gen recommended_cost = total_calc_cost_PB if recommended == 1 ; 
	egen md_recommended_cost = mode(recommended_cost), by(familyid) ; 
	replace recommended_cost = md_recommended_cost if recommended_cost == . ; 
	unique(familyid) ; 
	unique(familyid recommended_cost) ; 
	drop md_recommended_cost ; 
	
	gen possible_savings = recommended_cost - min_costtot ; 
	sum possible_savings, detail ; 
	replace possible_savings = 0 if possible_savings < 0 ; 

	clogit chosen recommended lowest_cost net_calc_ooptotal_PB gross_premium resid_prem rank1 rank2 rank3 inertia tierplan_dum_t*, group(familyid) ;
	estimates store prob_choice1 ;

	assert 0 == 1 ; 
	log close ; 
/* Code below is outdated and has hard coding that needs to be updated if used. */;
/*	
tempfile skeleton ; 
save `skeleton' ; 

	estimates restore prob_choice1 ;
	predict prob_choice_observed, pc1 ;
	predict xbobserved, xb ;
	keep familyid prob_choice_observed plan xbobserved ; 
	tempfile observed ; 
	save `observed' ; 

use `skeleton', clear ; 
	replace recommended = 0 ; 

	estimates restore prob_choice1 ;
	predict prob_choice_no_recs, pc1 ;
	predict xb_norecs, xb ;
	keep familyid prob_choice_no_recs plan xb_norecs ; 
	tempfile norecs ; 
	save `norecs' ; 

use `skeleton', clear ; 
	keep familyid plan chosenplan2013 chosen net_calc_ooptotal_PB total_calc_cost_PB gross_premium resid_prem recommended ; 
	replace costtot = costtot * 1000  ; 
	replace gross_premium = gross_premium * 1000 ; 
	replace resid_prem = resid_prem * 1000 ; 
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ; 
	merge 1:1 familyid plan using `observed' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	merge 1:1 familyid plan using `norecs' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	
	pause ; 
	* obs ; 
	gen prob_obs_times_cost = prob_choice_observed * costtot ; 
	egen prob_obs_cost = sum(prob_obs_times_cost), by(familyid) ; 
	gen prob_obs_times_oop = prob_choice_observed * net_calc_ooptotal_PB ; 
	egen prob_obs_oop = sum(prob_obs_times_oop), by(familyid) ; 
	gen prob_obs_times_grossprem = prob_choice_observed * gross_premium ; 
	egen prob_obs_grossprem = sum(prob_obs_times_grossprem), by(familyid) ; 
	gen prob_obs_times_residprem = prob_choice_observed * resid_prem ; 
	egen prob_obs_residprem = sum(prob_obs_times_residprem), by(familyid) ;
	* no rec ; 
	gen prob_norecs_times_cost = prob_choice_no_recs * costtot ; 
	egen prob_norecs_cost = sum(prob_norecs_times_cost), by(familyid) ; 
	gen prob_norecs_times_oop = prob_choice_no_recs * net_calc_ooptotal_PB ; 
	egen prob_norecs_oop = sum(prob_norecs_times_oop), by(familyid) ; 
	gen prob_norecs_times_grossprem = prob_choice_no_recs * gross_premium ; 
	egen prob_norecs_grossprem = sum(prob_norecs_times_grossprem), by(familyid) ; 
	gen prob_norecs_times_residprem = prob_choice_no_recs * resid_prem ; 
	egen prob_norecs_residprem = sum(prob_norecs_times_residprem), by(familyid) ;
	pause ; 
	gen chose_times_rec = chosen*recommended ; 
	egen choserec = max(chose_times_rec), by(familyid) ; 
	preserve ; 
	keep familyid prob_obs_cost prob_obs_oop prob_obs_grossprem prob_obs_residprem prob_norecs_cost prob_norecs_oop prob_norecs_grossprem prob_norecs_residprem choserec; 
	duplicates drop ; 
	isid familyid ; 
	
	sum prob_obs_cost, detail ;
	sum prob_obs_oop, detail ; 
	sum prob_obs_grossprem, detail ; 
	sum prob_obs_residprem, detail ; 
	sum prob_norecs_cost, detail ; 
	sum prob_norecs_oop, detail ; 
	sum prob_norecs_grossprem, detail ; 	
	sum prob_norecs_residprem, detail ; 
	tab choserec ; 
	restore ; 
	pause ; 
	

	keep if recommended == 1 ; 
	sum costtot, detail ; 
	sum gross_premium, detail ; 
	sum resid_prem, detail ; 
	sum net_calc_ooptotal_PB, detail ; 
	
	egen prob_choice_obs_sum = sum(prob_choice_observed) ; 
	gen prob_choice_obs_avg = prob_choice_obs_sum / 4810 ; 
	
	egen prob_choice_norec_sum = sum(prob_choice_no_recs) ; 
	gen prob_choice_norec_avg = prob_choice_norec_sum / 4810 ;
	
	tab prob_choice_obs_avg ; 
	tab prob_choice_norec_avg ; 
	
	
use "`indata'/IE2013_simulation_data_`simuldate'.dta", clear ;

	tab hasrec ; 
	keep if lcplan != "" ; * keeps only those with recommendation ; 
	assert hasrec == 1 ; 
	unique(familyid) ;

	replace recommended = 0 ; 
	replace recommended = 1 if lowest_cost == 1 ; 
	egen multi = sum(recommended), by(familyid) ;
	gen rand = uniform() ; 
	gsort familyid -lowest_cost rand ;
	by familyid : gen order = _n ;

	pause ; 
	replace recommended = 0 if multi > 1 & order > 1 ; 
	pause ; 
	gen recommended_cost = costtot if recommended == 1 ; 
	egen md_recommended_cost = mode(recommended_cost), by(familyid) ; 
	replace recommended_cost = md_recommended_cost if recommended_cost == . ; 
	unique(familyid) ; 
	unique(familyid recommended_cost) ; 
	drop md_recommended_cost ; 
	
	gen possible_savings = recommended_cost - min_costtot ; 
	sum possible_savings, detail ; 
	replace possible_savings = 0 if possible_savings < 0 ; 

	tempfile skeleton2 ; 
save `skeleton2' ; 

	estimates restore prob_choice1 ;
	predict prob_choice_observed, pc1 ;
	predict xbobserved, xb ;
	keep familyid prob_choice_observed plan xbobserved ; 
	tempfile observed2 ; 
	save `observed2' ; 

use `skeleton2', clear ; 
	replace recommended = 0 ; 

	estimates restore prob_choice1 ;
	predict prob_choice_no_recs, pc1 ;
	predict xb_norecs, xb ;
	keep familyid prob_choice_no_recs plan xb_norecs ; 
	tempfile norecs2 ; 
	save `norecs2' ; 

use `skeleton2', clear ; 
	keep familyid plan chosenplan2013 chosen costtot net_calc_ooptotal_PB gross_premium resid_prem recommended ; 
	replace costtot = costtot * 1000  ; 
	replace resid_prem = resid_prem * 1000 ; 
	replace gross_premium = gross_premium * 1000 ; 
	replace net_calc_ooptotal_PB = net_calc_ooptotal_PB * 1000 ; 
	merge 1:1 familyid plan using `observed2' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	merge 1:1 familyid plan using `norecs2' ; 
	assert _merge == 3 ; 
	drop _merge ; 
	
	pause ; 
	* obs ; 
	gen prob_obs_times_cost = prob_choice_observed * costtot ; 
	egen prob_obs_cost = sum(prob_obs_times_cost), by(familyid) ; 
	gen prob_obs_times_oop = prob_choice_observed * net_calc_ooptotal_PB ; 
	egen prob_obs_oop = sum(prob_obs_times_oop), by(familyid) ; 
	gen prob_obs_times_grossprem = prob_choice_observed * gross_premium ; 
	egen prob_obs_grossprem = sum(prob_obs_times_grossprem), by(familyid) ; 
	gen prob_obs_times_residprem = prob_choice_observed * resid_prem ; 
	egen prob_obs_residprem = sum(prob_obs_times_residprem), by(familyid) ; 
	* no rec ; 
	gen prob_norecs_times_cost = prob_choice_no_recs * costtot ; 
	egen prob_norecs_cost = sum(prob_norecs_times_cost), by(familyid) ; 
	gen prob_norecs_times_oop = prob_choice_no_recs * net_calc_ooptotal_PB ; 
	egen prob_norecs_oop = sum(prob_norecs_times_oop), by(familyid) ; 
	gen prob_norecs_times_grossprem = prob_choice_no_recs * gross_premium ; 
	egen prob_norecs_grossprem = sum(prob_norecs_times_grossprem), by(familyid) ; 
	gen prob_norecs_times_residprem = prob_choice_no_recs * resid_prem ; 
	egen prob_norecs_residprem = sum(prob_norecs_times_residprem), by(familyid) ; 
	pause ; 
	gen chose_times_rec = chosen*recommended ; 
	egen choserec = max(chose_times_rec), by(familyid) ; 
	preserve ; 
	keep familyid prob_obs_cost prob_obs_oop prob_obs_prem prob_norecs_cost prob_norecs_oop prob_norecs_prem choserec; 
	duplicates drop ; 
	isid familyid ; 
	
	sum prob_obs_cost, detail ;
	sum prob_obs_oop, detail ; 
	sum prob_obs_grossprem, detail ; 
	sum prob_obs_residprem, detail ;
	sum prob_norecs_cost, detail ; 
	sum prob_norecs_oop, detail ; 
	sum prob_norecs_grossprem, detail ;
	sum prob_norecs_residprem, detail ;
	tab choserec ; 	
	restore ; 
	pause ; 
	tab chosen recommended ; 
	keep if recommended == 1 ; 
	sum costtot, detail ; 
	sum gross_premium, detail ; 
	sum resid_prem, detail ; 
	sum net_calc_ooptotal_PB, detail ;
	
	egen prob_choice_obs_sum = sum(prob_choice_observed) ; 
	pause on ; 
	pause ; 
	gen prob_choice_obs_avg = prob_choice_obs_sum / 4810 ; 
	
	egen prob_choice_norec_sum = sum(prob_choice_no_recs) ; 
	gen prob_choice_norec_avg = prob_choice_norec_sum / 4810 ;
	
	tab prob_choice_obs_avg ; 
	tab prob_choice_norec_avg ; 
	
log close ; 
*/;