#delimit ;
clear;
set more off;

/*** Project: 		Oregon Health Plan Choice Analysis 									*/;
/*** Program: 		9_IE_recommendation_only_simulations									*/;
/*** Author:		Chris Behrer (christopher_behrer@post.harvard.edu) 						*/;
/*** Dates:			Created: 	7 January 2015											*/;
/***					Modified: 22 July 2016										*/;

/*** Purpose & Description: 
1)Specifically, using the model in Tab 4.2, we can generate probabilities: a) taking the model as given (LHS, “treatment as treatment”) and b) setting recommendation = 0 for all plans.  We can see how total costs, premiums, OOP costs and the probability of choosing a recommended plan (analogue of row 31, but computed just by literally asking what fraction of beneficiaries chose the actually recommended plan) by looking only at the subset of people who received a recommendation.

2) We can also reproduce that table in a counterfactual where we set the recommendation = 1 for the lowest cost plan, 0 for all other plans, regenerate the choice probabilities using the model and then recompute all the numbers in Panel A including the probability of choosing a recommended plan in control and treatment scenarios with the new recommendation variable.
*/;

/*** 0. Initializations and log*/;
pause off;

global directory /disk/agedisk3/oebb.work/cbehrer/oregon/;

local c_date = c(current_date);
local cdate = subinstr("`c_date'", " ", "_", .);
local ctime = c(current_time);

global cdate `cdate';
global ctime `ctime';
di "$cdate";

local simuldate _6_Oct_2016 ; 
local calcoutdate _7_Oct_2016 ;
cap mkdir "$directory/log/informedenrollment/`cdate'/" ; 
log using "$directory/log/informedenrollment/`cdate'/9_IE_recommendation_only_simulations_ACG_`cdate'_`ctime'.log";

local indata "$directory/data/analysis/formal_reg_datasets";

use "`indata'/IE2013_simulation_data_`simuldate'.dta", clear ;

drop net_calc_ooptotal_PB total_calc_cost_PB ;

merge 1:1 familyid plan year using "`indata'/temp/analysis_dataset_2KandIE_`calcoutdate'.dta" , keepusing(acg_mean_2k_cellreg) ;
assert _merge != 1 ; 
drop if _merge == 2 ; 
drop _merge ; 

gen net_calc_ooptotal_ACG = acg_mean_2k_cellreg ; 
gen total_calc_cost_ACG = net_calc_ooptotal_ACG + net_premium ; 
drop acg_mean_2k_cellreg ;

	tab hasrec ; 
	keep if hasrec == 1 ; 
	unique(familyid) ;

	gen recommended_cost = total_calc_cost_ACG if recommended == 1 ; 
	egen md_recommended_cost = mode(recommended_cost), by(familyid) ; 
	replace recommended_cost = md_recommended_cost if recommended_cost == . ; 
	unique(familyid) ; 
	unique(familyid recommended_cost) ; 
	drop md_recommended_cost ; 
	
	gen possible_savings = recommended_cost - min_costtot ; 
	sum possible_savings, detail ; 
	replace possible_savings = 0 if possible_savings < 0 ; 

	clogit chosen recommended lowest_cost net_calc_ooptotal_ACG gross_premium resid_prem rank1 rank2 rank3 inertia tierplan_dum_t*, group(familyid) ;
	estimates store prob_choice1 ;
log close ; 