set more off
#delimit ;

preserve;
keep year familyid plan chosen expend;
keep if chosen == 1;
sort familyid year;
gen yearminus = year-1;
gen yearminus2 = year-2;
gen yearplus = year+1;
gen expendlast2 = expend[_n-2] if familyid == familyid[_n-2] & yearminus2 == year[_n-2];
gen expendlast = expend[_n-1] if familyid == familyid[_n-1] & yearminus == year[_n-1];
gen planlast = plan[_n-1] if familyid == familyid[_n-1] & yearminus == year[_n-1];
gen plannext = plan[_n+1] if familyid == familyid[_n+1] & yearplus == year[_n+1];
drop yearminus;
tempfile lastyearplan;
save `lastyearplan', replace;
restore;

merge m:1 year familyid using `lastyearplan', keep(1 3);
assert _merge == 3;
drop _merge;

*Now we have plan and last year plan;

gen currnum = real(substr(plan,-1,1));
gen lastnum = real(substr(planlast,-1,1));
gen nextnum = real(substr(plannext,-1,1));

gen currnum1 = substr(plan,1,1);
gen lastnum1 = substr(planlast,1,1);

gen diff = currnum-lastnum;
replace diff = 999 if currnum1 != lastnum1;
gen diffdum = (diff == 1) | (diff == 2);
replace diffdum = 0 if year == 2013;

*Is OMED`lastnum' present in current year?;

gen lastpresent = 1 if plan == planlast;
gen nextpresent = 1 if plan == plannext;

local eachvar = "lastpresent nextpresent";
foreach x of local eachvar {;
bys year familyid: egen max`x' = max(`x');
drop `x';
rename max`x' `x';
};

preserve;
keep year familyid nextpresent;
duplicates drop;
replace year = year+1;
tempfile nextpresent;
save `nextpresent', replace;
restore;

drop nextpresent;
merge m:1 year familyid using `nextpresent', keep(1 3);
assert _merge == 3 if lastpresent == 1;
drop _merge;

gen bothavailcurr = (lastpresent == 1);
gen bothavaillast = (nextpresent == 1);

**Merge in total cost from previous year;
preserve;
keep year familyid plan total_calc_cost_PF;
duplicates drop;
rename total_calc_cost_PF total_calc_cost_PF_last;
replace year = year+1;
tempfile cost;
save `cost', replace;
restore;

merge 1:1 year familyid plan using `cost', keep(1 3);
drop _merge;

*Also generate newbest and newbestlast comparing currplan and last plan when both present;
gen totcostcurr = total_calc_cost_PF if chosen == 1;
gen totcostlast = total_calc_cost_PF if plan == planlast;
*totcostcurrlast should be total costs of current plan last year;
*totcostlastlast should be total costs of last year's plan last year;
gen totcostcurrlast = total_calc_cost_PF_last if chosen == 1;
gen totcostlastlast = total_calc_cost_PF_last if plan == planlast;

local eachvar = "totcostcurr totcostlast totcostcurrlast totcostlastlast";
foreach x of local eachvar {;
bys year familyid: egen max`x' = max(`x');
drop `x';
rename max`x' `x';
};

gen newbest = (totcostcurr < totcostlast);
gen newbestlast = (totcostcurrlast < totcostlastlast);

gen inertia = sharp_inertia + fuzzy_inertia;
tab inertia if chosen == 1 & insurer == "MODA" & year > 2008;
tab inertia if chosen == 1 & insurer == "MODA" & year > 2008 & lastpresent == 1;
drop inertia;

