set more off
#delimit ;
* copied and updated log and data inputs from 072616 version from ~abaluckj/oregon/ ;

capture log close;

cd "/disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/";

local name = "`1'";
local exp = "`2'";
local shock = `3';
local mixed = `4';
local dummies = `5';
local modelfit = `6';
local MODA = `7';
local regoutput = `8';
local date = "`9'";

local inc = 0.05;
local qinit = 0.5;
local qmax = 200;

local shockdiff = 5000;

if(`MODA' == 1) local ins = "MODA";
if(`MODA' == 0) local ins = "ALL";
log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanal`date'`ins'aux`exp'`name'_mixed`mixed'.log, replace;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

*Create last year's plan and diffdum;
*Create indicators for whether last year's plan is present this year and whether this year's plan is present last year;
*Create indicators for which of this year's or last year's plan are lower cost in this year and last year;
gen expend = totallowedamt_PF;
do makeplandiff.do;
gen expenddiff = expend-expendlast;
*gen expenddiff = expendlast-expendlast2;
gen shock = (expenddiff > `shockdiff');
replace shock = 0 if expenddiff == .;
tab shock if chosen == 1;
if(`shock' != 1) replace shock = 0;


*1 = actual choices;
*2 = random choices;
*3 = cost minimizing choices;
local choicetype = "1";
*keep if shock == 1;
*do makeplantable.do `choicetype';

*Impose sample restrictions;
*Keep only people for whom ACG is non-blank;
*Keep only insurers we want to keep;
*Drop choice sets with 1 plan;
*Create numplans;
do finalsamprestrict.do `MODA';

*Makes shock variable;
*Makes residual premium;
do regsetup.do;
local plancontrols "ded_in max_oop_in haspcpcopayin pcp_copay_in";
if("`exp'" == "PF") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PF";
gen totcost_PF = gross_premium+resid_premium+net_calc_ooptotal_PF;
local ratvars = "totcost_PF";
local nopremvars = "net_calc_ooptotal_PF";
gen totalcst = totcost_PF;
};
if("`exp'" == "PB") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PB";
gen totcost_PB = gross_premium+resid_premium+net_calc_ooptotal_PB;
local ratvars = "totcost_PB";
local nopremvars = "net_calc_ooptotal_PB";
gen totalcst = totcost_PB;
};
if("`exp'" == "RE") {;
local variables "gross_premium resid_premium acg_mean_2k_cellreg acg_var_cellreg";
gen totcost_RE = gross_premium+resid_premium+acg_mean_2k_cellreg;
local ratvars = "totcost_RE acg_var_cellreg";
local nopremvars "acg_mean_2k_cellreg acg_var_cellreg";
gen totalcst = totcost_RE;
};

*Define diffdum so that it is only unshocked people;
if(`shock' == 0) local inertia "inertia diffdum";
if(`shock' == 1) local inertia "inertia diffdum shockdiffdum";

local plandums "";
distinct planyear;
local maxplanyear = r(ndistinct);
forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';
};

distinct plantier;
local maxplantier = r(ndistinct);
forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';
};

local ratplandums = "`plandums'";
if(`dummies' == 0) {;
local plandums = "`plancontrols'";
local ratplandums = "";
};

if(`mixed' == 0) {;
clogit chosen `variables' `inertia' `plandums', group(yearben) vce(cluster entitynum);
*clogit chosen `variables' `inertia', group(yearben) vce(cluster entitynum);
predict fullprob, pc1;
};


predict origvij, xb;
predict origprob, pc1;
*Turn off inertia and approximate inertia;
gen oldinertia = inertia;



gen olddiff = diffdum;
replace inertia = 0;
predict approx, pc1;
replace diffdum = 0;
predict noinertia, pc1;
replace inertia = oldinertia;
predict noapprox, pc1;
replace diffdum = olddiff;
capture drop oldinertia olddiff;


*Normalize welf so that smaller is better (i.e. same normalization as total costs);




local riskcoef = "0.0003";  

gen negwelfbase = totcost_RE;
local beta2 = _b[gross_premium]*`riskcoef'/2;
gen welf = negwelfbase+`beta2'*acg_var_cellreg/_b[gross_premium];

gen predcost = origprob*totcost_RE;
gen predwelf = origprob*welf;
bys yearben: egen simcost = sum(predcost);
bys yearben: egen simwelf = sum(predwelf);

sum totcost_RE if chosen == 1;
sum simcost if chosen == 1;
sum simwelf if chosen == 1;

bys yearben: egen mincost = min(totcost_RE);
gen forgsave_RE = totcost_RE-mincost;


sum forgsave_RE if chosen == 1, detail;

keep if numplan > 2;

sum forgsave_RE if chosen == 1, detail;




preserve;
keep if chosen == 1;
collapse (mean) totcost_RE forgsave_RE, by(year plan);
rename totcost_RE meancost;
rename forgsave_RE savings;
gsort year -savings;
by year: gen costrankyear = _n;
by year: egen maxcostrankyear = max(costrankyear);
tempfile avgcostyear;
save `avgcostyear', replace;
restore;

preserve;
keep if chosen == 1;
collapse (mean) totcost_RE forgsave_RE, by(plan);
rename totcost_RE meancost;
rename forgsave_RE savings;
gsort -savings;
gen costrankall = _n;
egen maxcostrankall = max(costrankall);
tempfile avgcost;
save `avgcost', replace;
restore;

preserve;
keep if chosen == 1;
collapse (mean) totcost_RE forgsave_RE, by(plan entitynum);
rename totcost_RE meancost;
rename forgsave_RE savings;
gsort entitynum -savings;
by entitynum: gen costrankdistrict = _n;
by entitynum: egen maxcostrankdistrict = max(costrankdistrict);
tempfile avgcostdistrict;
save `avgcostdistrict', replace;
restore;

preserve;
keep if chosen == 1;
collapse (mean) totcost_RE forgsave_RE, by(year plan entitynum);
rename totcost_RE meancost;
rename forgsave_RE savings;
gsort year entitynum -savings;
by year entitynum: gen costrankdistyear = _n;
by year entitynum: egen maxcostrankdistyear = max(costrankdistyear);
tempfile avgcostdistyear;
save `avgcostdistyear', replace;
restore;



merge m:1 year plan using `avgcostyear';
assert _merge == 3; 
drop _merge;

merge m:1 plan using `avgcost';
assert _merge == 3;
drop _merge;

merge m:1 plan entitynum using `avgcostdistrict';
*assert _merge == 3;
keep if _merge == 3;
drop _merge;

merge m:1 year plan entitynum using `avgcostdistyear';
*assert _merge == 3;
keep if _merge == 3;
drop _merge;


distinct yearben;
local totben = r(ndistinct);

preserve;
keep if chosen == 1;
keep yearben simwelf;
sum simwelf;
local initmean = r(mean);
restore;




bys year familyid: egen mintotalcst = min(totcost_RE);
gen forgsavingtotalcst = round(totcost_RE-mintotalcst,.1);

bys year familyid: egen minwelf = min(welf);
gen forgsavingwelf = round(welf-minwelf,.1);


local cases = "origprob approx noinertia";

foreach c of local cases {;

local type = "removebad";

local varlist = "year distyear benyear";

foreach var of local varlist {;

display "VAR is `var'";

preserve;
display "c is `c' and var is `var' and `type'";
if("`var'" == "benyear") {;
gsort yearben -totcost_RE;
by yearben: gen costrank`var' = _n;
};
tab plan if costrank`var' == 1 | costrank`var' == 2;
gen dropper = (costrank`var' == 1 | costrank`var' == 2);
bys yearben: egen mindropper = min(dropper);
replace dropper = 0 if mindropper == 1;
drop if dropper == 1;
bys yearben: egen newtot = sum(`c');
gen newprobchoice = `c'/newtot;
gen newsimcost = newprobchoice*totcost_RE;
gen newsimwelf = newprobchoice*welf;
bys yearben: egen simcost`var' = sum(newsimcost);   
bys yearben: egen simwelf`var' = sum(newsimwelf);   
bys yearben: egen totprob = sum(newprobchoice); 
sum totprob, detail;
keep yearben simwelf simwelf`var';
duplicates drop;
count;
assert r(N) == `totben';
sum simwelf;
local roundmean = round(r(mean),0.1);
local roundinit = round(`initmean',0.1);
assert `roundmean' == `roundinit';
sum simwelf`var';
local newmean = r(mean);
local diff`c'`var'`type' = `initmean'-`newmean';
restore;




if("`c'" == "origprob") {;

preserve;
do makegridsearchwelf.do `inc' `qinit' `qmax' `diff`c'`var'`type'';
egen mindiff = min(absdiff);
sum mindiff;
gen finq = _n if absdiff == mindiff;
egen minfinq = min(finq);
local finq = minfinq;
restore;


preserve;
do makeinfosimwelf.do `inc' `qinit' `finq';
sum forgsavingwelf if chosen == 1;
local origforg = r(mean);
sum newforgnoinertia if chosen == 1;
local noinertiaforg = r(mean);
sum newforgapprox if chosen == 1;
local approxforg = r(mean);
sum newforginertia if chosen == 1;
local inertiaforg = r(mean);
local diff = `origforg'-`inertiaforg';
local approxdiff = `origforg' - `approxforg';
local noinertiadiff = `origforg'-`noinertiaforg';
local Idifforigprob`var'`type' = `diff';
local Idiffapprox`var'`type' = `approxdiff';
local Idiffnoinertia`var'`type' = `noinertiadiff';
local scale = `qinit'+`finq'*`inc';
local Idiffscale`var'`type' = `scale';
restore;

};

};


**NOW KEEP ONLY BEST PLAN!;

local type = "keepgood";

foreach var of local varlist {;

preserve;
display "c is `c' and var is `var' and `type'";
if("`var'" == "benyear") {;
gsort yearben -totcost_RE;
by yearben: gen costrank`var' = _n;
by yearben: egen maxcostrank`var' = max(costrank`var');
keep if costrank`var' == maxcostrank`var';
};
else {;
bys yearben: egen benrank = max(costrank`var');
keep if costrank`var' == benrank;
};

tab plan;
bys yearben: egen newtot = sum(`c');
gen newprobchoice = `c'/newtot;
gen newsimcost = newprobchoice*totcost_RE;
gen newsimwelf = newprobchoice*welf;
bys yearben: egen simcost`var' = sum(newsimcost);   
bys yearben: egen simwelf`var' = sum(newsimwelf);   
bys yearben: egen totprob = sum(newprobchoice); 
sum totprob, detail;
keep yearben simwelf simwelf`var';
duplicates drop;
count;
assert r(N) == `totben';
sum simwelf;
local roundmean = round(r(mean),0.1);
local roundinit = round(`initmean',0.1);
assert `roundmean' == `roundinit';
sum simwelf`var';
local newmean = r(mean);
local diff`c'`var'`type' = `initmean'-`newmean';
restore;

if("`c'" == "origprob") {;   

preserve;
do makegridsearchwelf.do `inc' `qinit' `qmax' `diff`c'`var'`type'';
egen mindiff = min(absdiff);   
gen finq = _n if absdiff == mindiff;
egen minfinq = min(finq);
local finq = minfinq;
*For one good plan, make scale huge;
*if("`var'" == "benyear") local finq = 500;
restore;

preserve;
do makeinfosimwelf.do `inc' `qinit' `finq';
sum forgsavingwelf if chosen == 1;
local origforg = r(mean);
sum newforgnoinertia if chosen == 1;
local noinertiaforg = r(mean);
sum newforgapprox if chosen == 1;
local approxforg = r(mean);
sum newforginertia if chosen == 1;
local inertiaforg = r(mean);
local diff = `origforg'-`inertiaforg';
local approxdiff = `origforg' - `approxforg';
local noinertiadiff = `origforg'-`noinertiaforg';
local Idifforigprob`var'`type' = `diff';
local Idiffapprox`var'`type' = `approxdiff';
local Idiffnoinertia`var'`type' = `noinertiadiff';
local scale = `qinit'+`finq'*`inc';
local Idiffscale`var'`type' = `scale';
restore;

};

};

};




local types = "removebad keepgood";

local var = "year distyear benyear";

local cases = "origprob approx noinertia";

foreach t of local types {;

foreach v of local var {;

display "Scale is `Idiffscale`v'`t''";

foreach c of local cases {;

display "t is `t', var is `v', and c is `c'";
display "Diff is `diff`c'`v'`t''";

display "Idiff is `Idiff`c'`v'`t''";

};

};

};
