set more off
#delimit ;
* copied and updated log and data inputs from 072616 version from ~abaluckj/oregon/ ;

capture log close;

cd "/disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/";

local name = "`1'";
local exp = "`2'";
local shock = `3';
local mixed = `4';
local dummies = `5';
local modelfit = `6';
local MODA = `7';
local regoutput = `8';
local date = "`9'";

local shockdiff = 5000;

if(`MODA' == 1) local ins = "MODA";
if(`MODA' == 0) local ins = "ALL";
log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanal`date'`ins'aux`exp'`name'_mixed`mixed'.log, replace;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

*Create last year's plan and diffdum;
*Create indicators for whether last year's plan is present this year and whether this year's plan is present last year;
*Create indicators for which of this year's or last year's plan are lower cost in this year and last year;
gen expend = totallowedamt_PF;
do makeplandiff.do;
gen expenddiff = expend-expendlast;
*gen expenddiff = expendlast-expendlast2;
gen shock = (expenddiff > `shockdiff');
replace shock = 0 if expenddiff == .;
tab shock if chosen == 1;
if(`shock' != 1) replace shock = 0;

*1 = actual choices;
*2 = random choices;
*3 = cost minimizing choices;
local choicetype = "1";
*keep if shock == 1;
*do makeplantable.do `choicetype';

*Impose sample restrictions;
*Keep only people for whom ACG is non-blank;
*Keep only insurers we want to keep;
*Drop choice sets with 1 plan;
*Create numplans;
do finalsamprestrict.do `MODA';

**Create Table 2;
preserve;
keep year familyid numplan;
duplicates drop;
tab numplan year;
restore;

*Makes shock variable;
*Makes residual premium;
do regsetup.do;
local plancontrols "ded_in max_oop_in haspcpcopayin pcp_copay_in";
if("`exp'" == "PF") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PF";
gen totcost_PF = gross_premium+resid_premium+net_calc_ooptotal_PF;
local ratvars = "totcost_PF";
local nopremvars = "net_calc_ooptotal_PF";
};
if("`exp'" == "PB") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PB";
gen totcost_PB = gross_premium+resid_premium+net_calc_ooptotal_PB;
local ratvars = "totcost_PB";
local nopremvars = "net_calc_ooptotal_PB";
};
if("`exp'" == "RE") {;
local variables "gross_premium resid_premium acg_mean_2k_cellreg acg_var_cellreg";
gen totcost_RE = gross_premium+resid_premium+acg_mean_2k_cellreg;
local ratvars = "totcost_RE acg_var_cellreg";
local nopremvars "acg_mean_2k_cellreg acg_var_cellreg";
};

*Define diffdum so that it is only unshocked people;
if(`shock' == 0) local inertia "inertia diffdum";
if(`shock' == 1) local inertia "inertia diffdum shockdiffdum";

local plandums "";
distinct planyear;
local maxplanyear = r(ndistinct);
forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';
};

distinct plantier;
local maxplantier = r(ndistinct);
forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';
};

local ratplandums = "`plandums'";
if(`dummies' == 0) {;
local plandums = "`plancontrols'";
local ratplandums = "";
};

if(`mixed' == 0) {;
clogit chosen `variables' `inertia' `plandums', group(yearben) vce(cluster entitynum);
predict fullprob, pc1;
};

if(`mixed' == 1) {;
egen familyidgroup = group(familyid);
egen yearbengroup = group(yearben);


display "`inertia'";
display "`plandums'";
display "`variables'";

*Make coefficients positive for log-normal;
foreach x of local variables {;
replace `x' = -`x';
};
*mixlogit chosen `inertia' `plandums', group(yearbengroup) id(familyidgroup) rand(`variables') ln(3);

*keep if familyidgroup < 1300;

sort year familyid plan;
bys year familyid: gen altID = _n;

cmset familyidgroup year altID;

local normvars "";
foreach x of local variables {;
egen meanx = mean(`x');
egen sdx = sd(`x');
gen norm`x' = (`x'-meanx)/sdx;
local normvars = "`normvars' norm`x'";
display "Variable is `x'";
sum meanx sdx;
drop meanx sdx;
};

local origplandums = "`plandums'";
if(`dummies' == 0) {;
local plandums = "";
foreach x of local origplandums {;
egen meanx = mean(`x');
egen sdx = sd(`x');
gen norm`x' = (`x'-meanx)/sdx;
local plandums = "`plandums' norm`x'";
display "Variable is `x'";
sum meanx sdx;
drop meanx sdx;
};
};

display "`inertia'";
display "`normvars'";
display "`plandums'";

cmxtmixlogit chosen `inertia' `plandums', random(`normvars') noconstant;

*mixlogit chosen `inertia', group(yearbengroup) id(familyidgroup) rand(`variables') ln(3);

foreach x of local variables {;
replace `x' = -`x';
};

};

if(`regoutput' == 1) do regoutput.do "`variables'" "`inertia'" "`plancontrols'" "`exp'" `shock';

if(`modelfit' == 1) {;

clogit chosen `variables' inertia `plandums', group(yearben) vce(cluster entitynum);
predict origprob, pc1;

clogit chosen `ratvars' inertia `ratplandums', group(yearben) vce(cluster entitynum);
predict ratprob, pc1;

clogit chosen `nopremvars' `inertia' `plandums', group(yearben) vce(cluster entitynum);
predict nopremprob, pc1;


*Random choices;
gen test = uniform();
sort year familyid test;
by year familyid: gen randchosen = _n;
*Only let you choose from non-inertial plans;
replace randchosen = 0 if randchosen != 1;

local probs = "randchosen origprob nopremprob ratprob fullprob";

*Generate randprob;
*Compare conditional market shares, weighted and unweighted;
drop if planlast == "";
collapse (sum) chosen `probs', by(year plan planlast);
*totchosen is total number chosing with that "planlast";
egen allchosen = sum(chosen);
gen shareweight = chosen/allchosen;
bys year planlast: egen totchosen = sum(chosen);
*This is market share of that plan;
gen marketshare = chosen/totchosen;

foreach x of local probs {;
bys year planlast: egen totprob`x' = sum(`x');
gen share`x' = `x'/totprob`x';
drop totprob`x';
gen error2`x' = (marketshare-share`x')^2;
gen abserror`x' = abs(marketshare-share`x');
*Compute share weighted mean squared error;
gen weighterror2`x' = shareweight*error2`x';
gen weightabserror`x' = shareweight*abserror`x';
egen MSE2`x' = sum(weighterror2`x');
egen absE`x' = sum(weightabserror`x');
};

sum MSE2* absE*;

};



