set more off
#delimit ;
* copied and updated log and data inputs from 072616 version from ~abaluckj/oregon/ ;

capture log close;

cd "/disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/";

local name = "`1'";
local exp = "`2'";
local shock = `3';
local mixed = `4';
local dummies = `5';
local modelfit = `6';
local MODA = `7';
local regoutput = `8';
local date = "`9'";

local shockdiff = 5000;

if(`MODA' == 1) local ins = "MODA";
if(`MODA' == 0) local ins = "ALL";
log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanal`date'`ins'aux`exp'`name'_mixed`mixed'.log, replace;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

*Create last year's plan and diffdum;
*Create indicators for whether last year's plan is present this year and whether this year's plan is present last year;
*Create indicators for which of this year's or last year's plan are lower cost in this year and last year;
gen expend = totallowedamt_PF;
do makeplandiff.do;
gen expenddiff = expend-expendlast;
*gen expenddiff = expendlast-expendlast2;
gen shock = (expenddiff > `shockdiff');
replace shock = 0 if expenddiff == .;
tab shock if chosen == 1;
if(`shock' != 1) replace shock = 0;

*1 = actual choices;
*2 = random choices;
*3 = cost minimizing choices;
local choicetype = "1";
*keep if shock == 1;
*do makeplantable.do `choicetype';

*Impose sample restrictions;
*Keep only people for whom ACG is non-blank;
*Keep only insurers we want to keep;
*Drop choice sets with 1 plan;
*Create numplans;
do finalsamprestrict.do `MODA';

*Makes shock variable;
*Makes residual premium;
do regsetup.do;
local plancontrols "ded_in max_oop_in haspcpcopayin pcp_copay_in";
if("`exp'" == "PF") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PF";
gen totcost_PF = gross_premium+resid_premium+net_calc_ooptotal_PF;
local ratvars = "totcost_PF";
local nopremvars = "net_calc_ooptotal_PF";
gen totalcst = totcost_PF;
};
if("`exp'" == "PB") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PB";
gen totcost_PB = gross_premium+resid_premium+net_calc_ooptotal_PB;
local ratvars = "totcost_PB";
local nopremvars = "net_calc_ooptotal_PB";
gen totalcst = totcost_PB;
};
if("`exp'" == "RE") {;
local variables "gross_premium resid_premium acg_mean_2k_cellreg acg_var_cellreg";
gen totcost_RE = gross_premium+resid_premium+acg_mean_2k_cellreg;
local ratvars = "totcost_RE acg_var_cellreg";
local nopremvars "acg_mean_2k_cellreg acg_var_cellreg";
gen totalcst = totcost_RE;
};

*Define diffdum so that it is only unshocked people;
if(`shock' == 0) local inertia "inertia diffdum";
if(`shock' == 1) local inertia "inertia diffdum shockdiffdum";

local plandums "";
distinct planyear;
local maxplanyear = r(ndistinct);
forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';
};

distinct plantier;
local maxplantier = r(ndistinct);
forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';
};

local ratplandums = "`plandums'";
if(`dummies' == 0) {;
local plandums = "`plancontrols'";
local ratplandums = "";
};

if(`mixed' == 0) {;
clogit chosen `variables' `inertia' `plandums', group(yearben) vce(cluster entitynum);
predict fullprob, pc1;
};





*Risk aversion;

*gamma = 2*beta_2 / beta_1;

*Solve for beta_2;


gen totalcstorig = totalcst;

local gammas = "0";

local variance "acg_var_cellreg";

capture drop expend;
rename numplan numplans;
quietly tab year, gen(yeardum);

foreach newvalue of local gammas {;

local newbeta2beta1 = `newvalue'/2;

replace totalcst = totalcstorig + `newbeta2beta1'*`variance';

bys year familyid: egen mintotalcst = min(totalcst);
gen forgsavingtotalcst = round(totalcst-mintotalcst,.1);

preserve;
keep if chosen == 1;

display "gamma is `gammas'";

global currvar forgsavingtotalcst;
do oregonanalchoice111616robust.do;

global currvar totalcst;
do oregonanalchoice111616robust.do;
restore;

drop forgsavingtotalcst mintotalcst;

};
