set more off
#delimit ;
* copied and updated log and data inputs from 072616 version from ~abaluckj/oregon/ ;

capture log close;

cd "/disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/";

local name = "`1'";
*local exp = "`2'";
local exp = "RE";
local dummies = `2';
local regoutput = `3';
local date = "`4'";

local shock = 0;
local MODA = 1;
local shockdiff = 5000;

if(`MODA' == 1) local ins = "MODA";
if(`MODA' == 0) local ins = "ALL";
log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanal`date'`ins'aux`exp'`name'.log, replace;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

*Create last year's plan and diffdum;
*Create indicators for whether last year's plan is present this year and whether this year's plan is present last year;
*Create indicators for which of this year's or last year's plan are lower cost in this year and last year;
gen expend = totallowedamt_PF;
do makeplandiff.do;
gen expenddiff = expend-expendlast;
*gen expenddiff = expendlast-expendlast2;
gen shock = (expenddiff > `shockdiff');
replace shock = 0 if expenddiff == .;
tab shock if chosen == 1;
if(`shock' != 1) replace shock = 0;

*1 = actual choices;
*2 = random choices;
*3 = cost minimizing choices;
local choicetype = "1";
*keep if shock == 1;
*do makeplantable.do `choicetype';

*Impose sample restrictions;
*Keep only people for whom ACG is non-blank;
*Keep only insurers we want to keep;
*Drop choice sets with 1 plan;
*Create numplans;
do finalsamprestrict.do `MODA';


*Makes shock variable;
*Makes residual premium;
do regsetup.do;
local plancontrols "ded_in max_oop_in haspcpcopayin pcp_copay_in";
if("`exp'" == "PF") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PF";
gen totcost_PF = gross_premium+resid_premium+net_calc_ooptotal_PF;
local ratvars = "totcost_PF";
local nopremvars = "net_calc_ooptotal_PF";
};
if("`exp'" == "PB") {;
local variables "gross_premium resid_premium net_calc_ooptotal_PB";
gen totcost_PB = gross_premium+resid_premium+net_calc_ooptotal_PB;
local ratvars = "totcost_PB";
local nopremvars = "net_calc_ooptotal_PB";
};
if("`exp'" == "RE") {;
local variables "gross_premium resid_premium acg_mean_2k_cellreg acg_var_cellreg";
gen totcost_RE = gross_premium+resid_premium+acg_mean_2k_cellreg;
local ratvars = "totcost_RE acg_var_cellreg";
local nopremvars "acg_mean_2k_cellreg acg_var_cellreg";
};

*Define diffdum so that it is only unshocked people;
if(`shock' == 0) local inertia "inertia diffdum";
if(`shock' == 1) local inertia "inertia diffdum shockdiffdum";

local plandums "";
distinct planyear;
local maxplanyear = r(ndistinct);
forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';
};

distinct plantier;
local maxplantier = r(ndistinct);
forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';
};

local ratplandums = "`plandums'";
if(`dummies' == 0) {;
local plandums = "`plancontrols'";
local ratplandums = "";
};

**Create separate variables for each choice set size;
local regvar = "`variables' `inertia'";

local regvarnum "";
local plancontrolnum "";

*regvar and inertiaplan;
*Let variables and degree of inertia vary with number of plans;
quietly tab numplan, gen(plannumdum);
egen maxplan = max(numplan);
local maxplan = maxplan;

forvalues pp = 2/`maxplan' {;
local pminus = `pp'-1;
foreach a of local regvar {;
        gen `a'_numplan`pp' = `a'*plannumdum`pminus';
        local regvarnum `regvarnum' `a'_numplan`pp';
};

if(`dummies' == 0) {;
foreach a of local plancontrols {;
        gen `a'_numplan`pp' = `a'*plannumdum`pminus';
        local plancontrolnum `plancontrolnum' `a'_numplan`pp';
};
};

};

local plannum = "";

if(`dummies' == 1) {;

forvalues pp = 2/`maxplan' {;
local pminus = `pp'-1;
foreach a of local plandums {;
*Count if at least 5 people with 1 and that plan number;
count if `a' == 1 & plannumdum`pminus' == 1 & chosen == 1;
local nums = r(N);
if(`nums' > 500) {; 
        gen `a'_numplan`pp' = `a'*plannumdum`pminus';
        local plannum `plannum' `a'_numplan`pp';
};
};
};

};

capture drop maxplan;

keep if ACG == 1;

clogit chosen `regvar' `plandums', group(yearben) vce(cluster entitynum);

capture drop negwelf negwelfbase;
gen negwelfbase = totcost_RE;
gen negwelf = negwelfbase+_b[acg_var_cellreg]*acg_var_cellreg/_b[gross_premium];
gen negwelfnovar = negwelfbase;
capture drop bestwelf forgwelf bestwelfnovar forgwelfnovar;
bys yearben: egen bestwelf = min(negwelf);
bys yearben: egen bestwelfnovar = min(negwelfnovar);

*clogit chosen `regvarnum' `plannum', group(yearben) vce(cluster entitynum) difficult;

if(`dummies' == 0) clogit chosen `regvarnum' `plancontrolnum', group(yearben) vce(cluster entitynum) difficult;
if(`dummies' == 1) clogit chosen `regvarnum' `plandums', group(yearben) vce(cluster entitynum) difficult;

predict fullprob, pc1;

*Simulate choices from all choice sets using variables for each number plans;

gen XBplan = 0;

if(`dummies' == 1) {;
foreach a of local plandums {;
replace XBplan = XBplan + _b[`a']*`a';
};
};

forvalues pp = 2/`maxplan' {;
gen XB`pp' = XBplan;
foreach a of local regvar {;
display "`a'";
assert `a' != .;
replace XB`pp' = XB`pp'+ _b[`a'_numplan`pp']*`a';
};

if(`dummies' == 0) {;
foreach a of local plancontrols {;
display "`a'";
assert `a' != .;
replace XB`pp' = XB`pp'+ _b[`a'_numplan`pp']*`a';
};
};

};


*Add in plan dummies;

*Given each XB`pp', simulate choices and evaluate foregone savings and foregone welfare;

*First, compute the choice probabilities associated with each XB`pp';

*Compute exp(XB_j-XB_i) since this is computationally feasible;
sort yearben plan;
by yearben: gen maxplan = _N;
by yearben: gen plannum = _n;
egen allmax = max(maxplan);
local maxplan = allmax;
gen probchatj = 0;
forvalues pp = 2/`maxplan' {;
gen prob`pp' = 0;
display "Plan number is `pp'";

forvalues a = 1/`maxplan' {;
capture drop currXb maxcurr expcurrdiff sumcurrdiff;
gen currXb = XB`pp' if plannum == `a';
by yearben: egen maxcurr = max(currXb);
gen expcurrdiff = exp(XB`pp'-maxcurr);
replace expcurrdiff = 1e20 if expcurrdiff == .;
by yearben: egen sumcurrdiff = sum(expcurrdiff);
replace prob`pp' = 1/sumcurrdiff if plannum == `a';
};

bys yearben: egen sumprob = sum(prob`pp');
gen absdiff = abs(1-sumprob);
assert absdiff < .00001;
capture drop sumprob absdiff;

};

*Now we have prob`pp' and fullprob;
*Now we can compute simulated foregone savings and foregone welfare;

*For each plan size, compute expected welfare and subtract bestwelf;

forvalues pp = 2/`maxplan' {;
gen expcost`pp'each = totcost_RE*prob`pp';
gen expwelf`pp'each = prob`pp'*negwelf;
gen expwelf`pp'eachnovar = prob`pp'*negwelfnovar;
bys yearben: egen expwelf`pp' = sum(expwelf`pp'each);
bys yearben: egen expwelf`pp'novar = sum(expwelf`pp'eachnovar);
bys yearben: egen expcost`pp' = sum(expcost`pp'each);
gen forgwelf`pp' = expwelf`pp'-bestwelf;
gen forgwelfnovar`pp' = expwelf`pp'novar-bestwelfnovar;
};


gen simcosteach = fullprob*totcost_RE;
bys yearben: egen simcost = sum(simcosteach);

gen forgwelfnovar = negwelfbase-bestwelfnovar;
gen forgwelf = negwelf-bestwelf;
gen forgwelfsim = simcost-bestwelfnovar;

if(`regoutput' == 1) do regoutputnumplans.do `maxplan' "`plancontrols'" `dummies' "`variables'" "`inertia'";

display "All, actual";
sum totcost_RE if chosen == 1;
display "All, simulated";
sum simcost forgwelf forgwelfnovar forgwelfsim if chosen == 1;
display "Best welf is:";
sum bestwelf if chosen == 1, detail;

display "Total costs, Foregone welfare, Foregone welfare (no variance)";
forvalues pp = 2/`maxplan' {;
display "Number of choices is `pp'";
sum expcost`pp' forgwelf`pp' forgwelfnovar`pp' if chosen == 1;
};
