set more off
#delimit ;
* copied and updated log and data inputs from 072616 version from ~abaluckj/oregon/ ;

capture log close;
*log using ~abaluckj/oregon/logdir/oregonanal072616MODAaux.log, replace;
log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanal111616ALLauxACGsens.log, replace;

*use ~abaluckj/oregon/analysis_dataset_PF_23_Mar_2016.dta, clear;
*use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_PBandPF__7_Apr_2016.dta, clear;
*use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_PBPFACG_27_May_2016.dta, clear;
*Drop anyone with just 1 one in their choice set;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

*use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_allvars_18_Jul_2016.dta, clear;

bys year familyid: gen numplan = _N;
keep if numplan > 1;
replace sharp_inertia = 0 if sharp_inertia == .;

egen choiceset = group(entitynum memid empid);

******************;
**Estimate conditional logit model;
******************;

*No perfect backcast in 2008;
drop if year == 2008;
*keep if year == 2012;

*Add recommendation;
*Add nudges;
*Add choice set size;

bys year familyid: gen numplans = _N;
quietly tab numplans, gen(numchoicedum);

egen maxnumplans = max(numplans);


*Do for all beneficiaries and with just ODS;

**Create copay controls;
**********************************************;

gen  haspcpcopayin = 1 if pcp_copay_in > 0;
replace haspcpcopayin = 0 if haspcpcopayin != 1;

gen  haspcpcopayout = 1 if pcp_copay_out > 0;
replace haspcpcopayout = 0 if haspcpcopayout != 1;

gen  hasspeccopayin = 1 if spec_copay_in > 0;
replace hasspeccopayin = 0 if hasspeccopayin != 1;

gen  hasspeccopayout = 1 if spec_copay_out > 0;
replace hasspeccopayout = 0 if hasspeccopayout != 1;

local plancontrols "ded_in max_oop_in haspcpcopayin pcp_copay_in";

**********************************************;
gen resid_premium = net_premium-gross_premium;
local inertia "fuzzy_inertia sharp_inertia";

gen stryear = string(year);
gen yearben = stryear + familyid;

quietly tab tier, gen(tierdum);
quietly tab year, gen(yeardum); 

**Add plan dummies;
egen planyear = group(plan year);
replace planyear = 1 if plan == "OMED3" | plan == "MMEDA";
quietly tab planyear, gen(planyeardum);
drop planyeardum1;

distinct planyear;
local maxplanyear = r(ndistinct);

forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';
};

egen plantier = group(plan tier);
replace plantier = 1 if plan == "OMED3" | plan == "MMEDA";
quietly tab plantier, gen(plantierdum);
drop plantierdum1;

distinct plantier;
local maxplantier = r(ndistinct);

forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';

};

local allvars = "3 dec reg";
foreach x of local allvars {;
gen acg_var2k_cell`x' = acg_sd_2k_cell`x'^2;
gen acg_var10k_cell`x' = acg_sd_10k_cell`x'^2;
gen acg_var20k_cell`x' = acg_sd_20k_cell`x'^2;
};

foreach cell in reg 3 dec  {;
foreach size in 2k 10k 20k {;

	clogit chosen gross_premium resid_premium acg_mean_`size'_cell`cell' acg_var`size'_cell`cell' `inertia' `plandums', group(yearben);

	capture drop negwelf negwelfbase;
	gen negwelf = 0;
	replace negwelf = negwelf+gross_premium;
	replace negwelf = negwelf+resid_premium;
	replace negwelf = negwelf+acg_mean_`size'_cell`cell';
	replace negwelf = negwelf+acg_var`size'_cell`cell';		

	gen negwelfbase = negwelf;
	replace negwelf = negwelfbase+(_b[acg_var`size'_cell`cell']/_b[gross_premium]-1)*acg_var`size'_cell`cell';
	capture drop negwelfnovar;
	gen negwelfnovar = negwelfbase-acg_var`size'_cell`cell';
	capture drop bestwelf forgwelf bestwelfnovar forgwelfnovar;
	bys yearben: egen bestwelf = min(negwelf);
	bys yearben: egen bestwelfnovar = min(negwelfnovar);
	gen forgwelf = negwelf-bestwelf;
	gen forgwelfnovar = negwelfnovar-bestwelfnovar;
	sum forgwelf forgwelfnovar negwelf negwelfnovar if chosen == 1;

	cap drop observed ; 
	gen observed = 0;
	replace observed = observed+_b[gross_premium]*gross_premium;
	replace observed = observed+_b[resid_premium]*resid_premium;
	replace observed = observed+_b[acg_mean_`size'_cell`cell']*acg_mean_`size'_cell`cell';
	replace observed = observed+_b[acg_var`size'_cell`cell']*acg_var`size'_cell`cell';
	
	foreach x of local inertia {;
	replace observed = observed+_b[`x']*`x';
	};

	constraint 1 observed = 1;
	cap drop insuredum*  ; 
	quietly tab insurer, gen(insuredum);
	clogit chosen observed `plancontrols' insuredum*, group(yearben) constraint(1);
};
};
