set more off
#delimit ;

capture log close;

* LOG name changed for various versions ; 
log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanal112916MODAREtable4.log, replace;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

keep if insurer == "MODA";

*No perfect backcast in 2008;
drop if year == 2008;
* we are using ACG costs ; 
drop if ACG == 0 ; 
* drop if family does not have a choice - e.g. they chose kaiser, and we are dropping kaiser plans ; 
bys year familyid : egen maxchosen = max(chosen) ; 
tab maxchosen ; 
drop if maxchosen == 0 ; 
drop maxchosen ; 
*Drop anyone with just 1 one in their choice set;
bys year familyid: gen numplan = _N;
keep if numplan > 1;
replace sharp_inertia = 0 if sharp_inertia == .;
replace fuzzy_inertia = 0 if sharp_inertia == 1 ; 

egen choiceset = group(entitynum memid empid);

*Add recommendation;
*Add nudges;
*Add choice set size;

bys year familyid: gen numplans = _N;
quietly tab numplans, gen(numchoicedum);

egen maxnumplans = max(numplans);


*Do for all beneficiaries and with just ODS;

**Create copay controls;
**********************************************;

gen  haspcpcopayin = 1 if pcp_copay_in > 0;
replace haspcpcopayin = 0 if haspcpcopayin != 1;

gen  haspcpcopayout = 1 if pcp_copay_out > 0;
replace haspcpcopayout = 0 if haspcpcopayout != 1;

gen  hasspeccopayin = 1 if spec_copay_in > 0;
replace hasspeccopayin = 0 if hasspeccopayin != 1;

gen  hasspeccopayout = 1 if spec_copay_out > 0;
replace hasspeccopayout = 0 if hasspeccopayout != 1;

local plancontrols "ded_in ded_out max_oop_in max_oop_out haspcpcopayin pcp_copay_in";

**********************************************;

gen resid_premium = net_premium-gross_premium;


*gen totalcst = -(net_premium + net_calc_ooptotal_PB);

local oop "acg_mean_2k_cellreg";

drop if `oop' == .;



gen acg_var_2k_cellreg = acg_sd_2k_cellreg^2;

local variance "acg_var_2k_cellreg";

*gen acg_var2k_cell`x' = acg_sd_2k_cell`x'^2;

local variables "gross_premium resid_premium `oop' `variance'";

local inertia "fuzzy_inertia sharp_inertia";

gen stryear = string(year);
gen yearben = stryear + familyid;



local regvar "";
local inertiavar "";
local choicesetvar "";

quietly tab tier, gen(tierdum);
quietly tab year, gen(yeardum);


foreach a of local variables {;
	local regvar `regvar' `a';
};              

display "`variables'";


**Add plan dummies;

egen planyear = group(plan year);
replace planyear = 1 if plan == "OMED3" | plan == "MMEDA";
quietly tab planyear, gen(planyeardum);
drop planyeardum1;

distinct planyear;
local maxplanyear = r(ndistinct);

forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';

};

egen plantier = group(plan tier);
replace plantier = 1 if plan == "OMED3" | plan == "MMEDA";
quietly tab plantier, gen(plantierdum);
drop plantierdum1;

distinct plantier;
local maxplantier = r(ndistinct);

forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';

};


display "`plandums'";
display "`maxplanyear'";


global regvar `regvar';


display "$regvar";
display "`variables'";


count;

clogit chosen `regvar' `plandums' `inertia', group(yearben);

count;




gen totalcst = -(net_premium+`oop');


predict predxb, xb;

predict probchoice, pc1;

predict chatj, xb;

replace chatj = chatj-_b[`oop']*`oop'-_b[fuzzy_inertia]*fuzzy_inertia-_b[sharp_inertia]*sharp_inertia;

gen xi1 = _b[sharp_inertia];
gen xi2 = _b[fuzzy_inertia];

bys year tier plan: egen meanoop = mean(`oop');

replace chatj = chatj+_b[`oop']*meanoop;

local alpha = _b[`oop']/_b[gross_premium];

local f = -1/_b[gross_premium];

gen fprem = (1/`f')*gross_premium;

gen foop = (1/`f')*`oop';

gen dmoop = -(`oop'-meanoop);

egen numyearben = group(yearben);

xtset numyearben;

xtreg dmoop, re;

local vari = e(sigma_u)^2;

xtreg dmoop, fe;

predict dmresid, e;



preserve;
collapse (sd) dmresid, by(year plan tier);
rename dmresid sdoop;
tempfile sdoop;
save `sdoop', replace;
restore;

merge m:1 year plan tier using `sdoop';
assert _merge == 3;
capture drop _merge;
gen varoop = sdoop^2;

bys yearben: egen sumprobchoice = sum(probchoice);
gen diff = abs(1-sumprobchoice);
assert diff < .00001;
capture drop diff;

gen predcost = probchoice*totalcst;

bys yearben: egen simcost = sum(predcost);

*Compute exp(XB_j-XB_i) since this is computationally feasible;
sort yearben plan;
by yearben: gen maxplan = _N;
by yearben: gen plannum = _n;
egen allmax = max(maxplan);
local maxplan = allmax;
gen probchatj = 0;
forvalues a = 1/`maxplan' {;
display "Plan number is `a'";
capture drop currXb maxcurr expcurrdiff sumcurrdiff;
gen currXb = chatj if plannum == `a';
by yearben: egen maxcurr = max(currXb);
gen expcurrdiff = exp(chatj-maxcurr);
replace expcurrdiff = 1e20 if expcurrdiff == .;
by yearben: egen sumcurrdiff = sum(expcurrdiff);
replace probchatj = 1/sumcurrdiff if plannum == `a';  
};

bys yearben: egen sumprob = sum(probchatj);
gen diff = abs(1-sumprob);
assert diff < .00001;



/*;
*FIX THIS!!!!;
*FIX THIS!!!!;

display `alpha';	

*Do only for first plan;

sort yearben plan;
by yearben: gen plannumber = _n;

gen probcurr = probchatj if plannumber == 1;
by yearben: egen maxprobcurr = max(probcurr);

gen eachterm = dmoop*maxprobcurr*(1-maxprobcurr) if plannumber == 1;
replace eachterm = -dmoop*maxprobcurr*probchatj if plannumber != 1;
bys yearben: egen sumeachterm = sum(eachterm);

gen newterm  = `alpha'*(1/`f')*sumeachterm;

keep if plannumber == 1;

list probchoice probchatj newterm in 1/10;

gen probdiff = probchoice-probchatj;

xtile vquant = probdiff, nq(10);

collapse (mean) probchoice probchatj newterm dmoop, by(vquant);

sort vquant;
list in 1/10;
assert 1 == 0;

*/;



*FIX THIS!!!!;
*FIX THIS!!!!;

display `alpha';	

sort yearben plan;
by yearben: gen plannumber = _n;

gen newterm = 0;

forvalues a = 1/`maxplan' {;
gen probcurr = probchatj if plannumber == `a';
by yearben: egen maxprobcurr = max(probcurr);
gen eachterm = dmoop*maxprobcurr*(1-maxprobcurr) if plannumber == `a';
replace eachterm = -dmoop*maxprobcurr*probchatj if plannumber != `a';
*replace eachterm = 0 if plannumber != `a';
bys yearben: egen sumeachterm = sum(eachterm);
replace newterm  = `alpha'*(1/`f')*sumeachterm if plannumber == `a';
capture drop probcurr maxprobcurr sumeachterm eachterm;
};

gen chatjcost = probchatj*totalcst;

bys yearben: egen simcostchatj = sum(chatjcost);

bys yearben: egen maxsharp = max(sharp_inertia);
bys yearben: egen maxfuzzy = max(fuzzy_inertia);

*What is the magnitude of xi?;
*Compute Pd;
gen Pd = probchatj if sharp_inertia == 1 & maxsharp == 1;
replace Pd = probchatj if fuzzy_inertia == 1 & maxfuzzy == 1;
bys yearben: egen maxpd = max(Pd);
replace Pd = maxpd;
replace Pd = 0 if maxsharp != 1 & maxfuzzy != 1;

gen isdef = 1 if sharp_inertia == 1 & maxsharp == 1;
replace isdef = 1 if fuzzy_inertia == 1 & maxfuzzy == 1;
replace isdef = 0 if isdef != 1;
gen nodef = 1-isdef;

gen nodefprob = probchatj if nodef == 1;
bys yearben: egen sumnodefprob = sum(nodefprob);

gen eachnodefcostj = nodef*probchatj*totalcst/sumnodefprob;
bys yearben: egen nodefcostj = sum(eachnodefcostj);



*gen predcost = probchoice*totalcst;
*bys yearben: egen simcost = sum(predcost);

sum newterm, detail;

global alpha = `alpha';
global f = `f';
global vari = `vari';

local f = $f;
local alpha = $alpha;
local vari = $vari;

gen term2 = newterm*dmoop;
bys yearben: egen sumterm2 = sum(term2);


*Seems to break down for very large values;
*Seems to break down for very large values;
*Seems to break down for very large values;
*Seems to break down for very large values;
*Seems to break down for very large values;
*Seems to break down for very large values;

list simcost simcostchatj sumterm2 probchatj probchoice newterm in 1/10;

gen simdiff = simcost-simcostchatj;

xtile vquant = simdiff, nq(10);


gen gradj = probchatj*(1-probchatj);
bys yearben: egen sumgrad = sum(gradj);
gen trueterm2 = `alpha'*varoop*(1/`f')*sumgrad;

*Pd is probability of inertial plan - 0 if no inertial plan;
*The estimated coefficient is xi/f;

gen xi = xi1 if maxsharp == 1;
replace xi = xi2 if maxfuzzy == 1;
assert maxsharp != 1 | maxfuzzy != 1;
replace xi = 0 if maxsharp != 1 & maxfuzzy != 1;

gen costdefault = totalcst if sharp_inertia == 1 & maxsharp == 1;
replace costdefault = totalcst if fuzzy_inertia == 1 & maxfuzzy == 1;
bys yearben: egen maxcostdefault = max(costdefault);
replace costdefault = maxcostdefault;
replace costdefault = 0 if maxsharp != 1 & maxfuzzy != 1;

gen inertterm = -xi*Pd*(simcostchatj-costdefault);

gen probtest = -xi*Pd*(1-Pd);

gen origdiff = simcostchatj-costdefault;

gen ddiff = nodefcostj-costdefault;

gen inertterm2 = probtest*ddiff;

sum probtest if numplans == 2;
sum ddiff if numplans == 2;

* everything is negative, so we have to do chosen - max rather than chosen - min ; 
bys year familyid: egen maxtotalcst = max(totalcst);
gen forgsavingtotalcst = round(totalcst-maxtotalcst,.1);
 
preserve;
keep if chosen == 1;

count if inertterm == .;
count if simcostchatj == .;
count if term2 == .;

capture drop term2;
gen term2 = `alpha'*varoop*(1/`f')*sumgrad;
gen term2alphaone = varoop*(1/`f')*sumgrad;
gen term2fdiv2 = varoop*(1/(`f'/2))*sumgrad;

gen modelcost = simcostchatj+inertterm+term2;

collapse (mean) totalcst forgsavingtotalcst modelcost inertterm term2 varoop simcost simcostchatj sumgrad term2alphaone term2fdiv2, by(numplans);



list totalcst forgsavingtotalcst simcost modelcost simcostchatj inertterm term2 varoop sumgrad term2alphaone term2fdiv2, clean;
pause ; 
display `alpha';
display `f';
restore;


*Create model cost;

egen meanvaroop = mean(varoop);

gen modelcost = simcostchatj+inertterm+`alpha'*meanvaroop*(1/`f')*sumgrad;
gen inertpart = inertterm;
gen indpart = `alpha'*varoop*(1/`f')*sumgrad;
gen indpartalphaone = varoop*(1/`f')*sumgrad;
gen indpartfdiv2 = varoop*(1/(`f'/2))*sumgrad;


preserve;
keep if chosen == 1;

global currvar forgsavingtotalcst;
do oregonanalchoice111616.do;

global currvar totalcst;
do oregonanalchoice111616.do;

*global currvar simcost;
*do oregonanalchoice111616.do;

global currvar modelcost;
do oregonanalchoice111616.do;

global currvar simcostchatj;
do oregonanalchoice111616.do;

global currvar inertpart;
do oregonanalchoice111616.do;

global currvar indpart;
do oregonanalchoice111616.do;

*global currvar indpartalphaone;
*do oregonanalchoice111616.do;

*global currvar indpartfdiv2;
*do oregonanalchoice111616.do;


restore;


assert 1 == 0;
