set more off
#delimit ;
* copied and updated log and data inputs from 072616 version from ~abaluckj/oregon/ ;

capture log close;

log using /disk/agedisk3/oebb.work/cbehrer/oregon/do/6paper_do/JAdofiles/logdir/oregonanalanyrestrict121718.log, replace;

*Drop anyone with just 1 one in their choice set;

use /disk/agedisk3/oebb.work/cbehrer/oregon/data/analysis/formal_reg_datasets/analysis_dataset_31_Oct_2016.dta, clear;

bys year familyid: gen numplan = _N;
keep if numplan > 1;
replace sharp_inertia = 0 if sharp_inertia == .;

egen choiceset = group(entitynum memid empid);

******************;
**Estimate conditional logit model;
******************;

*No perfect backcast in 2008;
drop if year == 2008;
*keep if year == 2012;

keep if year == 2012 | year == 2013;

keep if insurer == "MODA";

*Add recommendation;
*Add nudges;
*Add choice set size;

bys year familyid: gen numplans = _N;
quietly tab numplans, gen(numchoicedum);

/*;
gen norestrict = 3 if year == 2013 & numplans == 8;
replace norestrict = 3 if year == 2012 & numplans == 7;
replace norestrict = 2 if numplans >= 4 & norestrict != 3;
replace norestrict = 1 if numplans < 4;
*/;

gen norestrict = 1 if year == 2013 & numplans == 8;
replace norestrict = 1 if year == 2012 & numplans == 7;
replace norestrict = 0 if norestrict != 1;

*entitynum, memid, empid;

gen expend = totallowedamt_PF;



gen type1 = (tier == 1);
gen type2 = (tier == 2);
gen type3 = (tier == 3);
gen type4 = (tier == 4);

replace sex_1 = sex_1-1;

*type1 is individual;
*type2 is individual & child;
*type3 is individual & spouse;
*type4 is family;

collapse (mean) expend age_1 sex_1 type1 type2 type3 type4, by(norestrict);

list, clean;

assert 1 == 0;

list, clean;

assert 1 == 0;

keep year familyid numplans;
duplicates drop;
tab year numplans;

assert 1 == 0;
*/;

egen maxnumplans = max(numplans);


*Do for all beneficiaries and with just ODS;

**Create copay controls;
**********************************************;

gen  haspcpcopayin = 1 if pcp_copay_in > 0;
replace haspcpcopayin = 0 if haspcpcopayin != 1;

gen  haspcpcopayout = 1 if pcp_copay_out > 0;
replace haspcpcopayout = 0 if haspcpcopayout != 1;

gen  hasspeccopayin = 1 if spec_copay_in > 0;
replace hasspeccopayin = 0 if hasspeccopayin != 1;

gen  hasspeccopayout = 1 if spec_copay_out > 0;
replace hasspeccopayout = 0 if hasspeccopayout != 1;

local plancontrols "ded_in max_oop_in haspcpcopayin pcp_copay_in";

**********************************************;

gen resid_premium = net_premium-gross_premium;

local variables "gross_premium resid_premium net_calc_ooptotal_PB";
local inertia "fuzzy_inertia sharp_inertia";

local oop = "acg_mean_2k_cellreg";

gen stryear = string(year);
gen yearben = stryear + familyid;

**Zeroth step, define plan attributes;

tempfile currvars;
save `currvars', replace;

collapse (mean) net_premium gross_premium resid_premium acg_mean_2k_cellreg `plancontrols', by(year plan tier);
tempfile covar;
save `covar', replace;


**First, build (chosen) set -- an observation for each (year, district, plan) which is available;

use `currvars', clear;
keep year entitynum plan tier;
duplicates drop;
tempfile allavail;
save `allavail', replace;

**Second, build choice set -- an observation for every possible (district, plan);

use `allavail', clear;
keep year entitynum;
duplicates drop;
tempfile allentity;
save `allentity', replace;

use `allavail', clear;
keep year plan tier;
duplicates drop;
tempfile allpossible;
save `allpossible', replace;

joinby year using `allentity';

merge 1:1 year entitynum plan tier using `allavail';
gen offerred = 1 if _merge == 3;
replace offerred = 0 if _merge != 3;

drop _merge;
merge m:1 year plan tier using `covar';
assert _merge == 3;
drop _merge;

**Third, estimate logit model of whether plan is offerred as a function of average attributes;

egen yeartier = group(year tier);

quietly tab yeartier, gen(yeartierdum);

gen totalcost = (net_premium+`oop');

egen planyeartier = group(plan year tier);

bys planyeartier: egen planmeancost = mean(totalcost);

xtile planquant = planmeancost, nq(10);

quietly tab planquant, gen(planquantdum);

regress offerred planquantdum* yeartierdum*, robust;

regress offerred planmeancost yeartierdum*, robust;

gen proboffer = .;

distinct planyear;
local maxplans = r(ndistinct);

forvalues x = 1/10 {;
replace proboffer = _b[planquantdum`x'] if planquantdum`x' == 1;
};

assert proboffer != .;

collapse (mean) proboffer planmeancost, by(planquant);

sort planmeancost;

list planquant planmeancost proboffer, clean;

assert 1 == 0;


logit offerred gross_premium resid_premium acg_mean_2k_cellreg `plancontrols' ded_in max_oop_in haspcpcopayin pcp_copay_in yeartierdum*;
predict probavail;

preserve;
keep year plan tier entitynum probavail;
tempfile probs;
save `probs', replace;
restore;

gen totalcost = (net_premium+`oop');

areg totalcost probavail, absorb(yeartier);

areg totalcost, absorb(yeartier);
predict costresid, resid;

areg probavail, absorb(yeartier);
predict probresid, resid;




xtile offerquant = probresid, nq(10);


bys plan: egen planmeancost = mean(costresid);

collapse (mean) probresid costresid planmeancost, by(offerquant);
list, clean;

assert 1 == 0;



**Simulate random choices from full choice set and choice sets with between 2 and 8 plans;

use `currvars', clear;
merge m:1 year plan tier entitynum using `probs';
assert _merge == 3;
drop _merge;

*Generate one random choice for each yearben;
gen tester = uniform();
sort yearben tester;
capture drop obscount;
bys yearben: gen obscount = _n;
gen simchoice = 1 if obscount == 1;
gen totalcost = (net_premium+`oop');
sum totalcost if simchoice == 1;






**Fourth, simulate random choices from different size choice sets given offer probabilities.




local regvar "";
local inertiavar "";
local choicesetvar "";

quietly tab tier, gen(tierdum);
quietly tab year, gen(yeardum);


foreach a of local variables {;
	local regvar `regvar' `a';
};              


**Add plan dummies;

egen planyear = group(plan year);
replace planyear = 1 if plan == "OMED3" | plan == "MMEDA";
quietly tab planyear, gen(planyeardum);
drop planyeardum1;

distinct planyear;
local maxplanyear = r(ndistinct);

forvalues qq = 2/`maxplanyear' {;
	local plandums `plandums' planyeardum`qq';

};

egen plantier = group(plan tier);
replace plantier = 1 if plan == "OMED3" | plan == "MMEDA";
quietly tab plantier, gen(plantierdum);
drop plantierdum1;

distinct plantier;
local maxplantier = r(ndistinct);

forvalues qq = 2/`maxplantier' {;
	local plandums `plandums' plantierdum`qq';

};


display "`plandums'";
display "`maxplanyear'";


global regvar `regvar';



local allvars = "3 dec reg";

foreach x of local allvars {;

gen acg_var_cell`x' = acg_sd_2k_cell`x'^2;

};

local variables "gross_premium resid_premium acg_mean_2k_cellreg acg_var_cellreg";
clogit chosen `variables' `inertia' `plandums', group(yearben);

capture drop negwelf negwelfbase;
gen negwelf = 0;
foreach y of local variables {;
replace negwelf = negwelf+`y';
};
gen negwelfbase = negwelf;
replace negwelf = negwelfbase+(_b[acg_var_cellreg]/_b[gross_premium]-1)*acg_var_cellreg;
capture drop negwelfnovar;
gen negwelfnovar = negwelfbase-acg_var_cellreg;
capture drop bestwelf forgwelf bestwelfnovar forgwelfnovar;
bys yearben: egen bestwelf = min(negwelf);
bys yearben: egen bestwelfnovar = min(negwelfnovar);
gen forgwelf = negwelf-bestwelf;
gen forgwelfnovar = negwelfnovar-bestwelfnovar;
sum forgwelf forgwelfnovar negwelf negwelfnovar if chosen == 1;

gen observed = 0;
foreach x of local variables {;
replace observed = observed+_b[`x']*`x';
};

foreach x of local inertia {;
replace observed = observed+_b[`x']*`x';
};

constraint 1 observed = 1;

quietly tab insurer, gen(insuredum);

clogit chosen observed `plancontrols' insuredum*, group(yearben) constraint(1);

assert 1 == 0;
