set more off
#delimit ;

preserve;

local model "PB";
gen total_calc_cost = total_calc_cost_`model';
gen expend = totallowedamt_`model';
local currvar $currvar;
*local currvar "forgsaving";

*keep if insurer == "MODA";

*drop if year == 2010 | year == 2012;

**Compute overspendingPF;

bys year familyid: egen mincost = min(total_calc_cost);
gen forgsaving = round(total_calc_cost-mincost,.1);

quietly tab plan, gen(plandum);

egen planvar = group(plan);
egen maxvar = max(planvar);
local maxvar = maxvar;
forvalues x = 1/`maxvar' {;
tab plan if plandum`x' == 1;
};

egen yearfam = group(year familyid);

quietly tab numplans, gen(plannumdum);

capture drop maxnumplans;
egen maxnumplans = max(numplans);
egen minnumplans = min(numplans);
local maxnumplans = maxnumplans-minnumplans;


forvalues x = 1/`maxvar' {;
forvalues y = 2/`maxnumplans' {;
gen num_plan_`y'_`x' = plandum`x'*plannumdum`y';
};
};

drop plannumdum1;

keep if chosen == 1;
sum forgsaving, detail;

gen newguy = 1 if experience == 1;
replace newguy = 0 if newguy != 1;


egen choicetierrate = group(entitynum tier ratestructure memid empid);
capture drop post;
gen post = (year > 2011);
capture drop bind;
gen bind = 1 if year > 2011 & numplans > 4;
replace bind = 0 if bind != 1;
bys choicetierrate: egen maxbind = max(bind);
drop bind;
rename maxbind bind;
gen postbind = post*bind;


egen tierrate = group(tier ratestructure);
quietly tab tierrate, gen(tierratedum);
quietly tab experience, gen(expdum);
xtile expendquant = expend, nq(20);
xtile expendbigquant = expend, nq(3);
quietly tab expendquant, gen(expenddum);
quietly tab experience, gen(experdum);

egen eachyear = tag(year);
egen numyear = sum(eachyear);
local numyear = numyear;

forvalues y = 1/`numyear' {;
forvalues zz = 1/20 {;
gen yearexpenddum`y'_`zz' = yeardum`y'*expenddum`zz';
};
};

egen maxexper = max(experience);
local maxexper = maxexper;
if(`maxexper' > 1) drop experdum1;
drop expenddum1;
if("`model'" == "PB") drop experdum2;

xtile subsidyquant = subsidy, nq(10);
quietly tab subsidyquant, gen(subsidydum);

egen tierrateyear = group(memid empid tier rate year);



*Maybe it doesn't make sense to control for meanOOP, just residual OOP given plan fixed effects;

local xvar plannumdum*;
*local controls experdum* yeardum* expenddum* subsidydum*;
local controls1 experdum* yearexpenddum* subsidydum*;
local controls2 experdum* yearexpenddum*;
local controls3 yearexpenddum*;
local controls4 yeardum*;
local cluster "entitynum";

*local controls plannumdum* yearexpenddum* subsidydum*;

display "`controls'";

areg `currvar' `xvar' `controls1', absorb(choicetierrate) cluster(`cluster');
areg `currvar' `xvar' `controls2', absorb(choicetierrate) cluster(`cluster');
areg `currvar' `xvar' `controls3', absorb(choicetierrate) cluster(`cluster');
areg `currvar' `xvar' `controls4', absorb(choicetierrate) cluster(`cluster');

restore;
