set more off
#delimit ;

local variables `1';
local inertia `2';
local plancontrols `3';
local exp `4';
local shock `5';

if("`exp'" == "RE") {;
capture drop negwelf negwelfbase;
gen negwelfbase = totcost_RE;
gen negwelf = negwelfbase+_b[acg_var_cellreg]*acg_var_cellreg/_b[gross_premium];
gen negwelfnovar = negwelfbase;
capture drop bestwelf forgwelf bestwelfnovar forgwelfnovar;
bys yearben: egen bestwelf = min(negwelf);
bys yearben: egen bestwelfnovar = min(negwelfnovar);
gen forgwelf = negwelf-bestwelf;
gen forgwelfnovar = negwelfnovar-bestwelfnovar;
};

if("`exp'" != "RE") {;
capture drop negwelf negwelfbase;
gen negwelf = 0;
foreach y of local variables {;
replace negwelf = negwelf+_b[`y']*`y';
};
gen negwelfbase = totcost_`exp';
replace negwelf = negwelfbase;
capture drop negwelfnovar;
gen negwelfnovar = negwelfbase;
capture drop bestwelf forgwelf bestwelfnovar forgwelfnovar;
bys yearben: egen bestwelf = min(negwelf);
bys yearben: egen bestwelfnovar = min(negwelfnovar);
gen forgwelf = negwelf-bestwelf;
gen forgwelfnovar = negwelfnovar-bestwelfnovar;
};


local premcoef = _b[gross_premium]*100;
local premstd = _se[gross_premium]*100;
local residpremcoef = _b[resid_premium]*100;
local residpremstd = _se[resid_premium]*100;
if("`exp'" == "PF") {;
local meanoop = _b[net_calc_ooptotal_PF]*100;
local meanoopstd = _se[net_calc_ooptotal_PF]*100;
};
if("`exp'" == "PB") {;
local meanoop = _b[net_calc_ooptotal_PB]*100;
local meanoopstd = _se[net_calc_ooptotal_PB]*100;
};
if("`exp'" == "RE") {;
local meanoop = _b[acg_mean_2k_cellreg]*100;
local meanoopstd = _se[acg_mean_2k_cellreg]*100;
local varoop = _b[acg_var_cellreg]*1e6;
local varoopstd = _se[acg_var_cellreg]*1e6;
};
local inertiacoef = -100*_b[inertia]/`premcoef';
local inertiastd = -100*_se[inertia]/`premcoef';
local approxinertia = -100*_b[diffdum]/`premcoef';
local approxinertiastd = -100*_se[diffdum]/`premcoef';
if(`shock' == 1) {;
local approxinertiashock = -100*_b[shockdiffdum]/`premcoef';
local approxinertiashockstd = -100*_se[shockdiffdum]/`premcoef';
};

gen observed = 0;
foreach x of local variables {;
replace observed = observed+_b[`x']*`x';
};

foreach x of local inertia {;
replace observed = observed+_b[`x']*`x';
};

constraint 1 observed = 1;

clogit chosen observed `plancontrols', group(yearben) constraint(1);

local deduct = _b[ded_in]*100;
local deductstd = _se[ded_in]*100;
local maxoop = _b[max_oop_in]*100;
local maxoopstd = _se[max_oop_in]*100;
local copay = _b[pcp_copay_in]*100;
local copaystd = _se[pcp_copay_in]*100;

sum forgwelf if chosen == 1, detail;
local forgwelf = r(mean);
local forgwelfsd = r(sd);
sum forgwelfnovar if chosen == 1, detail;
local forgwelfnovar = r(mean);
local forgwelfnovarsd = r(sd);

gen totalcst = net_premium+net_calc_ooptotal_PF;
bys yearben: egen mincost = min(totalcst);
gen minchosen = (mincost == totalcst);

sum minchosen if chosen == 1;
local perccost = r(mean);

**Relevant output;

display "Model is `exp'";
display "Premium is `premcoef' (`premstd')";
display "Resid prem is `residpremcoef' (`residpremstd')";
display "OOP is `meanoop' (`meanoopstd')";
display "Var is `varoop' (`varoopstd')";
display "Inertia is `inertiacoef' (`inertiastd')";
display "Approx inertia is `approxinertia' (`approxinertiastd')";
if(`shock' == 1) display "Approx inertia shock is `approxinertiashock' (`approxinertiashockstd')";
display "Deduct is `deduct' (`deductstd')";
display "maxoop is `maxoop' (`maxoopstd')";
display "copay is `copay' (`copaystd')";

display "forgwelf is `forgwelf' and forgwelfsd is `forgwelfsd'";
display "forgwelfnovar is `forgwelfnovar' and forgwelfnovarsd is `forgwelfnovarsd'";
display "Percent cost minimizing is `perccost'";


